@@ -30,7 +30,6 @@
 package org.jvnet.substance;
 
 import java.awt.*;
-import java.awt.image.BufferedImage;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
@@ -42,12 +41,10 @@ import javax.swing.text.View;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.button.SubstanceButtonShaper;
-import org.jvnet.substance.combo.SubstanceComboBoxButton;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.scroll.SubstanceScrollButton;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.shaper.SubstanceButtonShaper;
 import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceButtonBorder;
 import org.jvnet.substance.utils.icon.GlowingIcon;
 
 /**
@@ -67,8 +64,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	public static final String BORDER_COMPUTING = "substancelaf.buttonbordercomputing";
 
 	/**
-	 * Property used to store the original (pre-<b>Substance</b>) button
-	 * border.
+	 * Property used to store the original (pre-<b>Substance</b>) button border.
 	 */
 	public static final String BORDER_ORIGINAL = "substancelaf.buttonborderoriginal";
 
@@ -84,8 +80,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	public static final String OPACITY_ORIGINAL = "substancelaf.buttonopacityoriginal";
 
 	/**
-	 * Property used to lock the original (pre-<b>Substance</b>) button
-	 * opacity.
+	 * Property used to lock the original (pre-<b>Substance</b>) button opacity.
 	 */
 	public static final String LOCK_OPACITY = "substancelaf.lockopacity";
 
@@ -99,11 +94,6 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 */
 	private ButtonBackgroundDelegate delegate;
 
-	/**
-	 * The rollover button listener.
-	 */
-	private RolloverButtonListener substanceButtonListener;
-
 	/**
 	 * The matching glowing icon. Is used only when
 	 * {@link FadeConfigurationManager#fadeAllowed(FadeKind, Component)} returns
@@ -119,19 +109,17 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	protected PropertyChangeListener substancePropertyListener;
 
 	/**
-	 * Listener for fade animations.
+	 * Tracker for visual state transitions.
 	 */
-	protected FadeStateListener substanceFadeStateListener;
+	protected ButtonVisualStateTracker substanceVisualStateTracker;
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		AbstractButton button = (AbstractButton) b;
-		button.setRolloverEnabled(true);
-		button.setOpaque(false);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceButtonUI();
 	}
 
@@ -145,10 +133,11 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installDefaults(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installDefaults(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
-	public void installDefaults(final AbstractButton b) {
+	public void installDefaults(AbstractButton b) {
 		super.installDefaults(b);
 
 		if (b.getClientProperty(SubstanceButtonUI.BORDER_ORIGINAL) == null)
@@ -173,6 +162,9 @@ public class SubstanceButtonUI extends BasicButtonUI {
 			}
 		}
 		b.putClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL, b.isOpaque());
+		b.setOpaque(false);
+
+		b.setRolloverEnabled(true);
 
 		LookAndFeel.installProperty(b, "iconTextGap", SubstanceSizeUtils
 				.getTextIconGap(SubstanceSizeUtils.getComponentFontSize(b)));
@@ -181,7 +173,8 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	public void uninstallDefaults(AbstractButton b) {
@@ -201,7 +194,9 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing.AbstractButton)
+	 * @see
+	 * javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected BasicButtonListener createButtonListener(AbstractButton b) {
@@ -211,42 +206,39 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void installListeners(final AbstractButton b) {
 		super.installListeners(b);
 
-		this.substanceButtonListener = new RolloverButtonListener(b);
-		b.addMouseListener(this.substanceButtonListener);
-		b.addMouseMotionListener(this.substanceButtonListener);
-		b.addFocusListener(this.substanceButtonListener);
-		b.addPropertyChangeListener(this.substanceButtonListener);
-		b.addChangeListener(this.substanceButtonListener);
+		this.substanceVisualStateTracker = new ButtonVisualStateTracker();
+		this.substanceVisualStateTracker.installListeners(b, true);
+
+		// this.substanceButtonListener = new RolloverButtonListener(b);
+		// b.addMouseListener(this.substanceButtonListener);
+		// b.addMouseMotionListener(this.substanceButtonListener);
+		// b.addFocusListener(this.substanceButtonListener);
+		// b.addPropertyChangeListener(this.substanceButtonListener);
+		// b.addChangeListener(this.substanceButtonListener);
 
 		this.substancePropertyListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
-				if (SubstanceLookAndFeel.BUTTON_SHAPER_PROPERTY.equals(evt
-						.getPropertyName())) {
-					SwingUtilities.invokeLater(new Runnable() {
-						public void run() {
-							SwingUtilities.updateComponentTreeUI(b);
-						}
-					});
-				}
-				if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
-						.getPropertyName())) {
-					if (substanceFadeStateListener != null)
-						substanceFadeStateListener.unregisterListeners();
-					boolean toRepaintParent = (b instanceof SubstanceScrollButton)
-							|| (b instanceof SubstanceSpinnerButton)
-							|| (b instanceof SubstanceComboBoxButton);
-					substanceFadeStateListener = new FadeStateListener(b, b
-							.getModel(), SubstanceCoreUtilities
-							.getFadeCallback(b, toRepaintParent));
-					substanceFadeStateListener
-							.registerListeners(toRepaintParent);
-				}
+				// if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
+				// .getPropertyName())) {
+				// if (substanceFadeStateListener != null)
+				// substanceFadeStateListener.unregisterListeners();
+				// boolean toRepaintParent = (b instanceof
+				// SubstanceScrollButton)
+				// || (b instanceof SubstanceSpinnerButton)
+				// || (b instanceof SubstanceComboBoxButton);
+				// substanceFadeStateListener = new FadeStateListener(b, b
+				// .getModel(), SubstanceCoreUtilities
+				// .getFadeCallback(b, toRepaintParent));
+				// substanceFadeStateListener
+				// .registerListeners(toRepaintParent);
+				// }
 				if (AbstractButton.ICON_CHANGED_PROPERTY.equals(evt
 						.getPropertyName())) {
 					trackGlowingIcon(b);
@@ -255,34 +247,40 @@ public class SubstanceButtonUI extends BasicButtonUI {
 		};
 		b.addPropertyChangeListener(this.substancePropertyListener);
 
-		boolean toRepaintParent = (b instanceof SubstanceScrollButton)
-				|| (b instanceof SubstanceSpinnerButton)
-				|| (b instanceof SubstanceComboBoxButton);
-		this.substanceFadeStateListener = new FadeStateListener(b,
-				b.getModel(), SubstanceCoreUtilities.getFadeCallback(b,
-						toRepaintParent));
-		this.substanceFadeStateListener.registerListeners(toRepaintParent);
+		// boolean toRepaintParent = (b instanceof SubstanceScrollButton)
+		// || (b instanceof SubstanceSpinnerButton)
+		// || (b instanceof SubstanceComboBoxButton);
+		// this.substanceFadeStateListener = new FadeStateListener(b,
+		// b.getModel(), SubstanceCoreUtilities.getFadeCallback(b,
+		// toRepaintParent));
+		// this.substanceFadeStateListener.registerListeners(toRepaintParent);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void uninstallListeners(AbstractButton b) {
-		b.removeMouseListener(this.substanceButtonListener);
-		b.removeMouseMotionListener(this.substanceButtonListener);
-		b.removeFocusListener(this.substanceButtonListener);
-		b.removePropertyChangeListener(this.substanceButtonListener);
-		b.removeChangeListener(this.substanceButtonListener);
-		this.substanceButtonListener = null;
+		this.substanceVisualStateTracker.uninstallListeners(b);
+		this.substanceVisualStateTracker = null;
+		// ButtonVisualStateTracker.untrack(b);
+		// this.substanceVisualStateTracker.uninstallListeners(b);
+		// this.substanceVisualStateTracker = null;
+		// b.removeMouseListener(this.substanceButtonListener);
+		// b.removeMouseMotionListener(this.substanceButtonListener);
+		// b.removeFocusListener(this.substanceButtonListener);
+		// b.removePropertyChangeListener(this.substanceButtonListener);
+		// b.removeChangeListener(this.substanceButtonListener);
+		// this.substanceButtonListener = null;
 
 		b.removePropertyChangeListener(this.substancePropertyListener);
 		this.substancePropertyListener = null;
 
-		this.substanceFadeStateListener.unregisterListeners();
-		this.substanceFadeStateListener = null;
+		// this.substanceFadeStateListener.unregisterListeners();
+		// this.substanceFadeStateListener = null;
 
 		super.uninstallListeners(b);
 	}
@@ -291,10 +289,13 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicButtonUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
+		if (!SubstanceLookAndFeel.isCurrentLookAndFeel())
+			return;
+
 		final AbstractButton b = (AbstractButton) c;
 
 		if (b instanceof JButton) {
@@ -330,69 +331,46 @@ public class SubstanceButtonUI extends BasicButtonUI {
 				.getHorizontalTextPosition(), viewRect, iconRect, textRect, b
 				.getText() == null ? 0 : b.getIconTextGap());
 
-		// Special case for scroll buttons - these are painted
-		// on top of the "real" controls (scroll bars). In order
-		// to properly handle the translucent states under the native
-		// text painter, we need to paint these buttons to offscreen
-		// image
-		Graphics2D g2d = null;
-		BufferedImage offscreen = null;
+		// // Special case for scroll buttons - these are painted
+		// // on top of the "real" controls (scroll bars). In order
+		// // to properly handle the translucent states under the native
+		// // text painter, we need to paint these buttons to offscreen
+		// // image
+		// Graphics2D g2d = null;
+		// BufferedImage offscreen = null;
+		//
+		// boolean isPartOfCompositeControl = SubstanceCoreUtilities
+		// .isScrollButton(b)
+		// || SubstanceCoreUtilities.isSpinnerButton(b);
+		// if (isPartOfCompositeControl) {
+		// offscreen = SubstanceCoreUtilities.getBlankImage(b.getWidth(), b
+		// .getHeight());
+		// g2d = offscreen.createGraphics();
+		// float themeAlpha = SubstanceThemeUtilities.getAlpha(b,
+		// ComponentState.getState(b));
+		//
+		// g2d.setComposite(AlphaComposite.getInstance(
+		// AlphaComposite.SRC_OVER, themeAlpha));
+		// } else {
+		Graphics2D g2d = (Graphics2D) g.create();
+		// }
 
-		boolean isPartOfCompositeControl = SubstanceCoreUtilities
-				.isScrollButton(b)
-				|| SubstanceCoreUtilities.isSpinnerButton(b);
-		if (isPartOfCompositeControl) {
-			offscreen = SubstanceCoreUtilities.getBlankImage(b.getWidth(), b
-					.getHeight());
-			g2d = offscreen.createGraphics();
-			SubstanceTheme buttonTheme = SubstanceThemeUtilities.getTheme(b);
-			float themeAlpha = buttonTheme.getThemeAlpha(b, ComponentState
-					.getState(b.getModel(), b));
-
-			g2d.setComposite(AlphaComposite.getInstance(
-					AlphaComposite.SRC_OVER, themeAlpha));
-		} else {
-			g2d = (Graphics2D) g.create();
-		}
-
-		boolean hasEmptyText = (text == null) || (text.length() == 0);
-
-		final View v = (View) c.getClientProperty(BasicHTML.propertyKey);
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(b, null, v != null);
+		View v = (View) c.getClientProperty(BasicHTML.propertyKey);
 		g2d.setFont(f);
 
-		if (!hasEmptyText && textPainter.needsBackgroundImage()) {
-			textPainter.setBackgroundFill(b, b.getParent().getBackground(),
-					true, 0, 0);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							delegate.updateBackground(g, b);
-						};
-					});
-		} else {
-			this.delegate.updateBackground(g2d, b);
-		}
-		float textAlpha = 1.0f;
+		this.delegate.updateBackground(g2d, b);
+
+		// float buttonAlpha = SubstanceThemeUtilities.getAlpha(b,
+		// ComponentState
+		// .getState(b.getModel(), b));
+		// g2d.setComposite(TransitionLayout.getAlphaComposite(b, buttonAlpha,
+		// g));
 		if (v != null) {
-			if (textPainter.needsBackgroundImage()) {
-				textPainter
-						.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-							public void paintBackground(Graphics g) {
-								v.paint(g, textRect);
-							}
-						});
-			} else {
-				v.paint(g2d, textRect);
-			}
+			v.paint(g2d, textRect);
 		} else {
-			textAlpha = this.paintButtonText(g, b, textRect, text);
+			this.paintButtonText(g2d, b, textRect, text);
 		}
-		g2d.setComposite(TransitionLayout.getAlphaComposite(b, textAlpha, g));
-		textPainter.renderSurface(g2d);
-		g2d.setComposite(TransitionLayout.getAlphaComposite(b, 1.0f, g));
+		// g2d.setComposite(TransitionLayout.getAlphaComposite(b, 1.0f, g));
 
 		// Paint the Icon
 		if (b.getIcon() != null) {
@@ -406,21 +384,22 @@ public class SubstanceButtonUI extends BasicButtonUI {
 			}
 		}
 
-//		g2d.setColor(Color.red);
-//		g2d.draw(iconRect);
-//		g2d.draw(viewRect);
-//		g2d.draw(textRect);
+		// g2d.setColor(Color.red);
+		// g2d.draw(iconRect);
+		// g2d.draw(viewRect);
+		// g2d.draw(textRect);
 
-		if (isPartOfCompositeControl) {
-			g.drawImage(offscreen, 0, 0, null);
-		}
+		// if (isPartOfCompositeControl) {
+		// g.drawImage(offscreen, 0, 0, null);
+		// }
 
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -433,6 +412,9 @@ public class SubstanceButtonUI extends BasicButtonUI {
 		if (superPref == null)
 			return null;
 
+		if (shaper == null)
+			return superPref;
+
 		return shaper.getPreferredSize(button, superPref);
 	}
 
@@ -440,8 +422,8 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicButtonUI#paintFocus(java.awt.Graphics,
-	 *      javax.swing.AbstractButton, java.awt.Rectangle, java.awt.Rectangle,
-	 *      java.awt.Rectangle)
+	 * javax.swing.AbstractButton, java.awt.Rectangle, java.awt.Rectangle,
+	 * java.awt.Rectangle)
 	 */
 	@Override
 	protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect,
@@ -458,7 +440,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#contains(javax.swing.JComponent, int,
-	 *      int)
+	 * int)
 	 */
 	@Override
 	public boolean contains(JComponent c, int x, int y) {
@@ -469,7 +451,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicButtonUI#paintIcon(java.awt.Graphics,
-	 *      javax.swing.JComponent, java.awt.Rectangle)
+	 * javax.swing.JComponent, java.awt.Rectangle)
 	 */
 	@Override
 	protected void paintIcon(Graphics g, JComponent c, Rectangle iconRect) {
@@ -485,25 +467,21 @@ public class SubstanceButtonUI extends BasicButtonUI {
 
 		graphics.setComposite(TransitionLayout.getAlphaComposite(b, g));
 		if (fadeTracker.isTracked(b, FadeKind.ROLLOVER)) {
-			ComponentState state = ComponentState.getState(b.getModel(), b);
+			ComponentState state = ComponentState.getState(b);
 			// System.out.println(state.name() + ":" + state.isRollover());
 			if (state.isKindActive(FadeKind.ROLLOVER)) {
 				// Came from default state
 				SubstanceCoreUtilities.getIcon(b, null, this.glowingIcon, true)
 						.paintIcon(b, graphics, iconRect.x, iconRect.y);
-				graphics
-						.setComposite(TransitionLayout
-								.getAlphaComposite(b, fadeTracker.getFade10(b,
-										FadeKind.ROLLOVER) / 10.0f, g));
+				graphics.setComposite(TransitionLayout.getAlphaComposite(b,
+						fadeTracker.getFade(b, FadeKind.ROLLOVER), g));
 				icon.paintIcon(b, graphics, iconRect.x, iconRect.y);
 			} else {
 				// if (state == ComponentState.DEFAULT) {
 				// Came from rollover state
 				icon.paintIcon(b, graphics, iconRect.x, iconRect.y);
-				graphics
-						.setComposite(TransitionLayout
-								.getAlphaComposite(b, fadeTracker.getFade10(b,
-										FadeKind.ROLLOVER) / 10.0f, g));
+				graphics.setComposite(TransitionLayout.getAlphaComposite(b,
+						fadeTracker.getFade(b, FadeKind.ROLLOVER), g));
 				b.getIcon().paintIcon(b, graphics, iconRect.x, iconRect.y);
 			}
 		} else {
@@ -523,11 +501,10 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 *            Text rectangle
 	 * @param text
 	 *            Text to paint
-	 * @return Text alpha channel.
 	 */
-	protected float paintButtonText(Graphics g, AbstractButton button,
+	protected void paintButtonText(Graphics g, AbstractButton button,
 			Rectangle textRect, String text) {
-		return SubstanceCoreUtilities.paintText(button, textRect, text, button
+		SubstanceTextUtilities.paintText(g, button, textRect, text, button
 				.getDisplayedMnemonicIndex());
 	}
 
@@ -550,7 +527,7 @@ public class SubstanceButtonUI extends BasicButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
