@@ -42,6 +42,7 @@ import org.jvnet.lafwidget.animation.FadeStateListener;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.CheckBoxMenuItemIcon;
 import org.jvnet.substance.utils.menu.MenuUtilities;
+import org.jvnet.substance.utils.menu.SubstanceMenu;
 import org.jvnet.substance.utils.menu.MenuUtilities.MenuPropertyListener;
 
 /**
@@ -77,8 +78,9 @@ public class SubstanceCheckBoxMenuItemUI extends BasicCheckBoxMenuItemUI
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		JCheckBoxMenuItem item = (JCheckBoxMenuItem) b;
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		JCheckBoxMenuItem item = (JCheckBoxMenuItem) comp;
 		// add rollover listener
 		item.setRolloverEnabled(true);
 		return new SubstanceCheckBoxMenuItemUI();
@@ -123,7 +125,9 @@ public class SubstanceCheckBoxMenuItemUI extends BasicCheckBoxMenuItemUI
 				if ("font".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							menuItem.updateUI();
+							if (menuItem != null) {
+								menuItem.updateUI();
+							}
 						}
 					});
 				}
@@ -224,8 +228,9 @@ public class SubstanceCheckBoxMenuItemUI extends BasicCheckBoxMenuItemUI
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax.swing.JComponent,
-	 *      javax.swing.Icon, javax.swing.Icon, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax
+	 * .swing.JComponent, javax.swing.Icon, javax.swing.Icon, int)
 	 */
 	@Override
 	protected Dimension getPreferredMenuItemSize(JComponent c, Icon checkIcon,
@@ -239,9 +244,10 @@ public class SubstanceCheckBoxMenuItemUI extends BasicCheckBoxMenuItemUI
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
-	 *      javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
-	 *      java.awt.Color, java.awt.Color, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
+	 * javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
+	 * java.awt.Color, java.awt.Color, int)
 	 */
 	@Override
 	protected void paintMenuItem(Graphics g, JComponent c, Icon checkIcon,
