@@ -31,8 +31,6 @@ package org.jvnet.substance;
 
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.HashMap;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.border.Border;
@@ -41,7 +39,9 @@ import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicButtonListener;
 
 import org.jvnet.lafwidget.animation.*;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTableCellRenderer;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -71,14 +71,16 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		return new SubstanceCheckBoxUI((JToggleButton) b);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceCheckBoxUI((JToggleButton) comp);
 	}
 
 	/**
 	 * Hash map for storing icons.
 	 */
-	private static Map<String, Icon> icons = new HashMap<String, Icon>();
+	private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+			"SubstanceCheckBoxUI");
 
 	/**
 	 * Simple constructor.
@@ -104,7 +106,8 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void installListeners(final AbstractButton b) {
@@ -132,7 +135,8 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void uninstallListeners(AbstractButton b) {
@@ -148,7 +152,9 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.SubstanceRadioButtonUI#installDefaults(javax.swing.AbstractButton)
+	 * @see
+	 * org.jvnet.substance.SubstanceRadioButtonUI#installDefaults(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected void installDefaults(AbstractButton b) {
@@ -160,16 +166,6 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 		}
 	}
 
-	/**
-	 * Resets image maps (used when setting new theme).
-	 * 
-	 * @see SubstanceLookAndFeel#setCurrentTheme(String)
-	 * @see SubstanceLookAndFeel#setCurrentTheme(SubstanceTheme)
-	 */
-	public static synchronized void reset() {
-		SubstanceCheckBoxUI.icons.clear();
-	}
-
 	/**
 	 * Returns the icon that matches the current and previous states of the
 	 * checkbox.
@@ -182,59 +178,48 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	 *            Previous state of the checkbox.
 	 * @return Matching icon.
 	 */
-	private static synchronized Icon getIcon(JToggleButton button,
-			ComponentState currState, ComponentState prevState) {
+	private static Icon getIcon(JToggleButton button, ComponentState currState,
+			ComponentState prevState) {
 		// check if fading
 		float checkMarkVisibility = currState.isKindActive(FadeKind.SELECTION) ? 10
 				: 0;
 		boolean isCheckMarkFadingOut = false;
 
 		boolean isTableRenderer = button instanceof SubstanceDefaultTableCellRenderer.BooleanRenderer;
-		// SubstanceTheme theme = SubstanceThemeUtilities
-		// .getTheme(button)
-		// .getTheme(button, currState,
-		// isTableRenderer && currState == ComponentState.SELECTED);
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(button,
-				currState, isTableRenderer
+		SubstanceColorScheme theme = SubstanceColorSchemeUtilities
+				.getColorScheme(button, currState, isTableRenderer
 						&& currState == ComponentState.SELECTED);
-		SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(button,
-				prevState, isTableRenderer
-						&& currState == ComponentState.SELECTED);
-		// SubstanceTheme theme2 = SubstanceThemeUtilities
-		// .getTheme(button)
-		// .getTheme(button, prevState,
-		// isTableRenderer && prevState == ComponentState.SELECTED);
+		SubstanceColorScheme theme2 = (prevState == currState) ? theme
+				: SubstanceColorSchemeUtilities.getColorScheme(button,
+						prevState, isTableRenderer
+								&& currState == ComponentState.SELECTED);
 		float cyclePos = 0;
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(button,
 				FadeKind.SELECTION, FadeKind.ROLLOVER, FadeKind.PRESS);
 		if (fadeState != null) {
 			cyclePos = fadeState.getFadePosition();
 			if (fadeState.isFadingIn())
-				cyclePos = 10 - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 			if (fadeState.fadeKind == FadeKind.SELECTION) {
 				checkMarkVisibility = fadeState.getFadePosition();
 				isCheckMarkFadingOut = !fadeState.isFadingIn();
 			}
 		}
 
-		// System.out.println(prevState.name() + ":" + theme.getDisplayName()
-		// + " -> " + currState.name() + ":" + theme2.getDisplayName()
-		// + " at " + cyclePos);
-
 		int checkMarkSize = SubstanceSizeUtils
 				.getCheckBoxMarkSize(SubstanceSizeUtils
 						.getComponentFontSize(button));
-		String key = checkMarkSize + ":" + currState.name() + ":"
-				+ prevState.name() + ":" + theme.getDisplayName() + ":"
-				+ theme2.getDisplayName() + ":" + cyclePos + ":"
-				+ checkMarkVisibility + ":" + isCheckMarkFadingOut;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(checkMarkSize,
+				currState.name(), prevState.name(), theme.getDisplayName(),
+				theme2.getDisplayName(), cyclePos, checkMarkVisibility,
+				isCheckMarkFadingOut);
 
-		Icon result = null;// SubstanceCheckBoxUI.icons.get(key);
+		Icon result = SubstanceCheckBoxUI.icons.get(key);
 		if (result != null)
 			return result;
 		result = new ImageIcon(SubstanceImageCreator.getCheckBox(button,
-				checkMarkSize, currState, theme, theme2, cyclePos,
-				checkMarkVisibility / 10.f, isCheckMarkFadingOut));
+				checkMarkSize, currState, prevState, theme, theme2, cyclePos,
+				checkMarkVisibility, isCheckMarkFadingOut));
 
 		SubstanceCheckBoxUI.icons.put(key, result);
 		return result;
@@ -243,7 +228,9 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing.AbstractButton)
+	 * @see
+	 * javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected BasicButtonListener createButtonListener(AbstractButton b) {
@@ -257,8 +244,7 @@ public class SubstanceCheckBoxUI extends SubstanceRadioButtonUI {
 	 */
 	@Override
 	public Icon getDefaultIcon() {
-		ButtonModel model = this.button.getModel();
-		ComponentState currState = ComponentState.getState(model, this.button);
+		ComponentState currState = ComponentState.getState(this.button);
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevComponentState(this.button);
 		return SubstanceCheckBoxUI.getIcon(this.button, currState, prevState);
