@@ -45,11 +45,12 @@ import contrib.ch.randelshofer.quaqua.Quaqua14ColorChooserUI;
 /**
  * UI for color chooser in <b>Substance</b> look and feel. This UI delegate is
  * removed in Lite versions of <b>Substance</b>.
- *
+ * 
  * @author Kirill Grouchnikov
  */
 public class SubstanceColorChooserUI extends Quaqua14ColorChooserUI {
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceColorChooserUI();
 	}
 
