@@ -43,14 +43,14 @@ import javax.swing.plaf.basic.ComboPopup;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.button.BaseButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.combo.*;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceConstants.Side;
+import org.jvnet.substance.api.renderers.SubstanceDefaultComboBoxRenderer;
 import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
 import org.jvnet.substance.utils.*;
-import org.jvnet.substance.utils.SubstanceConstants.Side;
+import org.jvnet.substance.utils.border.SubstanceBorder;
+import org.jvnet.substance.utils.combo.*;
 
 /**
  * UI for combo boxes in <b>Substance </b> look and feel.
@@ -77,16 +77,15 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	 */
 	protected FocusListener substanceFocusListener;
 
-	private static SubstanceFillBackgroundDelegate backgroundDelegate = new SubstanceFillBackgroundDelegate();
-
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		SubstanceComboBoxUI ui = new SubstanceComboBoxUI();
-		ui.comboBox = (JComboBox) b;
+		ui.comboBox = (JComboBox) comp;
 		ui.comboBox.setOpaque(false);
 		return ui;
 	}
@@ -100,8 +99,11 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	protected JButton createArrowButton() {
 		SubstanceComboBoxButton result = new SubstanceComboBoxButton(
 				this.comboBox);
-		result.setIcon(this.comboBox, getCurrentIcon(result));
 		result.setFont(this.comboBox.getFont());
+		result.setIcon(getCurrentIcon(result));
+		// System.out.println("Combo [@" + this.comboBox.hashCode() + "] font "
+		// + this.comboBox.getFont().getSize() + ", button [@"
+		// + result.hashCode() + "] font " + result.getFont().getSize());
 		return result;
 	}
 
@@ -114,7 +116,7 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	 */
 	private Icon getCurrentIcon(JButton button) {
 		Icon icon = SubstanceCoreUtilities
-				.getArrowIcon(this.comboBox, button, SubstanceCoreUtilities
+				.getArrowIcon(button, SubstanceCoreUtilities
 						.getPopupFlyoutOrientation(this.comboBox));
 		return icon;
 	}
@@ -213,8 +215,8 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 			int buttonWidth = SubstanceSizeUtils
 					.getScrollBarWidth(SubstanceSizeUtils
 							.getComponentFontSize(comboBox));
-			buttonWidth = Math.max(buttonWidth,
-					arrowButton.getPreferredSize().width);
+			// buttonWidth = Math.max(buttonWidth,
+			// arrowButton.getPreferredSize().width);
 
 			if (SubstanceComboBoxUI.this.arrowButton != null) {
 				if (cb.getComponentOrientation().isLeftToRight()) {
@@ -251,7 +253,9 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicComboBoxUI#getMinimumSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicComboBoxUI#getMinimumSize(javax.swing.JComponent
+	 * )
 	 */
 	@Override
 	public Dimension getMinimumSize(JComponent c) {
@@ -297,7 +301,8 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.plaf.basic.BasicComboBoxUI$PropertyChangeHandler#propertyChange(java.beans.PropertyChangeEvent)
+		 * @seejavax.swing.plaf.basic.BasicComboBoxUI$PropertyChangeHandler#
+		 * propertyChange(java.beans.PropertyChangeEvent)
 		 */
 		@Override
 		public void propertyChange(final PropertyChangeEvent e) {
@@ -339,21 +344,19 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 			if (SubstanceLookAndFeel.COMBO_BOX_POPUP_FLYOUT_ORIENTATION
 					.equals(propertyName)) {
 				((SubstanceComboBoxButton) arrowButton)
-						.setIcon(
-								comboBox,
-								SubstanceCoreUtilities
-										.getArrowIcon(comboBox,
-												arrowButton,
-												// theme,
-												SubstanceCoreUtilities
-														.getPopupFlyoutOrientation(SubstanceComboBoxUI.this.comboBox)));
+						.setIcon(SubstanceCoreUtilities
+								.getArrowIcon(
+										arrowButton,
+										SubstanceCoreUtilities
+												.getPopupFlyoutOrientation(SubstanceComboBoxUI.this.comboBox)));
 
 			}
 
 			if ("font".equals(propertyName)) {
 				SwingUtilities.invokeLater(new Runnable() {
 					public void run() {
-						comboBox.updateUI();
+						if (comboBox != null)
+							comboBox.updateUI();
 					}
 				});
 			}
@@ -413,20 +416,18 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicComboBoxUI#paintCurrentValueBackground(java.awt.Graphics,
-	 *      java.awt.Rectangle, boolean)
+	 * @see
+	 * javax.swing.plaf.basic.BasicComboBoxUI#paintCurrentValueBackground(java
+	 * .awt.Graphics, java.awt.Rectangle, boolean)
 	 */
 	@Override
 	public void paintCurrentValueBackground(Graphics g, Rectangle bounds,
 			boolean hasFocus) {
 		ListUI listUI = this.popup.getList().getUI();
 		SubstanceListUI ui = (SubstanceListUI) listUI;
-		ComponentState state = ui.getCellState(-1);
-		// ComponentState prevState = ui.getPrevCellState(-1);
+		ComponentState state = ui.getCellState(-1, null);
 		boolean isEnabled = this.comboBox.isEnabled();
-		boolean isSelected = hasFocus
-				|| SubstanceCoreUtilities
-						.isControlAlwaysPaintedActive(this.comboBox);
+		boolean isSelected = hasFocus;
 		if (isSelected && isEnabled) {
 			state = ComponentState.SELECTED;
 		}
@@ -435,107 +436,36 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 		}
 
 		Graphics2D graphics = (Graphics2D) g.create();
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.comboBox,
-				state);
-		final ColorScheme colorScheme = theme.getColorScheme();
-		float alpha = theme.getThemeAlpha(this.comboBox, state);
-		if (!SubstanceCoreUtilities.isControlAlwaysPaintedActive(this.comboBox)) {
-			alpha = 0.8f * alpha;
-		}
+		SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(this.comboBox, state);
+		float alpha = SubstanceColorSchemeUtilities.getAlpha(this.comboBox,
+				state) * 0.8f;
 
-		ListCellRenderer renderer = this.comboBox.getRenderer();
-		boolean toRegardAsFocused = hasFocus
-				|| SubstanceCoreUtilities
-						.isControlAlwaysPaintedActive(this.comboBox);
-		Component c = renderer.getListCellRendererComponent(this.listBox,
-				this.comboBox.getSelectedItem(), -1, toRegardAsFocused,
-				hasFocus);
+		Rectangle newBounds = new Rectangle(1, 1, this.comboBox.getWidth() - 2,
+				this.comboBox.getHeight() - 2);
 
-		Color background = c.getBackground();
-		if (!(background instanceof UIResource)) {
-			// support for enhancement 256 - colorizing components
-			double colorization = SubstanceCoreUtilities
-					.getColorizationFactor(this.comboBox);
-			if (!this.comboBox.isEnabled())
-				colorization /= 2.0;
-			if (colorization > 0.0) {
-				// the larger the colorization is, the lighter should the
-				// overlay be
-				alpha *= (1.0 - colorization);
-			}
-		}
+		graphics.setComposite(TransitionLayout.getAlphaComposite(this.comboBox,
+				alpha, g));
 
-		final float finalAlpha = alpha;
-
-		// final SubstanceTheme theme =
-		// SubstanceCoreUtilities.getTheme(this.popup
-		// .getList(), state, true, true, true);
-
-		final Rectangle newBounds = new Rectangle(1, 1, this.comboBox
-				.getWidth() - 2, this.comboBox.getHeight() - 2);
-
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(this.comboBox, null, true);
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.setBackgroundFill(this.comboBox, this.comboBox
-					.getBackground(), false, 0, 0);
-			// final ComponentState finalState = state;
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							g2d
-									.setComposite(TransitionLayout
-											.getAlphaComposite(comboBox,
-													finalAlpha, g));
-							SubstanceHighlightUtils.paintHighlight(g2d,
-									comboBox, new Rectangle(0, 0, comboBox
-											.getWidth(), comboBox.getHeight()),
-									0.0f, null, colorScheme, colorScheme, 0.0f);
-							g2d.dispose();
-						}
-					});
-			// The text GC will be clipped to the renderer bound. To
-			// have the background painted across the entire area, enforce
-			// this by painting space string now that the clip is not set
-			textPainter.attachText(this.comboBox, newBounds, " ", -1, graphics
-					.getFont(), graphics.getColor(), graphics.getClipBounds());
-			textPainter.renderSurface(graphics);
-		} else {
-			backgroundDelegate.fillAndWatermark(graphics, this.comboBox,
-					background, newBounds);
-			graphics.setComposite(TransitionLayout.getAlphaComposite(
-					this.comboBox, finalAlpha, g));
-
-			SubstanceHighlightUtils.paintHighlight(graphics, this.comboBox,
-					newBounds, 0.0f, null, colorScheme, colorScheme, 0.0f);
-		}
+		SubstanceHighlightUtils.paintHighlight(graphics, this.comboBox,
+				newBounds, 0.0f, null, colorScheme, colorScheme, 0.0f);
 		graphics.dispose();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicComboBoxUI#paintCurrentValue(java.awt.Graphics,
-	 *      java.awt.Rectangle, boolean)
+	 * @see
+	 * javax.swing.plaf.basic.BasicComboBoxUI#paintCurrentValue(java.awt.Graphics
+	 * , java.awt.Rectangle, boolean)
 	 */
 	@Override
 	public void paintCurrentValue(Graphics g, Rectangle bounds, boolean hasFocus) {
 		Graphics2D graphics = (Graphics2D) g.create();
-		ComponentState state = this.comboBox.isEnabled() ? ComponentState.DEFAULT
-				: ComponentState.DISABLED_UNSELECTED;
-		float alpha = SubstanceThemeUtilities.getTheme(this.comboBox)
-				.getThemeAlpha(this.comboBox, state);
-		graphics.setComposite(TransitionLayout.getAlphaComposite(this.comboBox,
-				alpha, g));
 
 		ListCellRenderer renderer = this.comboBox.getRenderer();
-		// if (renderer instanceof SubstanceDefaultListCellRenderer) {
 		Component c;
-		if (hasFocus
-				|| SubstanceCoreUtilities
-						.isControlAlwaysPaintedActive(this.comboBox)) {
+		if (hasFocus) {
 			c = renderer.getListCellRendererComponent(this.listBox,
 					this.comboBox.getSelectedItem(), -1, true, hasFocus);
 		} else {
@@ -552,14 +482,6 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 
 		// SubstanceCoreUtilities.workaroundBug6576507(graphics);
 
-		if (c instanceof JComponent) {
-			((JComponent) comboBox)
-					.putClientProperty(
-							SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND,
-							Boolean.TRUE);
-		}
-		// Insets ins = this.comboBox.getInsets();
-
 		if (this.comboBox.getComponentOrientation().isLeftToRight()) {
 			this.currentValuePane.paintComponent(graphics, c, this.comboBox, 1,
 					1, this.arrowButton.getX() - 1,
@@ -570,13 +492,6 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 					startX, 1, this.comboBox.getWidth() - startX - 1,
 					this.comboBox.getHeight() - 2, shouldValidate);
 		}
-		if (c instanceof JComponent) {
-			((JComponent) comboBox).putClientProperty(
-					SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, null);
-		}
-		// } else {
-		// super.paintCurrentValue(g, bounds, hasFocus);
-		// }
 
 		graphics.dispose();
 	}
@@ -585,7 +500,7 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicComboBoxUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
@@ -612,11 +527,11 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 		int fontSize = SubstanceSizeUtils.getComponentFontSize(this.comboBox);
 		int focusRingPadding = SubstanceSizeUtils.getFocusRingPadding(fontSize);
 		SubstanceCoreUtilities.paintFocus(g, this.comboBox, this.comboBox,
-				BaseButtonShaper.getBaseOutline(this.arrowButton.getX() - 1,
-						this.comboBox.getHeight() - 3 * focusRingPadding / 2,
-						SubstanceSizeUtils
-								.getClassicButtonCornerRadius(fontSize), null,
-						0), bounds, 0.4f, 3 * focusRingPadding / 2);
+				SubstanceOutlineUtilities.getBaseOutline(this.arrowButton
+						.getX() - 1, this.comboBox.getHeight() - 3
+						* focusRingPadding / 2, SubstanceSizeUtils
+						.getClassicButtonCornerRadius(fontSize), null, 0),
+				bounds, 0.4f, 3 * focusRingPadding / 2);
 	}
 
 	/**
@@ -628,23 +543,22 @@ public class SubstanceComboBoxUI extends BasicComboBoxUI {
 		return this.popup;
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
-	 */
-	@Override
-	public void update(Graphics g, JComponent c) {
-		if (!this.comboBox.isEditable()) {
-			SubstanceCoreUtilities.paintTextCompBackground(g, c);
-		} else {
-			// SubstanceCoreUtilities.paintTextCompBackground(g, c, Color.red);
-			SubstanceCoreUtilities.paintTextCompBackground(g, c, this.editor
-					.getBackground(), false);
-		}
-		this.paint(g, c);
-	}
+	// /*
+	// * (non-Javadoc)
+	// *
+	// * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
+	// * javax.swing.JComponent)
+	// */
+	// @Override
+	// public void update(Graphics g, JComponent c) {
+	// if (!this.comboBox.isEditable()) {
+	// SubstanceTextUtilities.paintTextCompBackground(g, c);
+	// } else {
+	// SubstanceTextUtilities.paintTextCompBackground(g, c, this.editor
+	// .getBackground(), false);
+	// }
+	// this.paint(g, c);
+	// }
 
 	/*
 	 * (non-Javadoc)
