@@ -39,6 +39,7 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicDesktopIconUI;
 
+import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -62,7 +63,8 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceDesktopIconUI();
 	}
 
@@ -79,9 +81,9 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 			this.desktopIcon.setFont(UIManager.getFont("DesktopIcon.font"));
 		}
 		this.width = UIManager.getInt("DesktopIcon.width");
-		this.desktopIcon.setBackground(SubstanceThemeUtilities.getTheme(
-				this.desktopIcon.getInternalFrame(), ComponentState.ACTIVE)
-				.getBackgroundColor());
+		this.desktopIcon.setBackground(SubstanceColorSchemeUtilities
+				.getColorScheme(this.desktopIcon.getInternalFrame(),
+						ComponentState.ACTIVE).getBackgroundFillColor());
 	}
 
 	/*
@@ -151,7 +153,8 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -229,7 +232,9 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicDesktopIconUI#installUI(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicDesktopIconUI#installUI(javax.swing.JComponent
+	 * )
 	 */
 	@Override
 	public void installUI(JComponent c) {
@@ -258,6 +263,12 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 		return this.iconPane;
 	}
 
+	/**
+	 * Installs the UI delegate on the desktop icon if necessary.
+	 * 
+	 * @param jdi
+	 *            Desktop icon.
+	 */
 	public void installIfNecessary(JDesktopIcon jdi) {
 		// fix for issue 344 - reopening an internal frame
 		// that has been closed.
@@ -266,6 +277,12 @@ public class SubstanceDesktopIconUI extends BasicDesktopIconUI {
 		}
 	}
 
+	/**
+	 * Uninstalls the UI delegate from the desktop icon if necessary.
+	 * 
+	 * @param jdi
+	 *            Desktop icon.
+	 */
 	public void uninstallIfNecessary(JDesktopIcon jdi) {
 		// fix for issue 345 - an internal frame used in inner option pane
 		// gets closed twice
