@@ -39,6 +39,9 @@ import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicDesktopPaneUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for desktop panes in <b>Substance</b> look and feel.
@@ -56,7 +59,8 @@ public class SubstanceDesktopPaneUI extends BasicDesktopPaneUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceDesktopPaneUI();
 	}
 
@@ -85,7 +89,7 @@ public class SubstanceDesktopPaneUI extends BasicDesktopPaneUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
