@@ -29,6 +29,7 @@
  */
 package org.jvnet.substance;
 
+import java.awt.Color;
 import java.awt.Graphics;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
@@ -38,12 +39,10 @@ import javax.swing.border.Border;
 import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicBorders;
 import javax.swing.plaf.basic.BasicEditorPaneUI;
-import javax.swing.text.Highlighter;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
-import org.jvnet.substance.text.SubstanceHighlighter;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceSizeUtils;
+import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for editor panes in <b>Substance</b> look and feel.
@@ -71,8 +70,9 @@ public class SubstanceEditorPaneUI extends BasicEditorPaneUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceEditorPaneUI(c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceEditorPaneUI(comp);
 	}
 
 	/**
@@ -149,25 +149,24 @@ public class SubstanceEditorPaneUI extends BasicEditorPaneUI {
 					new BasicBorders.MarginBorder());
 			this.editorPane.setBorder(newB);
 		}
+
+		// support for per-window skins
+		Color foregr = this.editorPane.getForeground();
+		if ((foregr == null) || (foregr instanceof UIResource)) {
+			this.editorPane.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceLookAndFeel.getCurrentSkin(
+							this.editorPane).getMainDefaultColorScheme()));
+		}
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
 	 */
 	@Override
 	protected void paintBackground(Graphics g) {
-		SubstanceCoreUtilities.paintTextCompBackground(g, this.editorPane);
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#createHighlighter()
-	 */
-	@Override
-	protected Highlighter createHighlighter() {
-		return new SubstanceHighlighter();
+		SubstanceTextUtilities.paintTextCompBackground(g, this.editorPane);
 	}
 }
