@@ -39,6 +39,7 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.basic.BasicFileChooserUI;
 import javax.swing.plaf.metal.MetalFileChooserUI;
 
+import org.jvnet.substance.api.ComponentState;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -68,7 +69,9 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#getCachedIcon(java.io.File)
+		 * @see
+		 * javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#getCachedIcon
+		 * (java.io.File)
 		 */
 		@Override
 		public Icon getCachedIcon(File f) {
@@ -78,7 +81,9 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#getIcon(java.io.File)
+		 * @see
+		 * javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#getIcon(java
+		 * .io.File)
 		 */
 		@Override
 		public Icon getIcon(File f) {
@@ -105,8 +110,9 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#cacheIcon(java.io.File,
-		 *      javax.swing.Icon)
+		 * @see
+		 * javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#cacheIcon
+		 * (java.io.File, javax.swing.Icon)
 		 */
 		@Override
 		public void cacheIcon(File f, Icon icon) {
@@ -116,7 +122,9 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#clearIconCache()
+		 * @see
+		 * javax.swing.plaf.basic.BasicFileChooserUI$BasicFileView#clearIconCache
+		 * ()
 		 */
 		@Override
 		public void clearIconCache() {
@@ -135,16 +143,18 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 			Icon icon = fileChooser.getFileSystemView().getSystemIcon(f);
 
 			if (SubstanceCoreUtilities.useThemedDefaultIcon(fileChooser)) {
-				icon = new ImageIcon(SubstanceImageCreator.getThemeImage(
-						fileChooser, icon, SubstanceThemeUtilities.getTheme(
-								fileChooser, ComponentState.DEFAULT), true));
+				icon = new ImageIcon(SubstanceImageCreator.getColorSchemeImage(
+						fileChooser, icon, SubstanceColorSchemeUtilities
+								.getColorScheme(fileChooser,
+										ComponentState.DEFAULT)));
 			}
 			return icon;
 		}
 	}
 
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceFileChooserUI((JFileChooser) c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceFileChooserUI((JFileChooser) comp);
 	}
 
 	/**
@@ -160,7 +170,8 @@ public class SubstanceFileChooserUI extends MetalFileChooserUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicFileChooserUI#getFileView(javax.swing.JFileChooser)
+	 * @seejavax.swing.plaf.basic.BasicFileChooserUI#getFileView(javax.swing.
+	 * JFileChooser)
 	 */
 	@Override
 	public FileView getFileView(JFileChooser fc) {
