@@ -29,7 +29,8 @@
  */
 package org.jvnet.substance;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Graphics;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
@@ -38,14 +39,10 @@ import javax.swing.border.Border;
 import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicBorders;
 import javax.swing.plaf.basic.BasicFormattedTextFieldUI;
-import javax.swing.text.*;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.text.SubstanceFieldView;
-import org.jvnet.substance.text.SubstanceHighlighter;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceSizeUtils;
+import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for formatted text fields in <b>Substance</b> look and feel.
@@ -73,8 +70,9 @@ public class SubstanceFormattedTextFieldUI extends BasicFormattedTextFieldUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceFormattedTextFieldUI(c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceFormattedTextFieldUI(comp);
 	}
 
 	/**
@@ -145,103 +143,24 @@ public class SubstanceFormattedTextFieldUI extends BasicFormattedTextFieldUI {
 					new BasicBorders.MarginBorder());
 			this.textField.setBorder(newB);
 		}
-	}
 
-//	/*
-//	 * (non-Javadoc)
-//	 * 
-//	 * @see javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
-//	 */
-//	@Override
-//	protected void paintBackground(Graphics g) {
-//		SubstanceCoreUtilities.paintCompBackground(g, this.textField);
-//	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextFieldUI#create(javax.swing.text.Element)
-	 */
-	@Override
-	public View create(Element elem) {
-		View superResult = super.create(elem);
-		if (superResult instanceof FieldView) {
-			return new SubstanceFieldView(elem);
+		// support for per-window skins
+		Color foregr = this.textField.getForeground();
+		if ((foregr == null) || (foregr instanceof UIResource)) {
+			this.textField.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceLookAndFeel.getCurrentSkin(
+							this.textField).getMainDefaultColorScheme()));
 		}
-		return superResult;
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#createHighlighter()
+	 * @see
+	 * javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
 	 */
 	@Override
-	protected Highlighter createHighlighter() {
-		return new SubstanceHighlighter();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#paintSafely(java.awt.Graphics)
-	 */
-	@Override
-	protected void paintSafely(Graphics _g) {
-//		// Have to call the super implementation since it sets a
-//		// private "painted" flag which affects many other places.
-//		// Without this there will be many visual artifacts with
-//		// painting the caret and highlights
-//		super.paintSafely(_g);
-//
-//		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-//				.getCurrentTextPainter();
-//
-//		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-//			public void paintBackground(Graphics g) {
-//				Highlighter highlighter = getComponent().getHighlighter();
-//
-//				// paint the background
-//				if (getComponent().isOpaque()) {
-//					SubstanceFormattedTextFieldUI.this.paintBackground(g);
-//				}
-//
-//				// paint the highlights
-//				if (highlighter != null) {
-//					highlighter.paint(g);
-//				}
-//			}
-//		};
-//		textPainter.init(textField, null, true);
-//		if (textPainter.needsBackgroundImage()) {
-//			textPainter.setBackgroundFill(textField, textField.getBackground(),
-//					false, 0, 0);
-//			textPainter.attachCallback(callback);
-//		} else {
-//			callback.paintBackground(_g);
-//		}
-//
-//		// paint the view hierarchy
-//		Rectangle alloc = getVisibleEditorRect();
-//		if (alloc != null) {
-//			getRootView(textField).paint(_g, alloc);
-//		}
-//		textPainter.renderSurface(_g);
-//
-//		// paint the caret
-//		Caret caret = getComponent().getCaret();
-//		if (caret != null) {
-//			caret.paint(_g);
-//		}
-		// Have to call the super implementation since it sets a
-		// private "painted" flag which affects many other places.
-		// Without this there will be many visual artifacts with
-		// painting the caret and highlights
-		Graphics2D dummy = (Graphics2D) _g.create(0, 0, 0, 0);
-		super.paintSafely(dummy);
-		dummy.dispose();
-
-		SubstanceCoreUtilities.paintTextComponent(_g, this.textField,
-				this.getRootView(this.textField), this.getVisibleEditorRect());
+	protected void paintBackground(Graphics g) {
+		SubstanceTextUtilities.paintTextCompBackground(g, this.textField);
 	}
 }
