@@ -40,6 +40,7 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicInternalFrameUI;
 
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.SubstanceInternalFrameTitlePane;
 
 /**
@@ -73,14 +74,17 @@ public class SubstanceInternalFrameUI extends BasicInternalFrameUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceInternalFrameUI((JInternalFrame) c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceInternalFrameUI((JInternalFrame) comp);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicInternalFrameUI#createNorthPane(javax.swing.JInternalFrame)
+	 * @see
+	 * javax.swing.plaf.basic.BasicInternalFrameUI#createNorthPane(javax.swing
+	 * .JInternalFrame)
 	 */
 	@Override
 	protected JComponent createNorthPane(JInternalFrame w) {
