@@ -35,12 +35,13 @@ import java.beans.PropertyChangeListener;
 
 import javax.swing.*;
 import javax.swing.plaf.ComponentUI;
+import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicHTML;
 import javax.swing.plaf.basic.BasicLabelUI;
 import javax.swing.text.View;
 
-import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -74,7 +75,8 @@ public class SubstanceLabelUI extends BasicLabelUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceLabelUI();
 	}
 
@@ -105,9 +107,10 @@ public class SubstanceLabelUI extends BasicLabelUI {
 					label.putClientProperty(ORIG_ICON, label.getIcon());
 					label.putClientProperty(REPLACING_ICON, Boolean.TRUE);
 					label.setIcon(new ImageIcon(SubstanceImageCreator
-							.getThemeImage(label, icon, SubstanceThemeUtilities
-									.getTheme(label, ComponentState.DEFAULT),
-									false)));
+							.getColorSchemeImage(label, icon,
+									SubstanceColorSchemeUtilities
+											.getColorScheme(label,
+													ComponentState.DEFAULT))));
 					label.putClientProperty(REPLACING_ICON, null);
 				}
 			});
@@ -117,7 +120,8 @@ public class SubstanceLabelUI extends BasicLabelUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicLabelUI#installDefaults(javax.swing.JLabel)
+	 * @see
+	 * javax.swing.plaf.basic.BasicLabelUI#installDefaults(javax.swing.JLabel)
 	 */
 	@Override
 	protected void installDefaults(JLabel c) {
@@ -128,7 +132,8 @@ public class SubstanceLabelUI extends BasicLabelUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicLabelUI#uninstallDefaults(javax.swing.JLabel)
+	 * @see
+	 * javax.swing.plaf.basic.BasicLabelUI#uninstallDefaults(javax.swing.JLabel)
 	 */
 	@Override
 	protected void uninstallDefaults(JLabel c) {
@@ -145,7 +150,8 @@ public class SubstanceLabelUI extends BasicLabelUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicLabelUI#installListeners(javax.swing.JLabel)
+	 * @see
+	 * javax.swing.plaf.basic.BasicLabelUI#installListeners(javax.swing.JLabel)
 	 */
 	@Override
 	protected void installListeners(final JLabel c) {
@@ -172,7 +178,8 @@ public class SubstanceLabelUI extends BasicLabelUI {
 						// + b.getText()
 						// + "->"
 						// + b
-						// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL));
+						//.getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL)
+						// );
 					}
 				}
 
@@ -184,7 +191,9 @@ public class SubstanceLabelUI extends BasicLabelUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicLabelUI#uninstallListeners(javax.swing.JLabel)
+	 * @see
+	 * javax.swing.plaf.basic.BasicLabelUI#uninstallListeners(javax.swing.JLabel
+	 * )
 	 */
 	@Override
 	protected void uninstallListeners(JLabel c) {
@@ -226,76 +235,61 @@ public class SubstanceLabelUI extends BasicLabelUI {
 						.getHorizontalTextPosition(), paintViewR, paintIconR,
 				paintTextR, label.getIconTextGap());
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-
 		Graphics2D g2d = (Graphics2D) g.create();
 
-		textPainter.init(label, null, true);
-		if (textPainter.needsBackgroundImage()) {
-			Color color = (label.isOpaque() || (label.getParent() == null)) ? label
-					.getBackground()
-					: label.getParent().getBackground();
-			textPainter.setBackgroundFill(label, color, true, 0, 0);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							if (icon != null) {
-								icon
-										.paintIcon(c, g, paintIconR.x,
-												paintIconR.y);
-							}
-						}
-					});
-		} else {
-			// Special case - support for applications that use default
-			// core renderers on lists and combo boxes.
-			if (!DefaultListCellRenderer.class.isAssignableFrom(c.getClass())) {
-				bgDelegate.updateIfOpaque(g2d, c);
-			}
-			if (icon != null) {
-				icon.paintIcon(c, g2d, paintIconR.x, paintIconR.y);
-			}
+		// // Special case - support for applications that use default
+		// // core renderers on lists and combo boxes.
+		// // boolean isNonSubstanceListRenderer = (c instanceof
+		// ListCellRenderer)
+		// // && !(c instanceof SubstanceDefaultListCellRenderer);
+		// if (!ListCellRenderer.class.isAssignableFrom(c.getClass()))
+		// || !Boolean.TRUE.equals(label
+		// .getClientProperty(CUSTOM_FILLING_CELL_RENDERER))) {
+		// if (c instanceof ListCellRenderer) {
+		// if (c instanceof SubstanceDefaultListCellRenderer)
+		// bgDelegate.updateIfOpaque(g2d, c);
+		// } else {
+		bgDelegate.updateIfOpaque(g2d, c);
+		// }
+		// }
+
+		if (icon != null) {
+			icon.paintIcon(c, g2d, paintIconR.x, paintIconR.y);
 		}
-		float textAlpha = 1.0f;
+		ComponentState labelState = label.isEnabled() ? ComponentState.DEFAULT
+				: ComponentState.DISABLED_UNSELECTED;
+		float labelAlpha = SubstanceColorSchemeUtilities.getAlpha(label,
+				labelState);
 		if (text != null) {
 			final View v = (View) c.getClientProperty(BasicHTML.propertyKey);
 			if (v != null) {
-				if (textPainter.needsBackgroundImage()) {
-					textPainter
-							.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-								public void paintBackground(Graphics g) {
-									v.paint(g, paintTextR);
-								}
-							});
-				} else {
-					v.paint(g2d, paintTextR);
-				}
+				v.paint(g2d, paintTextR);
 			} else {
-				ComponentState labelState = label.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED;
-				textAlpha = SubstanceCoreUtilities.paintText(label, paintTextR,
-						clippedText, label.getDisplayedMnemonicIndex(),
-						labelState, labelState);
+
+				Color fgColor = label.getForeground();
+				if (fgColor instanceof UIResource) {
+					fgColor = SubstanceTextUtilities.getForegroundColor(label,
+							text, labelState, labelState, labelAlpha);
+				}
+
+				SubstanceTextUtilities.paintText(g2d, label, paintTextR,
+						clippedText, label.getDisplayedMnemonicIndex(), label
+								.getFont(), fgColor, null);
 			}
 		}
-		g2d.setComposite(TransitionLayout
-				.getAlphaComposite(label, textAlpha, g));
-		textPainter.renderSurface(g2d);
 		g2d.dispose();
-
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
 		// failsafe for LAF change
-		if (!(UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel))
+		if (!SubstanceLookAndFeel.isCurrentLookAndFeel())
 			return;
 		this.paint(g, c);
 	}
