@@ -44,9 +44,11 @@ import javax.swing.plaf.basic.BasicListUI;
 import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.renderers.SubstanceDefaultListCellRenderer;
 import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -106,6 +108,11 @@ public class SubstanceListUI extends BasicListUI {
 	 */
 	private Map<Integer, ComponentState> nextStateMap;
 
+	/**
+	 * The current default color scheme.
+	 */
+	private SubstanceColorScheme currDefaultColorScheme;
+
 	/**
 	 * Listener for fade animations on list rollovers.
 	 * 
@@ -161,8 +168,12 @@ public class SubstanceListUI extends BasicListUI {
 		 *            Mouse event.
 		 */
 		private void handleMove(MouseEvent e) {
-			boolean fadeAllowed = FadeConfigurationManager.getInstance()
-					.fadeAllowed(FadeKind.ROLLOVER, list);
+			boolean fadeAllowed = !LafWidgetUtilities.hasNoFades(list,
+					FadeKind.ROLLOVER);
+			// no rollover effects on non-Substance renderers
+			if (!(list.getCellRenderer() instanceof SubstanceDefaultListCellRenderer))
+				fadeAllowed = false;
+
 			if (!fadeAllowed) {
 				fadeOut();
 				resetRolloverIndex();
@@ -223,7 +234,8 @@ public class SubstanceListUI extends BasicListUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent list) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceListUI();
 	}
 
@@ -250,7 +262,7 @@ public class SubstanceListUI extends BasicListUI {
 				.getClientProperty("List.isFileList"));
 		isLeftToRight = list.getComponentOrientation().isLeftToRight();
 
-		if (SubstanceCoreUtilities.toBleedWatermark(list)) {
+		if (SubstanceCoreUtilities.toDrawWatermark(list)) {
 			list.setOpaque(false);
 		}
 
@@ -260,6 +272,9 @@ public class SubstanceListUI extends BasicListUI {
 				prevStateMap.put(i, ComponentState.SELECTED);
 			}
 		}
+
+		this.list.putClientProperty(SubstanceCoreUtilities.USE_HIGHLIGHT,
+				Boolean.TRUE);
 		// this.list.putClientProperty(SubstanceListUI.SELECTED_INDICES,
 		// selected);
 	}
@@ -277,7 +292,7 @@ public class SubstanceListUI extends BasicListUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected class CellRepaintCallback extends FadeTrackerAdapter {
+	protected class CellRepaintCallback extends UIThreadFadeTrackerAdapter {
 		/**
 		 * Associated list.
 		 */
@@ -288,6 +303,11 @@ public class SubstanceListUI extends BasicListUI {
 		 */
 		protected int cellIndex;
 
+		/**
+		 * Renderer component for the cell.
+		 */
+		private Component rendererComponent;
+
 		/**
 		 * Creates a new animation repaint callback.
 		 * 
@@ -299,18 +319,31 @@ public class SubstanceListUI extends BasicListUI {
 		public CellRepaintCallback(JList list, int cellIndex) {
 			this.list = list;
 			this.cellIndex = cellIndex;
+			this.rendererComponent = list
+					.getCellRenderer()
+					.getListCellRendererComponent(
+							list,
+							list.getModel().getElementAt(cellIndex),
+							cellIndex,
+							list.getSelectionModel().isSelectedIndex(cellIndex),
+							list.hasFocus()
+									&& (cellIndex == list
+											.getLeadSelectionIndex()));
 		}
 
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded(org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
 		 */
 		@Override
 		public void fadeEnded(FadeKind fadeKind) {
 			if ((SubstanceListUI.this.list == list)
 					&& (cellIndex < list.getModel().getSize())) {
-				ComponentState currState = getCellState(cellIndex);
+				ComponentState currState = getCellState(cellIndex,
+						this.rendererComponent);
 				if (currState == ComponentState.DEFAULT) {
 					prevStateMap.remove(cellIndex);
 					nextStateMap.remove(cellIndex);
@@ -327,8 +360,9 @@ public class SubstanceListUI extends BasicListUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org.jvnet.lafwidget.animation.FadeKind,
-		 *      boolean, float)
+		 * @see
+		 * org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org
+		 * .jvnet.lafwidget.animation.FadeKind, boolean, float)
 		 */
 		@Override
 		public void fadeReversed(FadeKind fadeKind, boolean isFadingIn,
@@ -350,14 +384,16 @@ public class SubstanceListUI extends BasicListUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed(org.jvnet.lafwidget.utils.FadeTracker.FadeKind,
-		 *      float)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind, float)
 		 */
 		@Override
-		public void fadePerformed(FadeKind fadeKind, float fade10) {
+		public void fadePerformed(FadeKind fadeKind, float fade) {
 			if ((SubstanceListUI.this.list == list)
 					&& (cellIndex < list.getModel().getSize())) {
-				nextStateMap.put(cellIndex, getCellState(cellIndex));
+				nextStateMap.put(cellIndex, getCellState(cellIndex,
+						this.rendererComponent));
 			}
 			repaintCell();
 		}
@@ -405,12 +441,15 @@ public class SubstanceListUI extends BasicListUI {
 				}
 			}
 
-			@SuppressWarnings("unchecked")
 			public void valueChanged(ListSelectionEvent e) {
 				// optimization on large lists and large selections
 				if (LafWidgetUtilities.hasNoFades(list, FadeKind.SELECTION))
 					return;
 
+				// no selection animations on non-Substance renderers
+				if (!(list.getCellRenderer() instanceof SubstanceDefaultListCellRenderer))
+					return;
+
 				Set<Long> initiatedFadeSequences = new HashSet<Long>();
 				boolean fadeCanceled = false;
 
@@ -483,10 +522,10 @@ public class SubstanceListUI extends BasicListUI {
 
 		substancePropertyChangeListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
-				if (SubstanceLookAndFeel.WATERMARK_TO_BLEED.equals(evt
+				if (SubstanceLookAndFeel.WATERMARK_VISIBLE.equals(evt
 						.getPropertyName())) {
 					list.setOpaque(!SubstanceCoreUtilities
-							.toBleedWatermark(list));
+							.toDrawWatermark(list));
 				}
 			}
 		};
@@ -513,8 +552,8 @@ public class SubstanceListUI extends BasicListUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicListUI#paintCell(java.awt.Graphics, int,
-	 *      java.awt.Rectangle, javax.swing.ListCellRenderer,
-	 *      javax.swing.ListModel, javax.swing.ListSelectionModel, int)
+	 * java.awt.Rectangle, javax.swing.ListCellRenderer, javax.swing.ListModel,
+	 * javax.swing.ListSelectionModel, int)
 	 */
 	@Override
 	protected void paintCell(Graphics g, int row, Rectangle rowBounds,
@@ -524,13 +563,20 @@ public class SubstanceListUI extends BasicListUI {
 		boolean cellHasFocus = list.hasFocus() && (row == leadIndex);
 		boolean isSelected = selModel.isSelectedIndex(row);
 
-		final boolean isWatermarkBleed = SubstanceCoreUtilities
-				.toBleedWatermark(list);
-
-		final Component rendererComponent = cellRenderer
+		Component rendererComponent = cellRenderer
 				.getListCellRendererComponent(list, value, row, isSelected,
 						cellHasFocus);
 
+		if (!(rendererComponent instanceof SubstanceDefaultListCellRenderer)) {
+			// if it's not Substance renderer - ask the Basic delegate to paint
+			// it.
+			super.paintCell(g, row, rowBounds, cellRenderer, dataModel,
+					selModel, leadIndex);
+			return;
+		}
+
+		boolean isWatermarkBleed = SubstanceCoreUtilities.toDrawWatermark(list);
+
 		int cx = rowBounds.x;
 		int cy = rowBounds.y;
 		int cw = rowBounds.width;
@@ -548,178 +594,71 @@ public class SubstanceListUI extends BasicListUI {
 			cw = w;
 		}
 
-		// Integer currRoIndex = (Integer) list
-		// .getClientProperty(ROLLED_OVER_INDEX);
-		boolean isRollover = ((rolledOverIndex >= 0) && (rolledOverIndex == row));
-
-		// Respect the current composite set on the graphics - for
-		// JXPanel alpha channel
-		// float currFactor = 1.0f;
-		// Composite currComposite = ((Graphics2D) g).getComposite();
-		// if (currComposite instanceof AlphaComposite) {
-		// AlphaComposite ac = (AlphaComposite) currComposite;
-		// if (ac.getRule() == AlphaComposite.SRC_OVER)
-		// currFactor = ac.getAlpha();
-		// }
-
 		Graphics2D g2d = (Graphics2D) g.create();
 		g2d.setComposite(TransitionLayout.getAlphaComposite(list, g));
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		if (textPainter.needsBackgroundImage()) {
-			final Rectangle offsetCellRect = new Rectangle(0, 0, cw, ch);
-			textPainter.init(this.list, offsetCellRect, true);
-			// textPainter.setBackgroundImage(this.list, null, false, 0, 0);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							if (!isWatermarkBleed) {
-								// fill with the renderer background color
-								g2d.setColor(rendererComponent.getBackground());
-								g2d.fillRect(0, 0, offsetCellRect.width,
-										offsetCellRect.height);
-							} else {
-								backgroundDelegate.fillAndWatermark(g2d, list,
-										rendererComponent.getBackground(),
-										offsetCellRect);
-							}
-							g2d.dispose();
-						}
-					});
-		} else {
-			if (!isWatermarkBleed) {
-				// fill with the renderer background color
-				g2d.setColor(rendererComponent.getBackground());
+		if (!isWatermarkBleed) {
+			Color background = rendererComponent.getBackground();
+			// optimization - only render background if it's different
+			// from the list background
+			if ((background != null)
+					&& !list.getBackground().equals(background)) {
+				g2d.setColor(background);
 				g2d.fillRect(cx, cy, cw, ch);
-			} else {
-				backgroundDelegate.fillAndWatermark(g2d, this.list,
-						rendererComponent.getBackground(), new Rectangle(cx,
-								cy, cw, ch));
 			}
+		} else {
+			backgroundDelegate.fillAndWatermark(g2d, this.list,
+					rendererComponent.getBackground(), new Rectangle(cx, cy,
+							cw, ch));
 		}
 
 		ComponentState prevState = getPrevCellState(row);
-		ComponentState currState = getCellState(row);
+		ComponentState currState = getCellState(row, rendererComponent);
 
 		// Compute the alpha values for the animation.
-		float startAlpha = SubstanceThemeUtilities.getHighlightAlpha(list,
-				prevState);
-		float endAlpha = SubstanceThemeUtilities.getHighlightAlpha(list,
+		float startAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(
+				list, prevState);
+		float endAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(list,
 				currState);
 
-		FadeState state = SubstanceFadeUtilities.getFadeState(list, row,
-				FadeKind.SELECTION, FadeKind.ROLLOVER);
+		// if the renderer is disabled, do not show any highlights
 		float totalAlpha = endAlpha;
 		float fadeCoef = 0.0f;
-		if (state != null) {
-			fadeCoef = state.getFadePosition();
+		if (rendererComponent.isEnabled()) {
+			FadeState state = SubstanceFadeUtilities.getFadeState(list, row,
+					FadeKind.SELECTION, FadeKind.ROLLOVER);
+			if (state != null) {
+				fadeCoef = state.getFadePosition();
 
-			// compute the total alpha of the overlays.
-			if (state.isFadingIn()) {
-				totalAlpha = startAlpha + (endAlpha - startAlpha) * fadeCoef
-						/ 10.0f;
-			} else {
-				totalAlpha = startAlpha + (endAlpha - startAlpha)
-						* (10.0f - fadeCoef) / 10.0f;
-			}
+				// compute the total alpha of the overlays.
+				if (state.isFadingIn()) {
+					totalAlpha = startAlpha + (endAlpha - startAlpha)
+							* fadeCoef;
+				} else {
+					totalAlpha = startAlpha + (endAlpha - startAlpha)
+							* (1.0f - fadeCoef);
+				}
 
-			if (state.isFadingIn())
-				fadeCoef = 10.0f - fadeCoef;
-		}
-
-		final SubstanceTheme prevTheme = SubstanceThemeUtilities
-				.getHighlightTheme(list, prevState);
-		final SubstanceTheme currTheme = SubstanceThemeUtilities
-				.getHighlightTheme(list, currState);
-
-		// System.out.println(row + ":" + prevTheme.getDisplayName() + "["
-		// + alphaForPrevBackground + "]:" + currTheme.getDisplayName()
-		// + "[" + alphaForCurrBackground + "]");
-
-		if (textPainter.needsBackgroundImage()) {
-			final float finalTotalAlpha = totalAlpha;
-			final float finalFadeCoef = fadeCoef;
-
-			// The text GC will be clipped to the renderer bound. To have the
-			// background painted in the correct location, enforce this by
-			// painting the background in 0, 0 position.
-			final Rectangle cellRect = new Rectangle(0, 0, cw, ch);
-			// textPainter.setBackgroundImage(this.list, rendererComponent
-			// .getBackground(), true, cx, cy);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-
-							if (finalTotalAlpha > 0.0f) {
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(list,
-												finalTotalAlpha, g));
-								SubstanceHighlightUtils.paintHighlight(g2d,
-										rendererComponent, cellRect, 0.8f,
-										null, currTheme.getColorScheme(),
-										prevTheme.getColorScheme(),
-										finalFadeCoef);
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(list, g));
-							}
-							g2d.dispose();
-						}
-					});
-		} else {
-			Rectangle cellRect = new Rectangle(cx, cy, cw, ch);
-			if (totalAlpha > 0.0f) {
-				g2d.setComposite(TransitionLayout.getAlphaComposite(list,
-						totalAlpha, g));
-				SubstanceHighlightUtils.paintHighlight(g2d, rendererComponent,
-						cellRect, 0.8f, null, currTheme.getColorScheme(),
-						prevTheme.getColorScheme(), fadeCoef);
-				g2d.setComposite(TransitionLayout.getAlphaComposite(list, g));
+				if (state.isFadingIn())
+					fadeCoef = 1.0f - fadeCoef;
 			}
 		}
 
-		this.list.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, Boolean.TRUE);
-		if (rendererComponent instanceof JComponent) {
-			// Play with opacity to make our own gradient background
-			// on selected elements to show.
-			JComponent jRenderer = (JComponent) rendererComponent;
-			synchronized (jRenderer) {
-				boolean newOpaque = !(isSelected || isRollover || (state != null));
-				if (isWatermarkBleed)
-					newOpaque = false;
+		SubstanceColorScheme prevScheme = SubstanceColorSchemeUtilities
+				.getHighlightColorScheme(list, prevState);
+		SubstanceColorScheme currScheme = SubstanceColorSchemeUtilities
+				.getHighlightColorScheme(list, currState);
 
-				Map<Component, Boolean> opacity = new HashMap<Component, Boolean>();
-				// System.out.println("Pre-painting at index " + row + " [" +
-				// value
-				// + "] " + (rendererComponent.isOpaque() ? "opaque" :
-				// "transparent")
-				// + " with bg " + rendererComponent.getBackground());
-				if (!newOpaque)
-					SubstanceCoreUtilities.makeNonOpaque(jRenderer, opacity);
-				// System.out.println("Painting at index " + row + " [" + value
-				// + "] " + (newOpaque ? "opaque" : "transparent")
-				// + " with bg " + rendererComponent.getBackground());
-				rendererPane.paintComponent(g2d, rendererComponent, list, cx,
-						cy, cw, ch, true);
-				// System.out.println("Painting at index " + row + " [" + value
-				// + "] " + (newOpaque ? "opaque" : "transparent")
-				// + " with bg " + rendererComponent.getBackground());
-				if (!newOpaque)
-					SubstanceCoreUtilities.restoreOpaque(jRenderer, opacity);
-				// System.out.println("Post-painting at index " + row + " [" +
-				// value
-				// + "] " + (rendererComponent.isOpaque() ? "opaque" :
-				// "transparent")
-				// + " with bg " + rendererComponent.getBackground());
-			}
-		} else {
-			rendererPane.paintComponent(g2d, rendererComponent, list, cx, cy,
-					cw, ch, true);
+		Rectangle cellRect = new Rectangle(cx, cy, cw, ch);
+		if (totalAlpha > 0.0f) {
+			g2d.setComposite(TransitionLayout.getAlphaComposite(list,
+					totalAlpha, g));
+			SubstanceHighlightUtils.paintHighlight(g2d, rendererComponent,
+					cellRect, 0.8f, null, currScheme, prevScheme, fadeCoef);
+			g2d.setComposite(TransitionLayout.getAlphaComposite(list, g));
 		}
-		this.list.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, null);
+
+		rendererPane.paintComponent(g2d, rendererComponent, list, cx, cy, cw,
+				ch, true);
 		g2d.dispose();
 	}
 
@@ -741,13 +680,18 @@ public class SubstanceListUI extends BasicListUI {
 	 * 
 	 * @param cellIndex
 	 *            Cell index.
+	 * @param rendererComponent
+	 *            Renderer component for the specified cell index.
 	 * @return The current state for the specified cell.
 	 */
-	public ComponentState getCellState(int cellIndex) {
+	public ComponentState getCellState(int cellIndex,
+			Component rendererComponent) {
 		ButtonModel synthModel = new DefaultButtonModel();
-		synthModel.setEnabled(list.isEnabled());
-		// Integer currRoIndex = (Integer) list
-		// .getClientProperty(ROLLED_OVER_INDEX);
+		boolean isEnabled = this.list.isEnabled();
+		if (rendererComponent != null) {
+			isEnabled = isEnabled && rendererComponent.isEnabled();
+		}
+		synthModel.setEnabled(isEnabled);
 		synthModel.setRollover((rolledOverIndex >= 0)
 				&& (rolledOverIndex == cellIndex));
 		synthModel.setSelected(list.isSelectedIndex(cellIndex));
@@ -765,24 +709,28 @@ public class SubstanceListUI extends BasicListUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
 		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(g, c);
 
 		Graphics2D g2d = (Graphics2D) g.create();
-		// install state-aware alpha channel (support for skins that use
-		// translucency on disabled states).
-		// SubstanceTheme theme = SubstanceCoreUtilities.getTheme(this.list,
-		// true,
-		// true);
-		// float themeAlpha = theme.getThemeAlpha(this.list,
-		// this.list.isEnabled() ? ComponentState.DEFAULT
-		// : ComponentState.DISABLED_UNSELECTED);
-		// g2d.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER,
-		// themeAlpha));
+		SubstanceStripingUtils.setup(c);
+		this.currDefaultColorScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(c, ComponentState.DEFAULT);
 		this.paint(g2d, c);
+		SubstanceStripingUtils.tearDown(c);
 		g2d.dispose();
 	}
+
+	/**
+	 * Returns the current default color scheme. This method is for internal use
+	 * only.
+	 * 
+	 * @return The current default color scheme.
+	 */
+	public SubstanceColorScheme getDefaultColorScheme() {
+		return this.currDefaultColorScheme;
+	}
 }
