@@ -41,6 +41,7 @@ import org.jvnet.lafwidget.animation.FadeStateListener;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.SubstanceSizeUtils;
 import org.jvnet.substance.utils.menu.MenuUtilities;
+import org.jvnet.substance.utils.menu.SubstanceMenu;
 import org.jvnet.substance.utils.menu.MenuUtilities.MenuPropertyListener;
 
 /**
@@ -71,7 +72,8 @@ public class SubstanceMenuItemUI extends BasicMenuItemUI implements
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceMenuItemUI();
 	}
 
@@ -195,8 +197,9 @@ public class SubstanceMenuItemUI extends BasicMenuItemUI implements
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax.swing.JComponent,
-	 *      javax.swing.Icon, javax.swing.Icon, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax
+	 * .swing.JComponent, javax.swing.Icon, javax.swing.Icon, int)
 	 */
 	@Override
 	protected Dimension getPreferredMenuItemSize(JComponent c, Icon checkIcon,
@@ -210,9 +213,10 @@ public class SubstanceMenuItemUI extends BasicMenuItemUI implements
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
-	 *      javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
-	 *      java.awt.Color, java.awt.Color, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
+	 * javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
+	 * java.awt.Color, java.awt.Color, int)
 	 */
 	@Override
 	protected void paintMenuItem(Graphics g, JComponent c, Icon checkIcon,
