@@ -46,6 +46,7 @@ import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.SubstanceSizeUtils;
 import org.jvnet.substance.utils.icon.MenuArrowIcon;
 import org.jvnet.substance.utils.menu.MenuUtilities;
+import org.jvnet.substance.utils.menu.SubstanceMenu;
 import org.jvnet.substance.utils.menu.MenuUtilities.MenuPropertyListener;
 
 /**
@@ -85,22 +86,41 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceMenuUI();
 	}
 
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see javax.swing.plaf.basic.BasicMenuUI#installDefaults()
+	 */
 	@Override
 	protected void installDefaults() {
 		super.installDefaults();
 		this.menuItem.setRolloverEnabled(true);
+		// this.menuItem.setOpaque(false);
 
 		this.arrowIcon = new MenuArrowIcon(this.menuItem);
 
 		this.defaultTextIconGap = SubstanceSizeUtils
 				.getTextIconGap(SubstanceSizeUtils
 						.getComponentFontSize(this.menuItem));
+
+		this.menuItem.putClientProperty(SubstanceLookAndFeel.FLAT_PROPERTY,
+				Boolean.TRUE);
+		this.menuItem.putClientProperty(SubstanceCoreUtilities.USE_HIGHLIGHT,
+				Boolean.TRUE);
+
+		LookAndFeel.installProperty(menuItem, "opaque", Boolean.FALSE);
 	}
 
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see javax.swing.plaf.basic.BasicMenuUI#installListeners()
+	 */
 	@Override
 	protected void installListeners() {
 		super.installListeners();
@@ -128,16 +148,24 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 			@Override
 			public void mouseEntered(MouseEvent e) {
 				if (this.toRepaint()) {
-					SubstanceMenuUI.this.menuItem.getModel().setRollover(true);
-					SubstanceMenuUI.this.menuItem.repaint();
+					menuItem.getModel().setRollover(true);
+					// fix for issue 371 - repaint the menu bar since the
+					// menu is marked as flat
+					Rectangle bounds = menuItem.getBounds();
+					menuItem.getParent().repaint(bounds.x, bounds.y,
+							bounds.width, bounds.height);
 				}
 			}
 
 			@Override
 			public void mouseExited(MouseEvent e) {
 				if (this.toRepaint()) {
-					SubstanceMenuUI.this.menuItem.getModel().setRollover(false);
-					SubstanceMenuUI.this.menuItem.repaint();
+					menuItem.getModel().setRollover(false);
+					// fix for issue 371 - repaint the menu bar since the
+					// menu is marked as flat
+					Rectangle bounds = menuItem.getBounds();
+					menuItem.getParent().repaint(bounds.x, bounds.y,
+							bounds.width, bounds.height);
 				}
 			}
 		};
@@ -159,19 +187,24 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 			@Override
 			public void focusLost(FocusEvent e) {
 				if (toRepaint()) {
-					SubstanceMenuUI.this.menuItem.getModel().setRollover(false);
-					SubstanceMenuUI.this.menuItem.repaint();
+					menuItem.getModel().setRollover(false);
+					// fix for issue 371 - repaint the menu bar since the
+					// menu is marked as flat
+					Rectangle bounds = menuItem.getBounds();
+					menuItem.getParent().repaint(bounds.x, bounds.y,
+							bounds.width, bounds.height);
 				}
 			}
 		};
 		this.menuItem.addFocusListener(this.substanceFocusListener);
 
 		final Set<FadeKind> toIgnore = new HashSet<FadeKind>();
-		// toIgnore.add(FadeKind.ROLLOVER);
+		// fix for issue 371 - repaint the menu bar since the
+		// menu is marked as flat
 		this.substanceFadeStateListener = new FadeStateListener(this.menuItem,
-				this.menuItem.getModel(), SubstanceCoreUtilities
+				null, this.menuItem.getModel(), SubstanceCoreUtilities
 						.getFadeCallback(this.menuItem, this.menuItem
-								.getModel(), false, false, this.menuItem),
+								.getModel(), false, true, this.menuItem),
 				toIgnore);
 		this.substanceFadeStateListener.registerListeners();
 
@@ -192,6 +225,7 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 						substanceFadeStateListener.unregisterListeners();
 					substanceFadeStateListener = new FadeStateListener(
 							menuItem,
+							null,
 							menuItem.getModel(),
 							SubstanceCoreUtilities
 									.getFadeCallback(menuItem, menuItem
@@ -202,7 +236,9 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 				if ("font".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							menuItem.updateUI();
+							if (menuItem != null) {
+								menuItem.updateUI();
+							}
 						}
 					});
 				}
@@ -286,8 +322,9 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax.swing.JComponent,
-	 *      javax.swing.Icon, javax.swing.Icon, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax
+	 * .swing.JComponent, javax.swing.Icon, javax.swing.Icon, int)
 	 */
 	@Override
 	protected Dimension getPreferredMenuItemSize(JComponent c, Icon checkIcon,
@@ -295,7 +332,7 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 		Dimension superDim = super.getPreferredMenuItemSize(c, checkIcon,
 				arrowIcon, defaultTextIconGap);
 
-		if (MenuUtilities.getPopupLayoutMetrics(menuItem) != null) {
+		if (MenuUtilities.getPopupLayoutMetrics(menuItem, false) != null) {
 			return new Dimension(MenuUtilities.getPreferredWidth(menuItem),
 					superDim.height);
 		}
@@ -306,9 +343,10 @@ public class SubstanceMenuUI extends BasicMenuUI implements SubstanceMenu {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
-	 *      javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
-	 *      java.awt.Color, java.awt.Color, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
+	 * javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
+	 * java.awt.Color, java.awt.Color, int)
 	 */
 	@Override
 	protected void paintMenuItem(Graphics g, JComponent c, Icon checkIcon,
