@@ -37,6 +37,8 @@ import javax.swing.plaf.basic.BasicOptionPaneUI;
 
 import org.jvnet.lafwidget.LafWidgetUtilities;
 import org.jvnet.lafwidget.animation.*;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.GlowingIcon;
 
@@ -77,7 +79,8 @@ public class SubstanceOptionPaneUI extends BasicOptionPaneUI {
 	/**
 	 * Creates a new SubstanceOptionPaneUI instance.
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceOptionPaneUI();
 	}
 
@@ -85,7 +88,7 @@ public class SubstanceOptionPaneUI extends BasicOptionPaneUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
@@ -106,9 +109,10 @@ public class SubstanceOptionPaneUI extends BasicOptionPaneUI {
 
 		if (sideIcon != null) {
 			if (!SubstanceLookAndFeel.isToUseConstantThemesOnDialogs()) {
-				sideIcon = new ImageIcon(SubstanceImageCreator.getThemeImage(
-						null, sideIcon, SubstanceThemeUtilities.getTheme(
-								optionPane, ComponentState.ACTIVE), false));
+				sideIcon = new ImageIcon(SubstanceImageCreator
+						.getColorSchemeImage(null, sideIcon,
+								SubstanceColorSchemeUtilities.getColorScheme(
+										optionPane, ComponentState.ACTIVE)));
 			}
 
 			substanceIconLabel = new OptionPaneLabel();
