@@ -29,14 +29,18 @@
  */
 package org.jvnet.substance;
 
+import java.awt.Color;
 import java.awt.Graphics;
 
 import javax.swing.JComponent;
 import javax.swing.JPanel;
-import javax.swing.plaf.ComponentUI;
+import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicPanelUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.utils.SubstanceColorUtilities;
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
 /**
  * UI for panels in <b>Substance</b> look and feel.
@@ -44,32 +48,37 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
  * @author Kirill Grouchnikov
  */
 public class SubstancePanelUI extends BasicPanelUI {
-	/**
-	 * Background delegate.
-	 */
-	//private SubstanceFillBackgroundDelegate bgDelegate;
-
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstancePanelUI();
 	}
 
-	/**
-	 * Simple constructor.
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see
+	 * javax.swing.plaf.basic.BasicPanelUI#installDefaults(javax.swing.JPanel)
 	 */
-	protected SubstancePanelUI() {
-		//bgDelegate = new SubstanceFillBackgroundDelegate();
+	@Override
+	protected void installDefaults(JPanel p) {
+		super.installDefaults(p);
+		// support for per-window skins
+		Color backgr = p.getBackground();
+		if ((backgr == null) || (backgr instanceof UIResource))
+			p.setBackground(new ColorUIResource(SubstanceColorUtilities
+					.getBackgroundFillColor(p)));
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
@@ -91,7 +100,6 @@ public class SubstancePanelUI extends BasicPanelUI {
 	 *         the background color, <code>false</code> otherwise.
 	 */
 	protected boolean toPaintBackground(JComponent c) {
-
 		return TransitionLayout.isOpaque(c);
 	}
 }
