@@ -41,11 +41,10 @@ import javax.swing.plaf.basic.BasicPasswordFieldUI;
 import javax.swing.text.*;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.text.SubstanceFieldView;
-import org.jvnet.substance.text.SubstanceHighlighter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for password fields in <b>Substance</b> look and feel.
@@ -73,7 +72,7 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	private static class SubstancePasswordView extends SubstanceFieldView {
+	private static class SubstancePasswordView extends FieldView {
 		/**
 		 * The associated password field.
 		 */
@@ -92,6 +91,25 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 			this.field = field;
 		}
 
+		/**
+		 * Draws the echo character(s) for a single password field character.
+		 * The number of echo characters is defined by
+		 * {@link SubstanceLookAndFeel#PASSWORD_ECHO_PER_CHAR} client property.
+		 * 
+		 * @param g
+		 *            Graphics context
+		 * @param x
+		 *            X coordinate of the first echo character to draw.
+		 * @param y
+		 *            Y coordinate of the first echo character to draw.
+		 * @param c
+		 *            Password field.
+		 * @param isSelected
+		 *            Indicates whether the password field character is
+		 *            selected.
+		 * @return The X location of the next echo character.
+		 * @see SubstanceLookAndFeel#PASSWORD_ECHO_PER_CHAR
+		 */
 		protected int drawEchoCharacter(Graphics g, int x, int y, char c,
 				boolean isSelected) {
 			Container container = this.getContainer();
@@ -109,10 +127,10 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 			ComponentState state = // isSelected ? ComponentState.SELECTED
 			(field.isEnabled() ? ComponentState.DEFAULT
 					: ComponentState.DISABLED_UNSELECTED);
-			SubstanceTheme theme = SubstanceThemeUtilities
-					.getTheme(field, state);
-			Color topColor = isSelected ? theme.getSelectionForegroundColor()
-					: theme.getForegroundColor();
+			SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+					.getColorScheme(field, state);
+			Color topColor = isSelected ? scheme.getSelectionForegroundColor()
+					: SubstanceColorUtilities.getForegroundColor(scheme);
 			Color bottomColor = topColor.brighter();
 			graphics.setPaint(new GradientPaint(x, y - dotDiameter, topColor,
 					x, y, bottomColor));
@@ -125,6 +143,16 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 			return x;
 		}
 
+		/**
+		 * Returns the advance of a single password field character. The advance
+		 * is the pixel distance between first echo characters of consecutive
+		 * password field characters. The
+		 * {@link SubstanceLookAndFeel#PASSWORD_ECHO_PER_CHAR} can be used to
+		 * specify that more than one echo character is used for each password
+		 * field character.
+		 * 
+		 * @return The advance of a single password field character
+		 */
 		protected int getEchoCharAdvance() {
 			int fontSize = SubstanceSizeUtils.getComponentFontSize(this.field);
 			int dotDiameter = SubstanceSizeUtils
@@ -138,7 +166,7 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.text.PlainView#drawSelectedText(java.awt.Graphics,
-		 *      int, int, int, int)
+		 * int, int, int, int)
 		 */
 		@Override
 		protected int drawSelectedText(Graphics g, final int x, final int y,
@@ -149,23 +177,11 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 				if (!f.echoCharIsSet()) {
 					return super.drawSelectedText(g, x, y, p0, p1);
 				}
-				final int n = p1 - p0;
-				final char echoChar = f.getEchoChar();
-				SubstanceTextPainter.BackgroundPaintingCallback echoCharsCallback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-					public void paintBackground(Graphics g) {
-						int currPos = x;
-						for (int i = 0; i < n; i++) {
-							currPos = drawEchoCharacter(g, currPos, y,
-									echoChar, true);
-						}
-					}
-				};
-				SubstanceTextPainter textPainter = SubstanceLookAndFeel
-						.getCurrentTextPainter();
-				if (textPainter.needsBackgroundImage()) {
-					textPainter.attachCallback(echoCharsCallback);
-				} else {
-					echoCharsCallback.paintBackground(g);
+				int n = p1 - p0;
+				char echoChar = f.getEchoChar();
+				int currPos = x;
+				for (int i = 0; i < n; i++) {
+					currPos = drawEchoCharacter(g, currPos, y, echoChar, true);
 				}
 				return x + n * getEchoCharAdvance();
 			}
@@ -176,7 +192,7 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.text.PlainView#drawUnselectedText(java.awt.Graphics,
-		 *      int, int, int, int)
+		 * int, int, int, int)
 		 */
 		@Override
 		protected int drawUnselectedText(Graphics g, final int x, final int y,
@@ -187,23 +203,11 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 				if (!f.echoCharIsSet()) {
 					return super.drawUnselectedText(g, x, y, p0, p1);
 				}
-				final int n = p1 - p0;
-				final char echoChar = f.getEchoChar();
-				SubstanceTextPainter.BackgroundPaintingCallback echoCharsCallback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-					public void paintBackground(Graphics g) {
-						int currPos = x;
-						for (int i = 0; i < n; i++) {
-							currPos = drawEchoCharacter(g, currPos, y,
-									echoChar, false);
-						}
-					}
-				};
-				SubstanceTextPainter textPainter = SubstanceLookAndFeel
-						.getCurrentTextPainter();
-				if (textPainter.needsBackgroundImage()) {
-					textPainter.attachCallback(echoCharsCallback);
-				} else {
-					echoCharsCallback.paintBackground(g);
+				int n = p1 - p0;
+				char echoChar = f.getEchoChar();
+				int currPos = x;
+				for (int i = 0; i < n; i++) {
+					currPos = drawEchoCharacter(g, currPos, y, echoChar, false);
 				}
 				return x + n * getEchoCharAdvance();
 			}
@@ -214,7 +218,7 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.text.View#modelToView(int, java.awt.Shape,
-		 *      javax.swing.text.Position.Bias)
+		 * javax.swing.text.Position.Bias)
 		 */
 		@Override
 		public Shape modelToView(int pos, Shape a, Position.Bias b)
@@ -246,7 +250,7 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.text.View#viewToModel(float, float, java.awt.Shape,
-		 *      javax.swing.text.Position.Bias[])
+		 * javax.swing.text.Position.Bias[])
 		 */
 		@Override
 		public int viewToModel(float fx, float fy, Shape a, Position.Bias[] bias) {
@@ -317,8 +321,9 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstancePasswordFieldUI(c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstancePasswordFieldUI(comp);
 	}
 
 	/**
@@ -404,91 +409,24 @@ public class SubstancePasswordFieldUI extends BasicPasswordFieldUI {
 					new BasicBorders.MarginBorder());
 			this.passwordField.setBorder(newB);
 		}
-	}
 
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see
-	// javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
-	// */
-	// @Override
-	// protected void paintBackground(Graphics g) {
-	// SubstanceCoreUtilities.paintCompBackground(g, this.passwordField);
-	// }
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#createHighlighter()
-	 */
-	@Override
-	protected Highlighter createHighlighter() {
-		return new SubstanceHighlighter();
+		// support for per-window skins
+		Color foregr = this.passwordField.getForeground();
+		if ((foregr == null) || (foregr instanceof UIResource)) {
+			this.passwordField.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceLookAndFeel.getCurrentSkin(
+							this.passwordField).getMainDefaultColorScheme()));
+		}
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#paintSafely(java.awt.Graphics)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
 	 */
 	@Override
-	protected void paintSafely(Graphics _g) {
-		// // Have to call the super implementation since it sets a
-		// // private "painted" flag which affects many other places.
-		// // Without this there will be many visual artifacts with
-		// // painting the caret and highlights
-		// super.paintSafely(_g);
-		//
-		// SubstanceTextPainter textPainter = SubstanceLookAndFeel
-		// .getCurrentTextPainter();
-		//
-		// SubstanceTextPainter.BackgroundPaintingCallback callback = new
-		// SubstanceTextPainter.BackgroundPaintingCallback() {
-		// public void paintBackground(Graphics g) {
-		// Highlighter highlighter = getComponent().getHighlighter();
-		//
-		// // paint the background
-		// if (getComponent().isOpaque()) {
-		// SubstancePasswordFieldUI.this.paintBackground(g);
-		// }
-		//
-		// // paint the highlights
-		// if (highlighter != null) {
-		// highlighter.paint(g);
-		// }
-		// }
-		// };
-		// textPainter.init(passwordField, null, true);
-		// if (textPainter.needsBackgroundImage()) {
-		// textPainter.setBackgroundFill(passwordField, passwordField
-		// .getBackground(), false, 0, 0);
-		// textPainter.attachCallback(callback);
-		// } else {
-		// callback.paintBackground(_g);
-		// }
-		//
-		// // paint the view hierarchy
-		// Rectangle alloc = getVisibleEditorRect();
-		// if (alloc != null) {
-		// getRootView(passwordField).paint(_g, alloc);
-		// }
-		// textPainter.renderSurface(_g);
-		//
-		// // paint the caret
-		// Caret caret = getComponent().getCaret();
-		// if (caret != null) {
-		// caret.paint(_g);
-		// }
-		// Have to call the super implementation since it sets a
-		// private "painted" flag which affects many other places.
-		// Without this there will be many visual artifacts with
-		// painting the caret and highlights
-		Graphics2D dummy = (Graphics2D) _g.create(0, 0, 0, 0);
-		super.paintSafely(dummy);
-		dummy.dispose();
-
-		SubstanceCoreUtilities.paintTextComponent(_g, this.passwordField, this
-				.getRootView(this.passwordField), this.getVisibleEditorRect());
+	protected void paintBackground(Graphics g) {
+		SubstanceTextUtilities.paintTextCompBackground(g, this.passwordField);
 	}
 }
\ No newline at end of file
