@@ -37,10 +37,12 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.basic.BasicPopupMenuSeparatorUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceConstants.MenuGutterFillKind;
+import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
-import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
 import org.jvnet.substance.utils.menu.MenuUtilities;
 
 /**
@@ -54,7 +56,8 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 	 */
 	private SubstanceFillBackgroundDelegate fillBackgroundDelegate;
 
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstancePopupMenuSeparatorUI();
 	}
 
@@ -70,12 +73,6 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 	public void paint(Graphics g, JComponent c) {
 		Graphics2D graphics = (Graphics2D) g.create();
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(c)
-				.getDefaultTheme();
-
-		boolean isDark = SubstanceCoreUtilities.isThemeDark(theme
-				.getActiveTheme());
-		ColorScheme colorScheme = theme.getColorScheme();
 		try {
 			JSeparator sep = (JSeparator) c;
 
@@ -89,8 +86,8 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 				MenuGutterFillKind fillKind = SubstanceCoreUtilities
 						.getMenuGutterFillKind();
 				if (fillKind != MenuGutterFillKind.NONE) {
-					ColorScheme scheme = SubstanceThemeUtilities.getTheme(sep,
-							ComponentState.DEFAULT).getColorScheme();
+					SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+							.getColorScheme(sep, ComponentState.DEFAULT);
 					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
 							.getUltraLightColor()
 							: scheme.getLightColor();
@@ -106,7 +103,8 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 					graphics.fillRect(0, 0, xOffset - 2, c.getHeight());
 				}
 
-				// graphics.setComposite(TransitionLayout.getAlphaComposite(sep));
+				//graphics.setComposite(TransitionLayout.getAlphaComposite(sep))
+				// ;
 				// graphics.setColor(c.getForeground());
 				// graphics.drawLine(xOffset, 1, s.width, 1);
 				// graphics.setColor(c.getBackground());
@@ -120,8 +118,8 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 				MenuGutterFillKind fillKind = SubstanceCoreUtilities
 						.getMenuGutterFillKind();
 				if (fillKind != MenuGutterFillKind.NONE) {
-					ColorScheme scheme = SubstanceThemeUtilities.getTheme(sep,
-							ComponentState.DEFAULT).getColorScheme();
+					SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+							.getColorScheme(sep, ComponentState.DEFAULT);
 					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
 							.getLightColor()
 							: scheme.getUltraLightColor();
@@ -136,20 +134,15 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 					graphics.setPaint(gp);
 					graphics.fillRect(xOffset - 2, 0, s.width, c.getHeight());
 				}
-				// graphics.setComposite(TransitionLayout.getAlphaComposite(sep));
-				// graphics.setColor(c.getForeground());
-				// graphics.drawLine(0, 1, s.width - xOffset - 4, 1);
-				// graphics.setColor(c.getBackground());
-				// graphics.drawLine(0, 2, s.width - xOffset - 4, 2);
-				// graphics.drawLine(0, 0, 0, 0);
-				// graphics.drawLine(0, 3, 0, 3);
 				startX = 0;
 				width = xOffset - 4;
 			}
 			graphics.translate(startX, 0);
 			graphics.setComposite(TransitionLayout.getAlphaComposite(sep));
-			SubstanceCoreUtilities.paintSeparator(sep, graphics, colorScheme,
-					isDark, width, s.height, sep.getOrientation(), true, 2);
+			SeparatorPainterUtils.paintSeparator(sep, graphics,
+					SubstanceColorSchemeUtilities.getColorScheme(c,
+							ComponentState.DEFAULT), width, s.height, sep
+							.getOrientation(), true, 2);
 		} finally {
 			graphics.dispose();
 		}
@@ -158,7 +151,9 @@ public class SubstancePopupMenuSeparatorUI extends BasicPopupMenuSeparatorUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicPopupMenuSeparatorUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicPopupMenuSeparatorUI#getPreferredSize(javax
+	 * .swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
