@@ -31,8 +31,6 @@ package org.jvnet.substance;
 
 import java.awt.*;
 import java.awt.image.BufferedImage;
-import java.util.HashMap;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.event.ChangeEvent;
@@ -43,13 +41,11 @@ import javax.swing.plaf.basic.BasicProgressBarUI;
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeTracker;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.border.InnerDelegateBorderPainter;
-import org.jvnet.substance.border.SubstanceBorderPainter;
-import org.jvnet.substance.button.BaseButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.painter.SubstanceGradientPainter;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.painter.border.InnerDelegateBorderPainter;
+import org.jvnet.substance.painter.border.SubstanceBorderPainter;
+import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -61,17 +57,14 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	/**
 	 * Hash for computed stripe images.
 	 */
-	private static Map<String, BufferedImage> stripeMap = new HashMap<String, BufferedImage>();
+	private static LazyResettableHashMap<BufferedImage> stripeMap = new LazyResettableHashMap<BufferedImage>(
+			"SubstanceProgressBarUI.stripeMap");
 
 	/**
-	 * Resets image maps (used when setting new theme).
-	 * 
-	 * @see SubstanceLookAndFeel#setCurrentTheme(String)
-	 * @see SubstanceLookAndFeel#setCurrentTheme(SubstanceTheme)
+	 * Hash for computed background images.
 	 */
-	public static synchronized void reset() {
-		SubstanceProgressBarUI.stripeMap.clear();
-	}
+	private static LazyResettableHashMap<BufferedImage> backgroundMap = new LazyResettableHashMap<BufferedImage>(
+			"SubstanceProgressBarUI.backgroundMap");
 
 	/**
 	 * The current state of the indeterminate animation's cycle. 0, the initial
@@ -98,10 +91,6 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	public static final FadeKind PROGRESS_BAR_VALUE_CHANGED = new FadeKind(
 			"substancelaf.progressBarValueChanged");
 
-	// static {
-	// FadeConfigurationManager.getInstance().allowFades(PROGRESS_BAR_VALUE_CHANGED);
-	// }
-
 	/**
 	 * Property name for storing the <code>from</code> value on progress bar
 	 * value animation. Is for internal use only.
@@ -109,8 +98,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	private static final String PROGRESS_BAR_FROM = "substancelaf.internal.from";
 
 	/**
-	 * Property name for storing the <code>to</code> value on progress bar
-	 * value animation. Is for internal use only.
+	 * Property name for storing the <code>to</code> value on progress bar value
+	 * animation. Is for internal use only.
 	 */
 	private static final String PROGRESS_BAR_TO = "substancelaf.internal.to";
 
@@ -119,7 +108,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceProgressBarUI();
 	}
 
@@ -166,7 +156,15 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 					}
 					progressBar.putClientProperty(PROGRESS_BAR_TO, progressBar
 							.getValue());
-					if (Math.abs(pixelDelta) > 5) {
+
+					// do not animate progress bars used in cell renderers
+					// since in this case it will most probably be the
+					// same progress bar used to display different
+					// values for different cells.
+					boolean isInCellRenderer = (SwingUtilities
+							.getAncestorOfClass(CellRendererPane.class,
+									progressBar) != null);
+					if (!isInCellRenderer && Math.abs(pixelDelta) > 5) {
 						FadeTracker.getInstance().trackFadeIn(
 								PROGRESS_BAR_VALUE_CHANGED, progressBar, false,
 								null);
@@ -201,10 +199,10 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 *            Color scheme to paint the stripe image.
 	 * @return Stripe image.
 	 */
-	private static synchronized BufferedImage getStripe(int baseSize,
-			boolean isRotated, ColorScheme colorScheme) {
-		String key = "" + baseSize + ":" + isRotated + ":"
-				+ SubstanceCoreUtilities.getSchemeId(colorScheme);
+	private static BufferedImage getStripe(int baseSize, boolean isRotated,
+			SubstanceColorScheme colorScheme) {
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(baseSize, isRotated,
+				colorScheme.getDisplayName());
 		BufferedImage result = SubstanceProgressBarUI.stripeMap.get(key);
 		if (result == null) {
 			result = SubstanceImageCreator.getStripe(baseSize, colorScheme
@@ -217,11 +215,58 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 		return result;
 	}
 
+	/**
+	 * Returns the background of a determinate progress bar.
+	 * 
+	 * @param width
+	 *            Progress bar width.
+	 * @param height
+	 *            Progress bar height.
+	 * @param scheme
+	 *            Color scheme for the background.
+	 * @param gp
+	 *            Gradient painter.
+	 * @param orientation
+	 *            Progress bar orientation (vertical / horizontal).
+	 * @param componentOrientation
+	 *            Progress bar LTR / RTL orientation.
+	 * @return Background image.
+	 */
+	private static BufferedImage getDeterminateBackground(JProgressBar bar,
+			int width, int height, SubstanceColorScheme scheme,
+			SubstanceGradientPainter gp, int orientation,
+			ComponentOrientation componentOrientation) {
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(width, height,
+				scheme.getDisplayName(), gp.getDisplayName(), orientation,
+				componentOrientation);
+		BufferedImage result = SubstanceProgressBarUI.backgroundMap.get(key);
+		if (result == null) {
+			result = SubstanceCoreUtilities.getBlankImage(width, height);
+			Graphics2D g2d = result.createGraphics();
+			Shape contour = SubstanceOutlineUtilities.getBaseOutline(width,
+					height, 0, null);
+			gp.paintContourBackground(g2d, bar, width, height, contour, false,
+					scheme, scheme, 0, true, false);
+			g2d.dispose();
+
+			if (orientation == SwingConstants.VERTICAL) {
+				if (componentOrientation.isLeftToRight())
+					result = SubstanceImageCreator.getRotated(result, 3);
+				else
+					result = SubstanceImageCreator.getRotated(result, 1);
+			}
+			SubstanceProgressBarUI.backgroundMap.put(key, result);
+		}
+		return result;
+
+	}
+
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicProgressBarUI#paintDeterminate(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicProgressBarUI#paintDeterminate(java.awt.Graphics
+	 * , javax.swing.JComponent)
 	 */
 	@Override
 	public void paintDeterminate(Graphics g, JComponent c) {
@@ -234,136 +279,123 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 		insets.left /= 2;
 		insets.bottom /= 2;
 		insets.right /= 2;
-		final int barRectWidth = progressBar.getWidth()
+		int barRectWidth = progressBar.getWidth()
 				- (insets.right + insets.left);
-		final int barRectHeight = progressBar.getHeight()
+		int barRectHeight = progressBar.getHeight()
 				- (insets.top + insets.bottom);
 
 		// amount of progress to draw
-		final int amountFull = getAmountFull(insets, barRectWidth,
-				barRectHeight);
-
-		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-			public void paintBackground(Graphics g) {
-				Graphics2D graphics = (Graphics2D) g.create();
-
-				SubstanceTheme bgTheme = SubstanceThemeUtilities
-						.getTheme(progressBar);
-				if (progressBar.isEnabled())
-					bgTheme = bgTheme.getDefaultTheme();
-				else
-					bgTheme = bgTheme.getDisabledTheme();
-
-				SubstanceGradientPainter gp = SubstanceCoreUtilities
-						.getGradientPainter(progressBar);
-				// background
-				if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
-					Shape contour = BaseButtonShaper.getBaseOutline(
-							barRectWidth + 1, barRectHeight + 1, 0, null);
-					BufferedImage bg = gp.getContourBackground(
-							barRectWidth + 1, barRectHeight + 1, contour,
-							false, bgTheme.getColorScheme(), bgTheme
-									.getColorScheme(), 0, true, false);
-					graphics.drawImage(bg, insets.left, insets.top, null);
-				} else { // VERTICAL
-					Shape contour = BaseButtonShaper.getBaseOutline(
-							barRectHeight + 1, barRectWidth + 1, 0, null);
-					BufferedImage bg = gp.getContourBackground(
-							barRectHeight + 1, barRectWidth + 1, contour,
-							false, bgTheme.getColorScheme(), bgTheme
-									.getColorScheme(), 0, true, false);
-					graphics.drawImage(SubstanceImageCreator.getRotated(bg, 3),
-							insets.left, insets.top, null);
-				}
-
-				if (amountFull > 0) {
-					float borderStrokeWidth = SubstanceSizeUtils
-							.getBorderStrokeWidth(SubstanceSizeUtils
-									.getComponentFontSize(progressBar));
-					SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
-							.getBorderPainter(null);
-					int borderDelta = (borderPainter instanceof InnerDelegateBorderPainter) ? (int) (Math
-							.ceil(2.0 * borderStrokeWidth)) / 2
-							: (int) (borderStrokeWidth / 2.0);
-
-					ColorScheme fillColorScheme = SubstanceThemeUtilities
-							.getTheme(
-									progressBar,
-									progressBar.isEnabled() ? ComponentState.SELECTED
-											: ComponentState.DISABLED_UNSELECTED)
-							.getColorScheme();
-					if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
-						int barWidth = amountFull - 2 * borderDelta;
-						int barHeight = barRectHeight - 2 * borderDelta;
-						if ((barWidth > 0) && (barHeight > 0)) {
-							if (progressBar.getComponentOrientation()
-									.isLeftToRight()) {
-								SubstanceImageCreator
-										.paintRectangularBackground(g,
-												insets.left + borderDelta,
-												insets.top + borderDelta,
-												barWidth, barHeight,
-												fillColorScheme, 0.6f, false);
-							} else {
-								// fix for RTL determinate horizontal progress
-								// bar in 2.3
-								SubstanceImageCreator
-										.paintRectangularBackground(g,
-												insets.left + barRectWidth
-														- amountFull - 2
-														* borderDelta,
-												insets.top + borderDelta,
-												barWidth, barHeight,
-												fillColorScheme, 0.6f, false);
-							}
-						}
-					} else { // VERTICAL
-						int barWidth = progressBar.getHeight() - insets.bottom
-								- amountFull - 2 * borderDelta;
-						int barHeight = barRectWidth - 2 * borderDelta;
-						if ((barWidth > 0) && (barHeight > 0)) {
-							// fix for issue 95. Vertical bar is growing from
-							// the bottom
-							SubstanceImageCreator.paintRectangularBackground(g,
-									insets.left + borderDelta, barWidth
-											+ borderDelta, barHeight,
-									amountFull, fillColorScheme, 0.6f, true);
-						}
-					}
-				}
-				graphics.dispose();
-			}
-		};
+		int amountFull = getAmountFull(insets, barRectWidth, barRectHeight);
 
 		Graphics2D g2d = (Graphics2D) g.create();
 		// install state-aware alpha channel (support for skins
 		// that use translucency on disabled states).
-		float themeAlpha = SubstanceThemeUtilities.getTheme(progressBar)
-				.getThemeAlpha(
-						progressBar,
-						progressBar.isEnabled() ? ComponentState.DEFAULT
-								: ComponentState.DISABLED_UNSELECTED);
+		float themeAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
+				progressBar.isEnabled() ? ComponentState.DEFAULT
+						: ComponentState.DISABLED_UNSELECTED);
 		g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
 				themeAlpha, g));
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(this.progressBar, null, true);
-		textPainter.setBackgroundFill(progressBar, progressBar.getParent()
-				.getBackground(), true, 0, 0);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(progressBar,
+						progressBar.isEnabled() ? ComponentState.DEFAULT
+								: ComponentState.DISABLED_UNSELECTED);
 
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.attachCallback(callback);
+		SubstanceGradientPainter gp = SubstanceCoreUtilities
+				.getGradientPainter(progressBar);
+		if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
+			BufferedImage back = getDeterminateBackground(progressBar,
+					barRectWidth + 1, barRectHeight + 1, scheme, gp,
+					progressBar.getOrientation(), this.progressBar
+							.getComponentOrientation());
+			g2d.drawImage(back, insets.left, insets.top, null);
 		} else {
-			callback.paintBackground(g2d);
+			BufferedImage back = getDeterminateBackground(progressBar,
+					barRectHeight + 1, barRectWidth + 1, scheme, gp,
+					progressBar.getOrientation(), this.progressBar
+							.getComponentOrientation());
+			g2d.drawImage(back, insets.left, insets.top, null);
+		}
+		// if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
+		// Shape contour = SubstanceOutlineUtilities.getBaseOutline(
+		// barRectWidth + 1, barRectHeight + 1, 0, null);
+		// gp.paintContourBackground(g2d, barRectWidth + 1, barRectHeight + 1,
+		// contour, false, scheme, scheme, 0, true, false);
+		// } else {
+		// Shape contour = SubstanceOutlineUtilities.getBaseOutline(
+		// barRectHeight + 1, barRectWidth + 1, 0, null);
+		//
+		// AffineTransform at = g2d.getTransform();
+		//
+		// AffineTransform rotated = new AffineTransform(at);
+		// if (this.progressBar.getComponentOrientation().isLeftToRight()) {
+		// rotated.translate(0, barRectHeight);
+		// rotated.rotate(-Math.PI / 2);
+		// } else {
+		// rotated.translate(barRectWidth, 0);
+		// rotated.rotate(Math.PI / 2);
+		// }
+		// g2d.setTransform(rotated);
+		// gp.paintContourBackground(g2d, barRectHeight + 1, barRectWidth + 1,
+		// contour, false, scheme, scheme, 0, true, false);
+		// g2d.setTransform(at);
+		// }
+		// g2d.translate(-insets.left, -insets.top);
+
+		if (amountFull > 0) {
+			float borderStrokeWidth = SubstanceSizeUtils
+					.getBorderStrokeWidth(SubstanceSizeUtils
+							.getComponentFontSize(progressBar));
+			SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
+					.getBorderPainter(null);
+			int borderDelta = (borderPainter instanceof InnerDelegateBorderPainter) ? (int) (Math
+					.ceil(2.0 * borderStrokeWidth)) / 2
+					: (int) (borderStrokeWidth / 2.0);
+
+			SubstanceColorScheme fillColorScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(progressBar,
+							progressBar.isEnabled() ? ComponentState.SELECTED
+									: ComponentState.DISABLED_UNSELECTED);
+			if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
+				int barWidth = amountFull - 2 * borderDelta;
+				int barHeight = barRectHeight - 2 * borderDelta;
+				if ((barWidth > 0) && (barHeight > 0)) {
+					if (progressBar.getComponentOrientation().isLeftToRight()) {
+						SubstanceImageCreator.paintRectangularBackground(g,
+								insets.left + borderDelta, insets.top
+										+ borderDelta, barWidth, barHeight,
+								fillColorScheme, 0.6f, false);
+					} else {
+						// fix for RTL determinate horizontal progress
+						// bar in 2.3
+						SubstanceImageCreator.paintRectangularBackground(g,
+								insets.left + barRectWidth - amountFull - 2
+										* borderDelta,
+								insets.top + borderDelta, barWidth, barHeight,
+								fillColorScheme, 0.6f, false);
+					}
+				}
+			} else { // VERTICAL
+				int barWidth = progressBar.getHeight() - insets.bottom
+						- amountFull - 2 * borderDelta;
+				int barHeight = barRectWidth - 2 * borderDelta;
+				if ((barWidth > 0) && (barHeight > 0)) {
+					// fix for issue 95. Vertical bar is growing from
+					// the bottom
+					SubstanceImageCreator.paintRectangularBackground(g,
+							insets.left + borderDelta, barWidth + borderDelta,
+							barHeight, amountFull, fillColorScheme, 0.6f, true);
+				}
+			}
 		}
 
 		// Deal with possible text painting
 		if (progressBar.isStringPainted()) {
+			g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
+					1.0f, g));
 			this.paintString(g2d, insets.left, insets.top, barRectWidth,
 					barRectHeight, amountFull, insets);
 		}
-		textPainter.renderSurface(g2d);
 		g2d.dispose();
 	}
 
@@ -374,18 +406,11 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 */
 	@Override
 	protected Color getSelectionBackground() {
-		ComponentState state = this.progressBar.isEnabled() ? ComponentState.DEFAULT
-				: ComponentState.DISABLED_UNSELECTED;
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(
-				this.progressBar, state);
-		return theme.getForegroundColor();
-		// SubstanceTheme bgTheme = SubstanceCoreUtilities.getTheme(progressBar,
-		// true, true);
-		// if (progressBar.isEnabled())
-		// bgTheme = bgTheme.getDefaultTheme();
-		// else
-		// bgTheme = bgTheme.getDisabledTheme();
-		// return bgTheme.getForegroundColor();
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(progressBar,
+						progressBar.isEnabled() ? ComponentState.DEFAULT
+								: ComponentState.DISABLED_UNSELECTED);
+		return SubstanceColorUtilities.getForegroundColor(scheme);
 	}
 
 	/*
@@ -395,23 +420,19 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 */
 	@Override
 	protected Color getSelectionForeground() {
-		ComponentState state = this.progressBar.isEnabled() ? ComponentState.ACTIVE
-				: ComponentState.DISABLED_UNSELECTED;
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(
-				this.progressBar, state);
-		return theme.getForegroundColor();
-		// ColorScheme fillColorScheme = progressBar.isEnabled() ?
-		// SubstanceCoreUtilities
-		// .getActiveScheme(progressBar)
-		// : SubstanceCoreUtilities.getDefaultScheme(progressBar);
-		// return fillColorScheme.getForegroundColor();
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(progressBar,
+						progressBar.isEnabled() ? ComponentState.SELECTED
+								: ComponentState.DISABLED_UNSELECTED);
+		return SubstanceColorUtilities.getForegroundColor(scheme);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicProgressBarUI#paintIndeterminate(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicProgressBarUI#paintIndeterminate(java.awt
+	 * .Graphics, javax.swing.JComponent)
 	 */
 	@Override
 	public void paintIndeterminate(Graphics g, JComponent c) {
@@ -425,64 +446,41 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 
 		final int valComplete = (int) animationIndex;
 
-		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-			public void paintBackground(Graphics g) {
-				Graphics2D graphics = (Graphics2D) g.create();
-
-				ColorScheme fillColorScheme = SubstanceThemeUtilities.getTheme(
-						progressBar,
-						progressBar.isEnabled() ? ComponentState.SELECTED
-								: ComponentState.DISABLED_UNSELECTED)
-						.getColorScheme();
-				if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
-					SubstanceImageCreator.paintRectangularStripedBackground(
-							graphics, b.left, b.top, barRectWidth,
-							barRectHeight, fillColorScheme,
-							SubstanceProgressBarUI.getStripe(barRectHeight,
-									false, fillColorScheme), valComplete, 0.6f,
-							false);
-				} else {
-					// fix for issue 95. Vertical progress bar grows from the
-					// bottom.
-					SubstanceImageCreator.paintRectangularStripedBackground(
-							graphics, b.left, b.top, barRectWidth,
-							barRectHeight, fillColorScheme,
-							SubstanceProgressBarUI.getStripe(barRectWidth,
-									true, fillColorScheme), 2 * barRectWidth
-									- valComplete, 0.6f, true);
-				}
-				graphics.dispose();
-			}
-		};
-
 		Graphics2D g2d = (Graphics2D) g.create();
 		// install state-aware alpha channel (support for skins
 		// that use translucency on disabled states).
-		float themeAlpha = SubstanceThemeUtilities.getTheme(progressBar)
-				.getThemeAlpha(
-						progressBar,
-						progressBar.isEnabled() ? ComponentState.DEFAULT
-								: ComponentState.DISABLED_UNSELECTED);
+		float themeAlpha = SubstanceColorSchemeUtilities.getAlpha(progressBar,
+				progressBar.isEnabled() ? ComponentState.SELECTED
+						: ComponentState.DISABLED_UNSELECTED);
 		g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
 				themeAlpha, g));
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(this.progressBar, null, true);
-		textPainter.setBackgroundFill(progressBar, progressBar.getParent()
-				.getBackground(), true, 0, 0);
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.attachCallback(callback);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(progressBar,
+						progressBar.isEnabled() ? ComponentState.SELECTED
+								: ComponentState.DISABLED_UNSELECTED);
+		if (progressBar.getOrientation() == SwingConstants.HORIZONTAL) {
+			SubstanceImageCreator.paintRectangularStripedBackground(g2d,
+					b.left, b.top, barRectWidth, barRectHeight, scheme,
+					SubstanceProgressBarUI.getStripe(barRectHeight, false,
+							scheme), valComplete, 0.6f, false);
 		} else {
-			callback.paintBackground(g2d);
+			// fix for issue 95. Vertical progress bar grows from the
+			// bottom.
+			SubstanceImageCreator.paintRectangularStripedBackground(g2d,
+					b.left, b.top, barRectWidth, barRectHeight, scheme,
+					SubstanceProgressBarUI
+							.getStripe(barRectWidth, true, scheme), 2
+							* barRectWidth - valComplete, 0.6f, true);
 		}
 
 		// Deal with possible text painting
 		if (progressBar.isStringPainted()) {
+			g2d.setComposite(TransitionLayout.getAlphaComposite(progressBar,
+					1.0f, g));
 			this.paintString(g2d, b.left, b.top, barRectWidth, barRectHeight,
 					barRectWidth, b);
 		}
-		textPainter.renderSurface(g2d);
 		g2d.dispose();
 	}
 
@@ -542,12 +540,12 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 		double currentValue = model.getValue();
 		FadeTracker fadeTracker = FadeTracker.getInstance();
 		if (fadeTracker.isTracked(progressBar, PROGRESS_BAR_VALUE_CHANGED)) {
-			double fade10 = fadeTracker.getFade10(progressBar,
+			double fade = fadeTracker.getFade(progressBar,
 					PROGRESS_BAR_VALUE_CHANGED);
 			int from = (Integer) progressBar
 					.getClientProperty(PROGRESS_BAR_FROM);
 			int to = (Integer) progressBar.getClientProperty(PROGRESS_BAR_TO);
-			currentValue = from + (fade10 * (to - from) / 10.0);
+			currentValue = from + (fade * (to - from));
 		}
 
 		double percentComplete = (currentValue - model.getMinimum()) / span;
@@ -565,7 +563,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicProgressBarUI#getPreferredInnerHorizontal()
+	 * @see
+	 * javax.swing.plaf.basic.BasicProgressBarUI#getPreferredInnerHorizontal()
 	 */
 	@Override
 	protected Dimension getPreferredInnerHorizontal() {
@@ -578,7 +577,8 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicProgressBarUI#getPreferredInnerVertical()
+	 * @see
+	 * javax.swing.plaf.basic.BasicProgressBarUI#getPreferredInnerVertical()
 	 */
 	@Override
 	protected Dimension getPreferredInnerVertical() {
@@ -595,21 +595,22 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 			if (progressBar.getComponentOrientation().isLeftToRight()) {
 				if (progressBar.isIndeterminate()) {
 					boxRect = getBox(boxRect);
-					paintString(x, y, width, height, boxRect.x, boxRect.width,
-							b);
+					paintString(g, x, y, width, height, boxRect.x,
+							boxRect.width, b);
 				} else {
-					paintString(x, y, width, height, x, amountFull, b);
+					paintString(g, x, y, width, height, x, amountFull, b);
 				}
 			} else {
-				paintString(x, y, width, height, x + width - amountFull,
+				paintString(g, x, y, width, height, x + width - amountFull,
 						amountFull, b);
 			}
 		} else {
 			if (progressBar.isIndeterminate()) {
 				boxRect = getBox(boxRect);
-				paintString(x, y, width, height, boxRect.y, boxRect.height, b);
+				paintString(g, x, y, width, height, boxRect.y, boxRect.height,
+						b);
 			} else {
-				paintString(x, y, width, height, y + height - amountFull,
+				paintString(g, x, y, width, height, y + height - amountFull,
 						amountFull, b);
 			}
 		}
@@ -637,33 +638,29 @@ public class SubstanceProgressBarUI extends BasicProgressBarUI {
 	 * @param b
 	 *            Insets of the progress bar.
 	 */
-	private void paintString(int x, int y, int width, int height,
+	private void paintString(Graphics g, int x, int y, int width, int height,
 			int fillStart, int amountFull, Insets b) {
 		String progressString = progressBar.getString();
 		Rectangle renderRectangle = getStringRectangle(progressString, x, y,
 				width, height);
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
 		if (progressBar.getOrientation() == JProgressBar.HORIZONTAL) {
-			textPainter.attachText(this.progressBar, renderRectangle,
-					progressString, -1, progressBar.getFont(),
+			SubstanceTextUtilities.paintText(g, this.progressBar,
+					renderRectangle, progressString, -1, progressBar.getFont(),
 					getSelectionBackground(), new Rectangle(amountFull, y,
 							progressBar.getWidth() - amountFull, height));
-
-			textPainter.attachText(this.progressBar, renderRectangle,
-					progressString, -1, progressBar.getFont(),
+			SubstanceTextUtilities.paintText(g, this.progressBar,
+					renderRectangle, progressString, -1, progressBar.getFont(),
 					getSelectionForeground(), new Rectangle(fillStart, y,
 							amountFull, height));
 		} else { // VERTICAL
-			textPainter.attachVerticalText(this.progressBar, renderRectangle,
-					progressString, -1, progressBar.getFont(),
+			SubstanceTextUtilities.paintVerticalText(g, this.progressBar,
+					renderRectangle, progressString, -1, progressBar.getFont(),
 					getSelectionBackground(), new Rectangle(x, y, width,
 							progressBar.getHeight() - amountFull), progressBar
 							.getComponentOrientation().isLeftToRight());
-
-			textPainter.attachVerticalText(this.progressBar, renderRectangle,
-					progressString, -1, progressBar.getFont(),
+			SubstanceTextUtilities.paintVerticalText(g, this.progressBar,
+					renderRectangle, progressString, -1, progressBar.getFont(),
 					getSelectionForeground(), new Rectangle(x, fillStart,
 							width, amountFull), progressBar
 							.getComponentOrientation().isLeftToRight());
