@@ -43,6 +43,7 @@ import org.jvnet.lafwidget.animation.FadeStateListener;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.RadioButtonMenuItemIcon;
 import org.jvnet.substance.utils.menu.MenuUtilities;
+import org.jvnet.substance.utils.menu.SubstanceMenu;
 import org.jvnet.substance.utils.menu.MenuUtilities.MenuPropertyListener;
 
 /**
@@ -78,8 +79,9 @@ public class SubstanceRadioButtonMenuItemUI extends BasicRadioButtonMenuItemUI
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		JRadioButtonMenuItem item = (JRadioButtonMenuItem) b;
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		JRadioButtonMenuItem item = (JRadioButtonMenuItem) comp;
 		item.setRolloverEnabled(true);
 
 		return new SubstanceRadioButtonMenuItemUI();
@@ -125,7 +127,9 @@ public class SubstanceRadioButtonMenuItemUI extends BasicRadioButtonMenuItemUI
 				if ("font".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							menuItem.updateUI();
+							if (menuItem != null) {
+								menuItem.updateUI();
+							}
 						}
 					});
 				}
@@ -225,8 +229,9 @@ public class SubstanceRadioButtonMenuItemUI extends BasicRadioButtonMenuItemUI
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax.swing.JComponent,
-	 *      javax.swing.Icon, javax.swing.Icon, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#getPreferredMenuItemSize(javax
+	 * .swing.JComponent, javax.swing.Icon, javax.swing.Icon, int)
 	 */
 	@Override
 	protected Dimension getPreferredMenuItemSize(JComponent c, Icon checkIcon,
@@ -241,7 +246,8 @@ public class SubstanceRadioButtonMenuItemUI extends BasicRadioButtonMenuItemUI
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.utils.Trackable#isInside(java.awt.event.MouseEvent)
+	 * @see
+	 * org.jvnet.substance.utils.Trackable#isInside(java.awt.event.MouseEvent)
 	 */
 	public boolean isInside(MouseEvent me) {
 		return this.menuItem.getBounds().contains(me.getX(), me.getY());
@@ -250,9 +256,10 @@ public class SubstanceRadioButtonMenuItemUI extends BasicRadioButtonMenuItemUI
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
-	 *      javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
-	 *      java.awt.Color, java.awt.Color, int)
+	 * @see
+	 * javax.swing.plaf.basic.BasicMenuItemUI#paintMenuItem(java.awt.Graphics,
+	 * javax.swing.JComponent, javax.swing.Icon, javax.swing.Icon,
+	 * java.awt.Color, java.awt.Color, int)
 	 */
 	@Override
 	protected void paintMenuItem(Graphics g, JComponent c, Icon checkIcon,
