@@ -32,8 +32,6 @@ package org.jvnet.substance;
 import java.awt.*;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.HashMap;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.border.Border;
@@ -44,8 +42,9 @@ import javax.swing.text.View;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -54,15 +53,6 @@ import org.jvnet.substance.utils.*;
  * @author Kirill Grouchnikov
  */
 public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
-	// /**
-	// * Default radio button dimension.
-	// */
-	// private static final int DIMENSION = 11;
-
-	/**
-	 * Background delegate.
-	 */
-	// private SubstanceFillBackgroundDelegate bgDelegate;
 	/**
 	 * Property change listener. Listens on changes to
 	 * {@link AbstractButton#MODEL_CHANGED_PROPERTY} property.
@@ -77,27 +67,19 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	/**
 	 * Icons for all component states
 	 */
-	private static Map<String, Icon> icons = new HashMap<String, Icon>();
+	private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+			"SubstanceRadioButtonUI");
 
 	/**
 	 * Listener for fade animations.
 	 */
 	protected FadeStateListener substanceFadeStateListener;
 
-	/**
-	 * Resets image maps (used when setting new theme).
-	 * 
-	 * @see SubstanceLookAndFeel#setCurrentTheme(String)
-	 * @see SubstanceLookAndFeel#setCurrentTheme(org.jvnet.substance.theme.SubstanceTheme)
-	 */
-	public static synchronized void reset() {
-		SubstanceRadioButtonUI.icons.clear();
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void installListeners(final AbstractButton b) {
@@ -128,7 +110,8 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 						// + b.getText()
 						// + "->"
 						// + b
-						// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL));
+						// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL
+						// ));
 					}
 				}
 				if ("font".equals(evt.getPropertyName())) {
@@ -146,7 +129,9 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicRadioButtonUI#installDefaults(javax.swing.AbstractButton)
+	 * @see
+	 * javax.swing.plaf.basic.BasicRadioButtonUI#installDefaults(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected void installDefaults(AbstractButton b) {
@@ -165,35 +150,8 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicRadioButtonUI#uninstallDefaults(javax.swing.AbstractButton)
-	 */
-	@Override
-	protected void uninstallDefaults(AbstractButton b) {
-		super.uninstallDefaults(b);
-
-		// b.setOpaque((Boolean) b
-		// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL));
-		// b.putClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL, null);
-	}
-
-	@Override
-	public void installUI(JComponent c) {
-		// c.putClientProperty(SubstanceButtonUI.LOCK_OPACITY, null);
-		super.installUI(c);
-	}
-
-	@Override
-	public void uninstallUI(JComponent c) {
-		// c.setOpaque((Boolean) c
-		// .getClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL));
-		// c.putClientProperty(SubstanceButtonUI.OPACITY_ORIGINAL, null);
-		super.uninstallUI(c);
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void uninstallListeners(AbstractButton b) {
@@ -218,16 +176,14 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	 *            Previous state of the checkbox.
 	 * @return Matching icon.
 	 */
-	private static synchronized Icon getIcon(JToggleButton button,
-			ComponentState currState, ComponentState prevState) {
-		// check if fading
-		// FadeTracker fadeTracker = FadeTracker.getInstance();
+	private static Icon getIcon(JToggleButton button, ComponentState currState,
+			ComponentState prevState) {
 		float visibility = currState.isKindActive(FadeKind.SELECTION) ? 10 : 0;
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(button,
-				currState);
-		SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(button,
-				prevState);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(button, currState);
+		SubstanceColorScheme scheme2 = SubstanceColorSchemeUtilities
+				.getColorScheme(button, prevState);
 		float cyclePos = 0;
 
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(button,
@@ -235,28 +191,25 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 		if (fadeState != null) {
 			cyclePos = fadeState.getFadePosition();
 			if (fadeState.isFadingIn())
-				cyclePos = 10 - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 			if (fadeState.fadeKind == FadeKind.SELECTION) {
 				visibility = fadeState.getFadePosition();
 			}
 		}
 
-		int checkMarkSize = // SubstanceSizeUtils
-		// .getRadioButtonMarkSize(SubstanceSizeUtils.getControlFontSize());
-		// if (!(button.getFont() instanceof UIResource))
-		// checkMarkSize =
-		SubstanceSizeUtils.getRadioButtonMarkSize(SubstanceSizeUtils
-				.getComponentFontSize(button));
-		String key = checkMarkSize + ":" + currState.name() + ":"
-				+ currState.name() + ":" + theme.getDisplayName() + ":"
-				+ theme2.getDisplayName() + ":" + cyclePos + ":" + visibility;
+		int checkMarkSize = SubstanceSizeUtils
+				.getRadioButtonMarkSize(SubstanceSizeUtils
+						.getComponentFontSize(button));
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(checkMarkSize,
+				currState.name(), currState.name(), scheme.getDisplayName(),
+				scheme2.getDisplayName(), cyclePos, visibility);
 
 		Icon result = SubstanceRadioButtonUI.icons.get(key);
 		if (result != null)
 			return result;
 		result = new ImageIcon(SubstanceImageCreator.getRadioButton(button,
-				checkMarkSize, currState, 0, theme, theme2, cyclePos,
-				visibility / 10.f));
+				checkMarkSize, currState, prevState, 0, scheme, scheme2,
+				cyclePos, visibility / 10.f));
 		SubstanceRadioButtonUI.icons.put(key, result);
 		return result;
 	}
@@ -266,8 +219,9 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		return new SubstanceRadioButtonUI((JToggleButton) b);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceRadioButtonUI((JToggleButton) comp);
 	}
 
 	/**
@@ -277,21 +231,20 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	 *            Associated radio button.
 	 */
 	public SubstanceRadioButtonUI(JToggleButton button) {
-		// bgDelegate = new SubstanceFillBackgroundDelegate();
 		this.button = button;
 		button.setRolloverEnabled(true);
-		// button.setOpaque(false);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing.AbstractButton)
+	 * @see
+	 * javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected BasicButtonListener createButtonListener(AbstractButton b) {
 		return new RolloverButtonListener(b);
-		// return RolloverButtonListener.getListener(b);
 	}
 
 	/*
@@ -301,8 +254,7 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	 */
 	@Override
 	public Icon getDefaultIcon() {
-		ButtonModel model = button.getModel();
-		ComponentState currState = ComponentState.getState(model, button);
+		ComponentState currState = ComponentState.getState(button);
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevComponentState(button);
 		return SubstanceRadioButtonUI.getIcon(button, currState, prevState);
@@ -324,18 +276,6 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 
 		b.putClientProperty(SubstanceButtonUI.LOCK_OPACITY, null);
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		// if (!(b instanceof
-		// SubstanceDefaultTableCellRenderer.BooleanRenderer)) {
-		textPainter.init(b, null, true);
-		// }
-		if (textPainter.needsBackgroundImage()) {
-			boolean hasColorization = SubstanceCoreUtilities.hasColorization(c);
-			textPainter.setBackgroundFill(b, hasColorization ? b.getParent()
-					.getBackground() : b.getBackground(), true, 0, 0);
-		}
-
 		FontMetrics fm = g.getFontMetrics();
 
 		Insets i = b.getInsets();
@@ -365,28 +305,15 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 						.getHorizontalTextPosition(), viewRect, iconRect,
 				textRect, b.getText() == null ? 0 : b.getIconTextGap());
 
-		float textAlpha = 1.0f;
+		Graphics2D g2d = (Graphics2D) g.create();
 		if (text != null && !text.equals("")) {
 			final View v = (View) b.getClientProperty(BasicHTML.propertyKey);
 			if (v != null) {
-				if (textPainter.needsBackgroundImage()) {
-					textPainter
-							.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-								public void paintBackground(Graphics g) {
-									v.paint(g, textRect);
-								}
-							});
-				} else {
-					v.paint(g, textRect);
-				}
+				v.paint(g2d, textRect);
 			} else {
-				textAlpha = this.paintButtonText(g, b, textRect, text);
+				this.paintButtonText(g2d, b, textRect, text);
 			}
 		}
-		Graphics2D g2d = (Graphics2D) g.create();
-		g2d.setComposite(TransitionLayout.getAlphaComposite(button, textAlpha,
-				g));
-		textPainter.renderSurface(g2d);
 
 		// Paint the Icon
 		if (icon != null) {
@@ -414,105 +341,6 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 		g2d.dispose();
 	}
 
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
-	// * javax.swing.JComponent)
-	// */
-	// @Override
-	// public void update(Graphics g, JComponent c) {
-	// // failsafe for LAF change
-	// if (!(UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel))
-	// return;
-	// boolean isOpaque = c.isOpaque();
-	// c.putClientProperty(SubstanceButtonUI.LOCK_OPACITY, Boolean.TRUE);
-	// c.setOpaque(false);
-	//
-	// if (isOpaque || TransitionLayout.isOpaque(c)) {
-	// bgDelegate.update(g, c);
-	// }
-	// super.paint(g, c);
-	//
-	// c.setOpaque(isOpaque);
-	//
-	// c.putClientProperty(SubstanceButtonUI.LOCK_OPACITY, null);
-	//
-	// // Some ugly hack to allow fade-out of focus ring. The code
-	// // in BasicRadioButtonUI doesn't call paintFocus() at all
-	// // when the component is not focus owner.
-	// AbstractButton b = (AbstractButton) c;
-	// if (!b.isFocusPainted())
-	// return;
-	//
-	// FontMetrics fm = c.getFontMetrics(c.getFont());
-	//
-	// Insets i = c.getInsets();
-	// Dimension size = new Dimension();
-	// Rectangle viewRect = new Rectangle();
-	// Rectangle iconRect = new Rectangle();
-	// Rectangle textRect = new Rectangle();
-	//
-	// size = b.getSize(size);
-	// viewRect.x = i.left;
-	// viewRect.y = i.top;
-	// viewRect.width = size.width - (i.right + viewRect.x);
-	// viewRect.height = size.height - (i.bottom + viewRect.y);
-	// iconRect.x = iconRect.y = iconRect.width = iconRect.height = 0;
-	// textRect.x = textRect.y = textRect.width = textRect.height = 0;
-	//
-	// Icon altIcon = b.getIcon();
-	//
-	// String text = SwingUtilities.layoutCompoundLabel(c, fm, b.getText(),
-	// altIcon != null ? altIcon : getDefaultIcon(), b
-	// .getVerticalAlignment(), b.getHorizontalAlignment(), b
-	// .getVerticalTextPosition(), b
-	// .getHorizontalTextPosition(), viewRect, iconRect,
-	// textRect, b.getText() == null ? 0 : b.getIconTextGap());
-	//
-	// if ((text != null) && (textRect.width > 0) && (textRect.height > 0)) {
-	// if (!(b.hasFocus() && b.isFocusPainted())) {
-	// if (FadeTracker.getInstance().isTracked(c, FadeKind.FOCUS))
-	// this.paintFocus(g, textRect, size);
-	// }
-	// }
-	// }
-
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see
-	// javax.swing.plaf.basic.BasicRadioButtonUI#paintFocus(java.awt.Graphics,
-	// * java.awt.Rectangle, java.awt.Dimension)
-	// */
-	// @Override
-	// protected void paintFocus(Graphics g, Rectangle t, Dimension d) {
-	// // System.out.println(button.getText() + " -> focus");
-	// SubstanceCoreUtilities.paintFocus(g, button, button, null, t, 1.0f, 1);
-	// // FadeTracker fadeTracker = FadeTracker.getInstance();
-	// // FocusKind focusKind =
-	// // SubstanceCoreUtilities.getFocusKind(this.button);
-	// // if ((focusKind == FocusKind.NONE)
-	// // && (!fadeTracker.isTracked(this.button, FadeKind.FOCUS)))
-	// // return;
-	// // Graphics2D graphics = (Graphics2D) g.create();
-	// // graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
-	// // RenderingHints.VALUE_ANTIALIAS_ON);
-	// //
-	// // float alpha = 1.0f;
-	// // if (fadeTracker.isTracked(this.button, FadeKind.FOCUS)) {
-	// // alpha = fadeTracker.getFade10(this.button, FadeKind.FOCUS) / 10.f;
-	// // }
-	// // // System.out.println(button.getText() + " -> " + alpha);
-	// // graphics.setComposite(TransitionLayout.getAlphaComposite(this.button,
-	// // alpha));
-	// //
-	// // Color color = SubstanceColorUtilities.getFocusColor(this.button);
-	// // graphics.setColor(color);
-	// // focusKind.paintFocus(this.button, graphics, t);
-	// // graphics.dispose();
-	// }
-
 	/**
 	 * Returns memory usage string.
 	 * 
@@ -536,11 +364,10 @@ public class SubstanceRadioButtonUI extends BasicRadioButtonUI {
 	 *            Text rectangle
 	 * @param text
 	 *            Text to paint
-	 * @return Text alpha channel.
 	 */
-	protected float paintButtonText(Graphics g, AbstractButton button,
+	protected void paintButtonText(Graphics g, AbstractButton button,
 			Rectangle textRect, String text) {
-		return SubstanceCoreUtilities.paintText(button, textRect, text, button
+		SubstanceTextUtilities.paintText(g, button, textRect, text, button
 				.getDisplayedMnemonicIndex());
 	}
 }
