@@ -32,7 +32,6 @@ package org.jvnet.substance;
 import java.awt.*;
 import java.awt.event.*;
 import java.beans.PropertyChangeEvent;
-import java.lang.reflect.Method;
 import java.security.*;
 
 import javax.swing.*;
@@ -84,8 +83,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	private MouseInputListener substanceTitleMouseInputListener;
 
 	/**
-	 * The <code>LayoutManager</code> that is set on the
-	 * <code>JRootPane</code>.
+	 * The <code>LayoutManager</code> that is set on the <code>JRootPane</code>.
 	 */
 	private LayoutManager layoutManager;
 
@@ -135,46 +133,27 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	private Cursor lastCursor = Cursor
 			.getPredefinedCursor(Cursor.DEFAULT_CURSOR);
 
-	/**
-	 * Stores the pointer to {@link MouseInfo#getLocationOnScreen()} method
-	 * (available only under JDK 6.0). Is used to provide fix for defect 198.
-	 */
-	protected static Method getLocationOnScreenMethod;
-
-	static {
-		try {
-			getLocationOnScreenMethod = MouseEvent.class.getDeclaredMethod(
-					"getLocationOnScreen", new Class[0]);
-		} catch (Exception e) {
-			// running under JDK 5.0 or sandbox
-			getLocationOnScreenMethod = null;
-		}
-	}
-
 	/**
 	 * Creates a UI for a <code>JRootPane</code>.
 	 * 
-	 * @param c
+	 * @param comp
 	 *            the JRootPane the RootPaneUI will be created for
 	 * @return the RootPaneUI implementation for the passed in JRootPane
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceRootPaneUI();
 	}
 
-	public SubstanceRootPaneUI() {
-	}
-
 	/**
 	 * Invokes supers implementation of <code>installUI</code> to install the
 	 * necessary state onto the passed in <code>JRootPane</code> to render the
 	 * metal look and feel implementation of <code>RootPaneUI</code>. If the
-	 * <code>windowDecorationStyle</code> property of the
-	 * <code>JRootPane</code> is other than <code>JRootPane.NONE</code>,
-	 * this will add a custom <code>Component</code> to render the widgets to
-	 * <code>JRootPane</code>, as well as installing a custom
-	 * <code>Border</code> and <code>LayoutManager</code> on the
-	 * <code>JRootPane</code>.
+	 * <code>windowDecorationStyle</code> property of the <code>JRootPane</code>
+	 * is other than <code>JRootPane.NONE</code>, this will add a custom
+	 * <code>Component</code> to render the widgets to <code>JRootPane</code>,
+	 * as well as installing a custom <code>Border</code> and
+	 * <code>LayoutManager</code> on the <code>JRootPane</code>.
 	 * 
 	 * @param c
 	 *            the JRootPane to install state onto
@@ -193,11 +172,11 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	/**
 	 * Invokes supers implementation to uninstall any of its state. This will
 	 * also reset the <code>LayoutManager</code> of the <code>JRootPane</code>.
-	 * If a <code>Component</code> has been added to the
-	 * <code>JRootPane</code> to render the window decoration style, this
-	 * method will remove it. Similarly, this will revert the Border and
-	 * LayoutManager of the <code>JRootPane</code> to what it was before
-	 * <code>installUI</code> was invoked.
+	 * If a <code>Component</code> has been added to the <code>JRootPane</code>
+	 * to render the window decoration style, this method will remove it.
+	 * Similarly, this will revert the Border and LayoutManager of the
+	 * <code>JRootPane</code> to what it was before <code>installUI</code> was
+	 * invoked.
 	 * 
 	 * @param c
 	 *            the JRootPane to uninstall state from
@@ -405,7 +384,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 										if (frame.isDisplayable())
 											return;
 									}
-									SubstanceLookAndFeel.stopThreads();
+									SubstanceCoreUtilities.stopThreads();
 								}
 							});
 						}
@@ -497,7 +476,9 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicRootPaneUI#uninstallListeners(javax.swing.JRootPane)
+	 * @see
+	 * javax.swing.plaf.basic.BasicRootPaneUI#uninstallListeners(javax.swing
+	 * .JRootPane)
 	 */
 	@Override
 	protected void uninstallListeners(JRootPane root) {
@@ -592,7 +573,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	 *            Root pane.
 	 * @return The title pane component.
 	 */
-	private JComponent createTitlePane(JRootPane root) {
+	protected JComponent createTitlePane(JRootPane root) {
 		return new SubstanceTitlePane(root, this);
 	}
 
@@ -628,8 +609,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	 * @param root
 	 *            Root pane
 	 * @param titlePane
-	 *            The <code>JComponent</code> to use for the window title
-	 *            pane.
+	 *            The <code>JComponent</code> to use for the window title pane.
 	 */
 	private void setTitlePane(JRootPane root, JComponent titlePane) {
 		JLayeredPane layeredPane = root.getLayeredPane();
@@ -695,8 +675,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	}
 
 	/**
-	 * Returns the <code>JRootPane</code> we're providing the look and feel
-	 * for.
+	 * Returns the <code>JRootPane</code> we're providing the look and feel for.
 	 * 
 	 * @return The associated root pane.
 	 */
@@ -707,7 +686,8 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicRootPaneUI#propertyChange(java.beans.PropertyChangeEvent)
+	 * @seejavax.swing.plaf.basic.BasicRootPaneUI#propertyChange(java.beans.
+	 * PropertyChangeEvent)
 	 */
 	@Override
 	public void propertyChange(PropertyChangeEvent e) {
@@ -762,7 +742,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 			int mbWidth = 0;
 			int mbHeight = 0;
 			int tpWidth = 0;
-			// int tpHeight = 0;
+			int tpHeight = 0;
 			Insets i = parent.getInsets();
 			JRootPane root = (JRootPane) parent;
 
@@ -792,13 +772,13 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 					tpd = titlePane.getPreferredSize();
 					if (tpd != null) {
 						tpWidth = tpd.width;
-						// tpHeight = tpd.height;
+						tpHeight = tpd.height;
 					}
 				}
 			}
 
 			return new Dimension(Math.max(Math.max(cpWidth, mbWidth), tpWidth)
-					+ i.left + i.right, cpHeight + mbHeight + tpWidth + i.top
+					+ i.left + i.right, cpHeight + mbHeight + tpHeight + i.top
 					+ i.bottom);
 		}
 
@@ -817,7 +797,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 			int mbWidth = 0;
 			int mbHeight = 0;
 			int tpWidth = 0;
-			// int tpHeight = 0;
+			int tpHeight = 0;
 			Insets i = parent.getInsets();
 			JRootPane root = (JRootPane) parent;
 
@@ -846,13 +826,13 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 					tpd = titlePane.getMinimumSize();
 					if (tpd != null) {
 						tpWidth = tpd.width;
-						// tpHeight = tpd.height;
+						tpHeight = tpd.height;
 					}
 				}
 			}
 
 			return new Dimension(Math.max(Math.max(cpWidth, mbWidth), tpWidth)
-					+ i.left + i.right, cpHeight + mbHeight + tpWidth + i.top
+					+ i.left + i.right, cpHeight + mbHeight + tpHeight + i.top
 					+ i.bottom);
 		}
 
@@ -1045,6 +1025,7 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 		 * PrivilegedExceptionAction needed by mouseDragged method to obtain new
 		 * location of window on screen during the drag.
 		 */
+		@SuppressWarnings("unchecked")
 		private final PrivilegedExceptionAction getLocationAction = new PrivilegedExceptionAction() {
 			public Object run() throws HeadlessException {
 				return MouseInfo.getPointerInfo().getLocation();
@@ -1422,16 +1403,8 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 			// Point pt = SwingUtilities.convertPoint(source, ev.getPoint(),
 			// SubstanceRootPaneUI.this.window);
 
-			Point eventLocationOnScreen = null;
-			if (getLocationOnScreenMethod != null) {
-				try {
-					// fix for issue 198 - only available under JDK 6.0+
-					eventLocationOnScreen = (Point) getLocationOnScreenMethod
-							.invoke(ev, new Object[0]);
-				} catch (Exception exc) {
-					eventLocationOnScreen = null;
-				}
-			}
+			// fix for issue 198
+			Point eventLocationOnScreen = ev.getLocationOnScreen();
 			if (eventLocationOnScreen == null) {
 				eventLocationOnScreen = new Point(ev.getX()
 						+ source.getLocationOnScreen().x, ev.getY()
@@ -1490,20 +1463,21 @@ public class SubstanceRootPaneUI extends BasicRootPaneUI {
 		}
 	}
 
-	/**
-	 * Makes the heap status panel appear / disappear permanently on the
-	 * associated title pane and removes the corresponding check box menu items
-	 * from the system menu.
-	 * 
-	 * @param isVisible
-	 *            if <code>true</code>, the heap status panel will be
-	 *            permanently shown, if <code>false</code>, the heap status
-	 *            panel will be permanently hidden.
-	 */
-	public void setHeapStatusPanePermanentVisibility(boolean isVisible) {
-		if (this.titlePane instanceof SubstanceTitlePane) {
-			((SubstanceTitlePane) this.titlePane)
-					.setHeapStatusPanePermanentVisibility(isVisible);
-		}
-	}
+	// /**
+	// * Makes the heap status panel appear / disappear permanently on the
+	// * associated title pane and removes the corresponding check box menu
+	// items
+	// * from the system menu.
+	// *
+	// * @param isVisible
+	// * if <code>true</code>, the heap status panel will be
+	// * permanently shown, if <code>false</code>, the heap status
+	// * panel will be permanently hidden.
+	// */
+	// public void setHeapStatusPanePermanentVisibility(boolean isVisible) {
+	// if (this.titlePane instanceof SubstanceTitlePane) {
+	// ((SubstanceTitlePane) this.titlePane)
+	// .setHeapStatusPanePermanentVisibility(isVisible);
+	// }
+	// }
 }
