@@ -31,17 +31,16 @@ package org.jvnet.substance;
 
 import java.awt.*;
 import java.awt.event.*;
-import java.awt.geom.Area;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.*;
+import java.util.HashSet;
+import java.util.Set;
 
 import javax.swing.*;
 import javax.swing.border.Border;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
-import javax.swing.plaf.ComponentUI;
-import javax.swing.plaf.UIResource;
+import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicScrollPaneUI;
 import javax.swing.table.JTableHeader;
 
@@ -50,9 +49,10 @@ import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionBorder;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.utils.LafConstants;
-import org.jvnet.substance.scroll.SubstanceScrollPaneBorder;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
 import org.jvnet.substance.utils.SubstanceSizeUtils;
+import org.jvnet.substance.utils.scroll.SubstanceScrollPaneBorder;
 
 /**
  * UI for scroll panes in <b>Substance</b> look and feel.
@@ -87,23 +87,26 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	/**
 	 * Creates new UI delegate.
 	 * 
-	 * @param c
+	 * @param comp
 	 *            Component.
 	 * @return UI delegate for the component.
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceScrollPaneUI();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicScrollPaneUI#installDefaults(javax.swing.JScrollPane)
+	 * @see
+	 * javax.swing.plaf.basic.BasicScrollPaneUI#installDefaults(javax.swing.
+	 * JScrollPane)
 	 */
 	@Override
 	protected void installDefaults(final JScrollPane scrollpane) {
 		super.installDefaults(scrollpane);
-		if (SubstanceCoreUtilities.toBleedWatermark(scrollpane)) {
+		if (SubstanceCoreUtilities.toDrawWatermark(scrollpane)) {
 			scrollpane.setOpaque(false);
 			scrollpane.getViewport().setOpaque(false);
 		}
@@ -112,6 +115,7 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
+				// System.out.println("Installing");
 				installTableHeaderCornerFiller(scrollpane);
 			}
 		});
@@ -120,7 +124,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicScrollPaneUI#uninstallDefaults(javax.swing.JScrollPane)
+	 * @see
+	 * javax.swing.plaf.basic.BasicScrollPaneUI#uninstallDefaults(javax.swing
+	 * .JScrollPane)
 	 */
 	@Override
 	protected void uninstallDefaults(JScrollPane c) {
@@ -144,7 +150,8 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	// * (non-Javadoc)
 	// *
 	// * @see
-	// javax.swing.plaf.basic.BasicScrollPaneUI#uninstallDefaults(javax.swing.JScrollPane)
+	// javax.swing.plaf.basic.BasicScrollPaneUI#uninstallDefaults(javax.swing.
+	// JScrollPane)
 	// */
 	// @Override
 	// protected void uninstallDefaults(JScrollPane c) {
@@ -155,7 +162,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicScrollPaneUI#installListeners(javax.swing.JScrollPane)
+	 * @see
+	 * javax.swing.plaf.basic.BasicScrollPaneUI#installListeners(javax.swing
+	 * .JScrollPane)
 	 */
 	@Override
 	protected void installListeners(final JScrollPane c) {
@@ -171,10 +180,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 						}
 					});
 				}
-				if (SubstanceLookAndFeel.WATERMARK_TO_BLEED.equals(evt
+				if (SubstanceLookAndFeel.WATERMARK_VISIBLE.equals(evt
 						.getPropertyName())) {
-					boolean toBleed = SubstanceCoreUtilities
-							.toBleedWatermark(c);
+					boolean toBleed = SubstanceCoreUtilities.toDrawWatermark(c);
 					c.setOpaque(!toBleed);
 					c.getViewport().setOpaque(!toBleed);
 					Component view = c.getViewport().getView();
@@ -218,22 +226,13 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 						}
 					}
 				}
-				if ("columnHeader".equals(evt.getPropertyName())) {
+				if ("columnHeader".equals(evt.getPropertyName())
+						|| "componentOrientation".equals(evt.getPropertyName())
+						|| "ancestor".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
 							// need to switch the corner filler based on the
-							// header
-							if (scrollpane != null) {
-								installTableHeaderCornerFiller(scrollpane);
-							}
-						}
-					});
-				}
-				if ("componentOrientation".equals(evt.getPropertyName())) {
-					SwingUtilities.invokeLater(new Runnable() {
-						public void run() {
-							// need to switch the corner filler based on the
-							// component orientation
+							// current scroll pane state.
 							if (scrollpane != null) {
 								installTableHeaderCornerFiller(scrollpane);
 							}
@@ -269,7 +268,7 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 						final int finalDelta = delta;
 						if (Math.abs(finalDelta) > viewportRect.width / 6) {
 							// System.err.println("Median : " + medianX);
-							FadeTrackerCallback callback = new EDTFadeTrackerAdapter() {
+							FadeTrackerCallback callback = new UIThreadFadeTrackerAdapter() {
 								@Override
 								public void fadeEnded(FadeKind fadeKind) {
 									// nothing to do here - the scroll has been
@@ -278,10 +277,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 
 								@Override
 								public void fadePerformed(FadeKind fadeKind,
-										float fadeCycle10) {
-									if (fadeCycle10 >= 5.0) {
-										int nudge = (int) (finalDelta
-												* (fadeCycle10 - 5.0) / 5.0);
+										float fadeCycle) {
+									if (fadeCycle >= 0.5) {
+										int nudge = (int) (finalDelta * (fadeCycle - 0.5));
 										c
 												.getViewport()
 												.setViewPosition(
@@ -293,15 +291,10 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 									// System.out.println(fadeCycle10);
 								}
 							};
-							// synchronized (SubstanceScrollPaneUI.this) {
 							if (horScrollId >= 0) {
 								// cancel previous horizontal scroll
-								// synchronized (SubstanceScrollPaneUI.this) {
-								// System.err.println("Cancelling " +
-								// horScrollId);
 								FadeTracker.getInstance().cancelFadeInstance(
 										horScrollId);
-								// }
 							}
 							final FadeStep delegate = LafWidgetUtilities
 									.getAnimationKind(tree).getStep();
@@ -352,7 +345,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicScrollPaneUI#uninstallListeners(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicScrollPaneUI#uninstallListeners(javax.swing
+	 * .JComponent)
 	 */
 	@Override
 	protected void uninstallListeners(JComponent c) {
@@ -386,7 +381,9 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see java.awt.event.MouseWheelListener#mouseWheelMoved(java.awt.event.MouseWheelEvent)
+		 * @see
+		 * java.awt.event.MouseWheelListener#mouseWheelMoved(java.awt.event.
+		 * MouseWheelEvent)
 		 */
 		public void mouseWheelMoved(java.awt.event.MouseWheelEvent e) {
 			if (SubstanceScrollPaneUI.this.scrollpane.isWheelScrollingEnabled()
@@ -658,39 +655,40 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
 		bgDelegate.updateIfOpaque(g, c);
 		JScrollPane jsp = (JScrollPane) c;
-		if (SubstanceCoreUtilities.hasOverlayProperty(jsp)) {
-			JViewport viewport = jsp.getViewport();
-			int dx = -viewport.getX() + viewport.getViewRect().x;
-			int dy = viewport.getY() - viewport.getViewRect().y;
-			Graphics2D graphics = (Graphics2D) g.create();
-
-			Area clip = new Area();
-			if ((jsp.getVerticalScrollBar() != null)
-					&& jsp.getVerticalScrollBar().isVisible())
-				clip.add(new Area(jsp.getVerticalScrollBar().getBounds()));
-			if ((jsp.getHorizontalScrollBar() != null)
-					&& jsp.getHorizontalScrollBar().isVisible())
-				clip.add(new Area(jsp.getHorizontalScrollBar().getBounds()));
-			graphics.setClip(clip);
-
-			graphics.translate(-dx, dy);
-			JComponent view = (JComponent) viewport.getView();
-			// fix for defect 201 - set non-double buffer for the viewport
-			// recursively. Takes care of desktop pane wrapped in scroll pane.
-			Map<Component, Boolean> dbSnapshot = new HashMap<Component, Boolean>();
-			SubstanceCoreUtilities.makeNonDoubleBuffered(view, dbSnapshot);
-			view.paint(graphics);
-			// restore the double buffer.
-			SubstanceCoreUtilities.restoreDoubleBuffered(view, dbSnapshot);
-			graphics.translate(dx, -dy);
-			graphics.dispose();
-		}
+		// if (SubstanceCoreUtilities.hasOverlayProperty(jsp)) {
+		// JViewport viewport = jsp.getViewport();
+		// int dx = -viewport.getX() + viewport.getViewRect().x;
+		// int dy = viewport.getY() - viewport.getViewRect().y;
+		// Graphics2D graphics = (Graphics2D) g.create();
+		//
+		// Area clip = new Area();
+		// if ((jsp.getVerticalScrollBar() != null)
+		// && jsp.getVerticalScrollBar().isVisible())
+		// clip.add(new Area(jsp.getVerticalScrollBar().getBounds()));
+		// if ((jsp.getHorizontalScrollBar() != null)
+		// && jsp.getHorizontalScrollBar().isVisible())
+		// clip.add(new Area(jsp.getHorizontalScrollBar().getBounds()));
+		// graphics.setClip(clip);
+		//
+		// graphics.translate(-dx, dy);
+		// JComponent view = (JComponent) viewport.getView();
+		// // fix for defect 201 - set non-double buffer for the viewport
+		// // recursively. Takes care of desktop pane wrapped in scroll pane.
+		// Map<Component, Boolean> dbSnapshot = new HashMap<Component,
+		// Boolean>();
+		// SubstanceCoreUtilities.makeNonDoubleBuffered(view, dbSnapshot);
+		// view.paint(graphics);
+		// // restore the double buffer.
+		// SubstanceCoreUtilities.restoreDoubleBuffered(view, dbSnapshot);
+		// graphics.translate(dx, -dy);
+		// graphics.dispose();
+		// }
 
 		LayoutManager lm = jsp.getLayout();
 		ScrollPaneLayout scrollLm = null;
@@ -735,21 +733,31 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 		super.paint(g, c);
 	}
 
+	/**
+	 * Installs a corner filler that matches the table header. This is done to
+	 * provide a continuous appearance for tables with table headers placed in
+	 * scroll panes.
+	 * 
+	 * @param scrollpane
+	 *            Scroll pane.
+	 */
 	protected static void installTableHeaderCornerFiller(JScrollPane scrollpane) {
 		// install custom scroll pane corner filler
 		// for continuous painting of table headers
 		JViewport columnHeader = scrollpane.getColumnHeader();
+		// System.out.println("Column header " + columnHeader);
 		if (columnHeader == null)
 			return;
 		Component columnHeaderComp = columnHeader.getView();
+		// System.out.println("Column header comp " + columnHeaderComp);
 		if (!(columnHeaderComp instanceof JTableHeader))
 			return;
 		JTableHeader tableHeader = (JTableHeader) columnHeaderComp;
-		SubstanceTableHeaderUI ui = (SubstanceTableHeaderUI) tableHeader
-				.getUI();
+		TableHeaderUI tableHeaderUI = tableHeader.getUI();
+		if (!(tableHeaderUI instanceof SubstanceTableHeaderUI))
+			return;
+		SubstanceTableHeaderUI ui = (SubstanceTableHeaderUI) tableHeaderUI;
 		JComponent scrollPaneCornerFiller = ui.getScrollPaneCornerFiller();
-		// System.err.println("Installed " + scrollPaneCornerFiller.hashCode()
-		// + " on " + scrollpane.hashCode());
 		String cornerKey = scrollpane.getComponentOrientation().isLeftToRight() ? JScrollPane.UPPER_RIGHT_CORNER
 				: JScrollPane.UPPER_LEFT_CORNER;
 		Component cornerComp = scrollpane.getCorner(cornerKey);
@@ -757,16 +765,7 @@ public class SubstanceScrollPaneUI extends BasicScrollPaneUI {
 		// UIResource
 		boolean canReplace = (cornerComp == null)
 				|| (cornerComp instanceof UIResource);
-		// Fix for issue 343 - don't set the corner when the
-		// component is JXTable
-		Class tableClass = tableHeader.getTable().getClass();
-		while (tableClass != null) {
-			if ("org.jdesktop.swingx.JXTable".equals(tableClass.getName())) {
-				canReplace = false;
-				break;
-			}
-			tableClass = tableClass.getSuperclass();
-		}
+		// System.out.println(canReplace + ":" + cornerComp);
 		if (canReplace) {
 			scrollpane.setCorner(cornerKey, scrollPaneCornerFiller);
 		}
