@@ -36,10 +36,11 @@ import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.basic.BasicSeparatorUI;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceConstants.MenuGutterFillKind;
+import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
 import org.jvnet.substance.utils.*;
-import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
 import org.jvnet.substance.utils.menu.MenuUtilities;
 
 /**
@@ -48,7 +49,8 @@ import org.jvnet.substance.utils.menu.MenuUtilities;
  * @author Kirill Grouchnikov
  */
 public class SubstanceSeparatorUI extends BasicSeparatorUI {
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceSeparatorUI();
 	}
 
@@ -56,22 +58,20 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicSeparatorUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
 		Graphics2D graphics = (Graphics2D) g.create();
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(c)
-				.getDefaultTheme();
-		ColorScheme colorScheme = theme.getColorScheme();
+		SubstanceColorScheme compScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(c, ComponentState.DEFAULT);
 
 		try {
 			Component parent = c.getParent();
 			if (!(parent instanceof JPopupMenu)) {
-				SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
-						SubstanceCoreUtilities.isThemeDark(theme),
-						c.getWidth(), c.getHeight(), ((JSeparator) c)
-								.getOrientation());
+				SeparatorPainterUtils.paintSeparator(c, graphics, compScheme, c
+						.getWidth(), c.getHeight(), ((JSeparator) c)
+						.getOrientation());
 				return;
 			}
 
@@ -84,14 +84,14 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 				MenuGutterFillKind fillKind = SubstanceCoreUtilities
 						.getMenuGutterFillKind();
 				if (fillKind != MenuGutterFillKind.NONE) {
-					ColorScheme scheme = SubstanceThemeUtilities.getTheme(
-							parent, ComponentState.DEFAULT).getColorScheme();
-					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
+					SubstanceColorScheme parentScheme = SubstanceColorSchemeUtilities
+							.getColorScheme(parent, ComponentState.DEFAULT);
+					Color leftColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? parentScheme
 							.getUltraLightColor()
-							: scheme.getLightColor();
-					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
+							: parentScheme.getLightColor();
+					Color rightColor = ((fillKind == MenuGutterFillKind.SOFT_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? parentScheme
 							.getUltraLightColor()
-							: scheme.getLightColor();
+							: parentScheme.getLightColor();
 					GradientPaint gp = new GradientPaint(0, 0, leftColor,
 							xOffset, 0, rightColor);
 
@@ -100,14 +100,6 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 					graphics.setPaint(gp);
 					graphics.fillRect(0, 0, xOffset - 2, c.getHeight());
 				}
-				// graphics.setComposite(TransitionLayout
-				// .getAlphaComposite(parent));
-				//
-				// graphics.setColor(c.getForeground());
-				// graphics.drawLine(xOffset, 0, s.width, 0);
-				//
-				// graphics.setColor(c.getBackground());
-				// graphics.drawLine(xOffset, 1, s.width, 1);
 				startX = xOffset - 2;
 				width = s.width - startX;
 			} else {
@@ -115,14 +107,14 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 				MenuGutterFillKind fillKind = SubstanceCoreUtilities
 						.getMenuGutterFillKind();
 				if (fillKind != MenuGutterFillKind.NONE) {
-					ColorScheme scheme = SubstanceThemeUtilities.getTheme(
-							parent, ComponentState.DEFAULT).getColorScheme();
-					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? scheme
+					SubstanceColorScheme parentScheme = SubstanceColorSchemeUtilities
+							.getColorScheme(parent, ComponentState.DEFAULT);
+					Color leftColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.HARD)) ? parentScheme
 							.getLightColor()
-							: scheme.getUltraLightColor();
-					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? scheme
+							: parentScheme.getUltraLightColor();
+					Color rightColor = ((fillKind == MenuGutterFillKind.HARD_FILL) || (fillKind == MenuGutterFillKind.SOFT)) ? parentScheme
 							.getLightColor()
-							: scheme.getUltraLightColor();
+							: parentScheme.getUltraLightColor();
 					GradientPaint gp = new GradientPaint(xOffset, 0, leftColor,
 							s.width, 0, rightColor);
 
@@ -131,22 +123,14 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 					graphics.setPaint(gp);
 					graphics.fillRect(xOffset - 2, 0, s.width, c.getHeight());
 				}
-				// graphics.setComposite(TransitionLayout
-				// .getAlphaComposite(parent));
-
-				// graphics.setColor(c.getForeground());
-				// graphics.drawLine(0, 0, s.width - xOffset - 4, 0);
-				//
-				// graphics.setColor(c.getBackground());
-				// graphics.drawLine(0, 1, s.width - xOffset - 4, 1);
 				startX = 0;
 				width = xOffset - 4;
 			}
 			graphics.translate(startX, 0);
 			graphics.setComposite(TransitionLayout.getAlphaComposite(parent));
-			SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
-					SubstanceCoreUtilities.isThemeDark(theme), width, s.height,
-					((JSeparator) c).getOrientation(), true, 2);
+			SeparatorPainterUtils
+					.paintSeparator(c, graphics, compScheme, width, s.height,
+							((JSeparator) c).getOrientation(), true, 2);
 		} finally {
 			graphics.dispose();
 		}
@@ -155,7 +139,9 @@ public class SubstanceSeparatorUI extends BasicSeparatorUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSeparatorUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSeparatorUI#getPreferredSize(javax.swing.
+	 * JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
