@@ -31,28 +31,26 @@ package org.jvnet.substance;
 
 import java.awt.*;
 import java.awt.event.MouseEvent;
+import java.awt.geom.AffineTransform;
 import java.awt.geom.GeneralPath;
 import java.awt.image.BufferedImage;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.Dictionary;
-import java.util.Enumeration;
+import java.util.ArrayList;
 
 import javax.swing.*;
 import javax.swing.plaf.*;
-import javax.swing.plaf.basic.BasicHTML;
 import javax.swing.plaf.basic.BasicSliderUI;
-import javax.swing.text.View;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.border.SubstanceBorderPainter;
-import org.jvnet.substance.button.BaseButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.painter.ClassicGradientPainter;
-import org.jvnet.substance.painter.SubstanceGradientPainter;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.painter.border.SubstanceBorderPainter;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
+import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
+import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 
@@ -62,11 +60,6 @@ import org.jvnet.substance.utils.icon.SubstanceIconFactory;
  * @author Kirill Grouchnikov
  */
 public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
-	/**
-	 * Background delegate.
-	 */
-	private static SubstanceFillBackgroundDelegate bgDelegate = new SubstanceFillBackgroundDelegate();
-
 	/**
 	 * Surrogate button model for tracking the thumb transitions.
 	 */
@@ -102,13 +95,20 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	 */
 	protected Icon verticalIcon;
 
+	/**
+	 * Cache of track images.
+	 */
+	protected static final LazyResettableHashMap<BufferedImage> trackCache = new LazyResettableHashMap<BufferedImage>(
+			"SubstanceSliderUI.track");
+
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceSliderUI((JSlider) c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceSliderUI((JSlider) comp);
 	}
 
 	/**
@@ -179,66 +179,72 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	@Override
 	public void paintTrack(Graphics g) {
 		Graphics2D graphics = (Graphics2D) g.create();
-		graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
-				RenderingHints.VALUE_ANTIALIAS_ON);
 
 		boolean drawInverted = this.drawInverted();
 
-		// Translate to the origin of the painting rectangle
 		Rectangle paintRect = this.getPaintTrackRect();
-		// System.out.println(paintRect);
-		graphics.translate(paintRect.x, paintRect.y);
 
 		// Width and height of the painting rectangle.
 		int width = paintRect.width;
 		int height = paintRect.height;
 
+		if (this.slider.getOrientation() == JSlider.VERTICAL) {
+			// apply rotation / translate transformation on vertical
+			// sider tracks
+			int temp = width;
+			width = height;
+			height = temp;
+			AffineTransform at = graphics.getTransform();
+			at.translate(paintRect.x, width + paintRect.y);
+			at.rotate(-Math.PI / 2);
+			graphics.setTransform(at);
+		} else {
+			graphics.translate(paintRect.x, paintRect.y);
+		}
+
 		ComponentState currState = ComponentState.getState(this.thumbModel,
 				this.slider);
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevComponentState(this.slider);
 
-		SubstanceTheme trackTheme = SubstanceThemeUtilities
-				.getTheme(this.slider);
-		if (this.slider.isEnabled())
-			trackTheme = trackTheme.getDefaultTheme();
-		else
-			trackTheme = trackTheme.getDisabledTheme();
+		SubstanceColorScheme trackScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(this.slider,
+						this.slider.isEnabled() ? ComponentState.DEFAULT
+								: ComponentState.DISABLED_UNSELECTED);
 
-		this.paintSliderTrack(graphics, drawInverted, trackTheme, width,
-				height, (this.slider.getOrientation() == JSlider.VERTICAL));
+		this.paintSliderTrack(graphics, drawInverted, trackScheme,
+				SubstanceColorSchemeUtilities.getBorderColorScheme(this.slider,
+						currState), width, height);
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.slider,
-				currState);
+		SubstanceColorScheme trackSchemeSelected = SubstanceColorSchemeUtilities
+				.getColorScheme(this.slider, currState);
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(this.slider,
 				FadeKind.ROLLOVER, FadeKind.SELECTION, FadeKind.PRESS);
 		if (fadeState != null) {
-			SubstanceTheme prevTheme = SubstanceThemeUtilities.getTheme(
-					this.slider, prevState);
+			SubstanceColorScheme prevScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(this.slider, prevState);
 			float cyclePos = fadeState.getFadePosition();
 			if (!fadeState.isFadingIn())
-				cyclePos = 10.0f - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 
 			if (prevState != ComponentState.DEFAULT) {
 				graphics.setComposite(TransitionLayout.getAlphaComposite(
-						this.slider, 1.0f - cyclePos / 10.0f, g));
+						this.slider, 1.0f - cyclePos, g));
 				this.paintSliderTrackSelected(graphics, drawInverted,
-						paintRect, prevTheme, width, height);
+						paintRect, prevScheme, width, height);
 			}
 			if (currState != ComponentState.DEFAULT) {
 				graphics.setComposite(TransitionLayout.getAlphaComposite(
-						this.slider, cyclePos / 10.0f, g));
+						this.slider, cyclePos, g));
 				this.paintSliderTrackSelected(graphics, drawInverted,
-						paintRect, theme, width, height);
+						paintRect, trackSchemeSelected, width, height);
 			}
 		} else {
 			boolean hasFill = currState.isKindActive(FadeKind.ROLLOVER)
-					|| currState.isKindActive(FadeKind.PRESS)
-					|| SubstanceCoreUtilities.isControlAlwaysPaintedActive(
-							this.slider, true);
+					|| currState.isKindActive(FadeKind.PRESS);
 			if (hasFill) {
 				this.paintSliderTrackSelected(graphics, drawInverted,
-						paintRect, theme, width, height);
+						paintRect, trackSchemeSelected, width, height);
 			}
 		}
 
@@ -253,61 +259,64 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	 * @param drawInverted
 	 *            Indicates whether the value-range shown for the slider is
 	 *            reversed.
-	 * @param theme
-	 *            Theme.
+	 * @param fillColorScheme
+	 *            Fill color scheme.
+	 * @param borderScheme
+	 *            Border color scheme.
 	 * @param width
 	 *            Track width.
 	 * @param height
 	 *            Track height.
-	 * @param toRotate
-	 *            Indicates whether the slider track image should be rotated (<code>true</code>
-	 *            if the slider is vertical).
 	 */
 	private void paintSliderTrack(Graphics2D graphics, boolean drawInverted,
-			SubstanceTheme theme, int width, int height, boolean toRotate) {
-		// ColorScheme colorScheme = theme.getColorScheme();
+			SubstanceColorScheme fillColorScheme,
+			SubstanceColorScheme borderScheme, int width, int height) {
+		Graphics2D g2d = (Graphics2D) graphics.create();
 
-		SubstanceGradientPainter gradientPainter = new ClassicGradientPainter();
-		ColorScheme fillColorScheme = theme.getColorScheme();
+		SubstanceGradientPainter gradientPainter = ClassicGradientPainter.INSTANCE;
 		SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
 				.getBorderPainter(this.slider);
 
-		// some strange bug in clipping a rotated Graphics removes the
-		// last pixel row during the border painting. So, for vertical sliders
-		// we create a temporary image, paint the slider there and then rotate
-		// the image
-		if (toRotate) {
-			BufferedImage image = SubstanceCoreUtilities.getBlankImage(
-					height + 1, width + 1);
-			this.paintSliderTrack((Graphics2D) image.getGraphics(),
-					drawInverted, theme, height, width, false);
-			BufferedImage track = SubstanceImageCreator.getRotated(image, 3);
-			graphics.drawImage(track, 0, 0, null);
-			return;
+		int componentFontSize = SubstanceSizeUtils
+				.getComponentFontSize(this.slider);
+		int borderDelta = (int) Math.floor(SubstanceSizeUtils
+				.getBorderStrokeWidth(componentFontSize) / 2.0);
+		float radius = SubstanceSizeUtils
+				.getClassicButtonCornerRadius(componentFontSize) / 2.0f;
+		int borderThickness = (int) SubstanceSizeUtils
+				.getBorderStrokeWidth(componentFontSize);
+
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(width, height,
+				radius, borderDelta, borderThickness, fillColorScheme
+						.getDisplayName(), borderScheme.getDisplayName());
+
+		if (!trackCache.containsKey(key)) {
+			BufferedImage trackImage = SubstanceCoreUtilities.getBlankImage(
+					width + 1, height + 1);
+			Graphics2D cacheGraphics = trackImage.createGraphics();
+
+			Shape contour = SubstanceOutlineUtilities.getBaseOutline(width + 1,
+					height + 1, radius, null, borderDelta);
+
+			gradientPainter.paintContourBackground(cacheGraphics, slider,
+					width, height, contour, false, fillColorScheme,
+					fillColorScheme, 0, false, false);
+
+			GeneralPath contourInner = SubstanceOutlineUtilities
+					.getBaseOutline(width + 1, height + 1, radius, null,
+							borderThickness + borderDelta);
+			borderPainter.paintBorder(cacheGraphics, slider, width + 1,
+					height + 1, contour, contourInner, borderScheme,
+					borderScheme, 0, false);
+
+			trackCache.put(key, trackImage);
+			cacheGraphics.dispose();
 		}
 
-		int borderDelta = (int) Math.floor(SubstanceSizeUtils
-				.getBorderStrokeWidth(SubstanceSizeUtils
-						.getComponentFontSize(slider)) / 2.0);
-		float radius = SubstanceSizeUtils
-				.getClassicButtonCornerRadius(SubstanceSizeUtils
-						.getComponentFontSize(slider)) / 2.0f;
-		Shape contour = BaseButtonShaper.getBaseOutline(width + 1, height + 1,
-				radius, null, borderDelta);
+		BufferedImage cached = trackCache.get(key);
+		g2d.drawImage(cached, 0, 0, null);
 
-		BufferedImage fillTrackImage = gradientPainter.getContourBackground(
-				width, height, contour, false, fillColorScheme,
-				fillColorScheme, 0, false, false);
-		graphics.drawImage(fillTrackImage, 0, 0, null);
-
-		ColorScheme borderScheme = theme.getBorderTheme().getColorScheme();
-		int borderThickness = (int) SubstanceSizeUtils
-				.getBorderStrokeWidth(SubstanceSizeUtils
-						.getComponentFontSize(this.slider));
-		GeneralPath contourInner = BaseButtonShaper.getBaseOutline(width + 1,
-				height + 1, radius, null, borderThickness + borderDelta);
-		borderPainter.paintBorder(graphics, slider, width + 1, height + 1,
-				contour, contourInner, borderScheme, borderScheme, 0, false);
+		g2d.dispose();
 	}
 
 	/**
@@ -320,16 +329,18 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	 *            reversed.
 	 * @param paintRect
 	 *            Selected portion.
-	 * @param theme
-	 *            Theme.
+	 * @param scheme
+	 *            Color scheme.
 	 * @param width
 	 *            Track width.
 	 * @param height
 	 *            Track height.
 	 */
 	private void paintSliderTrackSelected(Graphics2D graphics,
-			boolean drawInverted, Rectangle paintRect, SubstanceTheme theme,
-			int width, int height) {
+			boolean drawInverted, Rectangle paintRect,
+			SubstanceColorScheme scheme, int width, int height) {
+
+		Graphics2D g2d = (Graphics2D) graphics.create();
 		Insets insets = this.slider.getInsets();
 		insets.top /= 2;
 		insets.left /= 2;
@@ -355,9 +366,6 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 				int fillMinX;
 				int fillMaxX;
 
-				// graphics.setPaint(new GradientPaint(0, 1, fillColor1, 0,
-				// height - 1, fillColor2));
-
 				if (drawInverted) {
 					fillMinX = middleOfThumb;
 					fillMaxX = width;
@@ -369,48 +377,48 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 				int fillWidth = fillMaxX - fillMinX;
 				int fillHeight = height + 1;
 				if ((fillWidth > 0) && (fillHeight > 0)) {
-					Shape contour = BaseButtonShaper.getBaseOutline(fillWidth,
-							fillHeight, radius, null, borderDelta);
-					BufferedImage im = gp.getContourBackground(fillWidth,
-							fillHeight, contour, false, theme.getColorScheme(),
-							theme.getColorScheme(), 0.0f, false, false);
-					borderPainter.paintBorder(im.getGraphics(), this.slider,
-							fillWidth, fillHeight, contour, null, theme
-									.getColorScheme(), theme.getColorScheme(),
-							0.0f, false);
-					graphics.drawImage(im, fillMinX, 0, null);
+					Shape contour = SubstanceOutlineUtilities.getBaseOutline(
+							fillWidth, fillHeight, radius, null, borderDelta);
+					g2d.translate(fillMinX, 0);
+					gp.paintContourBackground(g2d, this.slider, fillWidth,
+							fillHeight, contour, false, scheme, scheme, 0.0f,
+							false, false);
+					borderPainter.paintBorder(g2d, this.slider, fillWidth,
+							fillHeight, contour, null, scheme, scheme, 0.0f,
+							false);
 				}
 			} else {
 				int middleOfThumb = this.thumbRect.y
 						+ (this.thumbRect.height / 2) - paintRect.y;
-				int fillMinY;
-				int fillMaxY;
+				int fillMin;
+				int fillMax;
 
 				if (this.drawInverted()) {
-					fillMinY = 0;
-					fillMaxY = middleOfThumb;
+					fillMin = 0;
+					fillMax = middleOfThumb;
+					// fix for issue 368 - inverted vertical sliders
+					g2d.translate(width + 2 - middleOfThumb, 0);
 				} else {
-					fillMinY = middleOfThumb;
-					fillMaxY = height + 1;
+					fillMin = middleOfThumb;
+					fillMax = width + 1;
 				}
 
-				int fillWidth = fillMaxY - fillMinY;
-				int fillHeight = width + 1;
+				int fillWidth = fillMax - fillMin;
+				int fillHeight = height + 1;
 				if ((fillWidth > 0) && (fillHeight > 0)) {
-					Shape contour = BaseButtonShaper.getBaseOutline(fillWidth,
-							fillHeight, radius, null, borderDelta);
-					BufferedImage im = gp.getContourBackground(fillWidth,
-							fillHeight, contour, false, theme.getColorScheme(),
-							theme.getColorScheme(), 0.0f, false, false);
-					borderPainter.paintBorder(im.getGraphics(), this.slider,
-							fillWidth, fillHeight, contour, null, theme
-									.getColorScheme(), theme.getColorScheme(),
-							0.0f, false);
-					im = SubstanceImageCreator.getRotated(im, 1);
-					graphics.drawImage(im, 0, fillMinY, null);
+					Shape contour = SubstanceOutlineUtilities.getBaseOutline(
+							fillWidth, fillHeight, radius, null, borderDelta);
+
+					gp.paintContourBackground(g2d, this.slider, fillWidth,
+							fillHeight, contour, false, scheme, scheme, 0.0f,
+							false, false);
+					borderPainter.paintBorder(g2d, this.slider, fillWidth,
+							fillHeight, contour, null, scheme, scheme, 0.0f,
+							false);
 				}
 			}
 		}
+		g2d.dispose();
 	}
 
 	/*
@@ -480,39 +488,19 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
-	public synchronized void paint(Graphics g, final JComponent c) {
+	public void paint(Graphics g, final JComponent c) {
 		Graphics2D graphics = (Graphics2D) g.create();
 
 		ComponentState currState = ComponentState.getState(this.thumbModel,
 				this.slider);
-		float alpha = SubstanceThemeUtilities.getTheme(this.slider)
-				.getThemeAlpha(this.slider, currState);
+		float alpha = SubstanceColorSchemeUtilities.getAlpha(this.slider,
+				currState);
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(c, null, true);
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.setBackgroundFill(c, c.getBackground(), true, 0, 0);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							// need for the non-showing labels
-							bgDelegate.updateIfOpaque(g, c);
-						}
-					});
-		} else {
-			bgDelegate.updateIfOpaque(graphics, c);
-			// graphics.setColor(c.getBackground());
-			// graphics.fillRect(0, 0, c.getWidth(), c.getHeight());
-			// System.out.println(c.isEnabled() + ":" + c.getBackground());
-		}
-		// // remove opacity
-		// boolean isOpaque = c.isOpaque();
-		// c.setOpaque(false);
-		// // super.paint(graphics, c);
+		SubstanceFillBackgroundDelegate.GLOBAL_INSTANCE.updateIfOpaque(
+				graphics, c);
 
 		recalculateIfInsetsChanged();
 		recalculateIfOrientationChanged();
@@ -523,36 +511,24 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 
 		graphics.setComposite(TransitionLayout.getAlphaComposite(this.slider,
 				alpha, g));
-		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-			public void paintBackground(Graphics g) {
-				if (slider.getPaintTrack() && clip.intersects(trackRect)) {
-					paintTrack(g);
-				}
-				if (slider.getPaintTicks() && clip.intersects(tickRect)) {
-					paintTicks(g);
-				}
-				if (slider.hasFocus() && clip.intersects(focusRect)) {
-					paintFocus(g);
-				}
-				if (clip.intersects(thumbRect)) {
-					paintThumb(g);
-				}
-			}
-		};
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.attachCallback(callback);
-		} else {
-			callback.paintBackground(graphics);
+		if (slider.getPaintTrack() && clip.intersects(trackRect)) {
+			paintTrack(graphics);
 		}
+		if (slider.getPaintTicks() && clip.intersects(tickRect)) {
+			paintTicks(graphics);
+		}
+		if (slider.hasFocus() && clip.intersects(focusRect)) {
+			paintFocus(graphics);
+		}
+		if (clip.intersects(thumbRect)) {
+			paintThumb(graphics);
+		}
+		graphics.setComposite(TransitionLayout.getAlphaComposite(this.slider,
+				1.0f, g));
 		if (slider.getPaintLabels() && clip.intersects(labelRect)) {
 			paintLabels(graphics);
 		}
 
-		textPainter.renderSurface(graphics);
-
-		// // restore opacity
-		// c.setOpaque(isOpaque);
-
 		if (!this.slider.hasFocus()) {
 			if (FadeTracker.getInstance().isTracked(c, FadeKind.FOCUS))
 				this.paintFocus(graphics);
@@ -585,7 +561,8 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#installDefaults(javax.swing.JSlider)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSliderUI#installDefaults(javax.swing.JSlider)
 	 */
 	@Override
 	protected void installDefaults(JSlider slider) {
@@ -614,7 +591,9 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#installListeners(javax.swing.JSlider)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSliderUI#installListeners(javax.swing.JSlider
+	 * )
 	 */
 	@Override
 	protected void installListeners(final JSlider slider) {
@@ -654,7 +633,9 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#uninstallListeners(javax.swing.JSlider)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSliderUI#uninstallListeners(javax.swing.JSlider
+	 * )
 	 */
 	@Override
 	protected void uninstallListeners(JSlider slider) {
@@ -724,37 +705,48 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	@Override
 	public void paintTicks(Graphics g) {
 		Rectangle tickBounds = this.tickRect;
+		SubstanceColorScheme tickScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(this.slider,
+						this.slider.isEnabled() ? ComponentState.DEFAULT
+								: ComponentState.DISABLED_UNSELECTED);
 		if (this.slider.getOrientation() == JSlider.HORIZONTAL) {
-			g.translate(0, tickBounds.y);
-
 			int value = this.slider.getMinimum()
 					+ this.slider.getMinorTickSpacing();
 			int xPos = 0;
 
 			if ((this.slider.getMinorTickSpacing() > 0)
 					&& (this.slider.getMajorTickSpacing() > 0)) {
+				// collect x's of the minor ticks
+				java.util.List<Integer> minorXs = new ArrayList<Integer>();
 				while (value < this.slider.getMaximum()) {
 					int delta = value - this.slider.getMinimum();
 					if (delta % this.slider.getMajorTickSpacing() != 0) {
 						xPos = this.xPositionForValue(value);
-						this.paintMinorTickForHorizSlider(g, tickBounds, xPos);
+						minorXs.add(xPos - 1);
 					}
 					value += this.slider.getMinorTickSpacing();
 				}
+				// and paint them in one call
+				SeparatorPainterUtils.paintVerticalLines(g, this.slider,
+						tickScheme, tickBounds.y, minorXs,
+						tickBounds.height / 2, 0.75f);
 			}
 
 			if (this.slider.getMajorTickSpacing() > 0) {
+				// collect x's of the major ticks
+				java.util.List<Integer> majorXs = new ArrayList<Integer>();
 				value = this.slider.getMinimum()
 						+ this.slider.getMajorTickSpacing();
-
 				while (value < this.slider.getMaximum()) {
 					xPos = this.xPositionForValue(value);
-					this.paintMajorTickForHorizSlider(g, tickBounds, xPos);
+					majorXs.add(xPos - 1);
 					value += this.slider.getMajorTickSpacing();
 				}
+				// and paint them in one call
+				SeparatorPainterUtils.paintVerticalLines(g, this.slider,
+						tickScheme, tickBounds.y, majorXs, tickBounds.height,
+						0.75f);
 			}
-
-			g.translate(0, -tickBounds.y);
 		} else {
 			g.translate(tickBounds.x, 0);
 
@@ -764,145 +756,46 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 
 			boolean ltr = this.slider.getComponentOrientation().isLeftToRight();
 			if (this.slider.getMinorTickSpacing() > 0) {
+				// collect y's of the minor ticks
+				java.util.List<Integer> minorYs = new ArrayList<Integer>();
 				int offset = 0;
 				if (!ltr) {
 					offset = tickBounds.width - tickBounds.width / 2;
-					g.translate(offset, 0);
 				}
 
 				while (value < this.slider.getMaximum()) {
 					yPos = this.yPositionForValue(value);
-					this.paintMinorTickForVertSlider(g, tickBounds, yPos);
+					minorYs.add(yPos);
 					value += this.slider.getMinorTickSpacing();
 				}
 
-				if (!ltr) {
-					g.translate(-offset, 0);
-				}
+				// and paint them in one call
+				SeparatorPainterUtils.paintHorizontalLines(g, this.slider,
+						tickScheme, offset, minorYs, tickBounds.width / 2,
+						ltr ? 0.75f : 0.25f, ltr);
 			}
 
 			if (this.slider.getMajorTickSpacing() > 0) {
+				// collect y's of the major ticks
+				java.util.List<Integer> majorYs = new ArrayList<Integer>();
 				value = this.slider.getMinimum()
 						+ this.slider.getMajorTickSpacing();
-				if (!ltr) {
-					g.translate(2, 0);
-				}
 
 				while (value < this.slider.getMaximum()) {
 					yPos = this.yPositionForValue(value);
-					this.paintMajorTickForVertSlider(g, tickBounds, yPos);
+					majorYs.add(yPos);
 					value += this.slider.getMajorTickSpacing();
 				}
 
-				if (!ltr) {
-					g.translate(-2, 0);
-				}
+				// and paint them in one call
+				SeparatorPainterUtils.paintHorizontalLines(g, this.slider,
+						tickScheme, 0, majorYs, tickBounds.width, ltr ? 0.75f
+								: 0.25f, ltr);
 			}
 			g.translate(-tickBounds.x, 0);
 		}
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#paintMajorTickForHorizSlider(java.awt.Graphics,
-	 *      java.awt.Rectangle, int)
-	 */
-	@Override
-	protected void paintMajorTickForHorizSlider(Graphics g,
-			Rectangle tickBounds, int x) {
-		boolean isDark = SubstanceCoreUtilities
-				.isThemeDark(SubstanceLookAndFeel.getTheme());
-
-		ColorScheme colorScheme = SubstanceThemeUtilities.getTheme(
-				this.slider,
-				this.slider.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED).getColorScheme();
-
-		Graphics2D graphics = (Graphics2D) g.create();
-		graphics.translate(x - 1, 0);
-		SubstanceCoreUtilities.paintSeparator(this.slider, graphics,
-				colorScheme, isDark, 0, tickBounds.height, JSeparator.VERTICAL,
-				true, 0, 4);
-		graphics.dispose();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#paintMajorTickForVertSlider(java.awt.Graphics,
-	 *      java.awt.Rectangle, int)
-	 */
-	@Override
-	protected void paintMajorTickForVertSlider(Graphics g,
-			Rectangle tickBounds, int y) {
-		boolean isDark = SubstanceCoreUtilities
-				.isThemeDark(SubstanceLookAndFeel.getTheme());
-		ColorScheme colorScheme = SubstanceThemeUtilities.getTheme(
-				this.slider,
-				this.slider.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED).getColorScheme();
-
-		Graphics2D graphics = (Graphics2D) g.create();
-		graphics.translate(0, y);
-		SubstanceCoreUtilities.paintSeparator(this.slider, graphics,
-				colorScheme, isDark, tickBounds.width - 1, 0,
-				JSeparator.HORIZONTAL, true, this.slider
-						.getComponentOrientation().isLeftToRight() ? 0 : 4,
-				this.slider.getComponentOrientation().isLeftToRight() ? 4 : 0);
-		graphics.dispose();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#paintMinorTickForHorizSlider(java.awt.Graphics,
-	 *      java.awt.Rectangle, int)
-	 */
-	@Override
-	protected void paintMinorTickForHorizSlider(Graphics g,
-			Rectangle tickBounds, int x) {
-		boolean isDark = SubstanceCoreUtilities
-				.isThemeDark(SubstanceLookAndFeel.getTheme());
-		ColorScheme colorScheme = SubstanceThemeUtilities.getTheme(
-				this.slider,
-				this.slider.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED).getColorScheme();
-
-		Graphics2D graphics = (Graphics2D) g.create();
-		graphics.translate(x - 1, 0);
-		SubstanceCoreUtilities.paintSeparator(this.slider, graphics,
-				colorScheme, isDark, 0, tickBounds.height / 2,
-				JSeparator.VERTICAL, true, 0, 4);
-		graphics.dispose();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#paintMinorTickForVertSlider(java.awt.Graphics,
-	 *      java.awt.Rectangle, int)
-	 */
-	@Override
-	protected void paintMinorTickForVertSlider(Graphics g,
-			Rectangle tickBounds, int y) {
-		boolean isDark = SubstanceCoreUtilities
-				.isThemeDark(SubstanceLookAndFeel.getTheme());
-		ColorScheme colorScheme = SubstanceThemeUtilities.getTheme(
-				this.slider,
-				this.slider.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED).getColorScheme();
-
-		Graphics2D graphics = (Graphics2D) g.create();
-		graphics.translate(0, y);
-		SubstanceCoreUtilities.paintSeparator(this.slider, graphics,
-				colorScheme, isDark, tickBounds.width / 2, 0,
-				JSeparator.HORIZONTAL, true, this.slider
-						.getComponentOrientation().isLeftToRight() ? 0 : 4,
-				this.slider.getComponentOrientation().isLeftToRight() ? 4 : 0);
-		graphics.dispose();
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -988,7 +881,9 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSliderUI#getPreferredSize(javax.swing.JComponent
+	 * )
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -1053,95 +948,4 @@ public class SubstanceSliderUI extends BasicSliderUI implements Trackable {
 				SubstanceSizeUtils.getComponentFontSize(this.slider), 200, 1,
 				20, false));
 	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicSliderUI#paintLabels(java.awt.Graphics)
-	 */
-	@Override
-	public void paintLabels(Graphics g) {
-		final Rectangle labelBounds = labelRect;
-
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		Dictionary<?, ?> dictionary = slider.getLabelTable();
-		if (dictionary != null) {
-			Enumeration<?> keys = dictionary.keys();
-			int minValue = slider.getMinimum();
-			int maxValue = slider.getMaximum();
-			while (keys.hasMoreElements()) {
-				Integer key = (Integer) keys.nextElement();
-				int value = key.intValue();
-				if (value >= minValue && value <= maxValue) {
-					Component label = (Component) dictionary.get(key);
-					Dimension prefSize = label.getPreferredSize();
-					JLabel jlabel = (JLabel) label;
-					final View v = (View) jlabel
-							.getClientProperty(BasicHTML.propertyKey);
-					String text = jlabel.getText();
-
-					// fix for issue 316 - respecting custom foreground
-					// colors on slider labels.
-					ComponentState state = slider.isEnabled() ? ComponentState.DEFAULT
-							: ComponentState.DISABLED_UNSELECTED;
-					Color labelColor = SubstanceCoreUtilities
-							.getForegroundColor(jlabel, state, state);
-
-					if (slider.getOrientation() == JSlider.HORIZONTAL) {
-						final Rectangle textRect = new Rectangle(
-								xPositionForValue(value) - prefSize.width / 2,
-								labelBounds.y, prefSize.width, prefSize.height);
-						if (v != null) {
-							// fix for issue 327 - support for custom HTML
-							// labels
-							if (textPainter.needsBackgroundImage()) {
-								textPainter
-										.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-											public void paintBackground(
-													Graphics g) {
-												v.paint(g, textRect);
-											}
-										});
-							} else {
-								v.paint(g, textRect);
-							}
-						} else {
-							textPainter.attachText(this.slider, textRect, text,
-									-1, g.getFont(), labelColor, g
-											.getClipBounds());
-						}
-					} else {
-						int offset = 0;
-						if (slider.getComponentOrientation().isLeftToRight()) {
-							offset = labelBounds.width
-									- label.getPreferredSize().height;
-						}
-						final Rectangle labelRect = new Rectangle(labelBounds.x
-								+ offset, yPositionForValue(value)
-								- prefSize.width / 2, prefSize.height,
-								prefSize.width);
-						// System.out.println(labelRect + ":" + text);
-						// textPainter
-						// .attachCallback(new
-						// SubstanceTextPainter.BackgroundPaintingCallback() {
-						// public void paintBackground(Graphics g) {
-						// g.setColor(Color.blue);
-						// g.drawRect(labelRect.x, labelRect.y,
-						// labelRect.width - 1,
-						// labelRect.height - 1);
-						// }
-						// });
-						textPainter.attachVerticalText(this.slider, labelRect,
-								text, -1, g.getFont(), labelColor, null, slider
-										.getComponentOrientation()
-										.isLeftToRight());
-					}
-				}
-			}
-		}
-		// textPainter.setBackgroundFill(slider, slider.getBackground(), true,
-		// 0,
-		// 0);
-	}
 }
