@@ -32,8 +32,7 @@ package org.jvnet.substance;
 import java.awt.*;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
-import java.util.HashSet;
-import java.util.Set;
+import java.util.EnumSet;
 
 import javax.swing.*;
 import javax.swing.border.Border;
@@ -43,9 +42,11 @@ import javax.swing.plaf.UIResource;
 import javax.swing.plaf.basic.BasicSpinnerUI;
 
 import org.jvnet.lafwidget.animation.*;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceConstants.Side;
 import org.jvnet.substance.utils.*;
-import org.jvnet.substance.utils.SubstanceConstants.Side;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 import org.jvnet.substance.utils.icon.TransitionAwareIcon;
 
 /**
@@ -54,11 +55,6 @@ import org.jvnet.substance.utils.icon.TransitionAwareIcon;
  * @author Kirill Grouchnikov
  */
 public class SubstanceSpinnerUI extends BasicSpinnerUI {
-	// /**
-	// * Focus listener.
-	// */
-	// protected FocusBorderListener substanceFocusListener;
-
 	/**
 	 * Tracks changes to editor, removing the border as necessary.
 	 */
@@ -69,8 +65,6 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	 */
 	protected FadeStateListener substanceFadeStateListener;
 
-	// protected ChangeListener substanceChangeListener;
-
 	/**
 	 * The next (increment) button.
 	 */
@@ -86,7 +80,8 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceSpinnerUI();
 	}
 
@@ -104,7 +99,7 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 
 		Icon icon = new TransitionAwareIcon(this.nextButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme scheme) {
 						int fontSize = SubstanceSizeUtils
 								.getComponentFontSize(spinner);
 						return SubstanceImageCreator.getArrowIcon(
@@ -114,24 +109,22 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 										.getSpinnerArrowIconHeight(fontSize),
 								SubstanceSizeUtils
 										.getArrowStrokeWidth(fontSize),
-								SwingConstants.NORTH, theme);
+								SwingConstants.NORTH, scheme);
 					}
 				});
-		this.nextButton.setIcon(this.spinner, icon);
+		this.nextButton.setIcon(icon);
 
-		int spinnerButtonSize = SubstanceSizeUtils
+		float spinnerButtonSize = SubstanceSizeUtils
 				.getSpinnerButtonWidth(SubstanceSizeUtils
 						.getComponentFontSize(spinner));
-		this.nextButton.setPreferredSize(new Dimension(spinnerButtonSize,
-				spinnerButtonSize));
+		this.nextButton.setPreferredSize(new Dimension((int) spinnerButtonSize,
+				(int) spinnerButtonSize));
 		this.nextButton.setMinimumSize(new Dimension(5, 5));
 
-		Set<Side> openSides = new HashSet<Side>();
-		openSides.add(Side.BOTTOM);
-		openSides.add(Side.TOP);
-		openSides.add(Side.RIGHT);
+		// Set<Side> openSides = EnumSet.of(Side.BOTTOM, Side.TOP, Side.RIGHT);
 		this.nextButton.putClientProperty(
-				SubstanceLookAndFeel.BUTTON_OPEN_SIDE_PROPERTY, openSides);
+				SubstanceLookAndFeel.BUTTON_OPEN_SIDE_PROPERTY, EnumSet
+						.allOf(Side.class));
 
 		this.installNextButtonListeners(this.nextButton);
 		return this.nextButton;
@@ -151,7 +144,7 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 
 		Icon icon = new TransitionAwareIcon(this.prevButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme scheme) {
 						// System.out.println(spinner.getFont().getSize());
 						int fontSize = SubstanceSizeUtils
 								.getComponentFontSize(spinner);
@@ -162,24 +155,22 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 										.getSpinnerArrowIconHeight(fontSize),
 								SubstanceSizeUtils
 										.getArrowStrokeWidth(fontSize),
-								SwingConstants.SOUTH, theme);
+								SwingConstants.SOUTH, scheme);
 					}
 				});
-		this.prevButton.setIcon(this.spinner, icon);
+		this.prevButton.setIcon(icon);
 
-		int spinnerButtonSize = SubstanceSizeUtils
+		float spinnerButtonSize = SubstanceSizeUtils
 				.getSpinnerButtonWidth(SubstanceSizeUtils
 						.getComponentFontSize(this.prevButton));
-		this.prevButton.setPreferredSize(new Dimension(spinnerButtonSize,
-				spinnerButtonSize));
+		this.prevButton.setPreferredSize(new Dimension((int) spinnerButtonSize,
+				(int) spinnerButtonSize));
 		this.prevButton.setMinimumSize(new Dimension(5, 5));
 
-		Set<Side> openSides = new HashSet<Side>();
-		openSides.add(Side.TOP);
-		openSides.add(Side.BOTTOM);
-		openSides.add(Side.RIGHT);
+		// Set<Side> openSides = EnumSet.of(Side.BOTTOM, Side.TOP, Side.RIGHT);
 		this.prevButton.putClientProperty(
-				SubstanceLookAndFeel.BUTTON_OPEN_SIDE_PROPERTY, openSides);
+				SubstanceLookAndFeel.BUTTON_OPEN_SIDE_PROPERTY, EnumSet
+						.allOf(Side.class));
 
 		this.installPreviousButtonListeners(this.prevButton);
 		return this.prevButton;
@@ -209,13 +200,9 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 
 		Border b = this.spinner.getBorder();
 		if (b == null || b instanceof UIResource) {
-			this.spinner.setBorder(// new
-					// BorderUIResource.CompoundBorderUIResource(
-					new SubstanceBorder(SubstanceSizeUtils
-							.getSpinnerBorderInsets(SubstanceSizeUtils
-									.getComponentFontSize(this.spinner))));
-			// ,
-			// new BasicBorders.MarginBorder()));
+			this.spinner.setBorder(new SubstanceBorder(SubstanceSizeUtils
+					.getSpinnerBorderInsets(SubstanceSizeUtils
+							.getComponentFontSize(this.spinner))));
 		}
 	}
 
@@ -227,9 +214,6 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	@Override
 	protected void installListeners() {
 		super.installListeners();
-		// this.substanceFocusListener = new FocusBorderListener(this.spinner);
-		// this.spinner.addFocusListener(this.substanceFocusListener);
-
 		this.substancePropertyChangeListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
 				if ("editor".equals(evt.getPropertyName())) {
@@ -281,7 +265,9 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 				if ("font".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
 						public void run() {
-							spinner.updateUI();
+							if (spinner != null) {
+								spinner.updateUI();
+							}
 						}
 					});
 				}
@@ -293,24 +279,24 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 						JTextField tf = ((JSpinner.DefaultEditor) editor)
 								.getTextField();
 						if (tf != null) {
-							if (tf.getBackground() instanceof UIResource) {
-								// can replace
-								tf.setBackground(spinner.getBackground());
+							// Use SubstanceColorResource to distingish between
+							// color set by application and color set
+							// (propagated)
+							// by Substance. In the second case we can replace
+							// that color (even though it's not a UIResource).
+							boolean canReplace = (tf.getBackground() instanceof UIResource)
+									|| (tf.getBackground() instanceof SubstanceColorResource);
+							// fix for issue 387 - if spinner background
+							// is null, do nothing
+							if (spinner.getBackground() == null)
+								canReplace = false;
+							if (canReplace) {
+								tf.setBackground(new SubstanceColorResource(
+										spinner.getBackground()));
 							}
 						}
 					}
 				}
-
-				// // enhancement 266 - track model changes to
-				// // disable spinner buttons
-				// if ("model".equals(evt.getPropertyName())) {
-				// SpinnerModel old = (SpinnerModel) evt.getOldValue();
-				// if (old != null) {
-				// (old).removeChangeListener(substanceChangeListener);
-				// }
-				// spinner.getModel().addChangeListener(
-				// substanceChangeListener);
-				// }
 			}
 		};
 		this.spinner
@@ -336,19 +322,6 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 					});
 			this.substanceFadeStateListener.registerListeners();
 		}
-
-		// // enhancement 266 - track model state and disable
-		// // spinner buttons if necessary (limit value
-		// // reached).
-		// this.substanceChangeListener = new ChangeListener() {
-		// public void stateChanged(ChangeEvent e) {
-		// boolean hasPrev = (spinner.getModel().getPreviousValue() != null);
-		// boolean hasNext = (spinner.getModel().getNextValue() != null);
-		// prevButton.setEnabled(hasPrev);
-		// nextButton.setEnabled(hasNext);
-		// }
-		// };
-		// this.spinner.getModel().addChangeListener(this.substanceChangeListener);
 	}
 
 	/*
@@ -376,7 +349,7 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
@@ -386,6 +359,26 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 						FadeKind.FOCUS)) {
 			this.paintFocus(g, this.spinner.getEditor().getBounds());
 		}
+		if (this.spinner.isEnabled()) {
+			Graphics2D g2d = (Graphics2D) g.create();
+			g2d.setColor(Color.red);
+			SubstanceColorScheme borderColorScheme = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(c, ComponentState.DEFAULT);
+			if (this.spinner.getComponentOrientation().isLeftToRight()) {
+				g2d.translate(this.spinner.getEditor().getX()
+						+ this.spinner.getEditor().getWidth(), -5);
+				SubstanceImageCreator.paintSimpleBorder(g2d, 2 * nextButton
+						.getWidth(), this.spinner.getHeight() + 10,
+						borderColorScheme, borderColorScheme, 0.0f);
+			} else {
+				g2d.translate(-5, -5);
+				SubstanceImageCreator.paintSimpleBorder(g2d, 5 + this.spinner
+						.getEditor().getX(), this.spinner.getHeight() + 10,
+						borderColorScheme, borderColorScheme, 0.0f);
+			}
+			g2d.dispose();
+		}
+
 	}
 
 	/**
@@ -434,7 +427,8 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -454,11 +448,11 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
-		SubstanceCoreUtilities.paintTextCompBackground(g, c);
+		SubstanceTextUtilities.paintTextCompBackground(g, c);
 		this.paint(g, c);
 	}
 
@@ -467,6 +461,11 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 		return new SpinnerLayoutManager();
 	}
 
+	/**
+	 * Layout manager for the spinner.
+	 * 
+	 * @author Kirill Grouchnikov
+	 */
 	protected class SpinnerLayoutManager implements LayoutManager {
 		public void addLayoutComponent(String name, Component comp) {
 		}
@@ -493,6 +492,12 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 			Insets insets = parent.getInsets();
 			size.width += insets.left + insets.right;
 			size.height += insets.top + insets.bottom;
+
+			Insets buttonInsets = SubstanceSizeUtils
+					.getSpinnerArrowButtonInsets(SubstanceSizeUtils
+							.getComponentFontSize(spinner));
+			size.width += (buttonInsets.left + buttonInsets.right);
+
 			return size;
 		}
 
@@ -509,9 +514,6 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 			Insets buttonInsets = SubstanceSizeUtils
 					.getSpinnerArrowButtonInsets(SubstanceSizeUtils
 							.getComponentFontSize(spinner));
-			if (buttonInsets == null) {
-				buttonInsets = insets;
-			}
 
 			/*
 			 * Deal with the spinner's componentOrientation property.
@@ -520,13 +522,13 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 			if (parent.getComponentOrientation().isLeftToRight()) {
 				editorX = insets.left;
 				editorWidth = width - insets.left - buttonsWidth
-						- buttonInsets.right;
+						- buttonInsets.right - buttonInsets.left;
 				buttonsX = width - buttonsWidth - buttonInsets.right;
 			} else {
 				buttonsX = buttonInsets.left;
-				editorX = buttonsX + buttonsWidth;
+				editorX = buttonsX + buttonsWidth + buttonInsets.left;
 				editorWidth = width - buttonInsets.left - buttonsWidth
-						- insets.right;
+						- insets.right - buttonInsets.left;
 			}
 
 			int nextY = buttonInsets.top;
@@ -539,7 +541,8 @@ public class SubstanceSpinnerUI extends BasicSpinnerUI {
 			nextButton.setBounds(buttonsX, nextY, buttonsWidth, nextHeight);
 			prevButton.setBounds(buttonsX, previousY, buttonsWidth,
 					previousHeight);
+			// System.out.println("next : " + nextButton.getBounds());
+			// System.out.println("prev : " + prevButton.getBounds());
 		}
-
 	}
 }
