@@ -43,9 +43,10 @@ import javax.swing.table.*;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTableHeaderCellRenderer;
 import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -84,6 +85,9 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 	 */
 	private Map<Integer, ComponentState> nextStateMap;
 
+	/**
+	 * Property change listener.
+	 */
 	protected PropertyChangeListener substancePropertyChangeListener;
 
 	/**
@@ -110,7 +114,9 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.event.ListSelectionListener#valueChanged(javax.swing.event.ListSelectionEvent)
+		 * @see
+		 * javax.swing.event.ListSelectionListener#valueChanged(javax.swing.
+		 * event.ListSelectionEvent)
 		 */
 		public void valueChanged(ListSelectionEvent e) {
 			if (ui.header == null)
@@ -125,9 +131,9 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent h) {
-		SubstanceTableHeaderUI result = new SubstanceTableHeaderUI();
-		return result;
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceTableHeaderUI();
 	}
 
 	/**
@@ -166,16 +172,24 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 				}
 			}
 
-			@SuppressWarnings("unchecked")
 			public void valueChanged(ListSelectionEvent e) {
 				if (header == null)
 					return;
 
+				// fix for issue 367 - check that there is an associated
+				// table and that it has a substance UI delegate
+				JTable table = header.getTable();
+				if (table == null)
+					return;
+
+				TableUI ui = table.getUI();
+				if (!(ui instanceof SubstanceTableUI))
+					return;
+
 				// optimization on large tables and large selections
 				// and syncing the fade presence with the table
 				// (issue 309)
-				SubstanceTableUI tableUI = (SubstanceTableUI) header.getTable()
-						.getUI();
+				SubstanceTableUI tableUI = (SubstanceTableUI) ui;
 				// System.out.println("Sel anim: "
 				// + tableUI.hasSelectionAnimations());
 				if (!tableUI.hasSelectionAnimations())
@@ -295,6 +309,8 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 				prevStateMap.put(i, ComponentState.SELECTED);
 			}
 		}
+		this.header.putClientProperty(SubstanceCoreUtilities.USE_HIGHLIGHT,
+				Boolean.TRUE);
 	}
 
 	/*
@@ -344,7 +360,7 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
@@ -449,14 +465,26 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 				aColumn.getHeaderValue(), false, false, -1, columnIndex);
 	}
 
-	public void paintGrid(Graphics g, JComponent c) {
+	/**
+	 * 
+	 * 
+	 * @param g
+	 * @param c
+	 */
+	protected void paintGrid(Graphics g, JComponent c) {
 		boolean ltr = header.getComponentOrientation().isLeftToRight();
 
 		Graphics2D g2d = (Graphics2D) g.create();
 
 		Rectangle clip = g.getClipBounds();
 		Point left = clip.getLocation();
-		Point right = new Point(clip.x + clip.width - 1, clip.y);
+		// tweak the points for issue 378 - making sure that the
+		// grid lines are repainted correctly on scroll.
+		int lineWeight = (int) Math.ceil(SubstanceSizeUtils
+				.getBorderStrokeWidth(SubstanceSizeUtils
+						.getComponentFontSize(c)));
+		left = new Point(left.x - 2 * lineWeight, left.y);
+		Point right = new Point(clip.x + clip.width + 2 * lineWeight, clip.y);
 
 		TableColumnModel cm = header.getColumnModel();
 
@@ -468,7 +496,7 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		}
 
 		Rectangle cellRect0 = header.getHeaderRect(cMin);
-		int top = cellRect0.y;
+		// int top = cellRect0.y;
 		int bottom = cellRect0.y + cellRect0.height;
 
 		Color gridColor = getGridColor(this.header);
@@ -484,8 +512,10 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		g2d.setComposite(TransitionLayout.getAlphaComposite(this.header, 0.7f,
 				g));
 
+		// g2d.setColor(Color.red);
 		g2d.drawLine((int) left.getX(), (int) (bottom - strokeWidth / 2),
 				(int) right.getX(), (int) (bottom - strokeWidth / 2));
+		// g2d.setColor(gridColor);
 		// g2d.drawLine((int) left.getX(), top + (int) (strokeWidth / 2),
 		// (int) right.getX(), top + (int) (strokeWidth / 2));
 
@@ -538,31 +568,19 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		g2d.dispose();
 	}
 
+	/**
+	 * Returns the grid color for the table header.
+	 * 
+	 * @param header
+	 *            Table header.
+	 * @return Grid color.
+	 */
 	protected static Color getGridColor(JTableHeader header) {
 		ComponentState currState = (header.isEnabled() && header.getTable()
 				.isEnabled()) ? ComponentState.DEFAULT
 				: ComponentState.DISABLED_UNSELECTED;
-		SubstanceTheme currTheme = SubstanceThemeUtilities.getHighlightTheme(
-				header, currState);
-		Color gridColor = currTheme.getBorderTheme().getColorScheme()
-				.getDarkColor();
-
-		// // support for enhancement 256 - colorization of controls.
-		// boolean hasColorization = SubstanceCoreUtilities
-		// .hasColorization(header);
-		// if (hasColorization) {
-		// Color backgr = header.getBackground();
-		// if (!(backgr instanceof UIResource)) {
-		// double colorizationFactor = SubstanceCoreUtilities
-		// .getColorizationFactor(header);
-		// if (!header.isEnabled() || !header.getTable().isEnabled())
-		// colorizationFactor /= 2.0;
-		// Color toShiftTo = SubstanceColorUtilities.deriveByBrightness(
-		// backgr, gridColor);
-		// gridColor = SubstanceColorUtilities.getInterpolatedColor(
-		// toShiftTo, gridColor, colorizationFactor);
-		// }
-		// }
+		Color gridColor = SubstanceColorSchemeUtilities.getBorderColorScheme(
+				header, currState).getDarkColor();
 		return gridColor;
 	}
 
@@ -584,189 +602,56 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		g2d.setComposite(TransitionLayout.getAlphaComposite(header, g));
 
 		// paint default background
-		final Component component = getHeaderRenderer(columnIndex);
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		final ComponentState prevState = getPrevColumnState(columnIndex);
-		final ComponentState currState = getColumnState(columnIndex);
-
-		final ComponentState backgroundState = (this.header.isEnabled() && this.header
-				.getTable().isEnabled()) ? ComponentState.DEFAULT
-				: ComponentState.DISABLED_UNSELECTED;
-		final SubstanceTheme theme = SubstanceThemeUtilities.getTheme(
-				component, backgroundState);
-		if (textPainter.needsBackgroundImage()) {
-			final Rectangle offsetCellRect = new Rectangle(0, 0,
-					cellRect.width, cellRect.height);
-			textPainter.init(header, offsetCellRect, true);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							SubstanceHighlightUtils.paintHighlight(g2d,
-									component, offsetCellRect, 0.0f, null,
-									theme.getColorScheme(), theme
-											.getColorScheme(), 0.0f);
-							// SubstanceHighlightUtils.paintHighlight(g2d,
-							// component, backgroundState,
-							// backgroundState, offsetCellRect, 0.0f);
-							g2d.dispose();
-						}
-					});
-		} else {
-			SubstanceHighlightUtils.paintHighlight(g2d, component, cellRect,
-					0.0f, null, theme.getColorScheme(), theme.getColorScheme(),
-					0.0f);
-			// highlightDelegate.paintClassicHighlight(g, component, cellRect,
-			// SubstanceCoreUtilities.getTheme(header, backgroundState,
-			// true, true, true), 0.0f);
-		}
-
-		// float alphaForPrevBackground = 0.0f;
+		Component component = getHeaderRenderer(columnIndex);
+		ComponentState prevState = getPrevColumnState(columnIndex);
+		ComponentState currState = getColumnState(columnIndex);
 
 		// Compute the alpha values for the animation.
-		float startAlpha = SubstanceThemeUtilities.getHighlightAlpha(header,
-				prevState);
-		float endAlpha = SubstanceThemeUtilities.getHighlightAlpha(header,
-				currState);
-		// float alphaForCurrBackground = endAlpha;
+		float startAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(
+				header, prevState);
+		float endAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(
+				header, currState);
 
 		FadeState state = SubstanceFadeUtilities.getFadeState(header,
 				columnIndex, FadeKind.SELECTION, FadeKind.ROLLOVER);
-		float totalAlpha = endAlpha;
+		float totalHighlightAlpha = endAlpha;
 		float fadeCoef = 0.0f;
 		if (state != null) {
 			fadeCoef = state.getFadePosition();
 
 			// compute the total alpha of the overlays.
 			if (state.isFadingIn()) {
-				totalAlpha = startAlpha + (endAlpha - startAlpha) * fadeCoef
-						/ 10.0f;
+				totalHighlightAlpha = startAlpha + (endAlpha - startAlpha)
+						* fadeCoef;
 			} else {
-				totalAlpha = startAlpha + (endAlpha - startAlpha)
-						* (10.0f - fadeCoef) / 10.0f;
+				totalHighlightAlpha = startAlpha + (endAlpha - startAlpha)
+						* (1.0f - fadeCoef);
 			}
 
 			if (state.isFadingIn())
-				fadeCoef = 10.0f - fadeCoef;
-
-			// compute the alpha for each one of the animation overlays
-			// alphaForPrevBackground = totalAlpha * fadeCoef / 10.0f;
-			// alphaForCurrBackground = totalAlpha * (10.0f - fadeCoef) / 10.0f;
+				fadeCoef = 1.0f - fadeCoef;
 		}
 
-		final SubstanceTheme prevTheme = SubstanceThemeUtilities
-				.getHighlightTheme(header, prevState);
-		final SubstanceTheme currTheme = SubstanceThemeUtilities
-				.getHighlightTheme(header, currState);
+		if (totalHighlightAlpha > 0.0f) {
+			SubstanceColorScheme prevHighlightScheme = SubstanceColorSchemeUtilities
+					.getHighlightColorScheme(header, prevState);
+			SubstanceColorScheme currHighlightScheme = SubstanceColorSchemeUtilities
+					.getHighlightColorScheme(header, currState);
 
-		// System.out.println(row + ":" + prevTheme.getDisplayName() + "["
-		// + alphaForPrevBackground + "]:" + currTheme.getDisplayName()
-		// + "[" + alphaForCurrBackground + "]");
-
-		if (textPainter.needsBackgroundImage()) {
-			// final float finalPrevAlpha = alphaForPrevBackground;
-			// final float finalCurrAlpha = alphaForCurrBackground;
-			final float finalTotalAlpha = totalAlpha;
-			final float finalFadeCoef = fadeCoef;
-
-			final Rectangle offsetCellRect = new Rectangle(0, 0,
-					cellRect.width, cellRect.height);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							if (finalTotalAlpha > 0.0f) {
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(header,
-												finalTotalAlpha, g));
-								SubstanceHighlightUtils.paintHighlight(g2d,
-										component, offsetCellRect, 0.0f, null,
-										currTheme.getColorScheme(), prevTheme
-												.getColorScheme(),
-										finalFadeCoef);
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(header, g));
-							}
-							// if (finalPrevAlpha > 0.0f) {
-							// g2d.setComposite(TransitionLayout
-							// .getAlphaComposite(header,
-							// finalPrevAlpha, g));
-							// SubstanceHighlightUtils.paintHighlight(g2d,
-							// component, prevState, prevState,
-							// offsetCellRect, 0.0f);
-							// // SubstanceTableHeaderUI.highlightDelegate
-							// // .paintClassicHighlight(g2d, component,
-							// // offsetCellRect, prevTheme, 0.0f);
-							// g2d.setComposite(TransitionLayout
-							// .getAlphaComposite(header, g));
-							// }
-							// if (finalCurrAlpha > 0.0f) {
-							// g2d.setComposite(TransitionLayout
-							// .getAlphaComposite(header,
-							// finalCurrAlpha, g));
-							// SubstanceHighlightUtils.paintHighlight(g2d,
-							// component, currState, currState,
-							// offsetCellRect, 0.0f);
-							// // SubstanceTableHeaderUI.highlightDelegate
-							// // .paintClassicHighlight(g2d, component,
-							// // offsetCellRect, currTheme, 0.0f);
-							// g2d.setComposite(TransitionLayout
-							// .getAlphaComposite(header, g));
-							// }
-							g2d.dispose();
-						}
-					});
-		} else {
-			if (totalAlpha > 0.0f) {
-				g2d.setComposite(TransitionLayout.getAlphaComposite(
-						this.header, totalAlpha, g));
-				SubstanceHighlightUtils.paintHighlight(g2d, component,
-						cellRect, 0.0f, null, currTheme.getColorScheme(),
-						prevTheme.getColorScheme(), fadeCoef);
-				g2d.setComposite(TransitionLayout.getAlphaComposite(
-						this.header, g));
-			}
-
-			// if (alphaForPrevBackground > 0.0f) {
-			// g2d.setComposite(TransitionLayout.getAlphaComposite(header,
-			// alphaForPrevBackground, g));
-			// SubstanceHighlightUtils.paintHighlight(g2d, component,
-			// prevState, prevState, cellRect, 0.0f);
-			// //
-			// SubstanceTableHeaderUI.highlightDelegate.paintClassicHighlight(
-			// // g2d, component, cellRect, prevTheme, 0.0f);
-			// g2d.setComposite(TransitionLayout.getAlphaComposite(header, g));
-			// }
-			// if (alphaForCurrBackground > 0.0f) {
-			// g2d.setComposite(TransitionLayout.getAlphaComposite(header,
-			// alphaForCurrBackground, g));
-			// SubstanceHighlightUtils.paintHighlight(g2d, component,
-			// currState, currState, cellRect, 0.0f);
-			// //
-			// SubstanceTableHeaderUI.highlightDelegate.paintClassicHighlight(
-			// // g2d, component, cellRect, currTheme, 0.0f);
-			// g2d.setComposite(TransitionLayout.getAlphaComposite(header, g));
-			// }
+			g2d.setComposite(TransitionLayout.getAlphaComposite(this.header,
+					totalHighlightAlpha, g));
+			SubstanceHighlightUtils.paintHighlight(g2d, component, cellRect,
+					0.0f, null, currHighlightScheme, prevHighlightScheme,
+					fadeCoef);
+			g2d
+					.setComposite(TransitionLayout.getAlphaComposite(
+							this.header, g));
 		}
 
-		this.header.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, Boolean.TRUE);
 		rendererPane.paintComponent(g2d, component, header, cellRect.x,
 				cellRect.y, cellRect.width, cellRect.height, true);
 
-		this.header.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, null);
 		g2d.dispose();
-		//
-		// Component component = getHeaderRenderer(columnIndex);
-		// SubstanceTheme theme = isSelected ? SubstanceCoreUtilities
-		// .getActiveTheme(header, true) : SubstanceCoreUtilities
-		// .getDefaultTheme(header, true);
-		// SubstanceTableHeaderUI.backgroundDelegate.update(g, component,
-		// cellRect, theme/* .getHighlightBackgroundTheme() */, true);
-		// rendererPane.paintComponent(g, component, header, cellRect.x,
-		// cellRect.y, cellRect.width, cellRect.height, true);
 	}
 
 	/**
@@ -790,33 +675,34 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
 		// fix for issue 175 - table header under resize mode off
 		// was painted in theme-agnostic (gray) color.
-		final ComponentState backgroundState = (this.header.isEnabled() && this.header
+		ComponentState backgroundState = (this.header.isEnabled() && this.header
 				.getTable().isEnabled()) ? ComponentState.DEFAULT
 				: ComponentState.DISABLED_UNSELECTED;
-		// SubstanceTheme theme = SubstanceCoreUtilities.getTheme(c,
-		// backgroundState, true, true, true);
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(c,
-				backgroundState);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(c, backgroundState);
 
-		SubstanceHighlightUtils.paintHighlight(g, c, c.getBounds(), 0.0f, null,
-				theme.getColorScheme(), theme.getColorScheme(), 0.0f);
-
-		// SubstanceHighlightUtils.paintHighlight(g, c, backgroundState,
-		// backgroundState, c.getBounds(), 0.0f);
-		// paintClassicHighlight(g, c, c.getBounds(), theme, 0.0f);
+		// fix for issue 360 - respect the clip bounds of the
+		// table header
+		Rectangle clip = g.getClipBounds();
+		if (clip == null)
+			clip = c.getBounds();
+		SubstanceHighlightUtils.paintHighlight(g, c, clip, 0.0f, null, scheme,
+				scheme, 0.0f);
 		paint(g, c);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTableHeaderUI#uninstallUI(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTableHeaderUI#uninstallUI(javax.swing.JComponent
+	 * )
 	 */
 	@Override
 	public void uninstallUI(JComponent c) {
@@ -903,20 +789,36 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		return new ColumnHeaderRepaintCallback(this.header, columnIndex);
 	}
 
+	/**
+	 * Returns the scroll pane corner filler component. This method is used in
+	 * {@link SubstanceScrollPaneUI} to put a consistent filler for tables.
+	 * 
+	 * @return Scroll pane corner filler.
+	 */
 	public JComponent getScrollPaneCornerFiller() {
 		return new ScrollPaneCornerFiller(this.header);
 	}
 
+	/**
+	 * Corner filler for tables wrapped in scroll panes.
+	 * 
+	 * @author Kirill Grouchnikov
+	 */
 	protected static class ScrollPaneCornerFiller extends JComponent implements
 			UIResource {
+		/**
+		 * Associated table header.
+		 */
 		protected JTableHeader header;
 
+		/**
+		 * Creates a new corner filler.
+		 * 
+		 * @param header
+		 *            Table header.
+		 */
 		public ScrollPaneCornerFiller(JTableHeader header) {
 			this.header = header;
-			// if (this.header == null) {
-			// System.err
-			// .println("************** Header is null ******************");
-			// }
 		}
 
 		@Override
@@ -929,19 +831,11 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 			final ComponentState backgroundState = (header.isEnabled() && header
 					.getTable().isEnabled()) ? ComponentState.DEFAULT
 					: ComponentState.DISABLED_UNSELECTED;
-			SubstanceTheme theme = SubstanceThemeUtilities.getTheme(header,
-					backgroundState);
+			SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+					.getColorScheme(header, backgroundState);
 			SubstanceHighlightUtils.paintHighlight(g2d, this.header,
 					new Rectangle(0, 0, this.getWidth(), this.getHeight()),
-					0.0f, null, theme.getColorScheme(), theme.getColorScheme(),
-					0.0f);
-
-			// SubstanceHighlightUtils.paintHighlight(g2d, header,
-			// backgroundState, backgroundState, new Rectangle(0, 0, this
-			// .getWidth(), this.getHeight()), 0.0f);
-			// paintClassicHighlight(g2d,
-			// header, new Rectangle(0, 0, this.getWidth(), this
-			// .getHeight()), theme, 0.0f);
+					0.0f, null, scheme, scheme, 0.0f);
 
 			g2d.setColor(getGridColor(this.header));
 			float strokeWidth = SubstanceSizeUtils
@@ -962,6 +856,14 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		}
 	}
 
+	/**
+	 * Processes the events on model changes on the table column model.
+	 * 
+	 * @param oldModel
+	 *            Old column model.
+	 * @param newModel
+	 *            New column model.
+	 */
 	public void processColumnModelChangeEvent(TableColumnModel oldModel,
 			TableColumnModel newModel) {
 		if (oldModel != null) {
@@ -1009,7 +911,9 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded(org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
 		 */
 		@Override
 		public void fadeEnded(FadeKind fadeKind) {
@@ -1032,8 +936,9 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org.jvnet.lafwidget.animation.FadeKind,
-		 *      boolean, float)
+		 * @see
+		 * org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org
+		 * .jvnet.lafwidget.animation.FadeKind, boolean, float)
 		 */
 		@Override
 		public void fadeReversed(FadeKind fadeKind, boolean isFadingIn,
@@ -1055,11 +960,12 @@ public class SubstanceTableHeaderUI extends BasicTableHeaderUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed(org.jvnet.lafwidget.utils.FadeTracker.FadeKind,
-		 *      float)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind, float)
 		 */
 		@Override
-		public void fadePerformed(FadeKind fadeKind, float fade10) {
+		public void fadePerformed(FadeKind fadeKind, float fade) {
 			if ((SubstanceTableHeaderUI.this.header == header)
 					&& (columnIndex < header.getColumnModel().getColumnCount())) {
 				nextStateMap.put(columnIndex, getColumnState(columnIndex));
