@@ -29,8 +29,8 @@
  */
 package org.jvnet.substance;
 
+import java.awt.Color;
 import java.awt.Graphics;
-import java.awt.Graphics2D;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
@@ -39,12 +39,10 @@ import javax.swing.border.Border;
 import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicBorders;
 import javax.swing.plaf.basic.BasicTextAreaUI;
-import javax.swing.text.*;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
-import org.jvnet.substance.text.*;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceSizeUtils;
+import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for text areas in <b>Substance</b> look and feel.
@@ -72,8 +70,9 @@ public class SubstanceTextAreaUI extends BasicTextAreaUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceTextAreaUI(c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceTextAreaUI(comp);
 	}
 
 	/**
@@ -149,131 +148,25 @@ public class SubstanceTextAreaUI extends BasicTextAreaUI {
 					new BasicBorders.MarginBorder());
 			this.textArea.setBorder(newB);
 		}
-	}
 
-	// /*
-	// * (non-Javadoc)
-	// *
-	// * @see
-	// javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
-	// */
-	// @Override
-	// protected void paintBackground(Graphics g) {
-	// SubstanceCoreUtilities.paintCompBackground(g, this.textArea);
-	// }
-	//
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#createHighlighter()
-	 */
-	@Override
-	protected Highlighter createHighlighter() {
-		return new SubstanceHighlighter();
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextAreaUI#create(javax.swing.text.Element)
-	 */
-	@Override
-	public View create(Element elem) {
-		View superResult = super.create(elem);
-		if (superResult instanceof PlainView) {
-			return new SubstancePlainView(elem);
-		}
-		if (superResult instanceof WrappedPlainView) {
-			return new SubstanceWrappedPlainView(elem,
-					((JTextArea) getComponent()).getWrapStyleWord());
-		}
-		return superResult;
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#modelChanged()
-	 */
-	@Override
-	protected void modelChanged() {
-		super.modelChanged();
-
-		JTextComponent component = this.getComponent();
-		View currView = getRootView(component);
-		Element defaultRootElement = component.getDocument()
-				.getDefaultRootElement();
-		if (currView instanceof PlainView) {
-			setView(new SubstancePlainView(defaultRootElement));
-		}
-		if (currView instanceof WrappedPlainView) {
-			setView(new SubstanceWrappedPlainView(defaultRootElement,
-					((JTextArea) getComponent()).getWrapStyleWord()));
+		// support for per-window skins
+		Color foregr = this.textArea.getForeground();
+		if ((foregr == null) || (foregr instanceof UIResource)) {
+			this.textArea.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceLookAndFeel.getCurrentSkin(
+							this.textArea).getMainDefaultColorScheme()));
 		}
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#paintSafely(java.awt.Graphics)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
 	 */
 	@Override
-	protected void paintSafely(Graphics _g) {
-		// // Have to call the super implementation since it sets a
-		// // private "painted" flag which affects many other places.
-		// // Without this there will be many visual artifacts with
-		// // painting the caret and highlights
-		// super.paintSafely(_g);
-		//
-		// SubstanceTextPainter textPainter = SubstanceLookAndFeel
-		// .getCurrentTextPainter();
-		//
-		// SubstanceTextPainter.BackgroundPaintingCallback callback = new
-		// SubstanceTextPainter.BackgroundPaintingCallback() {
-		// public void paintBackground(Graphics g) {
-		// Highlighter highlighter = getComponent().getHighlighter();
-		//
-		// // paint the background
-		// if (getComponent().isOpaque()) {
-		// SubstanceTextAreaUI.this.paintBackground(g);
-		// }
-		//
-		// // paint the highlights
-		// if (highlighter != null) {
-		// highlighter.paint(g);
-		// }
-		// }
-		// };
-		// textPainter.init(textArea, null, true);
-		// if (textPainter.needsBackgroundImage()) {
-		// textPainter.setBackgroundFill(textArea, textArea.getBackground(),
-		// false, 0, 0);
-		// textPainter.attachCallback(callback);
-		// } else {
-		// callback.paintBackground(_g);
-		// }
-		//
-		// // paint the view hierarchy
-		// Rectangle alloc = getVisibleEditorRect();
-		// if (alloc != null) {
-		// getRootView(textArea).paint(_g, alloc);
-		// }
-		// textPainter.renderSurface(_g);
-		//
-		// // paint the caret
-		// Caret caret = getComponent().getCaret();
-		// if (caret != null) {
-		// caret.paint(_g);
-		// }
-		// Have to call the super implementation since it sets a
-		// private "painted" flag which affects many other places.
-		// Without this there will be many visual artifacts with
-		// painting the caret and highlights
-		Graphics2D dummy = (Graphics2D) _g.create(0, 0, 0, 0);
-		super.paintSafely(dummy);
-		dummy.dispose();
-
-		SubstanceCoreUtilities.paintTextComponent(_g, this.textArea, this
-				.getRootView(this.textArea), this.getVisibleEditorRect());
+	protected void paintBackground(Graphics g) {
+		SubstanceTextUtilities.paintTextCompBackground(g, this.textArea);
 	}
+
 }
