@@ -29,7 +29,8 @@
  */
 package org.jvnet.substance;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Graphics;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 
@@ -38,12 +39,10 @@ import javax.swing.border.Border;
 import javax.swing.plaf.*;
 import javax.swing.plaf.basic.BasicBorders;
 import javax.swing.plaf.basic.BasicTextFieldUI;
-import javax.swing.text.*;
 
 import org.jvnet.lafwidget.animation.FadeStateListener;
-import org.jvnet.substance.text.SubstanceFieldView;
-import org.jvnet.substance.text.SubstanceHighlighter;
 import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceBorder;
 
 /**
  * UI for text fields in <b>Substance</b> look and feel.
@@ -71,8 +70,9 @@ public class SubstanceTextFieldUI extends BasicTextFieldUI {
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
-		return new SubstanceTextFieldUI(c);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
+		return new SubstanceTextFieldUI(comp);
 	}
 
 	/**
@@ -86,28 +86,15 @@ public class SubstanceTextFieldUI extends BasicTextFieldUI {
 		this.textField = (JTextField) c;
 	}
 
-//	/*
-//	 * (non-Javadoc)
-//	 * 
-//	 * @see javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
-//	 */
-//	@Override
-//	protected void paintBackground(Graphics g) {
-//		SubstanceCoreUtilities.paintCompBackground(g, this.textField);
-//	}
-//
+	/*
+	 * (non-Javadoc)
+	 * 
+	 * @see
+	 * javax.swing.plaf.basic.BasicTextUI#paintBackground(java.awt.Graphics)
+	 */
 	@Override
-	protected void paintSafely(Graphics _g) {
-		// Have to call the super implementation since it sets a
-		// private "painted" flag which affects many other places.
-		// Without this there will be many visual artifacts with
-		// painting the caret and highlights
-		Graphics2D dummy = (Graphics2D) _g.create(0, 0, 0, 0);
-		super.paintSafely(dummy);
-		dummy.dispose();
-
-		SubstanceCoreUtilities.paintTextComponent(_g, this.textField,
-				this.getRootView(this.textField), this.getVisibleEditorRect());
+	protected void paintBackground(Graphics g) {
+		SubstanceTextUtilities.paintTextCompBackground(g, this.textField);
 	}
 
 	/*
@@ -172,29 +159,13 @@ public class SubstanceTextFieldUI extends BasicTextFieldUI {
 					new BasicBorders.MarginBorder());
 			this.textField.setBorder(newB);
 		}
-	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextFieldUI#create(javax.swing.text.Element)
-	 */
-	@Override
-	public View create(Element elem) {
-		View superResult = super.create(elem);
-		if (superResult instanceof FieldView) {
-			return new SubstanceFieldView(elem);
+		// support for per-window skins
+		Color foregr = this.textField.getForeground();
+		if ((foregr == null) || (foregr instanceof UIResource)) {
+			this.textField.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceLookAndFeel.getCurrentSkin(
+							this.textField).getMainDefaultColorScheme()));
 		}
-		return superResult;
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see javax.swing.plaf.basic.BasicTextUI#createHighlighter()
-	 */
-	@Override
-	protected Highlighter createHighlighter() {
-		return new SubstanceHighlighter();
 	}
 }
