@@ -41,9 +41,10 @@ import javax.swing.text.View;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.button.SubstanceButtonShaper;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.shaper.SubstanceButtonShaper;
 import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.border.SubstanceButtonBorder;
 import org.jvnet.substance.utils.icon.GlowingIcon;
 
 /**
@@ -57,11 +58,6 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 */
 	private ButtonBackgroundDelegate delegate;
 
-	/**
-	 * The rollover button listener.
-	 */
-	private RolloverButtonListener substanceButtonListener;
-
 	/**
 	 * The matching glowing icon. Is used only when
 	 * {@link FadeConfigurationManager#fadeAllowed(FadeKind, Component)} returns
@@ -77,17 +73,17 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	protected PropertyChangeListener substancePropertyListener;
 
 	/**
-	 * Listener for fade animations.
+	 * Tracker for visual state transitions.
 	 */
-	protected FadeStateListener substanceFadeStateListener;
+	protected ButtonVisualStateTracker substanceVisualStateTracker;
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent b) {
-		((AbstractButton) b).setRolloverEnabled(true);
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceToggleButtonUI();
 	}
 
@@ -101,7 +97,8 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installDefaults(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installDefaults(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	public void installDefaults(AbstractButton b) {
@@ -135,6 +132,8 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 		// fix for defect 140
 		b.setOpaque(false);
 
+		b.setRolloverEnabled(true);
+
 		LookAndFeel.installProperty(b, "iconTextGap", SubstanceSizeUtils
 				.getTextIconGap(SubstanceSizeUtils.getComponentFontSize(b)));
 	}
@@ -142,7 +141,8 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallDefaults(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	public void uninstallDefaults(AbstractButton b) {
@@ -158,7 +158,9 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing.AbstractButton)
+	 * @see
+	 * javax.swing.plaf.basic.BasicButtonUI#createButtonListener(javax.swing
+	 * .AbstractButton)
 	 */
 	@Override
 	protected BasicButtonListener createButtonListener(AbstractButton b) {
@@ -168,39 +170,34 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#installListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void installListeners(final AbstractButton b) {
 		super.installListeners(b);
 
-		this.substanceButtonListener = new RolloverButtonListener(b);
-		b.addMouseListener(this.substanceButtonListener);
-		b.addMouseMotionListener(this.substanceButtonListener);
-		b.addFocusListener(this.substanceButtonListener);
-		b.addPropertyChangeListener(this.substanceButtonListener);
-		b.addChangeListener(this.substanceButtonListener);
+		this.substanceVisualStateTracker = new ButtonVisualStateTracker();
+		this.substanceVisualStateTracker.installListeners(b, true);
+		// ButtonVisualStateTracker.track(b, true);
+		// this.substanceButtonListener = new RolloverButtonListener(b);
+		// b.addMouseListener(this.substanceButtonListener);
+		// b.addMouseMotionListener(this.substanceButtonListener);
+		// b.addFocusListener(this.substanceButtonListener);
+		// b.addPropertyChangeListener(this.substanceButtonListener);
+		// b.addChangeListener(this.substanceButtonListener);
 
 		this.substancePropertyListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
-				if (SubstanceLookAndFeel.BUTTON_SHAPER_PROPERTY.equals(evt
-						.getPropertyName())) {
-					SwingUtilities.invokeLater(new Runnable() {
-						public void run() {
-							SwingUtilities.updateComponentTreeUI(b);
-						}
-					});
-				}
-
-				if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
-						.getPropertyName())) {
-					if (substanceFadeStateListener != null)
-						substanceFadeStateListener.unregisterListeners();
-					substanceFadeStateListener = new FadeStateListener(b, b
-							.getModel(), SubstanceCoreUtilities
-							.getFadeCallback(b, false));
-					substanceFadeStateListener.registerListeners();
-				}
+				// if (AbstractButton.MODEL_CHANGED_PROPERTY.equals(evt
+				// .getPropertyName())) {
+				// if (substanceFadeStateListener != null)
+				// substanceFadeStateListener.unregisterListeners();
+				// substanceFadeStateListener = new FadeStateListener(b, b
+				// .getModel(), SubstanceCoreUtilities
+				// .getFadeCallback(b, false));
+				// substanceFadeStateListener.registerListeners();
+				// }
 				if (AbstractButton.ICON_CHANGED_PROPERTY.equals(evt
 						.getPropertyName())) {
 					trackGlowingIcon(b);
@@ -209,30 +206,34 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 		};
 		b.addPropertyChangeListener(this.substancePropertyListener);
 
-		this.substanceFadeStateListener = new FadeStateListener(b,
-				b.getModel(), SubstanceCoreUtilities.getFadeCallback(b, false));
-		this.substanceFadeStateListener.registerListeners();
+		// this.substanceFadeStateListener = new FadeStateListener(b,
+		// b.getModel(), SubstanceCoreUtilities.getFadeCallback(b, false));
+		// this.substanceFadeStateListener.registerListeners();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.AbstractButton)
+	 * @seejavax.swing.plaf.basic.BasicButtonUI#uninstallListeners(javax.swing.
+	 * AbstractButton)
 	 */
 	@Override
 	protected void uninstallListeners(AbstractButton b) {
-		b.removeMouseListener(this.substanceButtonListener);
-		b.removeMouseMotionListener(this.substanceButtonListener);
-		b.removeFocusListener(this.substanceButtonListener);
-		b.removePropertyChangeListener(this.substanceButtonListener);
-		b.removeChangeListener(this.substanceButtonListener);
-		this.substanceButtonListener = null;
+		this.substanceVisualStateTracker.uninstallListeners(b);
+		this.substanceVisualStateTracker = null;
+		// ButtonVisualStateTracker.untrack(b);
+		// b.removeMouseListener(this.substanceButtonListener);
+		// b.removeMouseMotionListener(this.substanceButtonListener);
+		// b.removeFocusListener(this.substanceButtonListener);
+		// b.removePropertyChangeListener(this.substanceButtonListener);
+		// b.removeChangeListener(this.substanceButtonListener);
+		// this.substanceButtonListener = null;
 
 		b.removePropertyChangeListener(this.substancePropertyListener);
 		this.substancePropertyListener = null;
 
-		this.substanceFadeStateListener.unregisterListeners();
-		this.substanceFadeStateListener = null;
+		// this.substanceFadeStateListener.unregisterListeners();
+		// this.substanceFadeStateListener = null;
 
 		super.uninstallListeners(b);
 	}
@@ -241,76 +242,78 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicToggleButtonUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
-//		final AbstractButton b = (AbstractButton) c;
-//
-//		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-//				.getCurrentTextPainter();
-//		textPainter.init(b, null, false);
-//		if (textPainter.needsBackgroundImage()) {
-//			textPainter.setBackgroundFill(b, b.getParent().getBackground(),
-//					true, 0, 0);
-//			textPainter
-//					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-//						public void paintBackground(Graphics g) {
-//							delegate.updateBackground(g, b);
-//						};
-//					});
-//		} else {
-//			this.delegate.updateBackground(g, b);
-//		}
-//
-//		FontMetrics fm = g.getFontMetrics();
-//
-//		Insets i = c.getInsets();
-//
-//		Rectangle viewRect = new Rectangle();
-//		Rectangle iconRect = new Rectangle();
-//		Rectangle textRect = new Rectangle();
-//
-//		viewRect.x = i.left;
-//		viewRect.y = i.top;
-//		viewRect.width = b.getWidth() - (i.right + viewRect.x);
-//		viewRect.height = b.getHeight() - (i.bottom + viewRect.y);
-//
-//		textRect.x = textRect.y = textRect.width = textRect.height = 0;
-//		iconRect.x = iconRect.y = iconRect.width = iconRect.height = 0;
-//
-//		Font f = c.getFont();
-//		g.setFont(f);
-//
-//		// layout the text and icon
-//		String text = SwingUtilities.layoutCompoundLabel(c, fm, b.getText(), b
-//				.getIcon(), b.getVerticalAlignment(), b
-//				.getHorizontalAlignment(), b.getVerticalTextPosition(), b
-//				.getHorizontalTextPosition(), viewRect, iconRect, textRect, b
-//				.getText() == null ? 0 : b.getIconTextGap());
-//
-//		View v = (View) c.getClientProperty(BasicHTML.propertyKey);
-//		if (v != null) {
-//			v.paint(g, textRect);
-//		} else {
-//			float alpha = this.paintButtonText(g, b, textRect, text);
-//			Graphics2D g2d = (Graphics2D) g.create();
-//			g2d.setComposite(TransitionLayout.getAlphaComposite(b, alpha, g));
-//			textPainter.renderSurface(g2d);
-//			g2d.dispose();
-//		}
-//
-//		// Paint the Icon
-//		if (b.getIcon() != null) {
-//			paintIcon(g, c, iconRect);
-//		}
-//
-//		if (b.isFocusPainted()) {
-//			if (b.hasFocus()
-//					|| FadeTracker.getInstance().isTracked(c, FadeKind.FOCUS)) {
-//				this.paintFocus(g, b, viewRect, textRect, iconRect);
-//			}
-//		}
+		// final AbstractButton b = (AbstractButton) c;
+		//
+		// SubstanceTextPainter textPainter = SubstanceLookAndFeel
+		// .getCurrentTextPainter();
+		// textPainter.init(b, null, false);
+		// if (textPainter.needsBackgroundImage()) {
+		// textPainter.setBackgroundFill(b, b.getParent().getBackground(),
+		// true, 0, 0);
+		// textPainter
+		// .attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback()
+		// {
+		// public void paintBackground(Graphics g) {
+		// delegate.updateBackground(g, b);
+		// };
+		// });
+		// } else {
+		// this.delegate.updateBackground(g, b);
+		// }
+		//
+		// FontMetrics fm = g.getFontMetrics();
+		//
+		// Insets i = c.getInsets();
+		//
+		// Rectangle viewRect = new Rectangle();
+		// Rectangle iconRect = new Rectangle();
+		// Rectangle textRect = new Rectangle();
+		//
+		// viewRect.x = i.left;
+		// viewRect.y = i.top;
+		// viewRect.width = b.getWidth() - (i.right + viewRect.x);
+		// viewRect.height = b.getHeight() - (i.bottom + viewRect.y);
+		//
+		// textRect.x = textRect.y = textRect.width = textRect.height = 0;
+		// iconRect.x = iconRect.y = iconRect.width = iconRect.height = 0;
+		//
+		// Font f = c.getFont();
+		// g.setFont(f);
+		//
+		// // layout the text and icon
+		// String text = SwingUtilities.layoutCompoundLabel(c, fm, b.getText(),
+		// b
+		// .getIcon(), b.getVerticalAlignment(), b
+		// .getHorizontalAlignment(), b.getVerticalTextPosition(), b
+		// .getHorizontalTextPosition(), viewRect, iconRect, textRect, b
+		// .getText() == null ? 0 : b.getIconTextGap());
+		//
+		// View v = (View) c.getClientProperty(BasicHTML.propertyKey);
+		// if (v != null) {
+		// v.paint(g, textRect);
+		// } else {
+		// float alpha = this.paintButtonText(g, b, textRect, text);
+		// Graphics2D g2d = (Graphics2D) g.create();
+		// g2d.setComposite(TransitionLayout.getAlphaComposite(b, alpha, g));
+		// textPainter.renderSurface(g2d);
+		// g2d.dispose();
+		// }
+		//
+		// // Paint the Icon
+		// if (b.getIcon() != null) {
+		// paintIcon(g, c, iconRect);
+		// }
+		//
+		// if (b.isFocusPainted()) {
+		// if (b.hasFocus()
+		// || FadeTracker.getInstance().isTracked(c, FadeKind.FOCUS)) {
+		// this.paintFocus(g, b, viewRect, textRect, iconRect);
+		// }
+		// }
 		final AbstractButton b = (AbstractButton) c;
 
 		if (b instanceof JButton) {
@@ -347,48 +350,26 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 				.getText() == null ? 0 : b.getIconTextGap());
 
 		Graphics2D g2d = (Graphics2D) g.create();
-		boolean hasEmptyText = (text == null) || (text.length() == 0);
 
-		final View v = (View) c.getClientProperty(BasicHTML.propertyKey);
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(b, null, v != null);
+		View v = (View) c.getClientProperty(BasicHTML.propertyKey);
 		g2d.setFont(f);
 
-		if (!hasEmptyText && textPainter.needsBackgroundImage()) {
-			textPainter.setBackgroundFill(b, b.getParent().getBackground(),
-					true, 0, 0);
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							delegate.updateBackground(g, b);
-						};
-					});
-		} else {
-			this.delegate.updateBackground(g2d, b);
-		}
-		float textAlpha = 1.0f;
+		this.delegate.updateBackground(g2d, b);
+		// float buttonAlpha = SubstanceThemeUtilities.getAlpha(b,
+		// ComponentState
+		// .getState(b.getModel(), b));
+		// g2d.setComposite(TransitionLayout.getAlphaComposite(b, buttonAlpha, g
+		// ));
 		if (v != null) {
-			if (textPainter.needsBackgroundImage()) {
-				textPainter
-						.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-							public void paintBackground(Graphics g) {
-								v.paint(g, textRect);
-							}
-						});
-			} else {
-				v.paint(g2d, textRect);
-			}
+			v.paint(g2d, textRect);
 		} else {
-			textAlpha = this.paintButtonText(g, b, textRect, text);
+			this.paintButtonText(g2d, b, textRect, text);
 		}
-		g2d.setComposite(TransitionLayout.getAlphaComposite(b, textAlpha, g));
-		textPainter.renderSurface(g2d);
-		g2d.setComposite(TransitionLayout.getAlphaComposite(b, 1.0f, g));
+		// g2d.setComposite(TransitionLayout.getAlphaComposite(b, 1.0f, g));
 
 		// Paint the Icon
 		if (b.getIcon() != null) {
-			paintIcon(g2d, c, iconRect);
+			paintIcon(g2d, b, iconRect);
 		}
 
 		if (b.isFocusPainted()) {
@@ -402,7 +383,8 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.ComponentUI#getPreferredSize(javax.swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -415,6 +397,9 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 		if (superPref == null)
 			return null;
 
+		if (shaper == null)
+			return superPref;
+
 		return shaper.getPreferredSize(button, superPref);
 	}
 
@@ -422,7 +407,7 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#contains(javax.swing.JComponent, int,
-	 *      int)
+	 * int)
 	 */
 	@Override
 	public boolean contains(JComponent c, int x, int y) {
@@ -433,8 +418,8 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicButtonUI#paintFocus(java.awt.Graphics,
-	 *      javax.swing.AbstractButton, java.awt.Rectangle, java.awt.Rectangle,
-	 *      java.awt.Rectangle)
+	 * javax.swing.AbstractButton, java.awt.Rectangle, java.awt.Rectangle,
+	 * java.awt.Rectangle)
 	 */
 	@Override
 	protected void paintFocus(Graphics g, AbstractButton b, Rectangle viewRect,
@@ -450,8 +435,9 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicToggleButtonUI#paintIcon(java.awt.Graphics,
-	 *      javax.swing.AbstractButton, java.awt.Rectangle)
+	 * @see
+	 * javax.swing.plaf.basic.BasicToggleButtonUI#paintIcon(java.awt.Graphics,
+	 * javax.swing.AbstractButton, java.awt.Rectangle)
 	 */
 	@Override
 	protected void paintIcon(Graphics g, AbstractButton b, Rectangle iconRect) {
@@ -462,26 +448,22 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 
 		graphics.setComposite(TransitionLayout.getAlphaComposite(b, g));
 		if (fadeTracker.isTracked(b, FadeKind.ROLLOVER)) {
-			ComponentState state = ComponentState.getState(b.getModel(), b);
+			ComponentState state = ComponentState.getState(b);
 			// System.out.println(state.name() + ":" + state.isRollover());
 			if (state.isKindActive(FadeKind.ROLLOVER)) {// ==
 				// ComponentState.ROLLOVER_UNSELECTED) {
 				// Came from default state
 				SubstanceCoreUtilities.getIcon(b, null, this.glowingIcon, true)
 						.paintIcon(b, graphics, iconRect.x, iconRect.y);
-				graphics
-						.setComposite(TransitionLayout
-								.getAlphaComposite(b, fadeTracker.getFade10(b,
-										FadeKind.ROLLOVER) / 10.0f, g));
+				graphics.setComposite(TransitionLayout.getAlphaComposite(b,
+						fadeTracker.getFade(b, FadeKind.ROLLOVER), g));
 				icon.paintIcon(b, graphics, iconRect.x, iconRect.y);
 			} else {
 				// if (state == ComponentState.DEFAULT) {
 				// Came from rollover state
 				icon.paintIcon(b, graphics, iconRect.x, iconRect.y);
-				graphics
-						.setComposite(TransitionLayout
-								.getAlphaComposite(b, fadeTracker.getFade10(b,
-										FadeKind.ROLLOVER) / 10.0f, g));
+				graphics.setComposite(TransitionLayout.getAlphaComposite(b,
+						fadeTracker.getFade(b, FadeKind.ROLLOVER), g));
 				b.getIcon().paintIcon(b, graphics, iconRect.x, iconRect.y);
 			}
 		} else {
@@ -502,12 +484,11 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 *            Text rectangle
 	 * @param text
 	 *            Text to paint
-	 * @return Text alpha channel.
 	 */
-	protected float paintButtonText(Graphics g, AbstractButton button,
+	protected void paintButtonText(Graphics g, AbstractButton button,
 			Rectangle textRect, String text) {
-		return SubstanceCoreUtilities.paintText(button, textRect, text,
-				(button).getDisplayedMnemonicIndex());
+		SubstanceTextUtilities.paintText(g, button, textRect, text, (button)
+				.getDisplayedMnemonicIndex());
 	}
 
 	/**
@@ -529,7 +510,7 @@ public class SubstanceToggleButtonUI extends BasicToggleButtonUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
