@@ -35,10 +35,11 @@ import javax.swing.*;
 import javax.swing.plaf.ComponentUI;
 import javax.swing.plaf.basic.BasicToolBarSeparatorUI;
 
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.painter.utils.SeparatorPainterUtils;
+import org.jvnet.substance.utils.SubstanceColorSchemeUtilities;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceThemeUtilities;
 
 /**
  * UI for toolbar separators in <b>Substance</b> look and feel.
@@ -46,7 +47,8 @@ import org.jvnet.substance.utils.SubstanceThemeUtilities;
  * @author Kirill Grouchnikov
  */
 public class SubstanceToolBarSeparatorUI extends BasicToolBarSeparatorUI {
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceToolBarSeparatorUI();
 	}
 
@@ -54,25 +56,25 @@ public class SubstanceToolBarSeparatorUI extends BasicToolBarSeparatorUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicSeparatorUI#paint(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void paint(Graphics g, JComponent c) {
 		Graphics2D graphics = (Graphics2D) g.create();
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(c)
-				.getDefaultTheme();
-		ColorScheme colorScheme = theme.getColorScheme();
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+				.getColorScheme(c, ComponentState.DEFAULT);
 
-		SubstanceCoreUtilities.paintSeparator(c, graphics, colorScheme,
-				SubstanceCoreUtilities.isThemeDark(theme), c.getWidth(), c
-						.getHeight(), ((JSeparator) c).getOrientation());
+		SeparatorPainterUtils.paintSeparator(c, graphics, scheme, c.getWidth(),
+				c.getHeight(), ((JSeparator) c).getOrientation());
 		graphics.dispose();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicToolBarSeparatorUI#getPreferredSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicToolBarSeparatorUI#getPreferredSize(javax
+	 * .swing.JComponent)
 	 */
 	@Override
 	public Dimension getPreferredSize(JComponent c) {
@@ -95,7 +97,9 @@ public class SubstanceToolBarSeparatorUI extends BasicToolBarSeparatorUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicSeparatorUI#getMaximumSize(javax.swing.JComponent)
+	 * @see
+	 * javax.swing.plaf.basic.BasicSeparatorUI#getMaximumSize(javax.swing.JComponent
+	 * )
 	 */
 	@Override
 	public Dimension getMaximumSize(JComponent c) {
