@@ -39,6 +39,8 @@ import javax.swing.plaf.basic.BasicToolBarUI;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
 /**
  * UI for tool bars in <b>Substance</b> look and feel.
@@ -46,17 +48,13 @@ import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
  * @author Kirill Grouchnikov
  */
 public class SubstanceToolBarUI extends BasicToolBarUI {
-	/**
-	 * Delegate for painting the background.
-	 */
-	// private static SubstanceFillBackgroundDelegate backgroundDelegate = new
-	// SubstanceFillBackgroundDelegate();
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent c) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceToolBarUI();
 	}
 
@@ -68,7 +66,7 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	@Override
 	protected void installDefaults() {
 		super.installDefaults();
-		SubstanceDecorationUtilities.setDecorationType(this.toolBar,
+		SubstanceLookAndFeel.setDecorationType(this.toolBar,
 				DecorationAreaType.TOOLBAR);
 	}
 
@@ -87,7 +85,7 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
@@ -102,7 +100,9 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicToolBarUI#setBorderToRollover(java.awt.Component)
+	 * @see
+	 * javax.swing.plaf.basic.BasicToolBarUI#setBorderToRollover(java.awt.Component
+	 * )
 	 */
 	@Override
 	protected void setBorderToRollover(Component c) {
@@ -111,7 +111,9 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicToolBarUI#setBorderToNonRollover(java.awt.Component)
+	 * @see
+	 * javax.swing.plaf.basic.BasicToolBarUI#setBorderToNonRollover(java.awt
+	 * .Component)
 	 */
 	@Override
 	protected void setBorderToNonRollover(Component c) {
@@ -120,7 +122,9 @@ public class SubstanceToolBarUI extends BasicToolBarUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicToolBarUI#setBorderToNormal(java.awt.Component)
+	 * @see
+	 * javax.swing.plaf.basic.BasicToolBarUI#setBorderToNormal(java.awt.Component
+	 * )
 	 */
 	@Override
 	protected void setBorderToNormal(Component c) {
