@@ -46,9 +46,11 @@ import javax.swing.tree.*;
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.utils.LookUtils;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.renderers.SubstanceDefaultTreeCellRenderer;
 import org.jvnet.substance.painter.highlight.SubstanceHighlightUtils;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.painter.utils.SubstanceFillBackgroundDelegate;
 import org.jvnet.substance.utils.*;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 
@@ -93,11 +95,11 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 */
 	protected MouseListener substanceRowSelectionListener;
 
-	/**
-	 * If <code>true</code>, the mouse pointer is in the bounds of the
-	 * associated tree.
-	 */
-	private boolean isInside = false;
+	// /**
+	// * If <code>true</code>, the mouse pointer is in the bounds of the
+	// * associated tree.
+	// */
+	// private boolean isInside = false;
 
 	/**
 	 * Map of previous fade states (for state-aware theme transitions).
@@ -109,12 +111,34 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 */
 	private Map<TreePathId, ComponentState> nextStateMap;
 
+	// /**
+	// * Current hash color.
+	// */
+	// private Color currHashColor;
+
+	/**
+	 * The current default color scheme. Is computed in
+	 * {@link #update(Graphics, JComponent)} and reused in
+	 * {@link SubstanceDefaultTreeCellRenderer#getTreeCellRendererComponent(JTree, Object, boolean, boolean, boolean, int, boolean)}
+	 * for performance optimizations.
+	 */
+	private SubstanceColorScheme currDefaultColorScheme;
+
+	/**
+	 * Cell renderer insets. Is computed in {@link #installDefaults()} and
+	 * reused in
+	 * {@link SubstanceDefaultTreeCellRenderer#getTreeCellRendererComponent(JTree, Object, boolean, boolean, boolean, int, boolean)}
+	 * for performance optimizations.
+	 */
+	private Insets cellRendererInsets;
+
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#createUI(javax.swing.JComponent)
 	 */
-	public static ComponentUI createUI(JComponent tree) {
+	public static ComponentUI createUI(JComponent comp) {
+		SubstanceCoreUtilities.testComponentCreationThreadingViolation(comp);
 		return new SubstanceTreeUI();
 	}
 
@@ -136,7 +160,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	@Override
 	protected void installDefaults() {
 		super.installDefaults();
-		if (SubstanceCoreUtilities.toBleedWatermark(this.tree))
+		if (SubstanceCoreUtilities.toDrawWatermark(this.tree))
 			this.tree.setOpaque(false);
 
 		if (this.tree.getSelectionPaths() != null) {
@@ -151,6 +175,15 @@ public class SubstanceTreeUI extends BasicTreeUI {
 				this.tree, false)));
 		setCollapsedIcon(new IconUIResource(SubstanceIconFactory.getTreeIcon(
 				this.tree, true)));
+		this.tree.putClientProperty(SubstanceCoreUtilities.USE_HIGHLIGHT,
+				Boolean.TRUE);
+
+		// instead of computing the cell renderer insets on
+		// every cell rendering, compute it once and expose to the
+		// SubstanceDefaultTreeCellRenderer
+		this.cellRendererInsets = SubstanceSizeUtils
+				.getTreeCellRendererInsets(SubstanceSizeUtils
+						.getComponentFontSize(tree));
 	}
 
 	/*
@@ -168,8 +201,8 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.basic.BasicTreeUI#paintRow(java.awt.Graphics,
-	 *      java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
-	 *      javax.swing.tree.TreePath, int, boolean, boolean, boolean)
+	 * java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
+	 * javax.swing.tree.TreePath, int, boolean, boolean, boolean)
 	 */
 	@Override
 	protected void paintRow(Graphics g, Rectangle clipBounds, Insets insets,
@@ -188,16 +221,23 @@ public class SubstanceTreeUI extends BasicTreeUI {
 			leadIndex = -1;
 		}
 
-		final Component renderer = this.currentCellRenderer
+		Component renderer = this.currentCellRenderer
 				.getTreeCellRendererComponent(this.tree, path
 						.getLastPathComponent(), this.tree.isRowSelected(row),
 						isExpanded, isLeaf, row, (leadIndex == row));
 
-		// // second part - fix for defect 214 (rollover effects on non-opaque
-		// // trees resulted in inconsistent behaviour)
-		// boolean isWatermarkBleed = SubstanceCoreUtilities
-		// .toBleedWatermark(tree)
-		// || !tree.isOpaque();
+		if (!(renderer instanceof SubstanceDefaultTreeCellRenderer)) {
+			// if it's not Substance renderer - ask the Basic delegate to paint
+			// it.
+			super.paintRow(g, clipBounds, insets, bounds, path, row,
+					isExpanded, hasBeenExpanded, isLeaf);
+			if (shouldPaintExpandControl(path, row, isExpanded,
+					hasBeenExpanded, isLeaf)) {
+				paintExpandControlEnforce(g, clipBounds, insets, bounds, path,
+						row, isExpanded, hasBeenExpanded, isLeaf);
+			}
+			return;
+		}
 
 		TreePathId pathId = new TreePathId(path);
 
@@ -224,19 +264,19 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		if (background == null)
 			background = tree.getBackground();
 
-		final ComponentState prevState = this.getPrevPathState(pathId);
-		final ComponentState currState = this.getPathState(pathId);
+		ComponentState prevState = this.getPrevPathState(pathId);
+		ComponentState currState = this.getPathState(pathId);
 
-		final SubstanceTheme prevTheme = SubstanceThemeUtilities
-				.getHighlightTheme(tree, prevState);
-		final SubstanceTheme currTheme = SubstanceThemeUtilities
-				.getHighlightTheme(tree, currState);
+		SubstanceColorScheme prevScheme = SubstanceColorSchemeUtilities
+				.getHighlightColorScheme(tree, prevState);
+		SubstanceColorScheme currScheme = SubstanceColorSchemeUtilities
+				.getHighlightColorScheme(tree, currState);
 
 		// Compute the alpha values for the animation.
-		float startAlpha = SubstanceThemeUtilities.getHighlightAlpha(this.tree,
-				prevState);
-		float endAlpha = SubstanceThemeUtilities.getHighlightAlpha(this.tree,
-				currState);
+		float startAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(
+				this.tree, prevState);
+		float endAlpha = SubstanceColorSchemeUtilities.getHighlightAlpha(
+				this.tree, currState);
 
 		FadeState state = SubstanceFadeUtilities.getFadeState(this.tree,
 				pathId, FadeKind.SELECTION, FadeKind.ROLLOVER);
@@ -247,15 +287,14 @@ public class SubstanceTreeUI extends BasicTreeUI {
 
 			// compute the total alpha of the overlays.
 			if (state.isFadingIn()) {
-				totalAlpha = startAlpha + (endAlpha - startAlpha) * fadeCoef
-						/ 10.0f;
+				totalAlpha = startAlpha + (endAlpha - startAlpha) * fadeCoef;
 			} else {
 				totalAlpha = startAlpha + (endAlpha - startAlpha)
-						* (10.0f - fadeCoef) / 10.0f;
+						* (1.0f - fadeCoef);
 			}
 
 			if (state.isFadingIn())
-				fadeCoef = 10.0f - fadeCoef;
+				fadeCoef = 1.0f - fadeCoef;
 		}
 
 		// System.out.println(row + ":" + prevTheme.getDisplayName() + "["
@@ -265,9 +304,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		// The DefaultTreeCellRenderer overrides the isOpaque method
 		// so that there is no point in trying to make it non-opaque.
 		// Fix for defect 181.
-		final boolean canHaveSubstanceEffects = !(renderer instanceof DefaultTreeCellRenderer);
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
+		boolean canHaveSubstanceEffects = !(renderer instanceof DefaultTreeCellRenderer);
 		if (canHaveSubstanceEffects && (totalAlpha > 0.0f)) {
 			g2d.setComposite(TransitionLayout.getAlphaComposite(this.tree,
 					currFactor * totalAlpha, g));
@@ -278,105 +315,40 @@ public class SubstanceTreeUI extends BasicTreeUI {
 							.getInsets().left, bounds.y, this.tree.getWidth()
 							- this.tree.getInsets().right
 							- this.tree.getInsets().left, bounds.height), 0.8f,
-							null, currTheme.getColorScheme(), prevTheme
-									.getColorScheme(), fadeCoef);
+							null, currScheme, prevScheme, fadeCoef);
 			g2d.setComposite(TransitionLayout.getAlphaComposite(this.tree,
 					currFactor));
 		}
 
 		// System.out.println("Painting row " + row);
-		final boolean isWatermarkBleed = SubstanceCoreUtilities
-				.toBleedWatermark(this.tree);
-		if (textPainter.needsBackgroundImage()) {
-			final float finalTotalAlpha = totalAlpha;
-			final float finalCurrFactor = currFactor;
-			final float finalFadeCoef = fadeCoef;
-			final Rectangle cellRect = new Rectangle(this.tree.getInsets().left
-					- bounds.x, 0, this.tree.getWidth()
-					- this.tree.getInsets().right - this.tree.getInsets().left,
-					bounds.height);
-			textPainter.init(this.tree, cellRect, true);
-			textPainter.setBackgroundFill(this.tree, background, true,
-					bounds.x, bounds.y);
-
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							if (!isWatermarkBleed) {
-								// fill with the renderer
-								// background color
-								g2d.setColor(renderer.getBackground());
-								g2d.fillRect(0, 0, cellRect.width,
-										cellRect.height);
-							} else {
-								backgroundDelegate.fillAndWatermark(g2d, tree,
-										renderer.getBackground(), cellRect);
-							}
-							g2d.dispose();
-						}
-					});
-
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							Graphics2D g2d = (Graphics2D) g.create();
-							if (canHaveSubstanceEffects
-									&& (finalTotalAlpha > 0.0f)) {
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(tree,
-												finalCurrFactor
-														* finalTotalAlpha, g));
-								// Fix for defect 180 - painting the
-								// highlight beneath the entire row
-								SubstanceHighlightUtils.paintHighlight(g2d,
-										renderer, cellRect, 0.8f, null,
-										currTheme.getColorScheme(), prevTheme
-												.getColorScheme(),
-										finalFadeCoef);
-								g2d.setComposite(TransitionLayout
-										.getAlphaComposite(tree,
-												finalCurrFactor));
-							}
-						}
-					});
-		} else {
-		}
-
-		this.tree.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, Boolean.TRUE);
 		if (renderer instanceof JComponent) {
 			// Play with opacity to make our own gradient background
 			// on selected elements to show.
 			JComponent jRenderer = (JComponent) renderer;
-			synchronized (jRenderer) {
-				boolean newOpaque = !this.tree.isRowSelected(row);
-				if (SubstanceCoreUtilities.toBleedWatermark(this.tree))
-					newOpaque = false;
+			boolean newOpaque = !this.tree.isRowSelected(row);
+			if (SubstanceCoreUtilities.toDrawWatermark(this.tree))
+				newOpaque = false;
 
-				// fix for defect 181 - no highlight on renderers
-				// that extend DefaultTreeCellRenderer
-				newOpaque = newOpaque && canHaveSubstanceEffects;
+			// fix for defect 181 - no highlight on renderers
+			// that extend DefaultTreeCellRenderer
+			newOpaque = newOpaque && canHaveSubstanceEffects;
 
-				Map<Component, Boolean> opacity = new HashMap<Component, Boolean>();
-				if (!newOpaque)
-					SubstanceCoreUtilities.makeNonOpaque(jRenderer, opacity);
-				this.rendererPane.paintComponent(g2d, renderer, this.tree,
-						bounds.x, bounds.y, Math.max(this.tree.getWidth()
-								- this.tree.getInsets().right
-								- this.tree.getInsets().left - bounds.x,
-								bounds.width), bounds.height, true);
-				if (!newOpaque)
-					SubstanceCoreUtilities.restoreOpaque(jRenderer, opacity);
-			}
+			Map<Component, Boolean> opacity = new HashMap<Component, Boolean>();
+			if (!newOpaque)
+				SubstanceCoreUtilities.makeNonOpaque(jRenderer, opacity);
+			this.rendererPane.paintComponent(g2d, renderer, this.tree,
+					bounds.x, bounds.y, Math.max(this.tree.getWidth()
+							- this.tree.getInsets().right
+							- this.tree.getInsets().left - bounds.x,
+							bounds.width), bounds.height, true);
+			if (!newOpaque)
+				SubstanceCoreUtilities.restoreOpaque(jRenderer, opacity);
 		} else {
 			this.rendererPane.paintComponent(g2d, renderer, this.tree,
 					bounds.x, bounds.y, Math
 							.max(clipBounds.width, bounds.width),
 					bounds.height, true);
 		}
-		this.tree.putClientProperty(
-				SubstanceCoreUtilities.DO_NOT_FILL_BACKGROUND, null);
 
 		// Paint the expand control now after the row background has been
 		// overlayed by the highlight background on selected and rolled over
@@ -397,9 +369,10 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTreeUI#paintExpandControl(java.awt.Graphics,
-	 *      java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
-	 *      javax.swing.tree.TreePath, int, boolean, boolean, boolean)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTreeUI#paintExpandControl(java.awt.Graphics,
+	 * java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
+	 * javax.swing.tree.TreePath, int, boolean, boolean, boolean)
 	 */
 	@Override
 	protected void paintExpandControl(Graphics g, Rectangle clipBounds,
@@ -417,123 +390,71 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		// super implementation of paintExpandControl().
 	}
 
+	/**
+	 * Paints the expand control of the specified row.
+	 * 
+	 * @param g
+	 *            Graphics context.
+	 * @param clipBounds
+	 *            Clip bounds.
+	 * @param insets
+	 *            Insets.
+	 * @param bounds
+	 *            Row bounds.
+	 * @param path
+	 *            Tree path.
+	 * @param row
+	 *            Tree row.
+	 * @param isExpanded
+	 *            Expand indication.
+	 * @param hasBeenExpanded
+	 *            Indication whether this row has ever been expanded.
+	 * @param isLeaf
+	 *            Indication whether this row is a leaf.
+	 */
 	protected void paintExpandControlEnforce(Graphics g, Rectangle clipBounds,
 			Insets insets, Rectangle bounds, TreePath path, int row,
 			boolean isExpanded, boolean hasBeenExpanded, boolean isLeaf) {
-		boolean toPaint = (!this.tree.isEnabled())
-				|| this.isInside
-				|| !FadeConfigurationManager.getInstance().fadeAllowed(
-						SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-						tree);
+		// boolean toPaint = (!this.tree.isEnabled()) || this.isInside;
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.tree);
-		float alpha = theme.getThemeAlpha(this.tree,
+		float alpha = SubstanceColorSchemeUtilities.getAlpha(this.tree,
 				this.tree.isEnabled() ? ComponentState.DEFAULT
 						: ComponentState.DISABLED_UNSELECTED);
 
 		Graphics2D graphics = (Graphics2D) g.create();
-		if (FadeTracker.getInstance().isTracked(this.tree,
-				SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND)) {
-			toPaint = true;
-			alpha *= FadeTracker.getInstance().getFade10(this.tree,
-					SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND) / 10.0f;
-		}
-		if (toPaint) {
-			graphics.setComposite(TransitionLayout.getAlphaComposite(this.tree,
-					alpha, g));
-			super.paintExpandControl(graphics, clipBounds, insets, bounds,
-					path, row, isExpanded, hasBeenExpanded, isLeaf);
-		}
+		// if (toPaint) {
+		graphics.setComposite(TransitionLayout.getAlphaComposite(this.tree,
+				alpha, g));
+		super.paintExpandControl(graphics, clipBounds, insets, bounds, path,
+				row, isExpanded, hasBeenExpanded, isLeaf);
+		// }
 		graphics.dispose();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTreeUI#paintHorizontalPartOfLeg(java.awt.Graphics,
-	 *      java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
-	 *      javax.swing.tree.TreePath, int, boolean, boolean, boolean)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTreeUI#paintHorizontalPartOfLeg(java.awt.
+	 * Graphics, java.awt.Rectangle, java.awt.Insets, java.awt.Rectangle,
+	 * javax.swing.tree.TreePath, int, boolean, boolean, boolean)
 	 */
 	@Override
 	protected void paintHorizontalPartOfLeg(Graphics g, Rectangle clipBounds,
 			Insets insets, Rectangle bounds, TreePath path, int row,
 			boolean isExpanded, boolean hasBeenExpanded, boolean isLeaf) {
-		Graphics2D graphics = (Graphics2D) g.create();
-		float strokeWidth = SubstanceSizeUtils
-				.getBorderStrokeWidth(SubstanceSizeUtils
-						.getComponentFontSize(this.tree));
-		graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_ROUND,
-				BasicStroke.JOIN_BEVEL));
-		graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
-				RenderingHints.VALUE_ANTIALIAS_ON);
-
-		boolean toPaint = (!this.tree.isEnabled())
-				|| this.isInside
-				|| !FadeConfigurationManager.getInstance().fadeAllowed(
-						SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-						tree);
-
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.tree);
-		float alpha = theme.getThemeAlpha(this.tree,
-				this.tree.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED);
-
-		if (FadeTracker.getInstance().isTracked(this.tree,
-				SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND)) {
-			toPaint = true;
-			alpha *= FadeTracker.getInstance().getFade10(this.tree,
-					SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND) / 10.0f;
-		}
-		if (toPaint) {
-			graphics.setComposite(TransitionLayout.getAlphaComposite(this.tree,
-					alpha, g));
-			super.paintHorizontalPartOfLeg(graphics, clipBounds, insets,
-					bounds, path, row, isExpanded, hasBeenExpanded, isLeaf);
-		}
-		graphics.dispose();
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTreeUI#paintVerticalPartOfLeg(java.awt.Graphics,
-	 *      java.awt.Rectangle, java.awt.Insets, javax.swing.tree.TreePath)
+	 * @see
+	 * javax.swing.plaf.basic.BasicTreeUI#paintVerticalPartOfLeg(java.awt.Graphics
+	 * , java.awt.Rectangle, java.awt.Insets, javax.swing.tree.TreePath)
 	 */
 	@Override
 	protected void paintVerticalPartOfLeg(Graphics g, Rectangle clipBounds,
 			Insets insets, TreePath path) {
-		Graphics2D graphics = (Graphics2D) g.create();
-		float strokeWidth = SubstanceSizeUtils
-				.getBorderStrokeWidth(SubstanceSizeUtils
-						.getComponentFontSize(this.tree));
-		graphics.setStroke(new BasicStroke(strokeWidth, BasicStroke.CAP_BUTT,
-				BasicStroke.JOIN_BEVEL));
-		graphics.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
-				RenderingHints.VALUE_ANTIALIAS_ON);
-
-		boolean toPaint = (!this.tree.isEnabled())
-				|| this.isInside
-				|| !FadeConfigurationManager.getInstance().fadeAllowed(
-						SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-						tree);
-
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.tree);
-		float alpha = theme.getThemeAlpha(this.tree,
-				this.tree.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED);
-
-		if (FadeTracker.getInstance().isTracked(this.tree,
-				SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND)) {
-			toPaint = true;
-			alpha *= FadeTracker.getInstance().getFade10(this.tree,
-					SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND) / 10.0f;
-		}
-		if (toPaint) {
-			graphics.setComposite(TransitionLayout.getAlphaComposite(this.tree,
-					alpha, g));
-			super.paintVerticalPartOfLeg(graphics, clipBounds, insets, path);
-		}
-		graphics.dispose();
 	}
 
 	/*
@@ -556,10 +477,10 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		super.installListeners();
 		this.substancePropertyChangeListener = new PropertyChangeListener() {
 			public void propertyChange(PropertyChangeEvent evt) {
-				if (SubstanceLookAndFeel.WATERMARK_TO_BLEED.equals(evt
+				if (SubstanceLookAndFeel.WATERMARK_VISIBLE.equals(evt
 						.getPropertyName())) {
 					tree.setOpaque(!SubstanceCoreUtilities
-							.toBleedWatermark(tree));
+							.toDrawWatermark(tree));
 				}
 				if ("font".equals(evt.getPropertyName())) {
 					SwingUtilities.invokeLater(new Runnable() {
@@ -618,7 +539,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 * @author Kirill Grouchnikov
 	 */
 	@SuppressWarnings("unchecked")
-	protected static class TreePathId implements Comparable {
+	public static class TreePathId implements Comparable {
 		/**
 		 * Tree path.
 		 */
@@ -694,9 +615,10 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see javax.swing.event.TreeSelectionListener#valueChanged(javax.swing.event.TreeSelectionEvent)
+		 * @see
+		 * javax.swing.event.TreeSelectionListener#valueChanged(javax.swing.
+		 * event.TreeSelectionEvent)
 		 */
-		@SuppressWarnings("unchecked")
 		public void valueChanged(TreeSelectionEvent e) {
 			// Map<TreePathId, Object> currSelected = (Map<TreePathId, Object>)
 			// tree
@@ -738,7 +660,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected class PathRepaintCallback extends FadeTrackerAdapter {
+	protected class PathRepaintCallback extends UIThreadFadeTrackerAdapter {
 		/**
 		 * Associated tree.
 		 */
@@ -766,7 +688,9 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded(org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadeEnded
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind)
 		 */
 		@Override
 		public void fadeEnded(FadeKind fadeKind) {
@@ -789,11 +713,12 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed(org.jvnet.lafwidget.utils.FadeTracker.FadeKind,
-		 *      float)
+		 * @see
+		 * org.jvnet.lafwidget.utils.FadeTracker$FadeTrackerCallback#fadePerformed
+		 * (org.jvnet.lafwidget.utils.FadeTracker.FadeKind, float)
 		 */
 		@Override
-		public void fadePerformed(FadeKind fadeKind, float fade10) {
+		public void fadePerformed(FadeKind fadeKind, float fade) {
 			if (SubstanceTreeUI.this.tree == tree) {
 				TreePathId pathId = new TreePathId(treePath);
 				nextStateMap.put(pathId, getPathState(pathId));
@@ -804,8 +729,9 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org.jvnet.lafwidget.animation.FadeKind,
-		 *      boolean, float)
+		 * @see
+		 * org.jvnet.lafwidget.animation.FadeTrackerAdapter#fadeReversed(org
+		 * .jvnet.lafwidget.animation.FadeKind, boolean, float)
 		 */
 		@Override
 		public void fadeReversed(FadeKind fadeKind, boolean isFadingIn,
@@ -873,13 +799,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		public void mouseEntered(MouseEvent e) {
 			if (!tree.isEnabled())
 				return;
-			isInside = true;
-			if (FadeConfigurationManager.getInstance().fadeAllowed(
-					SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND, tree)) {
-				FadeTracker.getInstance().trackFadeIn(
-						SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-						tree, false, null);
-			}
+			// isInside = true;
 		}
 
 		public void mousePressed(MouseEvent e) {
@@ -891,13 +811,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		public void mouseExited(MouseEvent e) {
 			if (!tree.isEnabled())
 				return;
-			isInside = false;
-			if (FadeConfigurationManager.getInstance().fadeAllowed(
-					SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND, tree)) {
-				FadeTracker.getInstance().trackFadeOut(
-						SubstanceLookAndFeel.TREE_DECORATIONS_ANIMATION_KIND,
-						tree, false, null);
-			}
+			// isInside = false;
 			this.fadeOut();
 			// System.out.println("Nulling RO index");
 			currRolloverPathId = null;
@@ -906,7 +820,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		public void mouseMoved(MouseEvent e) {
 			if (!tree.isEnabled())
 				return;
-			isInside = true;
+			// isInside = true;
 			handleMove(e);
 		}
 
@@ -987,7 +901,8 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see java.awt.event.MouseAdapter#mousePressed(java.awt.event.MouseEvent)
+		 * @see
+		 * java.awt.event.MouseAdapter#mousePressed(java.awt.event.MouseEvent)
 		 */
 		@Override
 		public void mousePressed(MouseEvent e) {
@@ -1017,7 +932,8 @@ public class SubstanceTreeUI extends BasicTreeUI {
 
 	/**
 	 * Returns the pivot X for the cells rendered in the specified area. Used
-	 * for the smart tree scroll ({@link SubstanceLookAndFeel#TREE_SMART_SCROLL_ANIMATION_KIND}).
+	 * for the smart tree scroll (
+	 * {@link SubstanceLookAndFeel#TREE_SMART_SCROLL_ANIMATION_KIND}).
 	 * 
 	 * @param paintBounds
 	 *            Area bounds.
@@ -1099,7 +1015,7 @@ public class SubstanceTreeUI extends BasicTreeUI {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.plaf.ComponentUI#update(java.awt.Graphics,
-	 *      javax.swing.JComponent)
+	 * javax.swing.JComponent)
 	 */
 	@Override
 	public void update(Graphics g, JComponent c) {
@@ -1110,23 +1026,32 @@ public class SubstanceTreeUI extends BasicTreeUI {
 			return;
 		}
 
+		// compute the default color scheme - to optimize the performance
+		// SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+		// .getColorScheme(this.tree,
+		// this.tree.isEnabled() ? ComponentState.DEFAULT
+		// : ComponentState.DISABLED_UNSELECTED);
+		// this.currHashColor = scheme.getLineColor();
+		this.currDefaultColorScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(tree, ComponentState.DEFAULT);
+
 		Rectangle paintBounds = g.getClipBounds();
 		Insets insets = tree.getInsets();
 
 		TreePath initialPath = getClosestPathForLocation(tree, 0, paintBounds.y);
-		Enumeration paintingEnumerator = treeState
+		Enumeration<?> paintingEnumerator = treeState
 				.getVisiblePathsFrom(initialPath);
 		int row = treeState.getRowForPath(initialPath);
 		int endY = paintBounds.y + paintBounds.height;
 
 		// second part - fix for defect 214 (rollover effects on non-opaque
 		// trees resulted in inconsistent behaviour)
-		boolean isWatermarkBleed = SubstanceCoreUtilities
-				.toBleedWatermark(tree)
+		boolean isWatermarkBleed = SubstanceCoreUtilities.toDrawWatermark(tree)
 				|| !tree.isOpaque();
 
 		Graphics2D g2d = (Graphics2D) g.create();
 
+		SubstanceStripingUtils.setup(c);
 		if (initialPath != null && paintingEnumerator != null) {
 			boolean done = false;
 			Rectangle boundsBuffer = new Rectangle();
@@ -1181,38 +1106,35 @@ public class SubstanceTreeUI extends BasicTreeUI {
 		}
 
 		this.paint(g2d, c);
+		SubstanceStripingUtils.tearDown(c);
 		g2d.dispose();
 	}
 
-	/*
-	 * (non-Javadoc)
+	// /*
+	// * (non-Javadoc)
+	// *
+	// * @see javax.swing.plaf.basic.BasicTreeUI#getHashColor()
+	// */
+	// @Override
+	// protected Color getHashColor() {
+	// return this.currHashColor;
+	// }
+
+	/**
+	 * Returns the default color scheme of this tree. Is for internal use only.
 	 * 
-	 * @see javax.swing.plaf.basic.BasicTreeUI#getHashColor()
+	 * @return The default color scheme of this tree.
 	 */
-	@Override
-	protected Color getHashColor() {
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.tree,
-				this.tree.isEnabled() ? ComponentState.DEFAULT
-						: ComponentState.DISABLED_UNSELECTED);
-		Color curr = theme.getLineColor();
+	public SubstanceColorScheme getDefaultColorScheme() {
+		return this.currDefaultColorScheme;
+	}
 
-		// // support for enhancement 256 - colorization of controls.
-		// boolean hasColorization = SubstanceCoreUtilities
-		// .hasColorization(this.tree);
-		// if (hasColorization) {
-		// Color backgr = this.tree.getBackground();
-		// if (!(backgr instanceof UIResource)) {
-		// double colorizationFactor = SubstanceCoreUtilities
-		// .getColorizationFactor(this.tree);
-		// if (!tree.isEnabled())
-		// colorizationFactor /= 2.0;
-		// Color toShiftTo = SubstanceColorUtilities.deriveByBrightness(
-		// backgr, curr);
-		// curr = SubstanceColorUtilities.getInterpolatedColor(toShiftTo,
-		// curr, colorizationFactor);
-		// }
-		// }
-
-		return curr;
+	/**
+	 * Returns the cell renderer insets of this tree. Is for internal use only.
+	 * 
+	 * @return The cell renderer insets of this tree.
+	 */
+	public Insets getCellRendererInsets() {
+		return cellRendererInsets;
 	}
 }
