@@ -35,7 +35,6 @@ import java.awt.Toolkit;
 import java.util.Locale;
 
 import org.jvnet.lafwidget.utils.LookUtils;
-import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
  * Provides static access to popular Windows fonts. The sizes of the font
@@ -50,7 +49,7 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Large).
  * 
  * @author Karsten Lentzsch
- * @version $Revision: 1.4 $
+ * @version $Revision: 1.5 $
  * 
  * @see FontSet
  * @see FontSets
@@ -275,11 +274,7 @@ public final class Fonts {
 		// Java 1.4 and Java 5 raster the Segoe UI poorly,
 		// so we use the older Tahoma, if it can display the localized text.
 		if (LookUtils.IS_OS_WINDOWS_VISTA) {
-			// Substance-specific addition since version 4.2 - if the
-			// current text painter uses native text rendering, we
-			// allow using Segoe UI under JDK 5.0 as well.
-			if (LookUtils.IS_JAVA_1_4_OR_5
-					&& !SubstanceLookAndFeel.getCurrentTextPainter().isNative()) {
+			if (LookUtils.IS_JAVA_1_4_OR_5) {
 				Font tahoma = getDefaultGUIFontWesternModernWindowsNormal();
 				return Boolean.TRUE.equals(canDisplayLocalizedText(tahoma,
 						Locale.getDefault())) ? tahoma : defaultGUIFont;
