@@ -34,16 +34,18 @@ import java.awt.image.BufferedImage;
 import java.util.*;
 import java.util.List;
 
-import javax.swing.*;
+import javax.swing.Icon;
+import javax.swing.UIDefaults;
 import javax.swing.plaf.*;
 
 import org.jvnet.lafplugin.LafComponentPlugin;
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.color.ColorScheme;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceSkin;
 import org.jvnet.substance.fonts.FontSet;
-import org.jvnet.substance.theme.SubstanceTheme;
-import org.jvnet.substance.utils.*;
+import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.utils.SubstanceImageCreator;
+import org.jvnet.substance.utils.SubstanceSizeUtils;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 
 import contrib.ch.randelshofer.quaqua.ButtonStateIcon;
@@ -128,7 +130,7 @@ public class BasePlugin implements LafComponentPlugin {
 	 * 
 	 * @see org.jvnet.lafplugin.LafComponentPlugin#getDefaults(java.lang.Object)
 	 */
-	public Object[] getDefaults(Object mTheme) {
+	public Object[] getDefaults(Object mSkin) {
 		ResourceBundle bundle = ResourceBundle
 				.getBundle("contrib.ch.randelshofer.quaqua.Labels");
 		List labelsList = new LinkedList();
@@ -138,9 +140,10 @@ public class BasePlugin implements LafComponentPlugin {
 			labelsList.add(bundle.getObject(key));
 		}
 		if (this.hasQuaquaColorChooser) {
-			SubstanceTheme theme = (SubstanceTheme) mTheme;
+			SubstanceSkin skin = (SubstanceSkin) mSkin;
+			final SubstanceColorScheme colorScheme = skin
+					.getMainActiveColorScheme(DecorationAreaType.NONE);
 			InsetsUIResource visualMargin = new InsetsUIResource(0, 0, 0, 0);
-			ColorScheme colorScheme = theme.getColorScheme();
 			Color foregroundColor = new ColorUIResource(colorScheme
 					.getForegroundColor());
 			Object[] mainDefaults = new Object[] {
@@ -174,137 +177,9 @@ public class BasePlugin implements LafComponentPlugin {
 					"Component.visualMargin",
 					visualMargin,
 
-					// quaqua
-					// "ColorChooser.swatchesSwatchSize",
-					// new DimensionUIResource(5, 5),
-					//
-					// // quaqua
-					// "ColorChooser.resetMnemonic",
-					// new Integer(-1),
-					//
-					// // class names of default choosers for quaqua
-					// "ColorChooser.defaultChoosers",
-					// new String[] {
-					// "contrib.ch.randelshofer.quaqua.colorchooser.ColorWheelChooser",
-					// "contrib.ch.randelshofer.quaqua.colorchooser.ColorSlidersChooser",
-					// "contrib.ch.randelshofer.quaqua.colorchooser.ColorPalettesChooser",
-					// "contrib.ch.randelshofer.quaqua.colorchooser.SwatchesChooser",
-					// "contrib.ch.randelshofer.quaqua.colorchooser.CrayonsChooser",
-					// "contrib.ch.randelshofer.quaqua.colorchooser.ColorPicker",
-					// "contrib.net.xoetrope.editor.color.ColorWheelPanel" },
-					//
 					// quaqua
 					"ColorChooser.foreground",
 					foregroundColor,
-					//
-					// // quaqua
-					// "ColorChooser.swatchesSwatchSize",
-					// new DimensionUIResource(5, 5),
-					//
-					// // quaqua
-					// "ColorChooser.resetMnemonic",
-					// new Integer(-1),
-					//
-					// // quaqua
-					// "ColorChooser.crayonsImage",
-					// new UIDefaults.LazyValue() {
-					// public Object createValue(UIDefaults table) {
-					// return Toolkit
-					// .getDefaultToolkit()
-					// .createImage(
-					// this
-					// .getClass()
-					// .getResource(
-					// commonDir
-					// + "ColorChooser.crayons.png"));
-					// }
-					// },
-
-					// quaqua
-					// "ColorChooser.textSliderGap",
-					// new Integer(3),
-					//
-					// // quaqua
-					// "ColorChooser.colorPalettesIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.colorPalettesIcons.png", 3),
-					//
-					// // quaqua
-					// "ColorChooser.colorSlidersIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.colorSlidersIcons.png", 3),
-					//
-					// // quaqua
-					// "ColorChooser.colorSwatchesIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.colorSwatchesIcons.png", 3),
-					//
-					// // quaqua
-					// "ColorChooser.colorWheelIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.colorWheelIcons.png", 3),
-					//
-					// // quaqua
-					// "ColorChooser.crayonsIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.crayonsIcons.png", 3),
-					//
-					// // quaqua
-					// "ColorChooser.imagePalettesIcon",
-					// makeButtonStateIcon(commonDir
-					// + "ColorChooser.imagePalettesIcons.png", 3),
-					//
-					// // Note: The following colors are used in color lists.
-					// // It is important that these colors are neutral (black,
-					// // white
-					// // or a shade of gray with saturation 0).
-					// // If they aren't neutral, human perception of the color
-					// // is negatively affected.
-					// "ColorChooser.listSelectionBackground",
-					// new ColorUIResource(0xd4d4d4),
-					//
-					// "ColorChooser.listSelectionForeground",
-					// new ColorUIResource(0x000000),
-					//
-					// // Icon of the color picker tool
-					// "ColorChooser.colorPickerIcon",
-					// makeIcon(this.getClass(), commonDir
-					// + "ColorChooser.colorPickerIcon.png"),
-					// // Magnifying glass used as the cursor image
-					// "ColorChooser.colorPickerMagnifier",
-					// this.makeBufferedImage(commonDir
-					// + "ColorChooser.colorPickerMagnifier.png"),
-					// // Hot spot of the magnifier cursor
-					// "ColorChooser.colorPickerHotSpot",
-					// new UIDefaults.ProxyLazyValue("java.awt.Point",
-					// new Object[] { new Integer(29), new Integer(29) }),
-					// // Pick point relative to hot spot
-					// "ColorChooser.colorPickerPickOffset",
-					// new UIDefaults.ProxyLazyValue("java.awt.Point",
-					// new Object[] { new Integer(-13), new Integer(-13) }),
-					// // Rectangle used for drawing the mask of the magnifying
-					// // glass
-					// "ColorChooser.colorPickerGlassRect",
-					// new UIDefaults.ProxyLazyValue("java.awt.Rectangle",
-					// new Object[] { new Integer(2), new Integer(2),
-					// new Integer(29), new Integer(29) }),
-					// // Capture rectangle. Width and height must be equal
-					// sized
-					// // and must be odd.
-					// // The position of the capture rectangle is relative to
-					// the
-					// // hot spot.
-					// "ColorChooser.colorPickerCaptureRect",
-					// new UIDefaults.ProxyLazyValue("java.awt.Rectangle",
-					// new Object[] { new Integer(-15), new Integer(-15),
-					// new Integer(5), new Integer(5) }),
-					// // Zoomed (magnified) capture image. Width and height
-					// must
-					// // be a multiple of the capture rectangles size.
-					// "ColorChooser.colorPickerZoomRect",
-					// new UIDefaults.ProxyLazyValue("java.awt.Rectangle",
-					// new Object[] { new Integer(4), new Integer(4),
-					// new Integer(25), new Integer(25) }),
 
 					// class names of default choosers
 					"ColorChooser.defaultChoosers",
@@ -347,11 +222,13 @@ public class BasePlugin implements LafComponentPlugin {
 
 					// Icon of the color picker tool
 					"ColorChooser.colorPickerIcon",
-					// makeIcon(getClass(), commonDir
-					// + "ColorChooser.colorPickerIcon.png"),
-					new IconUIResource(SubstanceImageCreator.getSearchIcon(15,
-							SubstanceThemeUtilities.getTheme(null,
-									ComponentState.ACTIVE), true)),
+					new UIDefaults.LazyValue() {
+						@Override
+						public Object createValue(UIDefaults table) {
+							return new IconUIResource(SubstanceImageCreator
+									.getSearchIcon(15, colorScheme, true));
+						}
+					},
 
 					// Magnifying glass used as the cursor image
 					"ColorChooser.colorPickerMagnifier",
@@ -455,13 +332,5 @@ public class BasePlugin implements LafComponentPlugin {
 	 * @see org.jvnet.lafplugin.LafPlugin#initialize()
 	 */
 	public void initialize() {
-		try {
-			if (System.getProperty("substancelaf.useDecorations") != null) {
-				JFrame.setDefaultLookAndFeelDecorated(true);
-				JDialog.setDefaultLookAndFeelDecorated(true);
-			}
-		} catch (Exception exc) {
-			// probably running in unsecure JNLP - ignore
-		}
 	}
 }
