@@ -76,12 +76,6 @@ public class BaseSkinPlugin implements SubstanceSkinPlugin {
 		result.add(create(CremeSkin.NAME, CremeSkin.class, false));
 		result.add(create(ModerateSkin.NAME, ModerateSkin.class, false));
 		result.add(create(SaharaSkin.NAME, SaharaSkin.class, false));
-		result
-				.add(create(FieldOfWheatSkin.NAME, FieldOfWheatSkin.class,
-						false));
-		result.add(create(FindingNemoSkin.NAME, FindingNemoSkin.class, false));
-		result.add(create(GreenMagicSkin.NAME, GreenMagicSkin.class, false));
-		result.add(create(MangoSkin.NAME, MangoSkin.class, false));
 		result.add(create(MagmaSkin.NAME, MagmaSkin.class, false));
 		result.add(create(OfficeBlue2007Skin.NAME, OfficeBlue2007Skin.class,
 				false));
