@@ -31,20 +31,15 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.BaseLightColorScheme;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.MarbleNoiseDecorationPainter;
+import org.jvnet.substance.painter.gradient.MatteGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.SubstanceComplexTheme;
-import org.jvnet.substance.theme.SubstanceTheme;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.utils.SubstanceColorUtilities;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Autumn</code> skin. This class is part of officially supported API.
@@ -52,7 +47,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 4.0
  */
-public class AutumnSkin extends SubstanceAbstractSkin {
+public class AutumnSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -63,7 +58,7 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class ActiveScheme implements ColorScheme {
+	protected static class ActiveScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -103,6 +98,13 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#AC623B");
 
+		/**
+		 * Creates an active scheme for this skin.
+		 */
+		public ActiveScheme() {
+			super("Autumn Active");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -172,7 +174,7 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class DefaultScheme implements ColorScheme {
+	protected static class DefaultScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -212,6 +214,13 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#AC623B");
 
+		/**
+		 * Creates a default scheme for this skin.
+		 */
+		public DefaultScheme() {
+			super("Autumn Default");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -280,76 +289,28 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Autumn</code> skin.
 	 */
 	public AutumnSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(new ActiveScheme(),
-				"Autumn Active", ThemeKind.COLD);
-		SubstanceTheme defaultTheme = new SubstanceTheme(new DefaultScheme(),
-				"Autumn Default", ThemeKind.COLD);
+		SubstanceColorScheme activeScheme = new ActiveScheme();
+		SubstanceColorScheme defaultScheme = new DefaultScheme();
+		SubstanceColorScheme disabledScheme = defaultScheme;
 
-		// final ColorScheme disabledScheme = new
-		// BlendBiColorScheme(defaultTheme
-		// .getColorScheme(), defaultTheme.getDisabledTheme()
-		// .getColorScheme(), 0.6) {
-		// Color foreColor = new Color(128, 131, 136);
-		//
-		// @Override
-		// public Color getForegroundColor() {
-		// return foreColor;
-		// }
-		// };
-		SubstanceTheme disabledTheme = defaultTheme;
-		// new SubstanceTheme(disabledScheme,
-		// "Disabled Autumn", ThemeKind.COLD);
-
-		SubstanceTheme activeTitleTheme = defaultTheme;
-
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme) {
-			/*
-			 * (non-Javadoc)
-			 * 
-			 * @see org.jvnet.substance.theme.SubstanceComplexTheme#getLightBackgroundColor()
-			 */
-			@Override
-			public Color getLightBackgroundColor() {
-				return SubstanceColorUtilities
-						.getInterpolatedColor(defaultTheme.getColorScheme()
-								.getUltraLightColor(), defaultTheme
-								.getColorScheme().getExtraLightColor(), 0.5);
-
-			}
-
-			/*
-			 * (non-Javadoc)
-			 * 
-			 * @see org.jvnet.substance.theme.SubstanceTheme#getDisabledForegroundColor()
-			 */
-			@Override
-			public Color getDisabledForegroundColor() {
-				return SubstanceColorUtilities.getInterpolatedColor(
-						defaultTheme.getColorScheme().getForegroundColor(),
-						defaultTheme.getColorScheme().getLightColor(), 0.6f);
-			}
-		};
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme.registerComponentStateTheme(disabledTheme, 0.6f, false,
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.6f,
 				ComponentState.DISABLED_UNSELECTED);
-		theme.registerComponentStateTheme(activeTheme, 0.6f, false,
+		defaultSchemeBundle.registerColorScheme(activeScheme, 0.6f,
 				ComponentState.DISABLED_SELECTED);
 
-		theme.registerDecorationAreaTheme(theme, false,
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(activeScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
 				DecorationAreaType.HEADER);
 
-		theme.setPaintingToolbarDropShadows();
+		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
 
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new MatteGradientPainter();
 		this.borderPainter = new ClassicInnerBorderPainter(0.8f,
 				ColorShiftKind.TINT);
@@ -360,8 +321,6 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 		decorationPainter.setPaintingSeparators(true);
 		decorationPainter.setTextureAlpha(0.7f);
 		this.decorationPainter = decorationPainter;
-
-		tabBackgroundComposite = new AlphaControlBackgroundComposite(0.75f);
 	}
 
 	/*
@@ -372,4 +331,5 @@ public class AutumnSkin extends SubstanceAbstractSkin {
 	public String getDisplayName() {
 		return NAME;
 	}
+
 }
