@@ -29,17 +29,15 @@
  */
 package org.jvnet.substance.skin;
 
-import org.jvnet.substance.border.ClassicBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.MetallicColorScheme;
-import org.jvnet.substance.color.SteelBlueColorScheme;
-import org.jvnet.substance.painter.*;
+import java.awt.Color;
+
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Business Black Steel</code> skin. This class is part of officially
@@ -48,7 +46,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.3
  */
-public class BusinessBlackSteelSkin extends SubstanceAbstractSkin {
+public class BusinessBlackSteelSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -58,62 +56,58 @@ public class BusinessBlackSteelSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Business</code> skin.
 	 */
 	public BusinessBlackSteelSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(
-				new SteelBlueColorScheme(), "Tint Steel Blue", ThemeKind.COLD)
-				.tint(0.15);
-		SubstanceTheme defaultTheme = new SubstanceTheme(
-				new MetallicColorScheme(), "Tint Metallic", ThemeKind.COLD)
-				.tint(0.05);
-		SubstanceTheme disabledTheme = defaultTheme.getDisabledTheme();
-		SubstanceTheme activeTitleTheme = new SubstanceEbonyTheme();
+		SubstanceColorScheme activeScheme = new SteelBlueColorScheme().tint(
+				0.15).named("Business Black Steel Active");
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme().tint(
+				0.05).named("Business Black Steel Default");
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme().tint(
+				0.05).named("Business Black Steel Disabled");
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		// theme.setCellRendererBackgroundTheme(new SubstanceBlendBiTheme(
-		// new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-		// 0.5).tint(0.2));
-
-		theme.registerComponentHighlightStateTheme(activeTheme, 0.6f,
+		// the default color scheme bundle
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.6f,
 				ComponentState.ROLLOVER_UNSELECTED);
-		theme.registerComponentHighlightStateTheme(activeTheme, 0.8f,
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.8f,
 				ComponentState.SELECTED);
-		theme.registerComponentHighlightStateTheme(activeTheme, 0.95f,
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.95f,
 				ComponentState.ROLLOVER_SELECTED);
-		theme.registerComponentHighlightStateTheme(activeTheme, 0.8f,
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.8f,
 				ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		SubstanceComplexTheme decorationTheme = new SubstanceComplexTheme(
-				"Business Black Steel Decoration", ThemeKind.DARK,
-				activeTitleTheme.shade(0.3), activeTitleTheme, disabledTheme);
-		theme.registerDecorationAreaTheme(decorationTheme, true,
+		// color scheme bundle for title panes
+		SubstanceColorScheme activeHeaderScheme = new EbonyColorScheme()
+				.shiftBackground(Color.black, 0.3).tint(0.05).named(
+						"Business Black Steel Active Header");
+		SubstanceColorScheme defaultHeaderScheme = new EbonyColorScheme().tint(
+				0.05).named("Business Black Steel Default Header");
+		SubstanceColorSchemeBundle headerSchemeBundle = new SubstanceColorSchemeBundle(
+				activeHeaderScheme, defaultHeaderScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(headerSchemeBundle,
+				activeHeaderScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
-				DecorationAreaType.SECONDARY_TITLE_PANE);
-
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
 				DecorationAreaType.HEADER);
 
-		SubstanceComplexTheme generalDecorationTheme = new SubstanceComplexTheme(
-				"Business Black Steel General Decoration", ThemeKind.DARK,
-				activeTheme.shade(0.1).saturate(-0.5), activeTheme.tint(0.3)
-						.saturate(-0.7), disabledTheme);
-		generalDecorationTheme.registerComponentStateTheme(disabledTheme, 0.5f,
-				false, ComponentState.DISABLED_UNSELECTED);
-		theme.registerDecorationAreaTheme(generalDecorationTheme, true,
-				DecorationAreaType.GENERAL);
+		// color scheme bundle for general areas
+		SubstanceColorScheme activeGeneralScheme = activeScheme.shade(0.1).saturate(-0.5).named(
+				"Business Black Steel Active General");
+		SubstanceColorScheme defaultGeneralScheme = activeScheme
+				.tint(0.3).saturate(-0.7).named(
+						"Business Black Steel Default General");
+		SubstanceColorSchemeBundle generalSchemeBundle = new SubstanceColorSchemeBundle(
+				activeGeneralScheme, defaultGeneralScheme,
+				disabledScheme);
+		generalSchemeBundle.registerColorScheme(disabledScheme, 0.5f,
+				ComponentState.DISABLED_UNSELECTED);
+		this.registerDecorationAreaSchemeBundle(generalSchemeBundle,
+				DecorationAreaType.FOOTER, DecorationAreaType.GENERAL);
 
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setDefaultTitlePaneTheme(activeTitleTheme);
+		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
 
-		theme.setPaintingToolbarDropShadows();
-
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.borderPainter = new ClassicBorderPainter();
 
@@ -124,8 +118,6 @@ public class BusinessBlackSteelSkin extends SubstanceAbstractSkin {
 
 		this.highlightPainter = new ClassicHighlightPainter();
 
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
-
 		this.borderPainter = new ClassicBorderPainter();
 	}
 
