@@ -29,17 +29,13 @@
  */
 package org.jvnet.substance.skin;
 
-import org.jvnet.substance.border.ClassicBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.MetallicColorScheme;
-import org.jvnet.substance.color.SteelBlueColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Business Blue Steel</code> skin. This class is part of officially
@@ -48,7 +44,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.3
  */
-public class BusinessBlueSteelSkin extends SubstanceAbstractSkin {
+public class BusinessBlueSteelSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -58,46 +54,45 @@ public class BusinessBlueSteelSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Business</code> skin.
 	 */
 	public BusinessBlueSteelSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(
-				new SteelBlueColorScheme(), "Tint Steel Blue", ThemeKind.COLD)
-				.tint(0.15);
-		SubstanceTheme defaultTheme = new SubstanceTheme(
-				new MetallicColorScheme(), "Tint Metallic", ThemeKind.COLD)
-				.tint(0.05);
-		SubstanceTheme disabledTheme = defaultTheme.getDisabledTheme();
-		SubstanceTheme activeTitleTheme = activeTheme;
+		SubstanceColorScheme activeScheme = new SteelBlueColorScheme().tint(
+				0.15).named("Business Blue Steel Active");
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme().tint(
+				0.05).named("Business Blue Steel Default");
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme().tint(
+				0.05).named("Business Blue Steel Disabled");
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.setDefaultTitlePaneTheme(activeTitleTheme);
-		theme.registerComponentHighlightStateTheme(new SubstanceBlendBiTheme(
-				new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-				0.5).tint(0.2));
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle
+				.registerHighlightColorScheme(new BlendBiColorScheme(
+						new TerracottaColorScheme(), new SunGlareColorScheme(),
+						0.5).tint(0.2).named("Business Blue Steel Highlight"));
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		SubstanceColorScheme activeHeaderScheme = activeScheme.saturate(0.2)
+				.named("Business Blue Steel Active Header");
+		SubstanceColorScheme defaultHeaderScheme = activeScheme.saturate(-0.2)
+				.named("Business Blue Steel Default Header");
+		SubstanceColorSchemeBundle headerSchemeBundle = new SubstanceColorSchemeBundle(
+				activeHeaderScheme, defaultHeaderScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(headerSchemeBundle,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
 				DecorationAreaType.HEADER, DecorationAreaType.TOOLBAR);
 
-		SubstanceComplexTheme generalDecorationTheme = new SubstanceComplexTheme(
-				"Business Black Steel General Decoration", ThemeKind.DARK,
-				activeTheme.saturate(-0.5), activeTheme.tint(0.3)
-						.saturate(-0.2), disabledTheme);
-		generalDecorationTheme.registerComponentStateTheme(
-				generalDecorationTheme.getDefaultTheme(), 0.7f, false,
+		SubstanceColorScheme activeGeneralScheme = activeScheme.saturate(-0.5)
+				.named("Business Blue Steel Active General");
+		SubstanceColorScheme defaultGeneralScheme = activeScheme.tint(0.3)
+				.saturate(-0.2).named("Business Blue Steel Default General");
+		SubstanceColorSchemeBundle generalSchemeBundle = new SubstanceColorSchemeBundle(
+				activeGeneralScheme, defaultGeneralScheme, disabledScheme);
+		generalSchemeBundle.registerColorScheme(defaultGeneralScheme, 0.7f,
 				ComponentState.DISABLED_UNSELECTED);
-		theme.registerDecorationAreaTheme(generalDecorationTheme, true,
-				DecorationAreaType.GENERAL);
+		this.registerDecorationAreaSchemeBundle(generalSchemeBundle,
+				DecorationAreaType.FOOTER, DecorationAreaType.GENERAL);
 
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.borderPainter = new ClassicBorderPainter();
 
@@ -107,9 +102,6 @@ public class BusinessBlueSteelSkin extends SubstanceAbstractSkin {
 		this.decorationPainter = decorationPainter;
 
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
-
 		this.borderPainter = new ClassicBorderPainter();
 	}
 
