@@ -29,18 +29,14 @@
  */
 package org.jvnet.substance.skin;
 
-import java.awt.Color;
-
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.MetallicColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Business</code> skin. This class is part of officially supported API.
@@ -48,7 +44,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class BusinessSkin extends SubstanceAbstractSkin {
+public class BusinessSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -58,42 +54,35 @@ public class BusinessSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Business</code> skin.
 	 */
 	public BusinessSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(
-				new MetallicColorScheme(), "Tint Metallic", ThemeKind.COLD)
-				.tint(0.15);
-		SubstanceTheme defaultTheme = new SubstanceTheme(
-				new MetallicColorScheme(), "Shade Metallic", ThemeKind.COLD)
-				.shade(0.1);
-		SubstanceTheme disabledTheme = defaultTheme.getDisabledTheme()
-				.tint(0.2);
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorScheme activeScheme = new MetallicColorScheme()
+				.tint(0.15).named("Business Active");
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme().shade(
+				0.1).named("Business Default");
+		SubstanceColorScheme disabledScheme = defaultScheme;
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme) {
-			@Override
-			public Color getLightBackgroundColor() {
-				return disabledTheme.getBackgroundColor();
-			}
-		};
-		theme.registerComponentHighlightStateTheme(new SubstanceBlendBiTheme(
-				new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-				0.5).tint(0.2));
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle
+				.registerHighlightColorScheme(new BlendBiColorScheme(
+						new TerracottaColorScheme(), new SunGlareColorScheme(),
+						0.5).tint(0.2).named("Business Highlight"));
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.4f,
+				ComponentState.DISABLED_UNSELECTED);
+		defaultSchemeBundle.registerColorScheme(activeScheme, 0.4f,
+				ComponentState.DISABLED_SELECTED);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL);
+
+		this.setSelectedTabFadeStart(0.6);
+		this.setSelectedTabFadeEnd(1.0);
 
-		theme.setSelectedTabFadeStart(0.6);
-		theme.setSelectedTabFadeEnd(1.0);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.borderPainter = new ClassicInnerBorderPainter(0.8f,
 				ColorShiftKind.TINT);
@@ -104,9 +93,6 @@ public class BusinessSkin extends SubstanceAbstractSkin {
 		this.decorationPainter = decorationPainter;
 
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
-
 		this.borderPainter = new ClassicInnerBorderPainter(0.9f,
 				ColorShiftKind.TINT);
 	}
@@ -119,4 +105,5 @@ public class BusinessSkin extends SubstanceAbstractSkin {
 	public String getDisplayName() {
 		return NAME;
 	}
+
 }
