@@ -31,26 +31,24 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.GlassBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.color.ToneColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.ToneColorScheme;
+import org.jvnet.substance.colorscheme.UltramarineColorScheme;
+import org.jvnet.substance.painter.border.GlassBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.SubstanceMagneticFieldWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
- * <code>Challenger Deep</code> skin. This class is part of officially
- * supported API.
+ * <code>Challenger Deep</code> skin. This class is part of officially supported
+ * API.
  * 
  * @author Kirill Grouchnikov
  * @since version 3.2
  */
-public class ChallengerDeepSkin extends SubstanceAbstractSkin {
+public class ChallengerDeepSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -60,44 +58,36 @@ public class ChallengerDeepSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Challenger Deep</code> skin.
 	 */
 	public ChallengerDeepSkin() {
-		SubstanceTheme activeTheme = new SubstanceUltramarineTheme();
-		SubstanceTheme defaultTheme = activeTheme.tone(0.1f);
+		SubstanceColorScheme activeScheme = new UltramarineColorScheme();
+		SubstanceColorScheme defaultScheme = activeScheme.tone(0.1f).named(
+				"Challenger Deep Default");
 
-		ColorScheme disabledScheme = new ToneColorScheme(activeTheme
-				.getColorScheme(), 0.3) {
+		SubstanceColorScheme disabledScheme = new ToneColorScheme(activeScheme,
+				0.3) {
 			Color foreColor = new Color(123, 118, 137);
 
 			@Override
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Disabled Challenger Deep", ThemeKind.DARK);
+		}.named("Challenger Deep Disabled");
 
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
 
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceMagneticFieldWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
 		this.borderPainter = new GlassBorderPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 	}
 
 	/*
