@@ -31,19 +31,16 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.border.GlassInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.color.LightGrayColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
+import org.jvnet.substance.painter.border.GlassInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.MatteGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Creme Coffee</code> skin. This class is part of officially supported
@@ -52,13 +49,13 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 4.1
  */
-public class CremeCoffeeSkin extends SubstanceAbstractSkin {
+public class CremeCoffeeSkin extends SubstanceSkin {
 	/**
 	 * Color scheme for active visual state.
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class ActiveScheme implements ColorScheme {
+	protected static class ActiveScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -96,6 +93,13 @@ public class CremeCoffeeSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = new Color(50, 34, 15);
 
+		/**
+		 * Creates a new active scheme for Creme Coffee skin.
+		 */
+		public ActiveScheme() {
+			super("Creme Coffee Active");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -169,43 +173,28 @@ public class CremeCoffeeSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Creme Coffee</code> skin.
 	 */
 	public CremeCoffeeSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(new ActiveScheme(),
-				"Creme Coffee Active", ThemeKind.COLD);
-		//			
-		// new SubstanceBrownTheme().tint(0.7)
-		// .saturate(0.2);
-		SubstanceTheme defaultTheme = new SubstanceCremeTheme();
-		SubstanceTheme disabledTheme = new SubstanceTheme(
-				new LightGrayColorScheme(), "Tint Light Gray", ThemeKind.COLD)
-				.tint(0.35);
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorScheme activeScheme = new ActiveScheme();
+		SubstanceColorScheme defaultScheme = new CremeColorScheme();
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme().tint(
+				0.35).named("Creme Coffee Disabled");
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
-
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		this.theme = theme;
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
 
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new MatteGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.borderPainter = new ClassicInnerBorderPainter(0.8f,
 				ColorShiftKind.TINT);
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.75f);
-
 		this.borderPainter = new GlassInnerBorderPainter(0.8f,
 				ColorShiftKind.TINT);
 	}
