@@ -29,17 +29,15 @@
  */
 package org.jvnet.substance.skin;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.LightGrayColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Creme</code> skin. This class is part of officially supported API.
@@ -47,7 +45,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class CremeSkin extends SubstanceAbstractSkin {
+public class CremeSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -57,43 +55,32 @@ public class CremeSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Creme</code> skin.
 	 */
 	public CremeSkin() {
-		SubstanceTheme activeTheme = new SubstanceLightAquaTheme().tint(0.3);
-		SubstanceTheme defaultTheme = new SubstanceCremeTheme();
-		SubstanceTheme disabledTheme = new SubstanceTheme(
-				new LightGrayColorScheme(), "Tint Light Gray", ThemeKind.COLD)
-				.tint(0.35);
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorScheme activeScheme = new LightAquaColorScheme()
+				.tint(0.3).named("Creme Active");
+		SubstanceColorScheme defaultScheme = new CremeColorScheme();
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme().tint(
+				0.35).named("Creme Disabled");
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+
+		setSelectedTabFadeStart(0.2);
+		setSelectedTabFadeEnd(0.4);
 
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.2);
-		theme.setSelectedTabFadeEnd(0.4);
-		this.theme = theme;
-		// ((SubstanceComplexTheme) this.theme)
-		// .setCellRendererBackgroundTheme(new SubstanceBlendBiTheme(
-		// new SubstanceTerracottaTheme(),
-		// new SubstanceSunGlareTheme(), 0.5).tint(0.2));
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.borderPainter = new ClassicInnerBorderPainter(0.8f,
 				ColorShiftKind.TINT);
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.75f);
-
 		this.borderPainter = new ClassicInnerBorderPainter(0.9f,
 				ColorShiftKind.TINT);
 	}
