@@ -31,17 +31,15 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.GlassBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.color.ToneColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.CharcoalColorScheme;
+import org.jvnet.substance.colorscheme.ToneColorScheme;
+import org.jvnet.substance.painter.border.GlassBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Emerald Dusk</code> skin. This class is part of officially supported
@@ -50,7 +48,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.2
  */
-public class EmeraldDuskSkin extends SubstanceAbstractSkin {
+public class EmeraldDuskSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -60,44 +58,37 @@ public class EmeraldDuskSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Emerald Dusk</code> skin.
 	 */
 	public EmeraldDuskSkin() {
-		SubstanceTheme activeTheme = new SubstanceCharcoalTheme().hueShift(0.3);
-		SubstanceTheme defaultTheme = new SubstanceCharcoalTheme()
-				.hueShift(0.4);
+		SubstanceColorScheme activeScheme = new CharcoalColorScheme()
+				.hueShift(0.3).named("Emerald Dusk Active");
+		SubstanceColorScheme defaultScheme = new CharcoalColorScheme()
+				.hueShift(0.4).named("Emerald Dusk Default");
 
-		ColorScheme disabledScheme = new ToneColorScheme(activeTheme
-				.getColorScheme(), 0.3) {
+		SubstanceColorScheme disabledScheme = new ToneColorScheme(activeScheme,
+				0.3) {
 			Color foreColor = new Color(120, 134, 128);
 
 			@Override
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Disabled Emerald Dusk", ThemeKind.DARK);
+		}.named("Emerald Dusk Disabled");
 
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
 
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.borderPainter = new GlassBorderPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 	}
 
 	/*
