@@ -31,16 +31,14 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.GlassBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.*;
-import org.jvnet.substance.painter.GlassGradientPainter;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.GlassBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstancePlanktonWatermark;
 
 /**
@@ -49,7 +47,7 @@ import org.jvnet.substance.watermark.SubstancePlanktonWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class MagmaSkin extends SubstanceAbstractSkin {
+public class MagmaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -59,66 +57,58 @@ public class MagmaSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Magma</code> skin.
 	 */
 	public MagmaSkin() {
-		ColorScheme shiftRed = new ShiftColorScheme(new SunsetColorScheme()
-		// {
-				// @Override
-				// public Color getForegroundColor() {
-				// return Color.white;
-				// }
-				// }
-				, Color.red, 0.3);
-		final SubstanceTheme defaultTheme = new SubstanceCharcoalTheme();
-		SubstanceTheme activeTheme = new SubstanceTheme(shiftRed, "Red sunset",
-				ThemeKind.BRIGHT) {
-			@Override
-			public SubstanceTheme getBorderTheme() {
-				return defaultTheme;
-			}
-		}.saturate(0.4);
+		SubstanceColorScheme shiftRed = new ShiftColorScheme(
+				new SunsetColorScheme(), Color.red, 0.3);
+		SubstanceColorScheme defaultScheme = new CharcoalColorScheme();
+		SubstanceColorScheme activeScheme = shiftRed.saturate(0.4).named(
+				"Magma Active");
 
-		ColorScheme disabledScheme = new ShadeColorScheme(defaultTheme
-				.getColorScheme(), 0.5) {
+		SubstanceColorScheme disabledScheme = new ShadeColorScheme(
+				new CharcoalColorScheme(), 0.5) {
 			Color foreColor = new Color(104, 93, 90);
 
 			@Override
 			public Color getForegroundColor() {
 				return this.foreColor;
 			}
-		};
-		SubstanceTheme disabledTheme = // defaultTheme;
-		new SubstanceTheme(disabledScheme, "Disabled Magma", ThemeKind.DARK);
+		}.named("Magma Disabled");
 
-		SubstanceTheme activeTitleTheme = defaultTheme.saturate(0.2);
-		SubstanceTheme watermarkTheme = defaultTheme.saturate(0.4);
-
-		SubstanceComplexTheme complexTheme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme, watermarkTheme);
-		complexTheme.registerComponentStateTheme(disabledTheme, 0.7f, false,
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerBorderColorScheme(
+				new CharcoalColorScheme(), ComponentState.getActiveStates());
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.7f,
 				ComponentState.DISABLED_UNSELECTED,
 				ComponentState.DISABLED_SELECTED);
 
-		complexTheme.registerComponentHighlightStateTheme(activeTheme
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme
 				.saturate(-0.2), 0.7f, ComponentState.ROLLOVER_UNSELECTED);
-		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.7f,
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.7f,
 				ComponentState.SELECTED);
-		complexTheme.registerComponentHighlightStateTheme(activeTheme, 0.9f,
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme, 0.9f,
 				ComponentState.ROLLOVER_SELECTED);
-		complexTheme.registerComponentHighlightStateTheme(activeTheme
+		defaultSchemeBundle.registerHighlightColorScheme(activeScheme
 				.saturate(-0.2), 0.7f, ComponentState.ARMED,
 				ComponentState.ROLLOVER_ARMED);
 
-		complexTheme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+
+		this.setSelectedTabFadeStart(1.0);
+		this.setSelectedTabFadeEnd(1.0);
+
+		this.watermarkScheme = defaultScheme.shade(0.5);
 
-		this.theme = complexTheme;
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstancePlanktonWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
+		this.watermark = new SubstancePlanktonWatermark();
 
 		this.borderPainter = new GlassBorderPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
