@@ -31,18 +31,14 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicBorderPainter;
-import org.jvnet.substance.button.StandardButtonShaper;
-import org.jvnet.substance.color.*;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.MatteDecorationPainter;
+import org.jvnet.substance.painter.gradient.MatteGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
-
-import contrib.ch.randelshofer.quaqua.colorchooser.GrayColorSliderModel;
+import org.jvnet.substance.shaper.StandardButtonShaper;
 
 /**
  * <code>Mist Aqua</code> skin. This class is experimental.
@@ -50,7 +46,7 @@ import contrib.ch.randelshofer.quaqua.colorchooser.GrayColorSliderModel;
  * @author Kirill Grouchnikov
  * @since version 4.0
  */
-public class MistAquaSkin extends SubstanceAbstractSkin {
+public class MistAquaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -61,7 +57,7 @@ public class MistAquaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class ActiveTitleScheme implements ColorScheme {
+	protected static class ActiveTitleScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -99,6 +95,13 @@ public class MistAquaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#000000");
 
+		/**
+		 * Creates an active title scheme for this skin.
+		 */
+		public ActiveTitleScheme() {
+			super("Mist Aqua Active Title");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -167,44 +170,34 @@ public class MistAquaSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Silver Aqua</code> skin.
 	 */
 	public MistAquaSkin() {
-		SubstanceTheme activeTheme = new SubstanceAquaTheme();
-		SubstanceTheme defaultTheme = new SubstanceTheme(
-				new MetallicColorScheme(), "Shade Metallic", ThemeKind.COLD)
-				.shade(0.05);
-		SubstanceTheme disabledTheme = new SubstanceTheme(
-				new LightGrayColorScheme(), "Tone Light Gray", ThemeKind.COLD)
-				.tone(0.2);
-		SubstanceTheme activeTitleTheme = new SubstanceTheme(
-				new ActiveTitleScheme(), "Silver Active Title", ThemeKind.COLD);
+		SubstanceColorScheme activeScheme = new AquaColorScheme();
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme().shade(
+				0.05).named("Mist Aqua Default");
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme().tone(
+				0.2).named("Mist Aqua Disabled");
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerDecorationAreaSchemeBundle(new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme),
+				new SteelBlueColorScheme().saturate(-0.3).tint(0.5).named(
+						"Mist Aqua Background"), DecorationAreaType.GENERAL);
+
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
 				DecorationAreaType.TOOLBAR);
 
-		// theme.registerComponentHighlightStateTheme(new SubstanceBlendBiTheme(
-		// new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-		// 0.5).tint(0.2));
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new StandardButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new MatteGradientPainter();
 		this.borderPainter = new ClassicBorderPainter();
 
 		this.decorationPainter = new MatteDecorationPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 	}
 
 	/*
