@@ -29,14 +29,14 @@
  */
 package org.jvnet.substance.skin;
 
-import org.jvnet.substance.border.ClassicBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.ClassicDecorationPainter;
+import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Moderate</code> skin. This class is part of officially supported API.
@@ -44,7 +44,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class ModerateSkin extends SubstanceAbstractSkin {
+public class ModerateSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -54,30 +54,28 @@ public class ModerateSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Moderate</code> skin.
 	 */
 	public ModerateSkin() {
-		SubstanceTheme activeTheme = new SubstanceSteelBlueTheme();
-		SubstanceTheme defaultTheme = activeTheme.getDefaultTheme();
-		SubstanceTheme disabledTheme = activeTheme.getDisabledTheme();
-		SubstanceTheme activeTitleTheme = activeTheme;
+		SubstanceColorScheme activeScheme = new SteelBlueColorScheme();
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme();
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme();
+
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle
+				.registerHighlightColorScheme(new BlendBiColorScheme(
+						new TerracottaColorScheme(), new SunGlareColorScheme(),
+						0.5));
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(activeScheme,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.registerComponentHighlightStateTheme(new SubstanceBlendBiTheme(
-				new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-				0.5));
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ClassicDecorationPainter();
 		this.borderPainter = new ClassicBorderPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 	}
 
 	/*
