@@ -29,9 +29,8 @@
  */
 package org.jvnet.substance.skin;
 
+import org.jvnet.substance.colorscheme.OrangeColorScheme;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
-import org.jvnet.substance.painter.decoration.MarbleNoiseDecorationPainter;
-import org.jvnet.substance.theme.*;
 
 /**
  * <code>Nebula Brick Wall</code> skin. This class is experimental.
@@ -50,17 +49,11 @@ public class NebulaBrickWallSkin extends NebulaSkin {
 	 */
 	public NebulaBrickWallSkin() {
 		super();
-		SubstanceComplexTheme cTheme = (SubstanceComplexTheme) this.theme;
-		SubstanceTheme activeTitlePaneTheme = new SubstanceOrangeTheme();
-		cTheme.setActiveTitlePaneTheme(activeTitlePaneTheme);
 
-		cTheme.registerDecorationAreaTheme(activeTitlePaneTheme, false,
+		this.registerAsDecorationArea(new OrangeColorScheme(),
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
 				DecorationAreaType.HEADER);
-
-		MarbleNoiseDecorationPainter mnDecorationPainter = (MarbleNoiseDecorationPainter) this.decorationPainter;
-		mnDecorationPainter.setTextureAlpha(0.3f);
 	}
 
 	/*
