@@ -31,18 +31,14 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.FlatBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.painter.SimplisticSoftBorderReverseGradientPainter;
-import org.jvnet.substance.painter.SubduedGradientPainter;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.BaseDarkColorScheme;
+import org.jvnet.substance.colorscheme.BaseLightColorScheme;
+import org.jvnet.substance.painter.border.FlatBorderPainter;
 import org.jvnet.substance.painter.decoration.*;
+import org.jvnet.substance.painter.gradient.SubduedGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.SubstanceComplexTheme;
-import org.jvnet.substance.theme.SubstanceTheme;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Nebula</code> skin. This class is part of officially supported API.
@@ -50,7 +46,7 @@ import org.jvnet.substance.watermark.SubstanceNullWatermark;
  * @author Kirill Grouchnikov
  * @since version 4.0
  */
-public class NebulaSkin extends SubstanceAbstractSkin {
+public class NebulaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -61,7 +57,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class ActiveScheme implements ColorScheme {
+	protected static class ActiveScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -99,6 +95,13 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#000000");
 
+		/**
+		 * Creates an active scheme for this skin.
+		 */
+		public ActiveScheme() {
+			super("Nebula Active");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -168,7 +171,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class DefaultScheme implements ColorScheme {
+	protected static class DefaultScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -206,6 +209,13 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#2A2E36");
 
+		/**
+		 * Creates a default scheme for this skin.
+		 */
+		public DefaultScheme() {
+			super("Nebula Default");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -275,7 +285,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class DisabledScheme implements ColorScheme {
+	protected static class DisabledScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -288,6 +298,13 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		private static final Color mainExtraLightColor = Color
 				.decode("#DFE2E6");
 
+		/**
+		 * Creates a disabled scheme for this skin.
+		 */
+		public DisabledScheme() {
+			super("Nebula Disabled");
+		}
+
 		/**
 		 * The main light color.
 		 */
@@ -382,7 +399,8 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class RolloverUnselectedScheme implements ColorScheme {
+	protected static class RolloverUnselectedScheme extends
+			BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -420,6 +438,13 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#2A2E36");
 
+		/**
+		 * Creates a rollover unselected scheme for this skin.
+		 */
+		public RolloverUnselectedScheme() {
+			super("Nebula Rollover Unselected");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
@@ -489,7 +514,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class RolloverSelectedTheme implements ColorScheme {
+	protected static class RolloverSelectedScheme extends BaseLightColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -527,13 +552,20 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#000000");
 
+		/**
+		 * Creates a rollover selected scheme for this skin.
+		 */
+		public RolloverSelectedScheme() {
+			super("Nebula Rollover Selected");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
 		 * @see org.jvnet.substance.color.ColorScheme#getForegroundColor()
 		 */
 		public Color getForegroundColor() {
-			return RolloverSelectedTheme.foregroundColor;
+			return RolloverSelectedScheme.foregroundColor;
 		}
 
 		/*
@@ -542,7 +574,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getUltraLightColor()
 		 */
 		public Color getUltraLightColor() {
-			return RolloverSelectedTheme.mainUltraLightColor;
+			return RolloverSelectedScheme.mainUltraLightColor;
 		}
 
 		/*
@@ -551,7 +583,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getExtraLightColor()
 		 */
 		public Color getExtraLightColor() {
-			return RolloverSelectedTheme.mainExtraLightColor;
+			return RolloverSelectedScheme.mainExtraLightColor;
 		}
 
 		/*
@@ -560,7 +592,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getLightColor()
 		 */
 		public Color getLightColor() {
-			return RolloverSelectedTheme.mainLightColor;
+			return RolloverSelectedScheme.mainLightColor;
 		}
 
 		/*
@@ -569,7 +601,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getMidColor()
 		 */
 		public Color getMidColor() {
-			return RolloverSelectedTheme.mainMidColor;
+			return RolloverSelectedScheme.mainMidColor;
 		}
 
 		/*
@@ -578,7 +610,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getDarkColor()
 		 */
 		public Color getDarkColor() {
-			return RolloverSelectedTheme.mainDarkColor;
+			return RolloverSelectedScheme.mainDarkColor;
 		}
 
 		/*
@@ -587,7 +619,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getUltraDarkColor()
 		 */
 		public Color getUltraDarkColor() {
-			return RolloverSelectedTheme.mainUltraDarkColor;
+			return RolloverSelectedScheme.mainUltraDarkColor;
 		}
 	}
 
@@ -597,7 +629,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * 
 	 * @author Kirill Grouchnikov
 	 */
-	protected static class PressedTheme implements ColorScheme {
+	protected static class PressedScheme extends BaseDarkColorScheme {
 		/**
 		 * The main ultra-light color.
 		 */
@@ -635,13 +667,20 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 */
 		private static final Color foregroundColor = Color.decode("#FFFFFF");
 
+		/**
+		 * Creates a pressed for this skin.
+		 */
+		public PressedScheme() {
+			super("Nebula Pressed");
+		}
+
 		/*
 		 * (non-Javadoc)
 		 * 
 		 * @see org.jvnet.substance.color.ColorScheme#getForegroundColor()
 		 */
 		public Color getForegroundColor() {
-			return PressedTheme.foregroundColor;
+			return PressedScheme.foregroundColor;
 		}
 
 		/*
@@ -650,7 +689,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getUltraLightColor()
 		 */
 		public Color getUltraLightColor() {
-			return PressedTheme.mainUltraLightColor;
+			return PressedScheme.mainUltraLightColor;
 		}
 
 		/*
@@ -659,7 +698,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getExtraLightColor()
 		 */
 		public Color getExtraLightColor() {
-			return PressedTheme.mainExtraLightColor;
+			return PressedScheme.mainExtraLightColor;
 		}
 
 		/*
@@ -668,7 +707,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getLightColor()
 		 */
 		public Color getLightColor() {
-			return PressedTheme.mainLightColor;
+			return PressedScheme.mainLightColor;
 		}
 
 		/*
@@ -677,7 +716,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getMidColor()
 		 */
 		public Color getMidColor() {
-			return PressedTheme.mainMidColor;
+			return PressedScheme.mainMidColor;
 		}
 
 		/*
@@ -686,7 +725,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getDarkColor()
 		 */
 		public Color getDarkColor() {
-			return PressedTheme.mainDarkColor;
+			return PressedScheme.mainDarkColor;
 		}
 
 		/*
@@ -695,7 +734,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		 * @see org.jvnet.substance.color.ColorScheme#getUltraDarkColor()
 		 */
 		public Color getUltraDarkColor() {
-			return PressedTheme.mainUltraDarkColor;
+			return PressedScheme.mainUltraDarkColor;
 		}
 	}
 
@@ -703,60 +742,46 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Nebula</code> skin.
 	 */
 	public NebulaSkin() {
-		SubstanceTheme activeTheme = new SubstanceTheme(new ActiveScheme(),
-				"Nebula Active", ThemeKind.COLD);
-		SubstanceTheme defaultTheme = new SubstanceTheme(new DefaultScheme(),
-				"Nebula Default", ThemeKind.COLD);
-		SubstanceTheme rolloverUnselectedTheme = new SubstanceTheme(
-				new RolloverUnselectedScheme(), "Nebula Rollover Unselected",
-				ThemeKind.COLD);
-		SubstanceTheme pressedTheme = new SubstanceTheme(new PressedTheme(),
-				"Nebula Pressed", ThemeKind.DARK);
-		SubstanceTheme rolloverSelectedTheme = new SubstanceTheme(
-				new RolloverSelectedTheme(), "Nebula Rollover Selected",
-				ThemeKind.COLD);
-		SubstanceTheme disabledTheme = new SubstanceTheme(new DisabledScheme(),
-				"Nebula Disabled", ThemeKind.COLD);
-		SubstanceTheme activeTitleTheme = activeTheme.getDefaultTheme();
+		SubstanceColorScheme activeScheme = new ActiveScheme();
+		SubstanceColorScheme defaultScheme = new DefaultScheme();
+		SubstanceColorScheme rolloverUnselectedScheme = new RolloverUnselectedScheme();
+		SubstanceColorScheme pressedScheme = new PressedScheme();
+		SubstanceColorScheme rolloverSelectedScheme = new RolloverSelectedScheme();
+		SubstanceColorScheme disabledScheme = new DisabledScheme();
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.registerComponentStateTheme(rolloverUnselectedTheme, false,
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerColorScheme(rolloverUnselectedScheme,
 				ComponentState.ROLLOVER_UNSELECTED);
-		theme.registerComponentStateTheme(rolloverSelectedTheme, false,
+		defaultSchemeBundle.registerColorScheme(rolloverSelectedScheme,
 				ComponentState.ROLLOVER_SELECTED);
-		theme.registerComponentStateTheme(pressedTheme, true,
+		defaultSchemeBundle.registerColorScheme(pressedScheme,
 				ComponentState.PRESSED_SELECTED,
-				ComponentState.PRESSED_UNSELECTED);
+				ComponentState.PRESSED_UNSELECTED, ComponentState.ARMED,
+				ComponentState.ROLLOVER_ARMED);
 
-		theme.registerComponentHighlightStateTheme(pressedTheme, 0.6f,
+		defaultSchemeBundle.registerHighlightColorScheme(pressedScheme, 0.6f,
 				ComponentState.ROLLOVER_UNSELECTED);
-		theme.registerComponentHighlightStateTheme(pressedTheme, 0.8f,
+		defaultSchemeBundle.registerHighlightColorScheme(pressedScheme, 0.8f,
 				ComponentState.SELECTED);
-		theme.registerComponentHighlightStateTheme(pressedTheme, 0.95f,
+		defaultSchemeBundle.registerHighlightColorScheme(pressedScheme, 0.95f,
 				ComponentState.ROLLOVER_SELECTED);
-		theme.registerComponentHighlightStateTheme(pressedTheme, 0.8f,
+		defaultSchemeBundle.registerHighlightColorScheme(pressedScheme, 0.8f,
 				ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(activeScheme.saturate(-0.5),
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL);
 
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-
-		theme.setPaintingToolbarDropShadows();
-
-		this.theme = theme;
+		this.setPaintingDropShadows(DecorationAreaType.TOOLBAR);
 
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new SubduedGradientPainter();
-		// this.titlePainter = new FlatTitlePainter();
 
 		MarbleNoiseDecorationPainter decorationPainter = new MarbleNoiseDecorationPainter();
 		decorationPainter.setPaintingSeparators(true);
@@ -765,10 +790,7 @@ public class NebulaSkin extends SubstanceAbstractSkin {
 		this.decorationPainter = decorationPainter;
 
 		this.highlightPainter = new ClassicHighlightPainter();
-
 		this.borderPainter = new FlatBorderPainter();
-		// this.tabBackgroundComposite = new
-		// AlphaControlBackgroundComposite(0.75f);
 	}
 
 	/*
