@@ -31,17 +31,15 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.*;
-import org.jvnet.substance.painter.ClassicGradientPainter;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.BrushedMetalDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstanceStripeWatermark;
 
 /**
@@ -51,7 +49,7 @@ import org.jvnet.substance.watermark.SubstanceStripeWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class OfficeBlue2007Skin extends SubstanceAbstractSkin {
+public class OfficeBlue2007Skin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -61,13 +59,14 @@ public class OfficeBlue2007Skin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Office Blue 2007</code> skin.
 	 */
 	public OfficeBlue2007Skin() {
-		ColorScheme shiftBlue = new ShiftColorScheme(new AquaColorScheme(),
-				new Color(100, 150, 255), 0.3);
-		SubstanceTheme activeTheme = new SubstanceOrangeTheme().saturate(0.4);
-		SubstanceTheme defaultTheme = new SubstanceTheme(shiftBlue,
-				"Aqua Blue", ThemeKind.BRIGHT).saturate(-0.3);
+		SubstanceColorScheme shiftBlue = new ShiftColorScheme(
+				new AquaColorScheme(), new Color(100, 150, 255), 0.3);
+		SubstanceColorScheme activeScheme = new OrangeColorScheme().saturate(
+				0.4).named("Office Blue 2007 Active");
+		SubstanceColorScheme defaultScheme = shiftBlue.saturate(-0.3).named(
+				"Office Blue 2007 Default");
 
-		final ColorScheme disabledScheme = new SaturatedColorScheme(
+		SubstanceColorScheme disabledScheme = new SaturatedColorScheme(
 				new ShiftColorScheme(new AquaColorScheme(), new Color(100, 150,
 						255), 0.3), -0.1) {
 			Color foreColor = new Color(36, 95, 142);
@@ -76,33 +75,24 @@ public class OfficeBlue2007Skin extends SubstanceAbstractSkin {
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Disabled Office Blue 2007", ThemeKind.COLD);
-
-		SubstanceTheme activeTitleTheme = defaultTheme.saturate(-0.1);
-
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.BRIGHT, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme) {
-			@Override
-			public Color getLightBackgroundColor() {
-				return disabledTheme.getColorScheme().getExtraLightColor();
-			}
-		};
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		theme.registerComponentStateTheme(disabledTheme, 0.5f, false,
+		}.named("Office Blue 2007 Disabled");
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.5f,
 				ComponentState.DISABLED_UNSELECTED);
-		theme.registerComponentStateTheme(activeTheme, 0.5f, false,
+		defaultSchemeBundle.registerColorScheme(activeScheme, 0.5f,
 				ComponentState.DISABLED_SELECTED);
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
 
-		this.theme = theme;
+		setSelectedTabFadeStart(0.1);
+		setSelectedTabFadeEnd(0.3);
 
 		this.buttonShaper = new ClassicButtonShaper();
 		this.watermark = new SubstanceStripeWatermark();
@@ -127,4 +117,5 @@ public class OfficeBlue2007Skin extends SubstanceAbstractSkin {
 	public String getDisplayName() {
 		return NAME;
 	}
+
 }
