@@ -31,17 +31,15 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.*;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.GlassHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
 
 /**
@@ -51,7 +49,7 @@ import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.3
  */
-public class RavenGraphiteGlassSkin extends SubstanceAbstractSkin {
+public class RavenGraphiteGlassSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -61,9 +59,11 @@ public class RavenGraphiteGlassSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Raven Graphite</code> skin.
 	 */
 	public RavenGraphiteGlassSkin() {
-		SubstanceTheme activeTheme = new SubstanceEbonyTheme().tint(0.2);
-		SubstanceTheme defaultTheme = activeTheme.shade(0.2);
-		ColorScheme disabledScheme = new ToneColorScheme(
+		SubstanceColorScheme activeScheme = new EbonyColorScheme().tint(0.2)
+				.named("Raven Graphite Glass Active");
+		SubstanceColorScheme defaultScheme = activeScheme.shade(0.2).named(
+				"Raven Graphite Glass Default");
+		SubstanceColorScheme disabledScheme = new ToneColorScheme(
 				new EbonyColorScheme(), 0.35) {
 			Color foreColor = new Color(32, 32, 32);
 
@@ -71,8 +71,8 @@ public class RavenGraphiteGlassSkin extends SubstanceAbstractSkin {
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		ColorScheme selectedDisabledScheme = new TintColorScheme(
+		}.named("Raven Graphite Glass Disabled");
+		SubstanceColorScheme selectedDisabledScheme = new TintColorScheme(
 				new EbonyColorScheme(), 0.2) {
 			Color foreColor = new Color(32, 32, 32);
 
@@ -80,53 +80,43 @@ public class RavenGraphiteGlassSkin extends SubstanceAbstractSkin {
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Raven Graphite Glass Disabled", ThemeKind.DARK);
-		SubstanceTheme selectedDisabledTheme = new SubstanceTheme(
-				selectedDisabledScheme,
-				"Raven Graphite Glass Selected Disabled", ThemeKind.DARK);
-
-		SubstanceTheme activeTitleTheme = defaultTheme;
-
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.3);
-		theme.setSelectedTabFadeEnd(0.6);
-
+		}.named("Raven Graphite Glass Selected Disabled");
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
 		// register highlight alphas
-		SubstanceTheme highlightTheme = new SubstanceEbonyTheme();
-		theme.registerComponentHighlightStateTheme(highlightTheme, 0.4f,
+		SubstanceColorScheme highlightScheme = new EbonyColorScheme();
+		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.4f,
 				ComponentState.ROLLOVER_UNSELECTED);
-		theme.registerComponentHighlightStateTheme(highlightTheme, 0.55f,
-				ComponentState.SELECTED);
-		theme.registerComponentHighlightStateTheme(highlightTheme, 0.7f,
+		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme,
+				0.55f, ComponentState.SELECTED);
+		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme, 0.7f,
 				ComponentState.ROLLOVER_SELECTED);
-		theme.registerComponentHighlightStateTheme(highlightTheme, 0.65f,
-				ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
+		defaultSchemeBundle.registerHighlightColorScheme(highlightScheme,
+				0.65f, ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
 
-		// register theme for disabled states
-		theme.registerComponentStateTheme(disabledTheme, 0.5f, false,
+		// register schemes for disabled states
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.5f,
 				ComponentState.DISABLED_UNSELECTED);
-		theme.registerComponentStateTheme(selectedDisabledTheme, 0.5f, false,
+		defaultSchemeBundle.registerColorScheme(selectedDisabledScheme, 0.5f,
 				ComponentState.DISABLED_SELECTED);
 
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+
+		setSelectedTabFadeStart(0.3);
+		setSelectedTabFadeEnd(0.6);
 
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
 		this.watermark = new SubstanceCrosshatchWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.highlightPainter = new GlassHighlightPainter();
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 		this.borderPainter = new ClassicInnerBorderPainter(0.5f,
 				ColorShiftKind.TONE);
 	}
