@@ -31,27 +31,25 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.ClassicInnerBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.*;
-import org.jvnet.substance.painter.AlphaControlBackgroundComposite;
-import org.jvnet.substance.painter.SimplisticSoftBorderReverseGradientPainter;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.api.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicInnerBorderPainter;
+import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.FlatDecorationPainter;
+import org.jvnet.substance.painter.gradient.SimplisticGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.ComponentState;
-import org.jvnet.substance.utils.SubstanceConstants.ColorShiftKind;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
 
 /**
- * <code>Raven Graphite</code> skin. This class is part of officially
- * supported API.
+ * <code>Raven Graphite</code> skin. This class is part of officially supported
+ * API.
  * 
  * @author Kirill Grouchnikov
  * @since version 3.3
  */
-public class RavenGraphiteSkin extends SubstanceAbstractSkin {
+public class RavenGraphiteSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -61,16 +59,16 @@ public class RavenGraphiteSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Raven Graphite</code> skin.
 	 */
 	public RavenGraphiteSkin() {
-		ColorScheme activeScheme = new TintColorScheme(new EbonyColorScheme(),
-				0.2) {
+		SubstanceColorScheme activeScheme = new TintColorScheme(
+				new EbonyColorScheme(), 0.2) {
 			Color foreColor = new Color(200, 200, 200);
 
 			@Override
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		ColorScheme selectedDisabledScheme = new TintColorScheme(
+		}.named("Raven Graphite Active");
+		SubstanceColorScheme selectedDisabledScheme = new TintColorScheme(
 				new EbonyColorScheme(), 0.2) {
 			Color foreColor = new Color(32, 32, 32);
 
@@ -78,8 +76,8 @@ public class RavenGraphiteSkin extends SubstanceAbstractSkin {
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		ColorScheme disabledScheme = new ToneColorScheme(
+		}.named("Raven Graphite Selected Disabled");
+		SubstanceColorScheme disabledScheme = new ToneColorScheme(
 				new EbonyColorScheme(), 0.35) {
 			Color foreColor = new Color(32, 32, 32);
 
@@ -87,51 +85,55 @@ public class RavenGraphiteSkin extends SubstanceAbstractSkin {
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
-		SubstanceTheme activeTheme = new SubstanceTheme(activeScheme,
-				"Raven Graphite Active", ThemeKind.DARK);
-		SubstanceTheme defaultTheme = activeTheme.shade(0.2);
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Raven Graphite Disabled", ThemeKind.DARK);
-		SubstanceTheme selectedDisabledTheme = new SubstanceTheme(
-				selectedDisabledScheme, "Raven Graphite Selected Disabled",
-				ThemeKind.DARK);
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		}.named("Raven Graphite Disabled");
+		SubstanceColorScheme defaultScheme = activeScheme.shade(0.2);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.3);
-		theme.setSelectedTabFadeEnd(0.6);
-		theme.registerComponentHighlightStateTheme(new SubstanceEbonyTheme(),
-				0.8f);
-		// ComponentState.ROLLOVER_ARMED,
-		// ComponentState.ROLLOVER_SELECTED,
-		// ComponentState.ROLLOVER_UNSELECTED,
-		// ComponentState.ARMED);
-		theme.registerComponentStateTheme(disabledTheme, 0.5f, false,
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerHighlightColorScheme(
+				new EbonyColorScheme(), 0.8f);
+		defaultSchemeBundle.registerColorScheme(disabledScheme, 0.5f,
 				ComponentState.DISABLED_UNSELECTED);
-		theme.registerComponentStateTheme(selectedDisabledTheme, 0.5f, false,
+		defaultSchemeBundle.registerColorScheme(selectedDisabledScheme, 0.5f,
 				ComponentState.DISABLED_SELECTED);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(defaultScheme,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE,
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+
+		setSelectedTabFadeStart(0.3);
+		setSelectedTabFadeEnd(0.6);
 
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
 		this.watermark = new SubstanceCrosshatchWatermark();
-		this.gradientPainter = new SimplisticSoftBorderReverseGradientPainter() {
+		this.gradientPainter = new SimplisticGradientPainter() {
 			@Override
-			public Color getBottomFillColor(ColorScheme interpolationScheme1,
-					ColorScheme interpolationScheme2, double cycleCoef,
-					boolean useCyclePosAsInterpolation) {
+			public Color getBottomFillColor(
+					SubstanceColorScheme interpolationScheme1,
+					SubstanceColorScheme interpolationScheme2,
+					double cycleCoef, boolean useCyclePosAsInterpolation) {
 				return getMidFillColorBottom(interpolationScheme1,
 						interpolationScheme2, cycleCoef,
 						useCyclePosAsInterpolation);
 			}
+
+			@Override
+			public Color getTopFillColor(
+					SubstanceColorScheme interpolationScheme1,
+					SubstanceColorScheme interpolationScheme2,
+					double cycleCoef, boolean useCyclePosAsInterpolation) {
+				return super.getBottomFillColor(interpolationScheme1,
+						interpolationScheme2, cycleCoef,
+						useCyclePosAsInterpolation);
+			}
 		};
+
 		this.decorationPainter = new FlatDecorationPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-		tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 		this.borderPainter = new ClassicInnerBorderPainter(0.55f,
 				ColorShiftKind.TONE);
 	}
