@@ -31,16 +31,14 @@ package org.jvnet.substance.skin;
 
 import java.awt.Color;
 
-import org.jvnet.substance.border.GlassBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.color.ShadeColorScheme;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.GlassBorderPainter;
 import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
 
 /**
@@ -49,7 +47,7 @@ import org.jvnet.substance.watermark.SubstanceCrosshatchWatermark;
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
-public class RavenSkin extends SubstanceAbstractSkin {
+public class RavenSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -59,41 +57,37 @@ public class RavenSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Raven</code> skin.
 	 */
 	public RavenSkin() {
-		SubstanceTheme activeTheme = new SubstanceEbonyTheme();
-		SubstanceTheme defaultTheme = activeTheme.getDefaultTheme();
+		SubstanceColorScheme activeScheme = new EbonyColorScheme();
+		SubstanceColorScheme defaultScheme = new DarkMetallicColorScheme();
 
-		ColorScheme disabledScheme = new ShadeColorScheme(activeTheme
-				.getColorScheme(), 0.5) {
+		SubstanceColorScheme disabledScheme = new ShadeColorScheme(
+				activeScheme, 0.5) {
 			Color foreColor = new Color(80, 80, 80);
 
 			@Override
 			public Color getForegroundColor() {
 				return foreColor;
 			}
-		};
+		}.named("Raven Disabled");
 
-		SubstanceTheme disabledTheme = new SubstanceTheme(disabledScheme,
-				"Disabled Raven", ThemeKind.DARK);
-		SubstanceTheme activeTitleTheme = defaultTheme;
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.DARK, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.registerDecorationAreaTheme(activeTitleTheme, false,
+		this.registerAsDecorationArea(defaultScheme,
 				DecorationAreaType.PRIMARY_TITLE_PANE,
 				DecorationAreaType.SECONDARY_TITLE_PANE,
-				DecorationAreaType.HEADER, DecorationAreaType.GENERAL,
-				DecorationAreaType.TOOLBAR);
+				DecorationAreaType.HEADER, DecorationAreaType.FOOTER,
+				DecorationAreaType.GENERAL, DecorationAreaType.TOOLBAR);
+		
+		this.watermarkScheme = activeScheme.shade(0.4);
 
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		this.theme = theme;
 		this.buttonShaper = new ClassicButtonShaper();
 		this.watermark = new SubstanceCrosshatchWatermark();
 		this.gradientPainter = new GlassGradientPainter();
 		this.decorationPainter = new ArcDecorationPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-		tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 		this.borderPainter = new GlassBorderPainter();
 	}
 
