@@ -29,21 +29,21 @@
  */
 package org.jvnet.substance.skin;
 
-import org.jvnet.substance.border.ClassicBorderPainter;
-import org.jvnet.substance.button.ClassicButtonShaper;
-import org.jvnet.substance.painter.*;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
 import org.jvnet.substance.painter.decoration.ClassicDecorationPainter;
+import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.ClassicGradientPainter;
 import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.SubstanceNullWatermark;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * <code>Sahara</code> skin. This class is part of officially supported API.
  * 
  * @author Kirill Grouchnikov
  */
-public class SaharaSkin extends SubstanceAbstractSkin {
+public class SaharaSkin extends SubstanceSkin {
 	/**
 	 * Display name for <code>this</code> skin.
 	 */
@@ -53,29 +53,26 @@ public class SaharaSkin extends SubstanceAbstractSkin {
 	 * Creates a new <code>Sahara</code> skin.
 	 */
 	public SaharaSkin() {
-		SubstanceTheme activeTheme = new SubstanceDesertSandTheme();
-		SubstanceTheme defaultTheme = activeTheme.getDefaultTheme();
-		SubstanceTheme disabledTheme = activeTheme.getDisabledTheme();
-		SubstanceTheme activeTitleTheme = activeTheme;
+		SubstanceColorScheme activeScheme = new DesertSandColorScheme();
+		SubstanceColorScheme defaultScheme = new MetallicColorScheme();
+		SubstanceColorScheme disabledScheme = new LightGrayColorScheme();
+
+		SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+				activeScheme, defaultScheme, disabledScheme);
+		defaultSchemeBundle.registerHighlightColorScheme(new OliveColorScheme()
+				.tint(0.2).named("Sahara Highlight"));
+		this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+				DecorationAreaType.NONE);
+
+		this.registerAsDecorationArea(activeScheme,
+				DecorationAreaType.PRIMARY_TITLE_PANE,
+				DecorationAreaType.SECONDARY_TITLE_PANE);
 
-		SubstanceComplexTheme theme = new SubstanceComplexTheme(NAME,
-				ThemeKind.COLD, activeTheme, defaultTheme, disabledTheme,
-				activeTitleTheme);
-		theme.registerComponentHighlightStateTheme(new SubstanceOliveTheme()
-				.tint(0.2));
-		theme
-				.setNonActivePainter(new SimplisticSoftBorderReverseGradientPainter());
-		theme.setSelectedTabFadeStart(0.1);
-		theme.setSelectedTabFadeEnd(0.3);
-		this.theme = theme;
-		// theme.addPaintAsActive(JScrollBar.class);
 		this.buttonShaper = new ClassicButtonShaper();
-		this.watermark = new SubstanceNullWatermark();
 		this.gradientPainter = new ClassicGradientPainter();
 		this.borderPainter = new ClassicBorderPainter();
 		this.decorationPainter = new ClassicDecorationPainter();
 		this.highlightPainter = new ClassicHighlightPainter();
-		this.tabBackgroundComposite = new AlphaControlBackgroundComposite(0.5f);
 	}
 
 	/*
