@@ -32,12 +32,15 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Business Black Steel</code>
- * skin from {@link BusinessBlackSteelSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Business Black Steel</code> skin
+ * from {@link BusinessBlackSteelSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel");</li>
- * <li>UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel"
+ * );</li>
+ * <li>UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+ * </li>
  * </ul>
  * 
  * @author Kirill Grouchnikov
@@ -45,34 +48,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  */
 public class SubstanceBusinessBlackSteelLookAndFeel extends
 		SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Business Black Steel</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Business Black Steel";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Business Black Steel";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new BusinessBlackSteelSkin());
+	public SubstanceBusinessBlackSteelLookAndFeel() {
+		super(new BusinessBlackSteelSkin());
 	}
 }
