@@ -32,46 +32,25 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Business Blue Steel</code>
- * skin from {@link BusinessBlueSteelSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Business Blue Steel</code> skin
+ * from {@link BusinessBlueSteelSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessBlueSteelLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessBlueSteelLookAndFeel");</li>
- * <li>UIManager.setLookAndFeel(new SubstanceBusinessBlueSteelLookAndFeel());</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessBlueSteelLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessBlueSteelLookAndFeel"
+ * );</li>
+ * <li>UIManager.setLookAndFeel(new SubstanceBusinessBlueSteelLookAndFeel());
+ * </li>
  * </ul>
  * 
  * @author Kirill Grouchnikov
  * @since version 3.3
  */
 public class SubstanceBusinessBlueSteelLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Business Blue Steel</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Business Blue Steel";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Business Blue Steel";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new BusinessBlueSteelSkin());
+	public SubstanceBusinessBlueSteelLookAndFeel() {
+		super(new BusinessBlueSteelSkin());
 	}
 }
