@@ -35,8 +35,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Standalone look-and-feel that uses the <code>Business</code> skin from
  * {@link BusinessSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceBusinessLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceBusinessLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceBusinessLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 3.1
  */
 public class SubstanceBusinessLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Business</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Business";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Business";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new BusinessSkin());
+	public SubstanceBusinessLookAndFeel() {
+		super(new BusinessSkin());
 	}
 }
