@@ -35,8 +35,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Standalone look-and-feel that uses the <code>Emerald Dusk</code> skin from
  * {@link EmeraldDuskSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceEmeraldDuskLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 3.2
  */
 public class SubstanceEmeraldDuskLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Emerald Dusk</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Emerald Dusk";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Emerald Dusk";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new EmeraldDuskSkin());
+	public SubstanceEmeraldDuskLookAndFeel() {
+		super(new EmeraldDuskSkin());
 	}
 }
