@@ -35,8 +35,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Standalone look-and-feel that uses the <code>Mist Aqua</code> skin from
  * {@link MistAquaSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceMistAquaLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 4.0
  */
 public class SubstanceMistAquaLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Mist Aqua</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Mist Aqua";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Mist Aqua";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new MistAquaSkin());
+	public SubstanceMistAquaLookAndFeel() {
+		super(new MistAquaSkin());
 	}
 }
