@@ -35,8 +35,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Standalone look-and-feel that uses the <code>Mist Silver</code> skin from
  * {@link MistSilverSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceMistSilverLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceMistSilverLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceMistSilverLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceMistSilverLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceMistSilverLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 4.0
  */
 public class SubstanceMistSilverLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Mist Silver</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Mist Silver";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Mist Silver";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new MistSilverSkin());
+	public SubstanceMistSilverLookAndFeel() {
+		super(new MistSilverSkin());
 	}
 }
