@@ -32,11 +32,13 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Nebula</code> skin from
- * {@link NebulaSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Nebula</code> skin from {@link
+ * NebulaSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceNebulaLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceNebulaLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceNebulaLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceNebulaLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceNebulaLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 4.0
  */
 public class SubstanceNebulaLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Nebula</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Nebula";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Nebula";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new NebulaSkin());
+	public SubstanceNebulaLookAndFeel() {
+		super(new NebulaSkin());
 	}
 }
