@@ -35,43 +35,22 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * Standalone look-and-feel that uses the <code>Office Silver 2007</code> skin
  * from {@link OfficeSilver2007Skin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceOfficeSilver2007LookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceOfficeSilver2007LookAndFeel");</li>
- * <li>UIManager.setLookAndFeel(new SubstanceOfficeSilver2007LookAndFeel());</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceOfficeSilver2007LookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceOfficeSilver2007LookAndFeel"
+ * );</li>
+ * <li>UIManager.setLookAndFeel(new SubstanceOfficeSilver2007LookAndFeel());
+ * </li>
  * </ul>
  * 
  * @author Kirill Grouchnikov
  * @since version 3.1
  */
 public class SubstanceOfficeSilver2007LookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Office Silver 2007</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Office Silver 2007";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Office Silver 2007";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new OfficeSilver2007Skin());
+	public SubstanceOfficeSilver2007LookAndFeel() {
+		super(new OfficeSilver2007Skin());
 	}
 }
