@@ -32,12 +32,15 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Raven Graphite Glass</code>
- * skin from {@link RavenGraphiteGlassSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Raven Graphite Glass</code> skin
+ * from {@link RavenGraphiteGlassSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel");</li>
- * <li>UIManager.setLookAndFeel(new SubstanceRavenGraphiteGlassLookAndFeel());</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel"
+ * );</li>
+ * <li>UIManager.setLookAndFeel(new SubstanceRavenGraphiteGlassLookAndFeel());
+ * </li>
  * </ul>
  * 
  * @author Kirill Grouchnikov
@@ -45,34 +48,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  */
 public class SubstanceRavenGraphiteGlassLookAndFeel extends
 		SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Raven Graphite Glass</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Raven Graphite Glass";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Raven Graphite Glass";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new RavenGraphiteGlassSkin());
+	public SubstanceRavenGraphiteGlassLookAndFeel() {
+		super(new RavenGraphiteGlassSkin());
 	}
 }
