@@ -32,11 +32,13 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Raven Graphite</code> skin
- * from {@link RavenGraphiteSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Raven Graphite</code> skin from
+ * {@link RavenGraphiteSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceRavenGraphiteLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 3.3
  */
 public class SubstanceRavenGraphiteLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Raven Graphite</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Raven Graphite";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Raven Graphite";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new RavenGraphiteSkin());
+	public SubstanceRavenGraphiteLookAndFeel() {
+		super(new RavenGraphiteSkin());
 	}
 }
