@@ -32,11 +32,13 @@ package org.jvnet.substance.skin;
 import org.jvnet.substance.SubstanceLookAndFeel;
 
 /**
- * Standalone look-and-feel that uses the <code>Sahara</code> skin from
- * {@link SaharaSkin}. You can set this look-and-feel by:
+ * Standalone look-and-feel that uses the <code>Sahara</code> skin from {@link
+ * SaharaSkin}. You can set this look-and-feel by:
  * <ul>
- * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceSaharaLookAndFeel</li>
- * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceSaharaLookAndFeel");</li>
+ * <li>-Dswing.defaultlaf=org.jvnet.substance.skin.SubstanceSaharaLookAndFeel
+ * </li>
+ * <li>UIManager.setLookAndFeel("org.jvnet.substance.skin.SubstanceSaharaLookAndFeel"
+ * );</li>
  * <li>UIManager.setLookAndFeel(new SubstanceSaharaLookAndFeel());</li>
  * </ul>
  * 
@@ -44,34 +46,10 @@ import org.jvnet.substance.SubstanceLookAndFeel;
  * @since version 3.1
  */
 public class SubstanceSaharaLookAndFeel extends SubstanceLookAndFeel {
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getID()
+	/**
+	 * Creates a new <code>Sahara</code> look-and-feel.
 	 */
-	@Override
-	public String getID() {
-		return "Substance Sahara";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#getName()
-	 */
-	@Override
-	public String getName() {
-		return "Substance Sahara";
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.SubstanceLookAndFeel#initialize()
-	 */
-	@Override
-	public void initialize() {
-		super.initialize();
-		setSkin(new SaharaSkin());
+	public SubstanceSaharaLookAndFeel() {
+		super(new SaharaSkin());
 	}
 }
