@@ -39,17 +39,15 @@ import javax.swing.UIDefaults;
 import javax.swing.UIManager;
 
 import org.jvnet.lafwidget.utils.TrackableThread;
-import org.jvnet.substance.*;
-import org.jvnet.substance.painter.highlight.ClassicHighlightPainter;
 
 /**
  * Tracer for memory usage patterns of <b>Substance</b> look-and-feel. The
- * tracer is started when VM has <code>-Dsubstancelaf.traceFile</code> flag.
- * The value of this flag specifies the location of trace log file. When
- * activated, the tracer runs a thread that collects information on memory usage
- * and appends it to the trace log file every <code>X</code> seconds. The
- * <code>X</code> (delay) is specified in the constructor. This class is
- * <b>for internal use only</b>.
+ * tracer is started when VM has <code>-Dsubstancelaf.traceFile</code> flag. The
+ * value of this flag specifies the location of trace log file. When activated,
+ * the tracer runs a thread that collects information on memory usage and
+ * appends it to the trace log file every <code>X</code> seconds. The
+ * <code>X</code> (delay) is specified in the constructor. This class is <b>for
+ * internal use only</b>.
  * 
  * @author Kirill Grouchnikov
  */
@@ -70,8 +68,8 @@ public class MemoryAnalyzer extends TrackableThread {
 	private static MemoryAnalyzer instance;
 
 	/**
-	 * If <code>true</code>, <code>this</code> tracer has received a
-	 * request to stop.
+	 * If <code>true</code>, <code>this</code> tracer has received a request to
+	 * stop.
 	 */
 	private static boolean isStopRequest = false;
 
@@ -89,9 +87,9 @@ public class MemoryAnalyzer extends TrackableThread {
 	 * Simple constructor.
 	 * 
 	 * @param delay
-	 *            Sleep delay between trace log iterations.
+	 * 		Sleep delay between trace log iterations.
 	 * @param filename
-	 *            Trace logfile name.
+	 * 		Trace logfile name.
 	 */
 	private MemoryAnalyzer(long delay, String filename) {
 		super();
@@ -104,9 +102,9 @@ public class MemoryAnalyzer extends TrackableThread {
 	 * Starts the memory tracing.
 	 * 
 	 * @param delay
-	 *            Sleep delay between trace log iterations.
+	 * 		Sleep delay between trace log iterations.
 	 * @param filename
-	 *            Trace logfile name.
+	 * 		Trace logfile name.
 	 */
 	public static synchronized void commence(long delay, String filename) {
 		if (instance == null) {
@@ -130,7 +128,7 @@ public class MemoryAnalyzer extends TrackableThread {
 	 * Checks whether a request to stop tracing has been issued.
 	 * 
 	 * @return <code>true</code> if a request to stop tracing has been issued,
-	 *         <code>false</code> otherwise.
+	 * 	<code>false</code> otherwise.
 	 */
 	private static synchronized boolean hasStopRequest() {
 		return isStopRequest;
@@ -140,7 +138,7 @@ public class MemoryAnalyzer extends TrackableThread {
 	 * Checks whether tracer is running.
 	 * 
 	 * @return <code>true</code> if tracer is running, <code>false</code>
-	 *         otherwise.
+	 * 	otherwise.
 	 */
 	public static boolean isRunning() {
 		return (instance != null);
@@ -150,8 +148,8 @@ public class MemoryAnalyzer extends TrackableThread {
 	 * Adds usage string.
 	 * 
 	 * @param usage
-	 *            Usage string. Will be output to the trace file at next
-	 *            iteration of the tracer.
+	 * 		Usage string. Will be output to the trace file at next iteration of
+	 * 		the tracer.
 	 */
 	public static synchronized void enqueueUsage(String usage) {
 		if (instance != null) {
@@ -249,19 +247,13 @@ public class MemoryAnalyzer extends TrackableThread {
 				bw = new BufferedWriter(new FileWriter(new File(this.filename),
 						true));
 				bw.write(sdf.format(new Date()) + "\n");
+				java.util.List<String> stats = LazyResettableHashMap.getStats();
+				if (stats != null) {
+					for (String stat : stats) {
+						bw.write(stat + "\n");
+					}
+				}
 				bw.write(PulseTracker.getMemoryUsage() + "\n");
-				// bw.write(RolloverButtonListener.getMemoryUsage() + "\n");
-				// bw.write(RolloverScrollBarButtonListener.getMemoryUsage()
-				// + "\n");
-				bw.write(ButtonBackgroundDelegate.getMemoryUsage() + "\n");
-				bw.write(SubstanceCheckBoxUI.getMemoryUsage() + "\n");
-				// bw.write(SubstanceComboBoxUI.getMemoryUsage() + "\n");
-				bw.write(SubstanceProgressBarUI.getMemoryUsage() + "\n");
-				bw.write(SubstanceRadioButtonUI.getMemoryUsage() + "\n");
-				// bw.write(SubstanceRootPaneUI.getMemoryUsage() + "\n");
-				bw.write(SubstanceScrollBarUI.getMemoryUsage() + "\n");
-				bw.write(SubstanceTabbedPaneUI.getMemoryUsage() + "\n");
-				bw.write(ClassicHighlightPainter.getMemoryUsage() + "\n");
 				ArrayList<String> usages = getUsages();
 				for (String usage : usages) {
 					bw.write(usage + "\n");
