@@ -29,11 +29,10 @@
  */
 package org.jvnet.substance.utils;
 
-import java.awt.*;
+import java.awt.Component;
 import java.awt.event.*;
 
 import javax.swing.ButtonModel;
-import javax.swing.SwingUtilities;
 
 // import org.jvnet.lafwidget.utils.FadeTracker;
 // import org.jvnet.lafwidget.utils.FadeTracker.FadeKind;
@@ -65,12 +64,6 @@ public class RolloverControlListener implements MouseListener,
 	 */
 	private Trackable trackableUI;
 
-	/**
-	 * If <code>true</code>, the mouse events will be redispatched to the
-	 * parent of the event source component.
-	 */
-	private boolean isRedispatching;
-
 	/**
 	 * Simple constructor.
 	 * 
@@ -85,17 +78,6 @@ public class RolloverControlListener implements MouseListener,
 		this.isMouseInside = false;
 	}
 
-	/**
-	 * Sets the redispatch indication.
-	 * 
-	 * @param isRedispatching
-	 *            If <code>true</code>, the mouse events will be redispatched
-	 *            to the parent of the event source component.
-	 */
-	public void setRedispatching(boolean isRedispatching) {
-		this.isRedispatching = isRedispatching;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -110,12 +92,6 @@ public class RolloverControlListener implements MouseListener,
 		this.isMouseInside = isInside;
 		this.model.setRollover(isInside);
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// isInside, false);
-		// component.repaint();
-
-		this.redispatchToParent(e);
 	}
 
 	/*
@@ -131,17 +107,13 @@ public class RolloverControlListener implements MouseListener,
 		this.isMouseInside = false;
 		this.model.setRollover(false);
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// this.isMouseInside, false);
-		// component.repaint();
-		this.redispatchToParent(e);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
+	 * @see
+	 * java.awt.event.MouseListener#mouseReleased(java.awt.event.MouseEvent)
 	 */
 	public void mouseReleased(MouseEvent e) {
 		// System.out.println("mouse released [" + e.getX() + ":" + e.getY() +
@@ -157,11 +129,6 @@ public class RolloverControlListener implements MouseListener,
 		this.model.setArmed(false);
 		this.model.setSelected(false);
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// isInside, false);
-		// component.repaint();
-		this.redispatchToParent(e);
 	}
 
 	/*
@@ -185,17 +152,14 @@ public class RolloverControlListener implements MouseListener,
 			this.model.setSelected(true);
 		}
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// isInside, false);
-		// component.repaint();
-		this.redispatchToParent(e);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see java.awt.event.MouseMotionListener#mouseDragged(java.awt.event.MouseEvent)
+	 * @see
+	 * java.awt.event.MouseMotionListener#mouseDragged(java.awt.event.MouseEvent
+	 * )
 	 */
 	public void mouseDragged(MouseEvent e) {
 		// System.out.println("mouse dragged [" + e.getX() + ":" + e.getY() +
@@ -207,17 +171,13 @@ public class RolloverControlListener implements MouseListener,
 		// boolean isInsideChanged = (this.isMouseInside != isInside);
 		this.isMouseInside = isInside;
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// isInside, false);
-		// component.repaint();
-		this.redispatchToParent(e);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see java.awt.event.MouseMotionListener#mouseMoved(java.awt.event.MouseEvent)
+	 * @see
+	 * java.awt.event.MouseMotionListener#mouseMoved(java.awt.event.MouseEvent)
 	 */
 	public void mouseMoved(MouseEvent e) {
 		// System.out.println("mouse moved [" + e.getX() + ":" + e.getY() +
@@ -231,11 +191,6 @@ public class RolloverControlListener implements MouseListener,
 		this.isMouseInside = isInside;
 		this.model.setRollover(isInside);
 		this.model.setEnabled(component.isEnabled());
-		// if (isInsideChanged)
-		// FadeTracker.getInstance().trackFade(component, FadeKind.ROLLOVER,
-		// isInside, false);
-		// component.repaint();
-		this.redispatchToParent(e);
 	}
 
 	/*
@@ -244,38 +199,5 @@ public class RolloverControlListener implements MouseListener,
 	 * @see java.awt.event.MouseListener#mouseClicked(java.awt.event.MouseEvent)
 	 */
 	public void mouseClicked(MouseEvent e) {
-		this.redispatchToParent(e);
-	}
-
-	/**
-	 * Redispatches the specified event to the parent of the event source
-	 * component, changing the event ID to {@link MouseEvent#MOUSE_MOVED} for
-	 * {@link MouseEvent#MOUSE_ENTERED} and {@link MouseEvent#MOUSE_EXITED}.
-	 * 
-	 * @param e
-	 *            Event to redispatch.
-	 */
-	private void redispatchToParent(final MouseEvent e) {
-		if (!this.isRedispatching)
-			return;
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				Component comp = (Component) e.getSource();
-				Container parent = comp.getParent();
-				if (parent == null)
-					return;
-				Point contPoint = SwingUtilities.convertPoint(comp, e
-						.getPoint(), parent);
-				int eventId = e.getID();
-				if ((eventId == MouseEvent.MOUSE_ENTERED)
-						|| (eventId == MouseEvent.MOUSE_EXITED)) {
-					// translate the ENTERED / EXITED into MOVED.
-					eventId = MouseEvent.MOUSE_MOVED;
-				}
-				parent.dispatchEvent(new MouseEvent(parent, eventId, e
-						.getWhen(), e.getModifiers(), contPoint.x, contPoint.y,
-						e.getClickCount(), e.isPopupTrigger(), e.getButton()));
-			}
-		});
 	}
 }
