@@ -32,16 +32,14 @@ package org.jvnet.substance.utils;
 import java.awt.Color;
 import java.awt.Component;
 
-import javax.swing.AbstractButton;
-import javax.swing.ButtonModel;
+import javax.swing.*;
+import javax.swing.plaf.ColorUIResource;
+import javax.swing.plaf.UIResource;
+import javax.swing.text.JTextComponent;
 
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeState;
-import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.color.ColorBlindColorScheme.BlindnessKind;
-import org.jvnet.substance.theme.SubstanceComplexTheme;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.*;
 
 /**
  * Various color-related utilities. This class is <b>for internal use only</b>.
@@ -61,8 +59,8 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @return The color of the top portion of border in control backgrounds.
 	 */
-	public static Color getTopBorderColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef) {
+	public static Color getTopBorderColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef) {
 		return SubstanceColorUtilities.getInterpolatedColor(scheme1
 				.getUltraDarkColor(), scheme2.getUltraDarkColor(), cycleCoef);
 	}
@@ -79,16 +77,10 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @return The color of the middle portion of border in control backgrounds.
 	 */
-	public static Color getMidBorderColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef) {
-		// if (isDark) {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getExtraLightColor(), scheme2.getExtraLightColor(),
-		// cycleCoef);
-		// } else {
+	public static Color getMidBorderColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef) {
 		return SubstanceColorUtilities.getInterpolatedColor(scheme1
 				.getDarkColor(), scheme2.getDarkColor(), cycleCoef);
-		// }
 	}
 
 	/**
@@ -103,18 +95,13 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @return The color of the bottom portion of border in control backgrounds.
 	 */
-	public static Color getBottomBorderColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef) {
-		// if (isDark) {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getLightColor(), scheme2.getLightColor(), cycleCoef);
-		// } else {
+	public static Color getBottomBorderColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef) {
 		Color c1 = SubstanceColorUtilities.getInterpolatedColor(scheme1
 				.getDarkColor(), scheme1.getMidColor(), 0.5);
 		Color c2 = SubstanceColorUtilities.getInterpolatedColor(scheme2
 				.getDarkColor(), scheme2.getMidColor(), 0.5);
 		return SubstanceColorUtilities.getInterpolatedColor(c1, c2, cycleCoef);
-		// }
 	}
 
 	/**
@@ -129,15 +116,15 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @param useCyclePosAsInterpolation
 	 *            Indicates the algorithm to use for computing various colors.
-	 *            If <code>true</code>, the <code>cyclePos</code> is used
-	 *            to interpolate colors between different color components of
-	 *            both color schemes. If <code>false</code>, the
+	 *            If <code>true</code>, the <code>cyclePos</code> is used to
+	 *            interpolate colors between different color components of both
+	 *            color schemes. If <code>false</code>, the
 	 *            <code>cyclePos</code> is used to interpolate colors between
 	 *            different color components of the first color scheme.
 	 * @return The color of the top portion of fill in control backgrounds.
 	 */
-	public static Color getTopFillColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef,
+	public static Color getTopFillColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef,
 			boolean useCyclePosAsInterpolation) {
 		if (!useCyclePosAsInterpolation) {
 			Color c = SubstanceColorUtilities.getInterpolatedColor(scheme1
@@ -166,15 +153,15 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @param useCyclePosAsInterpolation
 	 *            Indicates the algorithm to use for computing various colors.
-	 *            If <code>true</code>, the <code>cyclePos</code> is used
-	 *            to interpolate colors between different color components of
-	 *            both color schemes. If <code>false</code>, the
+	 *            If <code>true</code>, the <code>cyclePos</code> is used to
+	 *            interpolate colors between different color components of both
+	 *            color schemes. If <code>false</code>, the
 	 *            <code>cyclePos</code> is used to interpolate colors between
 	 *            different color components of the first color scheme.
 	 * @return The color of the middle portion of fill in control backgrounds.
 	 */
-	public static Color getMidFillColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef,
+	public static Color getMidFillColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef,
 			boolean useCyclePosAsInterpolation) {
 		if (!useCyclePosAsInterpolation) {
 			return SubstanceColorUtilities.getInterpolatedColor(scheme1
@@ -197,25 +184,16 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @param useCyclePosAsInterpolation
 	 *            Indicates the algorithm to use for computing various colors.
-	 *            If <code>true</code>, the <code>cyclePos</code> is used
-	 *            to interpolate colors between different color components of
-	 *            both color schemes. If <code>false</code>, the
+	 *            If <code>true</code>, the <code>cyclePos</code> is used to
+	 *            interpolate colors between different color components of both
+	 *            color schemes. If <code>false</code>, the
 	 *            <code>cyclePos</code> is used to interpolate colors between
 	 *            different color components of the first color scheme.
 	 * @return The color of the bottom portion of fill in control backgrounds.
 	 */
-	public static Color getBottomFillColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef,
+	public static Color getBottomFillColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef,
 			boolean useCyclePosAsInterpolation) {
-		// if (isDark) {
-		// if (!useCyclePosAsInterpolation) {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getDarkColor(), scheme2.getMidColor(), cycleCoef);
-		// } else {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getDarkColor(), scheme2.getDarkColor(), cycleCoef);
-		// }
-		// } else {
 		if (!useCyclePosAsInterpolation) {
 			return SubstanceColorUtilities.getInterpolatedColor(scheme1
 					.getUltraLightColor(), scheme2.getExtraLightColor(),
@@ -225,7 +203,6 @@ public class SubstanceColorUtilities {
 					.getUltraLightColor(), scheme2.getUltraLightColor(),
 					cycleCoef);
 		}
-		// }
 	}
 
 	/**
@@ -240,15 +217,15 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @param useCyclePosAsInterpolation
 	 *            Indicates the algorithm to use for computing various colors.
-	 *            If <code>true</code>, the <code>cyclePos</code> is used
-	 *            to interpolate colors between different color components of
-	 *            both color schemes. If <code>false</code>, the
+	 *            If <code>true</code>, the <code>cyclePos</code> is used to
+	 *            interpolate colors between different color components of both
+	 *            color schemes. If <code>false</code>, the
 	 *            <code>cyclePos</code> is used to interpolate colors between
 	 *            different color components of the first color scheme.
 	 * @return The color of the top portion of shine in control backgrounds.
 	 */
-	public static Color getTopShineColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef,
+	public static Color getTopShineColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef,
 			boolean useCyclePosAsInterpolation) {
 		return getBottomFillColor(scheme1, scheme2, cycleCoef,
 				useCyclePosAsInterpolation);
@@ -266,25 +243,16 @@ public class SubstanceColorUtilities {
 	 *            Must be in 0.0 .. 1.0 range.
 	 * @param useCyclePosAsInterpolation
 	 *            Indicates the algorithm to use for computing various colors.
-	 *            If <code>true</code>, the <code>cyclePos</code> is used
-	 *            to interpolate colors between different color components of
-	 *            both color schemes. If <code>false</code>, the
+	 *            If <code>true</code>, the <code>cyclePos</code> is used to
+	 *            interpolate colors between different color components of both
+	 *            color schemes. If <code>false</code>, the
 	 *            <code>cyclePos</code> is used to interpolate colors between
 	 *            different color components of the first color scheme.
 	 * @return The color of the bottom portion of shine in control backgrounds.
 	 */
-	public static Color getBottomShineColor(ColorScheme scheme1,
-			ColorScheme scheme2, double cycleCoef,
+	public static Color getBottomShineColor(SubstanceColorScheme scheme1,
+			SubstanceColorScheme scheme2, double cycleCoef,
 			boolean useCyclePosAsInterpolation) {
-		// if (isDark) {
-		// if (!useCyclePosAsInterpolation) {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getMidColor(), scheme2.getDarkColor(), cycleCoef);
-		// } else {
-		// return SubstanceCoreUtilities.getInterpolatedColor(scheme1
-		// .getMidColor(), scheme2.getMidColor(), cycleCoef);
-		// }
-		// } else {
 		if (!useCyclePosAsInterpolation) {
 			return SubstanceColorUtilities.getInterpolatedColor(scheme1
 					.getLightColor(), scheme2.getUltraLightColor(), cycleCoef);
@@ -292,7 +260,6 @@ public class SubstanceColorUtilities {
 			return SubstanceColorUtilities.getInterpolatedColor(scheme1
 					.getLightColor(), scheme2.getLightColor(), cycleCoef);
 		}
-		// }
 	}
 
 	/**
@@ -309,6 +276,10 @@ public class SubstanceColorUtilities {
 	 */
 	public static int getInterpolatedRGB(Color color1, Color color2,
 			double color1Likeness) {
+		if ((color1Likeness < 0.0) || (color1Likeness > 1.0))
+			throw new IllegalArgumentException(
+					"Color likeness should be in 0.0-1.0 range [is "
+							+ color1Likeness + "]");
 		int lr = color1.getRed();
 		int lg = color1.getGreen();
 		int lb = color1.getBlue();
@@ -323,14 +294,6 @@ public class SubstanceColorUtilities {
 		int b = (int) (color1Likeness * lb + (1.0 - color1Likeness) * db);
 		int a = (int) (color1Likeness * la + (1.0 - color1Likeness) * da);
 
-		r = Math.min(255, r);
-		g = Math.min(255, g);
-		b = Math.min(255, b);
-		a = Math.min(255, a);
-		r = Math.max(0, r);
-		g = Math.max(0, g);
-		b = Math.max(0, b);
-		a = Math.max(0, a);
 		return (a << 24) | (r << 16) | (g << 8) | b;
 	}
 
@@ -370,130 +333,6 @@ public class SubstanceColorUtilities {
 				255 - color.getBlue(), color.getAlpha());
 	}
 
-	/**
-	 * Returns background color for the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Background color for the specified theme.
-	 */
-	public static Color getBackgroundColor(SubstanceTheme theme) {
-		if (theme instanceof SubstanceComplexTheme) {
-			SubstanceComplexTheme sct = (SubstanceComplexTheme) theme;
-			SubstanceTheme defTheme = sct.getDefaultTheme();
-			switch (defTheme.getKind()) {
-			case DARK:
-				return defTheme.getColorScheme().getDarkColor().brighter();
-			default:
-				return defTheme.getColorScheme().getExtraLightColor();
-			}
-		}
-		switch (theme.getKind()) {
-		case DARK:
-			return theme.getColorScheme().getDarkColor().brighter();
-		default:
-			return theme.getDefaultColorScheme().getExtraLightColor();
-			// SubstanceTheme.getMetallic(theme.getKind())
-			// .getExtraLightColor();
-		}
-	}
-
-	/**
-	 * Returns disabled foreground color for the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Disabled foreground color for the specified theme.
-	 */
-	public static Color getDisabledForegroundColor(SubstanceTheme theme) {
-		return theme.getDisabledTheme().getForegroundColor();
-		// switch (theme.getKind()) {
-		// case DARK:
-		// return getInterpolatedColor(theme.getDefaultColorScheme()
-		// .getForegroundColor(), theme.getColorScheme()
-		// .getDarkColor(), 0.45);
-		// default:
-		// return getInterpolatedColor(theme.getDefaultColorScheme()
-		// .getMidColor(), theme.getDefaultColorScheme()
-		// .getDarkColor(), 0.7);
-		// }
-	}
-
-	/**
-	 * Returns selection background color for the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Selection background color for the specified theme.
-	 */
-	public static Color getSelectionBackgroundColor(SubstanceTheme theme) {
-		// fix for enhancement 182 - use highlight theme as
-		// selection background.
-		switch (theme.getKind()) {
-		case DARK:
-			return theme.getHighlightTheme(null, ComponentState.ACTIVE)
-					.getColorScheme().getUltraLightColor().brighter();
-			// .brighter();
-		default:
-			return theme.getHighlightTheme(null, ComponentState.ACTIVE)
-					.getColorScheme().getExtraLightColor();
-		}
-
-	}
-
-	/**
-	 * Returns line color for the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Line color for the specified theme.
-	 */
-	public static Color getLineColor(SubstanceTheme theme) {
-		switch (theme.getKind()) {
-		case DARK:
-			return theme.getColorScheme().getUltraLightColor();
-		default:
-			return theme.getColorScheme().getMidColor();
-		}
-	}
-
-	/**
-	 * Returns selection foreground color for the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Selection foreground color for the specified theme.
-	 */
-	public static Color getSelectionForegroundColor(SubstanceTheme theme) {
-		switch (theme.getKind()) {
-		case DARK:
-			return theme.getActiveTheme().getColorScheme().getUltraDarkColor()
-					.darker();
-		default:
-			return theme.getActiveTheme().getColorScheme().getUltraDarkColor();
-		}
-	}
-
-	/**
-	 * Returns the watermark stamp color for the current theme.
-	 * 
-	 * @return Watermark stamp color for the current theme.
-	 */
-	public static Color getWatermarkStampColor() {
-		return getWatermarkStampColor(SubstanceLookAndFeel.getTheme());
-	}
-
-	/**
-	 * Returns the watermark stamp color for the current theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Watermark stamp color for the current theme.
-	 */
-	public static Color getWatermarkStampColor(SubstanceTheme theme) {
-		return theme.getWatermarkTheme().getWatermarkStampColor();
-	}
-
 	/**
 	 * Returns a negative of the specified color.
 	 * 
@@ -523,100 +362,6 @@ public class SubstanceColorUtilities {
 				| (255 - b);
 	}
 
-	/**
-	 * Returns the watermark light color for the current theme.
-	 * 
-	 * @return Watermark light color for the current theme.
-	 */
-	public static Color getWatermarkLightColor() {
-		return getWatermarkLightColor(1.0f);
-	}
-
-	/**
-	 * Returns the watermark light color for the current theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Watermark light color for the current theme.
-	 */
-	public static Color getWatermarkLightColor(SubstanceTheme theme) {
-		return getWatermarkLightColor(theme, 1.0f);
-	}
-
-	/**
-	 * Returns the watermark light color for the current theme.
-	 * 
-	 * @param coef
-	 *            Translucency coefficient.
-	 * @return Watermark light color for the current theme.
-	 */
-	public static Color getWatermarkLightColor(float coef) {
-		return getWatermarkLightColor(SubstanceLookAndFeel.getTheme(), coef);
-	}
-
-	/**
-	 * Returns the watermark light color for the current theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @param coef
-	 *            Translucency coefficient.
-	 * @return Watermark light color for the current theme.
-	 */
-	public static Color getWatermarkLightColor(SubstanceTheme theme, float coef) {
-		SubstanceTheme watermarkTheme = theme.getWatermarkTheme();
-		int alpha = SubstanceCoreUtilities.isThemeDark(watermarkTheme) ? (int) (coef * 100)
-				: (int) (coef * 255);
-		if (alpha > 255)
-			alpha = 255;
-		return SubstanceColorUtilities.getAlphaColor(watermarkTheme
-				.getColorScheme().getLightColor(), alpha);
-	}
-
-	/**
-	 * Returns the watermark dark color for the current theme.
-	 * 
-	 * @return Watermark dark color for the current theme.
-	 */
-	public static Color getWatermarkDarkColor() {
-		return getWatermarkDarkColor(SubstanceLookAndFeel.getTheme());
-	}
-
-	/**
-	 * Returns the watermark dark color for the current theme.
-	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Watermark dark color for the current theme.
-	 */
-	public static Color getWatermarkDarkColor(SubstanceTheme theme) {
-		SubstanceTheme watermarkTheme = theme.getWatermarkTheme();
-		return SubstanceCoreUtilities.isThemeDark(watermarkTheme) ? SubstanceColorUtilities
-				.getAlphaColor(watermarkTheme.getColorScheme()
-						.getUltraLightColor(), 128)
-				: SubstanceColorUtilities.getAlphaColor(watermarkTheme
-						.getColorScheme().getDarkColor(), 15);
-	}
-
-	/**
-	 * Returns the watermark stamp color of the specified opacity for the
-	 * current theme.
-	 * 
-	 * @param alpha
-	 *            Alpha channel value.
-	 * @return Watermark stamp color of the specified opacity for the current
-	 *         theme.
-	 */
-	public static Color getWatermarkStampColor(int alpha) {
-		SubstanceTheme watermarkTheme = SubstanceLookAndFeel.getTheme()
-				.getWatermarkTheme();
-		return SubstanceCoreUtilities.isThemeDark(watermarkTheme) ? SubstanceColorUtilities
-				.getAlphaColor(watermarkTheme.getColorScheme()
-						.getUltraLightColor(), alpha)
-				: SubstanceColorUtilities.getAlphaColor(watermarkTheme
-						.getColorScheme().getDarkColor(), alpha);
-	}
-
 	/**
 	 * Returns a translucent of the specified color.
 	 * 
@@ -705,14 +450,14 @@ public class SubstanceColorUtilities {
 	}
 
 	/**
-	 * Returns the foreground color of the specified theme.
+	 * Returns the foreground color of the specified color scheme.
 	 * 
-	 * @param theme
-	 *            Theme.
-	 * @return Theme foreground color.
+	 * @param scheme
+	 *            Color scheme.
+	 * @return Color scheme foreground color.
 	 */
-	public static Color getForegroundColor(SubstanceTheme theme) {
-		return theme.getColorScheme().getForegroundColor();
+	public static ColorUIResource getForegroundColor(SubstanceColorScheme scheme) {
+		return new ColorUIResource(scheme.getForegroundColor());
 	}
 
 	/**
@@ -749,117 +494,6 @@ public class SubstanceColorUtilities {
 		return new Color(r, g, b);
 	}
 
-	/**
-	 * Converts the specified color into color-blind version.
-	 * 
-	 * @param orig
-	 *            The original color.
-	 * @param rgbToLms
-	 *            RGB to LMS conversion matrix.
-	 * @param kind
-	 *            Color-blindness kind.
-	 * @param lmsToRgb
-	 *            LMS to RGB conversion matrix.
-	 * @return Color-blind version of the original color.
-	 */
-	public static Color getColorBlindColor(Color orig, double[][] rgbToLms,
-			BlindnessKind kind, double[][] lmsToRgb) {
-		double r = orig.getRed();
-		double g = orig.getGreen();
-		double b = orig.getBlue();
-
-		double[] rgbOrig = new double[] { r, g, b };
-		double[] lms = mult3(rgbToLms, rgbOrig);
-		double tmp = 0.0;
-
-		double[] anchor = { 0.08008, 0.1579, 0.5897, 0.1284, 0.2237, 0.3636,
-				0.9856, 0.7325, 0.001079, 0.0914, 0.007009, 0.0 };
-
-		double[] rgbAnchor = {
-				rgbToLms[0][0] + rgbToLms[0][1] + rgbToLms[0][2],
-				rgbToLms[1][0] + rgbToLms[1][1] + rgbToLms[1][2],
-				rgbToLms[2][0] + rgbToLms[2][1] + rgbToLms[2][2] };
-
-		double a1, a2, b1, b2, c1, c2, inflection;
-
-		switch (kind) {
-		case PROTANOPIA:
-			a1 = rgbAnchor[1] * anchor[8] - rgbAnchor[2] * anchor[7];
-			b1 = rgbAnchor[2] * anchor[6] - rgbAnchor[0] * anchor[8];
-			c1 = rgbAnchor[0] * anchor[7] - rgbAnchor[1] * anchor[6];
-			a2 = rgbAnchor[1] * anchor[2] - rgbAnchor[2] * anchor[1];
-			b2 = rgbAnchor[2] * anchor[0] - rgbAnchor[0] * anchor[2];
-			c2 = rgbAnchor[0] * anchor[1] - rgbAnchor[1] * anchor[0];
-			inflection = rgbAnchor[2] / rgbAnchor[1];
-			tmp = lms[2] / lms[1];
-			if (tmp < inflection)
-				lms[0] = -(b1 * lms[1] + c1 * lms[2]) / a1;
-			else
-				lms[0] = -(b2 * lms[1] + c2 * lms[2]) / a2;
-			break;
-
-		case DEUTERANOPIA:
-			a1 = rgbAnchor[1] * anchor[8] - rgbAnchor[2] * anchor[7];
-			b1 = rgbAnchor[2] * anchor[6] - rgbAnchor[0] * anchor[8];
-			c1 = rgbAnchor[0] * anchor[7] - rgbAnchor[1] * anchor[6];
-			a2 = rgbAnchor[1] * anchor[2] - rgbAnchor[2] * anchor[1];
-			b2 = rgbAnchor[2] * anchor[0] - rgbAnchor[0] * anchor[2];
-			c2 = rgbAnchor[0] * anchor[1] - rgbAnchor[1] * anchor[0];
-			inflection = rgbAnchor[2] / rgbAnchor[0];
-			tmp = lms[2] / lms[0];
-			/* See which side of the inflection line we fall... */
-			if (tmp < inflection)
-				lms[1] = -(a1 * lms[0] + c1 * lms[2]) / b1;
-			else
-				lms[1] = -(a2 * lms[0] + c2 * lms[2]) / b2;
-			break;
-
-		case TRITANOPIA:
-			a1 = rgbAnchor[1] * anchor[11] - rgbAnchor[2] * anchor[10];
-			b1 = rgbAnchor[2] * anchor[9] - rgbAnchor[0] * anchor[11];
-			c1 = rgbAnchor[0] * anchor[10] - rgbAnchor[1] * anchor[9];
-			a2 = rgbAnchor[1] * anchor[5] - rgbAnchor[2] * anchor[4];
-			b2 = rgbAnchor[2] * anchor[3] - rgbAnchor[0] * anchor[5];
-			c2 = rgbAnchor[0] * anchor[4] - rgbAnchor[1] * anchor[3];
-			inflection = (rgbAnchor[1] / rgbAnchor[0]);
-			tmp = lms[1] / lms[0];
-			if (tmp < inflection)
-				lms[2] = -(a1 * lms[0] + b1 * lms[1]) / c1;
-			else
-				lms[2] = -(a2 * lms[0] + b2 * lms[1]) / c2;
-			break;
-
-		default:
-			break;
-		}
-		double[] rgbCb = mult3(lmsToRgb, lms);
-
-		double nr = Math.min(255.0, Math.max(0.0, rgbCb[0]));
-		double ng = Math.min(255.0, Math.max(0.0, rgbCb[1]));
-		double nb = Math.min(255.0, Math.max(0.0, rgbCb[2]));
-		return new Color((int) nr, (int) ng, (int) nb);
-	}
-
-	/**
-	 * Multiplies the specified 3x3 matrix by the specified 3x1 vector.
-	 * 
-	 * @param matrix
-	 *            Matrix.
-	 * @param vector
-	 *            Vector.
-	 * @return Vector multiplication.
-	 */
-	private static double[] mult3(double[][] matrix, double[] vector) {
-		double[] res = new double[3];
-		res[0] = matrix[0][0] * vector[0] + matrix[0][1] * vector[1]
-				+ matrix[0][2] * vector[2];
-		res[1] = matrix[1][0] * vector[0] + matrix[1][1] * vector[1]
-				+ matrix[1][2] * vector[2];
-		res[2] = matrix[2][0] * vector[0] + matrix[2][1] * vector[1]
-				+ matrix[2][2] * vector[2];
-		return res;
-	}
-
 	/**
 	 * Returns the brightness of the specified color.
 	 * 
@@ -883,19 +517,17 @@ public class SubstanceColorUtilities {
 	 * @return The color of the focus ring for the specified component.
 	 */
 	public static Color getFocusColor(Component comp) {
-		SubstanceTheme activeTheme = SubstanceThemeUtilities.getTheme(comp,
-				ComponentState.ACTIVE);
+		SubstanceColorScheme activeScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(comp, ComponentState.ACTIVE);
 
 		if (comp instanceof AbstractButton) {
 			AbstractButton ab = (AbstractButton) comp;
 			ButtonModel model = ab.getModel();
 
 			ComponentState currState = ComponentState.getState(model, ab);
-			SubstanceTheme currTheme = SubstanceThemeUtilities.getTheme(comp,
-					currState);
-			Color currColor = SubstanceCoreUtilities.isThemeDark(currTheme) ? currTheme
-					.getColorScheme().getUltraDarkColor()
-					: currTheme.getColorScheme().getDarkColor();
+			SubstanceColorScheme currScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(comp, currState);
+			Color currColor = currScheme.getFocusRingColor();
 
 			FadeState fadeState = SubstanceFadeUtilities.getFadeState(comp,
 					FadeKind.PRESS, FadeKind.SELECTION, FadeKind.ROLLOVER);
@@ -904,14 +536,12 @@ public class SubstanceColorUtilities {
 				ComponentState prevState = SubstanceCoreUtilities
 						.getPrevComponentState(ab);
 
-				SubstanceTheme prevTheme = SubstanceThemeUtilities.getTheme(
-						comp, prevState);
+				SubstanceColorScheme prevScheme = SubstanceColorSchemeUtilities
+						.getColorScheme(comp, prevState);
 
-				Color prevColor = SubstanceCoreUtilities.isThemeDark(prevTheme) ? prevTheme
-						.getColorScheme().getUltraDarkColor()
-						: prevTheme.getColorScheme().getDarkColor();
+				Color prevColor = prevScheme.getFocusRingColor();
 
-				float likeness = fadeState.getFadePosition() / 10.0f;
+				float likeness = fadeState.getFadePosition();
 				if (fadeState.isFadingIn())
 					likeness = 1.0f - likeness;
 				return SubstanceColorUtilities.getInterpolatedColor(prevColor,
@@ -921,9 +551,7 @@ public class SubstanceColorUtilities {
 			}
 		}
 
-		Color color = SubstanceCoreUtilities.isThemeDark(activeTheme) ? activeTheme
-				.getColorScheme().getUltraDarkColor()
-				: activeTheme.getColorScheme().getDarkColor();
+		Color color = activeScheme.getFocusRingColor();
 		return color;
 	}
 
@@ -938,4 +566,272 @@ public class SubstanceColorUtilities {
 		return Math.max(getColorBrightness(color.getRGB()),
 				getColorBrightness(getNegativeColor(color.getRGB()))) / 255.0f;
 	}
+
+	/**
+	 * Returns the color of mark icons (checkbox, radio button, scrollbar
+	 * arrows, combo arrows, menu arrows etc) for the specified color scheme.
+	 * 
+	 * @param colorScheme
+	 *            Color scheme.
+	 * @param isEnabled
+	 *            If <code>true</code>, the mark should be painted in enabled
+	 *            state.
+	 * @return Color of mark icons.
+	 */
+	public static Color getMarkColor(SubstanceColorScheme colorScheme,
+			boolean isEnabled) {
+		if (colorScheme.isDark()) {
+			if (!isEnabled) {
+				return colorScheme.getDarkColor();
+
+			} else {
+				return getInterpolatedColor(colorScheme.getForegroundColor(),
+						colorScheme.getUltraLightColor(), 0.9);
+			}
+		} else {
+			Color color1 = isEnabled ? colorScheme.getUltraDarkColor()
+					: colorScheme.getUltraDarkColor();
+			Color color2 = isEnabled ? colorScheme.getDarkColor() : colorScheme
+					.getLightColor();
+			return getInterpolatedColor(color1, color2, 0.9);
+		}
+	}
+
+	/**
+	 * Returns the foreground text color of the specified component.
+	 * 
+	 * @param component
+	 *            Component.
+	 * @param state
+	 *            Component current state.
+	 * @param prevState
+	 *            Component previous state.
+	 * @return The foreground text color of the specified component.
+	 */
+	public static Color getForegroundColor(Component component,
+			ComponentState state, ComponentState prevState) {
+		SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(component, state);
+		if (!state.isKindActive(FadeKind.ENABLE)) {
+			return colorScheme.getForegroundColor();
+		}
+		if (component instanceof JMenuItem) {
+			return SubstanceColorUtilities.getInterpolatedForegroundColor(
+					component, null, colorScheme, state, prevState,
+					FadeKind.ROLLOVER, FadeKind.SELECTION, FadeKind.PRESS,
+					FadeKind.ARM);
+		} else {
+			return SubstanceColorUtilities.getInterpolatedForegroundColor(
+					component, null, colorScheme, state, prevState,
+					FadeKind.ROLLOVER, FadeKind.SELECTION, FadeKind.PRESS);
+		}
+	}
+
+	/**
+	 * Returns the foreground text color of the specified tabbed pane tab.
+	 * 
+	 * @param tabPane
+	 *            Tabbed pane.
+	 * @param tabIndex
+	 *            Tab index.
+	 * @param state
+	 *            Component current state.
+	 * @param prevState
+	 *            Component previous state.
+	 * @return The foreground text color of the specified tabbed pane tab.
+	 */
+	public static Color getForegroundColor(JTabbedPane tabPane, int tabIndex,
+			ComponentState state, ComponentState prevState) {
+		SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(tabPane, tabIndex, state);
+		return SubstanceColorUtilities.getInterpolatedForegroundColor(tabPane,
+				tabIndex, colorScheme, state, prevState, FadeKind.ROLLOVER,
+				FadeKind.SELECTION, FadeKind.PRESS);
+	}
+
+	/**
+	 * Returns the foreground color for the specified component.
+	 * 
+	 * @param comp
+	 *            Component.
+	 * @param componentId
+	 *            Optional component ID. Can be used to differentiate sub-parts
+	 *            of the component, such as tabs in tabbed pane, cells in list
+	 *            etc.
+	 * @param colorScheme
+	 *            Component color scheme.
+	 * @param state
+	 *            Component current state.
+	 * @param prevState
+	 *            Component previous state.
+	 * @param kinds
+	 *            Animation kinds to consult for computing the foreground color.
+	 * @return Foreground color.
+	 */
+	public static Color getInterpolatedForegroundColor(Component comp,
+			Comparable<?> componentId, SubstanceColorScheme colorScheme,
+			ComponentState state, ComponentState prevState, FadeKind... kinds) {
+		SubstanceColorScheme colorScheme2 = colorScheme;
+		float cyclePos = state.getCyclePosition();
+
+		FadeState fadeState = SubstanceFadeUtilities.getFadeState(comp,
+				componentId, kinds);
+		if (fadeState != null) {
+			colorScheme = (comp instanceof JTabbedPane) ? SubstanceColorSchemeUtilities
+					.getColorScheme((JTabbedPane) comp, (Integer) componentId,
+							state)
+					: SubstanceColorSchemeUtilities.getColorScheme(comp, state);
+			colorScheme2 = (comp instanceof JTabbedPane) ? SubstanceColorSchemeUtilities
+					.getColorScheme((JTabbedPane) comp, (Integer) componentId,
+							prevState)
+					: SubstanceColorSchemeUtilities.getColorScheme(comp,
+							prevState);
+			cyclePos = fadeState.getFadePosition();
+			if (!fadeState.isFadingIn())
+				cyclePos = 1.0f - cyclePos;
+		}
+
+		Color c1 = colorScheme.getForegroundColor();
+		Color c2 = colorScheme2.getForegroundColor();
+
+		return getInterpolatedColor(c1, c2, cyclePos);
+	}
+
+	/**
+	 * Returns the background fill color of the specified component.
+	 * 
+	 * @param component
+	 *            Component.
+	 * @return The background fill color of the specified component.
+	 */
+	public static Color getBackgroundFillColor(Component component) {
+		// special case - sliders, check boxes and radio buttons. For this,
+		// switch to component parent
+		// boolean isColorized = hasColorization(component);
+		if ((component instanceof JCheckBox)
+				|| (component instanceof JRadioButton)
+				|| (component instanceof JSlider)) {
+			component = component.getParent();
+		} else {
+			// Fix for 325 - respect the opacity setting of the text
+			// component
+			if (component instanceof JTextComponent && !component.isOpaque())
+				component = component.getParent();
+		}
+
+		Color backgr = component.getBackground();
+		// do not change the background color on cell
+		// renderers
+		if (SwingUtilities
+				.getAncestorOfClass(CellRendererPane.class, component) != null)
+			return backgr;
+
+		boolean isBackgroundUiResource = backgr instanceof UIResource;
+
+		if (!isBackgroundUiResource) {
+			SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+					.getColorScheme(component,
+							component.isEnabled() ? ComponentState.DEFAULT
+									: ComponentState.DISABLED_UNSELECTED);
+			backgr = scheme.getBackgroundFillColor();
+		} else {
+			ComponentState state = component.isEnabled() ? ComponentState.DEFAULT
+					: ComponentState.DISABLED_UNSELECTED;
+			if (component instanceof JTextComponent) {
+				if (!((JTextComponent) component).isEditable()) {
+					state = ComponentState.DISABLED_UNSELECTED;
+				}
+			}
+			// menu items always use the same background color so that the
+			// menu looks continuous
+			if (component instanceof JMenuItem) {
+				state = ComponentState.DEFAULT;
+			}
+			backgr = SubstanceColorUtilities.getDefaultBackgroundColor(
+					component, state);
+		}
+		return backgr;
+	}
+
+	/**
+	 * Returns the default background color for the components of the specified
+	 * class.
+	 * 
+	 * @param componentClass
+	 *            Component class.
+	 * @param skin
+	 *            Skin.
+	 * @param isDisabled
+	 *            Indication whether the result should be for disabled
+	 *            components.
+	 * @return The default background color for the components of the specified
+	 *         class.
+	 */
+	public static ColorUIResource getDefaultBackgroundColor(
+			Class<?> componentClass, SubstanceSkin skin, boolean isDisabled) {
+		boolean useLightBackgroundColor = (JTextComponent.class
+				.isAssignableFrom(componentClass))
+				|| (JComboBox.class.isAssignableFrom(componentClass))
+				|| (JSpinner.class.isAssignableFrom(componentClass));
+		if (useLightBackgroundColor || isDisabled)
+			return new ColorUIResource(skin.getMainDefaultColorScheme()
+					.getLightBackgroundFillColor());
+		return new ColorUIResource(skin.getMainDefaultColorScheme()
+				.getBackgroundFillColor());
+	}
+
+	/**
+	 * Returns the default background color for the specified component.
+	 * 
+	 * @param comp
+	 *            Component.
+	 * @param compState
+	 *            Component state.
+	 * @return The default background color for the components of the specified
+	 *         class.
+	 */
+	public static ColorUIResource getDefaultBackgroundColor(Component comp,
+			ComponentState compState) {
+		// SubstanceSkin skin = SubstanceCoreUtilities.getSkin(comp);
+		if ((comp instanceof JTextComponent) || (comp instanceof JComboBox)
+				|| (comp instanceof JSpinner)) {
+			// special case for text-based components - use lighter
+			// background fill color.
+			return new ColorUIResource(SubstanceColorSchemeUtilities
+					.getColorScheme(comp, compState)
+					.getLightBackgroundFillColor());
+		}
+		return new ColorUIResource(SubstanceColorSchemeUtilities
+				.getColorScheme(comp, compState).getBackgroundFillColor());
+	}
+
+	/**
+	 * Returns the striped background for the specified component. This method
+	 * is relevant for components such as trees, tables and lists that use
+	 * odd-even striping for the alternating rows.
+	 * 
+	 * @param component
+	 *            Component.
+	 * @param rowIndex
+	 *            Row index.
+	 * @return The striped background for the specified component.
+	 */
+	public static Color getStripedBackground(JComponent component, int rowIndex) {
+		Color backgr = getBackgroundFillColor(component);
+		if (backgr == null)
+			return null;
+
+		if (rowIndex % 2 == 0)
+			return backgr;
+		int r = backgr.getRed();
+		int g = backgr.getGreen();
+		int b = backgr.getBlue();
+		double coef = 0.96;
+		if (!component.isEnabled())
+			coef = 1.0 - (1.0 - coef) / 2.0;
+		Color darkerColor = new ColorUIResource((int) (coef * r),
+				(int) (coef * g), (int) (coef * b));
+
+		return darkerColor;
+	}
 }
