@@ -58,10 +58,10 @@ public class SubstanceFadeUtilities {
 		float highest = -1.0f;
 		for (Component comp : comps) {
 			if (tracker.isTracked(comp, fadeKind)) {
-				float fade10 = tracker.getFade10(comp, fadeKind);
-				if (fade10 > highest) {
+				float fade = tracker.getFade(comp, fadeKind);
+				if (fade > highest) {
 					result = comp;
-					highest = fade10;
+					highest = fade;
 				}
 			}
 		}
@@ -141,6 +141,33 @@ public class SubstanceFadeUtilities {
 		return null;
 	}
 
+	/**
+	 * Returns the first matching fade state for the specified component.
+	 * 
+	 * @param comp
+	 *            Component.
+	 * @param comparables
+	 *            Identifiers of sub-entities.
+	 * @param fadeKinds
+	 *            Fade kinds. The list is scanned from the start. The first fade
+	 *            kind that is currently "happening" on the specified component
+	 *            will be used to fetch the fade state.
+	 * @return The first matching fade state for the specified component.
+	 */
+	public static FadeState getFadeState(Component comp,
+			Comparable<?>[] comparables, FadeKind[] fadeKinds) {
+		FadeTracker tracker = FadeTracker.getInstance();
+		for (FadeKind fadeKind : fadeKinds) {
+			for (Comparable<?> comparable : comparables) {
+				FadeState result = tracker.getFadeState(comp, comparable,
+						fadeKind);
+				if (result != null)
+					return result;
+			}
+		}
+		return null;
+	}
+
 	/**
 	 * Cancels the specified fade sequences.
 	 * 
