@@ -43,11 +43,10 @@ import javax.swing.plaf.basic.BasicInternalFrameTitlePane;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.*;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.colorscheme.ShiftColorScheme;
 import org.jvnet.substance.painter.decoration.DecorationAreaType;
 import org.jvnet.substance.painter.decoration.SubstanceDecorationUtilities;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.theme.SubstanceShiftTheme;
-import org.jvnet.substance.theme.SubstanceTheme;
 import org.jvnet.substance.utils.icon.SubstanceIconFactory;
 import org.jvnet.substance.utils.icon.TransitionAwareIcon;
 
@@ -65,7 +64,8 @@ public class SubstanceInternalFrameTitlePane extends
 
 	/**
 	 * Listens to the changes to the
-	 * {@link SubstanceLookAndFeel#WINDOW_MODIFIED} property on the internal
+	 * {@link SubstanceLookAndFeel#WINDOW_MODIFIED
+	 * } property on the internal
 	 * frame and its root pane.
 	 */
 	protected PropertyChangeListener substanceWinModifiedListener;
@@ -80,6 +80,8 @@ public class SubstanceInternalFrameTitlePane extends
 	 */
 	protected static final String UNINSTALLED = "substance.internal.internalTitleFramePane.uninstalled";
 
+	// protected boolean wasClosable;
+
 	/**
 	 * Simple constructor.
 	 * 
@@ -89,7 +91,7 @@ public class SubstanceInternalFrameTitlePane extends
 	public SubstanceInternalFrameTitlePane(JInternalFrame f) {
 		super(f);
 		this.setToolTipText(f.getTitle());
-		SubstanceDecorationUtilities.setDecorationType(this,
+		SubstanceLookAndFeel.setDecorationType(this,
 				DecorationAreaType.SECONDARY_TITLE_PANE);
 	}
 
@@ -101,14 +103,34 @@ public class SubstanceInternalFrameTitlePane extends
 	@Override
 	protected void installDefaults() {
 		super.installDefaults();
-		this.setForeground(SubstanceLookAndFeel.getTheme()
-				.getActiveTitlePaneTheme().getForegroundColor());
+		if (SubstanceLookAndFeel.isCurrentLookAndFeel()) {
+			this.setForeground(SubstanceColorUtilities
+					.getForegroundColor(SubstanceCoreUtilities.getSkin(
+							this.frame).getMainActiveColorScheme(
+							DecorationAreaType.SECONDARY_TITLE_PANE)));
+		}
+		// this.wasClosable = this.frame.isClosable();
 	}
 
+	// /*
+	// * (non-Javadoc)
+	// *
+	// * @see
+	// * javax.swing.plaf.basic.BasicInternalFrameTitlePane#uninstallDefaults()
+	// */
+	// @Override
+	// protected void uninstallDefaults() {
+	// super.uninstallDefaults();
+	// if (this.wasClosable != this.frame.isClosable()) {
+	// this.frame.setClosable(this.wasClosable);
+	// }
+	// }
+
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicInternalFrameTitlePane#installListeners()
+	 * @see
+	 * javax.swing.plaf.basic.BasicInternalFrameTitlePane#installListeners()
 	 */
 	@Override
 	protected void installListeners() {
@@ -163,7 +185,8 @@ public class SubstanceInternalFrameTitlePane extends
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see javax.swing.plaf.basic.BasicInternalFrameTitlePane#uninstallListeners()
+	 * @see
+	 * javax.swing.plaf.basic.BasicInternalFrameTitlePane#uninstallListeners()
 	 */
 	@Override
 	public void uninstallListeners() {
@@ -191,8 +214,11 @@ public class SubstanceInternalFrameTitlePane extends
 	public void uninstall() {
 		if ((this.menuBar != null) && (this.menuBar.getMenuCount() > 0)) {
 			MenuBarUI menuBarUI = this.menuBar.getUI();
-			if (menuBarUI instanceof SubstanceMenuBarUI)
-				menuBarUI.uninstallUI(this.menuBar);
+			if (menuBarUI instanceof SubstanceMenuBarUI) {
+				SubstanceMenuBarUI ui = (SubstanceMenuBarUI) menuBarUI;
+				if (ui.getMenuBar() == this.menuBar)
+					menuBarUI.uninstallUI(this.menuBar);
+			}
 			SubstanceCoreUtilities.uninstallMenu(this.menuBar.getMenu(0));
 			this.remove(menuBar);
 			// fix for issue 362 - remove the buttons so that we don't
@@ -251,16 +277,15 @@ public class SubstanceInternalFrameTitlePane extends
 		graphics.setComposite(TransitionLayout.getAlphaComposite(this.frame,
 				coef, g));
 
-		boolean isSelected = this.frame.isSelected();
 		boolean leftToRight = this.frame.getComponentOrientation()
 				.isLeftToRight();
 
-		final int width = this.getWidth();
-		final int height = this.getHeight() + 2;
+		int width = this.getWidth();
+		int height = this.getHeight() + 2;
 
-		SubstanceTheme theme = isSelected ? SubstanceLookAndFeel.getTheme()
-				.getActiveTitlePaneTheme() : SubstanceLookAndFeel.getTheme()
-				.getDefaultTitlePaneTheme();
+		SubstanceColorScheme scheme = SubstanceCoreUtilities
+				.getSkin(this.frame).getMainDefaultColorScheme(
+						DecorationAreaType.SECONDARY_TITLE_PANE);
 		JInternalFrame hostFrame = (JInternalFrame) SwingUtilities
 				.getAncestorOfClass(JInternalFrame.class, this);
 		JComponent hostForColorization = hostFrame;
@@ -272,15 +297,16 @@ public class SubstanceInternalFrameTitlePane extends
 				hostFrame = desktopIcon.getInternalFrame();
 			hostForColorization = desktopIcon;
 		}
-		if ((hostFrame != null) && SubstanceCoreUtilities.hasColorization(this)) {
-			Color backgr = hostFrame.getBackground();
-			if (!(backgr instanceof UIResource)) {
-				double colorization = SubstanceCoreUtilities
-						.getColorizationFactor(hostForColorization);
-				theme = SubstanceShiftTheme.getShiftedTheme(theme, backgr,
-						colorization, null, 0.0);
-			}
+		// if ((hostFrame != null) && SubstanceCoreUtilities.hasColorization(
+		// this)) {
+		Color backgr = hostFrame.getBackground();
+		if (!(backgr instanceof UIResource)) {
+			double colorization = SubstanceCoreUtilities
+					.getColorizationFactor(hostForColorization);
+			scheme = ShiftColorScheme.getShiftedScheme(scheme, backgr,
+					colorization, null, 0.0);
 		}
+		// }
 		String theTitle = this.frame.getTitle();
 
 		// offset of border
@@ -379,25 +405,8 @@ public class SubstanceInternalFrameTitlePane extends
 			}
 		}
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(this, null, true);
-
-		if (textPainter.needsBackgroundImage()) {
-			textPainter
-					.attachCallback(new SubstanceTextPainter.BackgroundPaintingCallback() {
-						public void paintBackground(Graphics g) {
-							SubstanceDecorationUtilities
-									.paintDecorationBackground(
-											g,
-											SubstanceInternalFrameTitlePane.this,
-											false);
-						}
-					});
-		} else {
-			SubstanceDecorationUtilities.paintDecorationBackground(graphics,
-					SubstanceInternalFrameTitlePane.this, false);
-		}
+		SubstanceDecorationUtilities.paintDecorationBackground(graphics,
+				SubstanceInternalFrameTitlePane.this, false);
 
 		// draw the title (if needed)
 		if (theTitle != null) {
@@ -405,11 +414,10 @@ public class SubstanceInternalFrameTitlePane extends
 			FontMetrics fm = rootPane.getFontMetrics(graphics.getFont());
 			int yOffset = ((height - fm.getHeight()) / 2) + fm.getAscent();
 
-			SubstanceCoreUtilities.paintTextWithDropShadow(this, graphics,
-					theme.getForegroundColor(), theTitle, width, height,
-					xOffset, yOffset);
+			SubstanceTextUtilities.paintTextWithDropShadow(this, graphics,
+					SubstanceColorUtilities.getForegroundColor(scheme),
+					theTitle, width, height, xOffset, yOffset);
 		}
-		textPainter.renderSurface(graphics);
 
 		Icon icon = this.frame.getFrameIcon();
 		if (icon != null) {
@@ -434,33 +442,33 @@ public class SubstanceInternalFrameTitlePane extends
 	@Override
 	protected void setButtonIcons() {
 		super.setButtonIcons();
-		// SubstanceTheme iconTheme = SubstanceLookAndFeel.getTheme()
-		// .getActiveTitlePaneTheme();
+		if (!SubstanceLookAndFeel.isCurrentLookAndFeel())
+			return;
 
 		Icon restoreIcon = new TransitionAwareIcon(this.maxButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme theme) {
 						return SubstanceIconFactory.getTitlePaneIcon(
 								SubstanceIconFactory.IconKind.RESTORE, theme);
 					}
 				});
 		Icon maximizeIcon = new TransitionAwareIcon(this.maxButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme theme) {
 						return SubstanceIconFactory.getTitlePaneIcon(
 								SubstanceIconFactory.IconKind.MAXIMIZE, theme);
 					}
 				});
 		Icon minimizeIcon = new TransitionAwareIcon(this.iconButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme theme) {
 						return SubstanceIconFactory.getTitlePaneIcon(
 								SubstanceIconFactory.IconKind.MINIMIZE, theme);
 					}
 				});
 		Icon closeIcon = new TransitionAwareIcon(this.closeButton,
 				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
+					public Icon getColorSchemeIcon(SubstanceColorScheme theme) {
 						return SubstanceIconFactory.getTitlePaneIcon(
 								SubstanceIconFactory.IconKind.CLOSE, theme);
 					}
@@ -507,7 +515,9 @@ public class SubstanceInternalFrameTitlePane extends
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
+		 * @see
+		 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent
+		 * )
 		 */
 		public void actionPerformed(ActionEvent e) {
 			AbstractButton src = (AbstractButton) e.getSource();
@@ -776,6 +786,9 @@ public class SubstanceInternalFrameTitlePane extends
 		}
 	}
 
+	/**
+	 * Updates the state of internal frames used in {@link JOptionPane}s.
+	 */
 	private void updateOptionPaneState() {
 		Object obj = frame.getClientProperty("JInternalFrame.messageType");
 
@@ -787,5 +800,4 @@ public class SubstanceInternalFrameTitlePane extends
 			frame.setClosable(false);
 		}
 	}
-
 }
