@@ -35,12 +35,13 @@ import javax.swing.border.Border;
 import javax.swing.plaf.BorderUIResource;
 
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.button.ClassicButtonShaper;
+import org.jvnet.substance.api.SubstanceConstants;
 import org.jvnet.substance.fonts.*;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
 
 /**
  * This class is responsible for computing DPI-aware insets, stroke widths,
- * paddings, icon sizes etc.
+ * paddings, icon sizes etc. This class if for internal use only.
  * 
  * @author Kirill Grouchnikov
  */
@@ -50,6 +51,9 @@ public class SubstanceSizeUtils {
 	 */
 	private static int controlFontSize = -1;
 
+	/**
+	 * The points to pixels ratio of the current font policy.
+	 */
 	private static double pointsToPixelsRatio = 1.0;
 
 	/**
@@ -70,7 +74,7 @@ public class SubstanceSizeUtils {
 	 * Sets the new value for the control font size.
 	 * 
 	 * @param size
-	 *            Control font size.
+	 * 		Control font size.
 	 */
 	public static void setControlFontSize(int size) {
 		controlFontSize = size;
@@ -79,11 +83,11 @@ public class SubstanceSizeUtils {
 	/**
 	 * Computes the font size for the specified component. If the component is
 	 * <code>null</code> or doesn't have font set ({@link Component#getFont()}
-	 * returns <code>null</code>), this method returns the default control
-	 * font size from {@link #getControlFontSize()}.
+	 * returns <code>null</code>), this method returns the default control font
+	 * size from {@link #getControlFontSize()}.
 	 * 
 	 * @param c
-	 *            Component.
+	 * 		Component.
 	 * @return Font size for the specified component
 	 */
 	public static int getComponentFontSize(Component c) {
@@ -97,9 +101,9 @@ public class SubstanceSizeUtils {
 	 * 
 	 * <ul>
 	 * <li>The <code>baseSize</code> parameter specifies the base value</li>
-	 * <li>The <code>forEachBase</code> and <code>toAdjustBy</code> specify
-	 * how to adjust the resulting value based on the passed
-	 * <code>fontSize</code>.</li>
+	 * <li>The <code>forEachBase</code> and <code>toAdjustBy</code> specify how
+	 * to adjust the resulting value based on the passed <code>fontSize</code>.
+	 * </li>
 	 * </ul>
 	 * 
 	 * For example, if you want base value to be 1.2 pixels, and have it grow by
@@ -113,13 +117,13 @@ public class SubstanceSizeUtils {
 	 * </ul>
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @param baseSize
-	 *            The base value.
+	 * 		The base value.
 	 * @param forEachBase
-	 *            Base units for computing the adjustment.
+	 * 		Base units for computing the adjustment.
 	 * @param toAdjustBy
-	 *            Adjustment amount for computing the adjustment.
+	 * 		Adjustment amount for computing the adjustment.
 	 * @return Adjusted size.
 	 */
 	public static float getAdjustedSize(int fontSize, float baseSize,
@@ -137,9 +141,9 @@ public class SubstanceSizeUtils {
 	 * 
 	 * <ul>
 	 * <li>The <code>baseSize</code> parameter specifies the base value</li>
-	 * <li>The <code>forEachBase</code> and <code>toAdjustBy</code> specify
-	 * how to adjust the resulting value based on the passed
-	 * <code>fontSize</code>.</li>
+	 * <li>The <code>forEachBase</code> and <code>toAdjustBy</code> specify how
+	 * to adjust the resulting value based on the passed <code>fontSize</code>.
+	 * </li>
 	 * </ul>
 	 * 
 	 * For example, if you want base value to be 4 pixels, and have it grow by 1
@@ -153,16 +157,16 @@ public class SubstanceSizeUtils {
 	 * </ul>
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @param baseSize
-	 *            The base value.
+	 * 		The base value.
 	 * @param forEachBase
-	 *            Base units for computing the adjustment.
+	 * 		Base units for computing the adjustment.
 	 * @param toAdjustBy
-	 *            Adjustment amount for computing the adjustment.
+	 * 		Adjustment amount for computing the adjustment.
 	 * @param toRoundAsEven
-	 *            If <code>true</code>, the final value will be rounded down
-	 *            to the closest even value.
+	 * 		If <code>true</code>, the final value will be rounded down to the
+	 * 		closest even value.
 	 * @return Adjusted size.
 	 */
 	public static int getAdjustedSize(int fontSize, int baseSize,
@@ -180,34 +184,34 @@ public class SubstanceSizeUtils {
 	 * Returns the height of arrow icons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Height of arrow icons under the specified font size.
 	 */
-	public static int getArrowIconHeight(int fontSize) {
+	public static float getArrowIconHeight(int fontSize) {
 		if (fontSize < 12)
-			return 3 + fontSize / 2;
-		return 3 + fontSize * 3 / 5;
+			return 2.5f + fontSize * 0.5f;
+		return 3.0f + fontSize * 0.6f;
 	}
 
 	/**
 	 * Returns the width of arrow icons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Width of arrow icons under the specified font size.
 	 */
-	public static int getArrowIconWidth(int fontSize) {
-		int result = fontSize - (int) (getBorderStrokeWidth(fontSize));
+	public static float getArrowIconWidth(int fontSize) {
+		int result = 2 * fontSize / 3;
 		if (result % 2 == 0)
-			result--;
-		return 2 + result;
+			result++;
+		return result + 4;
 	}
 
 	/**
 	 * Returns the stroke width of arrow icons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Stroke width of arrow icons under the specified font size.
 	 */
 	public static float getArrowStrokeWidth(int fontSize) {
@@ -218,7 +222,7 @@ public class SubstanceSizeUtils {
 	 * Returns the stroke width of borders under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Stroke width of borders under the specified font size.
 	 */
 	public static float getBorderStrokeWidth(int fontSize) {
@@ -229,7 +233,7 @@ public class SubstanceSizeUtils {
 	 * Returns the border for check boxes under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Border for check boxes under the specified font size.
 	 */
 	public static Border getCheckBoxBorder(int fontSize) {
@@ -246,7 +250,7 @@ public class SubstanceSizeUtils {
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Check mark size for check boxes under the specified font size.
 	 */
 	public static int getCheckBoxMarkSize(int fontSize) {
@@ -258,9 +262,9 @@ public class SubstanceSizeUtils {
 	 * specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Corner radius for {@link ClassicButtonShaper} under the specified
-	 *         font size.
+	 * 	font size.
 	 */
 	public static float getClassicButtonCornerRadius(int fontSize) {
 		return getAdjustedSize(fontSize, 2, 6, 1, false);
@@ -270,7 +274,7 @@ public class SubstanceSizeUtils {
 	 * Returns the combo box border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Combo box border insets under the specified font size.
 	 */
 	public static Insets getComboBorderInsets(int fontSize) {
@@ -285,7 +289,7 @@ public class SubstanceSizeUtils {
 	 * Returns the combo box text border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Combo box text border insets under the specified font size.
 	 */
 	public static Insets getComboTextBorderInsets(int fontSize) {
@@ -305,7 +309,7 @@ public class SubstanceSizeUtils {
 	 * Returns the default border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Default border insets under the specified font size.
 	 */
 	public static Insets getDefaultBorderInsets(int fontSize) {
@@ -320,7 +324,7 @@ public class SubstanceSizeUtils {
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Stroke width of double arrow icons under the specified font size.
 	 */
 	public static float getDoubleArrowStrokeWidth(int fontSize) {
@@ -331,7 +335,7 @@ public class SubstanceSizeUtils {
 	 * Returns the diameter of a drag bump dot under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Diameter of a drag bump dot under the specified font size.
 	 */
 	public static int getDragBumpDiameter(int fontSize) {
@@ -343,7 +347,7 @@ public class SubstanceSizeUtils {
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Diameter of a big drag bump dot under the specified font size.
 	 */
 	public static int getBigDragBumpDiameter(int fontSize) {
@@ -357,7 +361,7 @@ public class SubstanceSizeUtils {
 	 * Returns the extra padding amount under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Extra padding amount under the specified font size.
 	 */
 	public static int getExtraPadding(int fontSize) {
@@ -366,6 +370,13 @@ public class SubstanceSizeUtils {
 		return (int) SubstanceSizeUtils.getAdjustedSize(fontSize, 0, 3, 1.2f);
 	}
 
+	/**
+	 * Returns the focus ring padding amount under the specified font size.
+	 * 
+	 * @param fontSize
+	 * 		Font size.
+	 * @return Focus ring padding amount under the specified font size.
+	 */
 	public static int getFocusRingPadding(int fontSize) {
 		if (fontSize < 14)
 			return 2;
@@ -377,7 +388,7 @@ public class SubstanceSizeUtils {
 	 * Returns the stroke width of focus rings under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Stroke width of focus rings under the specified font size.
 	 */
 	public static float getFocusStrokeWidth(int fontSize) {
@@ -388,7 +399,7 @@ public class SubstanceSizeUtils {
 	 * Returns the list cell renderer insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return List cell renderer insets under the specified font size.
 	 */
 	public static Insets getListCellRendererInsets(int fontSize) {
@@ -412,9 +423,9 @@ public class SubstanceSizeUtils {
 	 * items under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Check mark size of check box menu items and radio button menu
-	 *         items under the specified font size.
+	 * 	items under the specified font size.
 	 */
 	public static int getMenuCheckMarkSize(int fontSize) {
 		int result = fontSize - 2;
@@ -427,7 +438,7 @@ public class SubstanceSizeUtils {
 	 * Returns the margin for menu items under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Margin for menu items under the specified font size.
 	 */
 	public static int getMenuItemMargin(int fontSize) {
@@ -439,9 +450,9 @@ public class SubstanceSizeUtils {
 	 * specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Gap between text and icon in button menu items under the
-	 *         specified font size.
+	 * 	specified font size.
 	 */
 	public static int getTextIconGap(int fontSize) {
 		return getAdjustedSize(fontSize, 4, 3, 1, false);
@@ -451,7 +462,7 @@ public class SubstanceSizeUtils {
 	 * Returns the minimum button height under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Minimum button height under the specified font size.
 	 */
 	public static int getMinButtonHeight(int fontSize) {
@@ -462,7 +473,7 @@ public class SubstanceSizeUtils {
 	 * Returns the maximum button height under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Maximum button height under the specified font size.
 	 */
 	public static int getMinButtonWidth(int fontSize) {
@@ -474,9 +485,9 @@ public class SubstanceSizeUtils {
 	 * font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Password dot diameter for password fields under the specified
-	 *         font size.
+	 * 	font size.
 	 */
 	public static int getPasswordDotDiameter(int fontSize) {
 		return getAdjustedSize(fontSize, 7, 2, 1, false);
@@ -487,9 +498,9 @@ public class SubstanceSizeUtils {
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Password dot gap for password fields under the specified font
-	 *         size.
+	 * 	size.
 	 */
 	public static int getPasswordDotGap(int fontSize) {
 		return (fontSize - 6) / 3;
@@ -499,7 +510,7 @@ public class SubstanceSizeUtils {
 	 * Returns the border for radio buttons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Border for radio buttons under the specified font size.
 	 */
 	public static Border getRadioButtonBorder(int fontSize) {
@@ -516,7 +527,7 @@ public class SubstanceSizeUtils {
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Check mark size for radio buttons under the specified font size.
 	 */
 	public static int getRadioButtonMarkSize(int fontSize) {
@@ -530,18 +541,21 @@ public class SubstanceSizeUtils {
 	 * Returns the width of scroll bars under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Width of scroll bars under the specified font size.
 	 */
 	public static int getScrollBarWidth(int fontSize) {
-		return fontSize + 4;
+		int result = fontSize + 4;
+		if (result % 2 == 0)
+			result++;
+		return result;
 	}
 
 	/**
 	 * Returns the slider thumb icon size under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Slider thumb icon size under the specified font size.
 	 */
 	public static int getSliderIconSize(int fontSize) {
@@ -555,7 +569,7 @@ public class SubstanceSizeUtils {
 	 * Returns the slider tick size under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Slider tick size under the specified font size.
 	 */
 	public static int getSliderTickSize(int fontSize) {
@@ -566,7 +580,7 @@ public class SubstanceSizeUtils {
 	 * Returns the slider track size under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Slider track size under the specified font size.
 	 */
 	public static int getSliderTrackSize(int fontSize) {
@@ -577,13 +591,13 @@ public class SubstanceSizeUtils {
 	 * Returns the height of spinner arrow icons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Height of spinner arrow icons under the specified font size.
 	 */
-	public static int getSpinnerArrowIconHeight(int fontSize) {
-		int result = SubstanceSizeUtils.getArrowIconHeight(fontSize)
-				+ (int) SubstanceSizeUtils.getAdjustedSize(fontSize, -1, 1,
-						-0.25f);
+	public static float getSpinnerArrowIconHeight(int fontSize) {
+		float result = SubstanceSizeUtils.getArrowIconHeight(fontSize)
+				+ SubstanceSizeUtils
+						.getAdjustedSize(fontSize + 1, 0, 1, -0.25f);
 		return result;
 	}
 
@@ -591,13 +605,12 @@ public class SubstanceSizeUtils {
 	 * Returns the width of spinner arrow icons under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Width of spinner arrow icons under the specified font size.
 	 */
-	public static int getSpinnerArrowIconWidth(int fontSize) {
-		int result = SubstanceSizeUtils.getArrowIconWidth(fontSize)
-				+ (int) SubstanceSizeUtils.getAdjustedSize(fontSize, -2, 1,
-						-0.15f);
+	public static float getSpinnerArrowIconWidth(int fontSize) {
+		int result = (int) (SubstanceSizeUtils.getArrowIconWidth(fontSize) + SubstanceSizeUtils
+				.getAdjustedSize(fontSize, 1, 1, -0.15f));
 		if (result % 2 == 0)
 			result--;
 		return result;
@@ -607,7 +620,7 @@ public class SubstanceSizeUtils {
 	 * Returns the spinner border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Spinner border insets under the specified font size.
 	 */
 	public static Insets getSpinnerBorderInsets(int fontSize) {
@@ -622,7 +635,7 @@ public class SubstanceSizeUtils {
 	 * Returns the spinner arrow button insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Spinner arrow button insets under the specified font size.
 	 */
 	public static Insets getSpinnerArrowButtonInsets(int fontSize) {
@@ -636,10 +649,10 @@ public class SubstanceSizeUtils {
 	 * Returns the spinner button width under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Spinner button width under the specified font size.
 	 */
-	public static int getSpinnerButtonWidth(int fontSize) {
+	public static float getSpinnerButtonWidth(int fontSize) {
 		return getArrowIconWidth(fontSize) * 3 / 2;
 	}
 
@@ -647,7 +660,7 @@ public class SubstanceSizeUtils {
 	 * Returns the spinner text border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Spinner text border insets under the specified font size.
 	 */
 	public static Insets getSpinnerTextBorderInsets(int fontSize) {
@@ -661,14 +674,13 @@ public class SubstanceSizeUtils {
 	 * font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Height of split pane divider arrow icons under the specified font
-	 *         size.
+	 * 	size.
 	 */
-	public static int getSplitPaneArrowIconHeight(int fontSize) {
-		int result = SubstanceSizeUtils.getArrowIconHeight(fontSize)
-				+ (int) SubstanceSizeUtils.getAdjustedSize(fontSize, -1, 1,
-						-0.3f);
+	public static float getSplitPaneArrowIconHeight(int fontSize) {
+		float result = SubstanceSizeUtils.getArrowIconHeight(fontSize)
+				+ SubstanceSizeUtils.getAdjustedSize(fontSize, -1, 1, -0.3f);
 		return result;
 	}
 
@@ -677,16 +689,15 @@ public class SubstanceSizeUtils {
 	 * font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Width of split pane divider arrow icons under the specified font
-	 *         size.
+	 * 	size.
 	 */
-	public static int getSplitPaneArrowIconWidth(int fontSize) {
-		int result = SubstanceSizeUtils.getArrowIconWidth(fontSize)
-				+ (int) SubstanceSizeUtils.getAdjustedSize(fontSize, -2, 1,
-						-0.25f);
-		if (result % 2 == 0)
-			result--;
+	public static float getSplitPaneArrowIconWidth(int fontSize) {
+		float result = SubstanceSizeUtils.getArrowIconWidth(fontSize)
+				+ SubstanceSizeUtils.getAdjustedSize(fontSize, -2, 1, -0.25f);
+		// if (result % 2 == 0)
+		// result--;
 		return result;
 	}
 
@@ -695,9 +706,9 @@ public class SubstanceSizeUtils {
 	 * specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Offset of the first split pane divider button under the specified
-	 *         font size.
+	 * 	font size.
 	 */
 	public static int getSplitPaneButtonOffset(int fontSize) {
 		return getAdjustedSize(fontSize, 2, 3, 1, false);
@@ -709,7 +720,7 @@ public class SubstanceSizeUtils {
 	 * assumed.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Tabbed pane content insets under the specified size.
 	 */
 	public static Insets getTabbedPaneContentInsets(int fontSize) {
@@ -723,7 +734,7 @@ public class SubstanceSizeUtils {
 	 * Returns the stroke width of tab close buttons under the specified size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Stroke width of tab close buttons under the specified size.
 	 */
 	public static float getTabCloseButtonStrokeWidth(int fontSize) {
@@ -734,7 +745,7 @@ public class SubstanceSizeUtils {
 	 * Returns the icon size of tab close buttons under the specified size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Icon size of tab close buttons under the specified size.
 	 */
 	public static int getTabCloseIconSize(int fontSize) {
@@ -745,7 +756,7 @@ public class SubstanceSizeUtils {
 	 * Returns the table cell renderer insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Table cell renderer insets under the specified font size.
 	 */
 	public static Insets getTableCellRendererInsets(int fontSize) {
@@ -758,7 +769,7 @@ public class SubstanceSizeUtils {
 	 * Returns the text border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Text border insets under the specified font size.
 	 */
 	public static Insets getTextBorderInsets(int fontSize) {
@@ -769,11 +780,24 @@ public class SubstanceSizeUtils {
 		return new Insets(tbInset, lrInset, tbInset, lrInset);
 	}
 
+	/**
+	 * Returns the text button padding amount on left and right sides under the
+	 * specified font size.
+	 * 
+	 * @param fontSize
+	 * 		Font size.
+	 * @return Text button padding amount on left and right sides under the
+	 * 	specified font size.
+	 */
+	public static int getTextButtonLRPadding(int fontSize) {
+		return SubstanceSizeUtils.getAdjustedSize(fontSize, 3, 2, 1, false);
+	}
+
 	/**
 	 * Returns the icon size of title pane buttons under the specified size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Icon size of title pane buttons under the specified size.
 	 */
 	public static int getTitlePaneIconSize() {
@@ -784,7 +808,7 @@ public class SubstanceSizeUtils {
 	 * Returns the tool bar drag inset under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Tool bar drag inset under the specified font size.
 	 */
 	public static int getToolBarDragInset(int fontSize) {
@@ -795,7 +819,7 @@ public class SubstanceSizeUtils {
 	 * Returns the tool bar insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Tool bar insets under the specified font size.
 	 */
 	public static Insets getToolBarInsets(int fontSize) {
@@ -808,7 +832,7 @@ public class SubstanceSizeUtils {
 	 * Returns the tooltip border insets under the specified font size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Tooltip border insets under the specified font size.
 	 */
 	public static Insets getToolTipBorderInsets(int fontSize) {
@@ -818,14 +842,27 @@ public class SubstanceSizeUtils {
 		return new Insets(inset, inset, inset, inset);
 	}
 
+	/**
+	 * Returns the tree cell renderer insets under the specified font size.
+	 * 
+	 * @param fontSize
+	 * 		Font size.
+	 * @return Tree cell renderer insets under the specified font size.
+	 */
+	public static Insets getTreeCellRendererInsets(int fontSize) {
+		Insets listCellInsets = getListCellRendererInsets(fontSize);
+		return new Insets(listCellInsets.top - 1, listCellInsets.left - 2,
+				listCellInsets.bottom - 1, listCellInsets.right - 2);
+	}
+
 	/**
 	 * Returns the icon size of tree expand / collapse icons under the specified
 	 * size.
 	 * 
 	 * @param fontSize
-	 *            Font size.
+	 * 		Font size.
 	 * @return Icon size of tree expand / collapse icons under the specified
-	 *         size.
+	 * 	size.
 	 */
 	public static int getTreeIconSize(int fontSize) {
 		int extraPadding = SubstanceSizeUtils.getExtraPadding(fontSize);
@@ -833,10 +870,21 @@ public class SubstanceSizeUtils {
 		return 10 + extraPadding2;
 	}
 
+	/**
+	 * Returns the points to pixels ratio of the current font policy.
+	 * 
+	 * @return The points to pixels ratio of the current font policy.
+	 */
 	public static double getPointsToPixelsRatio() {
 		return pointsToPixelsRatio;
 	}
 
+	/**
+	 * Resets the points to pixels ratio based on the specified font policy.
+	 * 
+	 * @param fontPolicy
+	 * 		Font policy.
+	 */
 	public static void resetPointsToPixelsRatio(FontPolicy fontPolicy) {
 		if (fontPolicy instanceof DefaultGnomeFontPolicy) {
 			pointsToPixelsRatio = DefaultGnomeFontPolicy
