@@ -36,9 +36,10 @@ import javax.swing.*;
 
 import org.jvnet.lafwidget.animation.FadeConfigurationManager;
 import org.jvnet.lafwidget.animation.FadeKind;
-import org.jvnet.substance.SubstanceButtonBorder;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.button.ClassicButtonShaper;
+import org.jvnet.substance.api.SubstanceConstants;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
+import org.jvnet.substance.utils.border.SubstanceButtonBorder;
 
 /**
  * Spinner button in <b>Substance</b> look and feel.
@@ -62,9 +63,9 @@ public class SubstanceSpinnerButton extends JButton implements Sideable {
 	 * Simple constructor.
 	 * 
 	 * @param spinner
-	 *            The owner spinner.
+	 * 		The owner spinner.
 	 * @param orientation
-	 *            The orientation of the spinner icon arrow.
+	 * 		The orientation of the spinner icon arrow.
 	 */
 	public SubstanceSpinnerButton(JSpinner spinner, final int orientation) {
 		// super(0, 0, false);
@@ -97,20 +98,6 @@ public class SubstanceSpinnerButton extends JButton implements Sideable {
 				Boolean.FALSE);
 	}
 
-	/**
-	 * Sets the icon for this button.
-	 * 
-	 * @param spinner
-	 *            Spinner.
-	 * @param defaultIcon
-	 *            Spinner icon.
-	 */
-	public void setIcon(JSpinner spinner, Icon defaultIcon) {
-		super.setIcon(defaultIcon);
-		// super.setDisabledIcon(SubstanceImageCreator.makeTransparent(spinner,
-		// defaultIcon, 0.4));
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -140,4 +127,13 @@ public class SubstanceSpinnerButton extends JButton implements Sideable {
 			return null;
 		}
 	}
+	//
+	// @Override
+	// public void paint(Graphics g) {
+	// super.paint(g);
+	// Color c = "Spinner.nextButton".equals(this.getName()) ? Color.red
+	// : Color.green.darker();
+	// g.setColor(c);
+	// g.drawRect(0, 0, getWidth() - 1, getHeight() - 1);
+	// }
 }
