@@ -31,16 +31,14 @@ package org.jvnet.substance.utils.icon;
 
 import java.awt.Component;
 import java.awt.Graphics;
-import java.util.HashMap;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.plaf.UIResource;
 
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeState;
-import org.jvnet.substance.SubstanceImageCreator;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -62,20 +60,20 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 	/**
 	 * Icon cache to speed up the painting.
 	 */
-	private Map<String, Icon> iconMap;
+	private static LazyResettableHashMap<Icon> iconMap = new LazyResettableHashMap<Icon>(
+			"CheckBoxMenuItemIcon");
 
 	/**
 	 * Creates a new icon.
 	 * 
 	 * @param menuItem
-	 *            The corresponding menu item.
+	 * 		The corresponding menu item.
 	 * @param size
-	 *            The size of <code>this</code> icon.
+	 * 		The size of <code>this</code> icon.
 	 */
 	public CheckBoxMenuItemIcon(JMenuItem menuItem, int size) {
 		this.menuItem = menuItem;
 		this.size = size;
-		this.iconMap = new HashMap<String, Icon>();
 	}
 
 	/**
@@ -83,7 +81,7 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 	 * 
 	 * @return Icon to paint.
 	 */
-	private synchronized Icon getIconToPaint() {
+	private Icon getIconToPaint() {
 		if (this.menuItem == null)
 			return null;
 		ComponentState currState = ComponentState.getState(this.menuItem
@@ -94,15 +92,14 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevSelComponentState(this.menuItem);
 
-		float checkMarkVisibility = currState.isKindActive(FadeKind.SELECTION) ? 10 : 0;
+		float checkMarkVisibility = currState.isKindActive(FadeKind.SELECTION) ? 10
+				: 0;
 		boolean isCheckMarkFadingOut = false;
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.menuItem)
-				.getTheme(this.menuItem, currState,
-						currState == ComponentState.SELECTED);
-		SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(this.menuItem)
-				.getTheme(this.menuItem, prevState,
-						prevState == ComponentState.SELECTED);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities.getColorScheme(
+				this.menuItem, currState, currState == ComponentState.SELECTED);
+		SubstanceColorScheme scheme2 = SubstanceColorSchemeUtilities.getColorScheme(
+				this.menuItem, prevState, prevState == ComponentState.SELECTED);
 		float cyclePos = 0;
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(
 				this.menuItem, FadeKind.SELECTION, FadeKind.ROLLOVER,
@@ -110,24 +107,25 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 		if (fadeState != null) {
 			cyclePos = fadeState.getFadePosition();
 			if (fadeState.isFadingIn())
-				cyclePos = 10 - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 			if (fadeState.fadeKind == FadeKind.SELECTION) {
 				checkMarkVisibility = fadeState.getFadePosition();
 				isCheckMarkFadingOut = !fadeState.isFadingIn();
 			}
 		}
 
-		String key = currState.name() + ":" + prevState.name() + ":"
-				+ theme.getDisplayName() + ":" + theme2.getDisplayName() + ":"
-				+ cyclePos + ":" + checkMarkVisibility;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(currState.name(),
+				prevState.name(), scheme.getDisplayName(), scheme2
+						.getDisplayName(), cyclePos, checkMarkVisibility,
+				this.size);
 
 		// System.out.println(key);
 
-		Icon result = this.iconMap.get(key);
+		Icon result = iconMap.get(key);
 		if (result != null)
 			return result;
 		result = new ImageIcon(SubstanceImageCreator.getCheckBox(this.menuItem,
-				this.size + 3, currState, theme, theme2, cyclePos,
+				this.size + 3, currState, prevState, scheme, scheme2, cyclePos,
 				checkMarkVisibility / 10.f, isCheckMarkFadingOut));
 
 		// if (this.menuItem.isSelected()) {
@@ -135,7 +133,7 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 		// + theme.getDisplayName());
 		// }
 
-		this.iconMap.put(key, result);
+		iconMap.put(key, result);
 		return result;
 	}
 
@@ -143,7 +141,7 @@ public class CheckBoxMenuItemIcon implements Icon, UIResource {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.Icon#paintIcon(java.awt.Component, java.awt.Graphics,
-	 *      int, int)
+	 * int, int)
 	 */
 	public void paintIcon(Component c, Graphics g, int x, int y) {
 		Icon iconToDraw = this.getIconToPaint();
