@@ -94,10 +94,10 @@ public class GlowingIcon implements Icon {
 	 * @see javax.swing.Icon#paintIcon(java.awt.Component, java.awt.Graphics,
 	 *      int, int)
 	 */
-	public synchronized void paintIcon(Component c, Graphics g, int x, int y) {
+	public void paintIcon(Component c, Graphics g, int x, int y) {
 		if (this.delegate == null)
 			return;
-		float fadePos = FadeTracker.getInstance().getFade10(this.component,
+		float fadePos = FadeTracker.getInstance().getFade(this.component,
 				FadeKind.ICON_GLOW);
 		// System.out.println(fadePos);
 		Icon toPaint = this.iconMap.get(fadePos);
@@ -112,7 +112,7 @@ public class GlowingIcon implements Icon {
 				for (int j = 0; j < height; j++) {
 					int rgba = image.getRGB(i, j);
 					int transp = (rgba >>> 24) & 0xFF;
-					double coef = Math.sin(2.0 * Math.PI * fadePos / 20.0) / 3.0;
+					double coef = Math.sin(2.0 * Math.PI * fadePos / 2.0) / 3.0;
 					Color newColor = (coef >= 0.0) ? SubstanceColorUtilities
 							.getLighterColor(new Color(rgba), coef)
 							: SubstanceColorUtilities.getDarkerColor(new Color(
