@@ -35,35 +35,35 @@ import java.awt.Graphics;
 import javax.swing.*;
 import javax.swing.plaf.UIResource;
 
-import org.jvnet.substance.SubstanceImageCreator;
-import org.jvnet.substance.theme.SubstanceTheme;
-import org.jvnet.substance.utils.SubstanceSizeUtils;
-
 public class MenuArrowIcon implements Icon, UIResource {
 	private Icon ltrIcon;
 
 	private Icon rtlIcon;
 
 	public MenuArrowIcon(final JMenuItem menuItem) {
-		this.ltrIcon = new TransitionAwareIcon(menuItem,
-				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
-						int fontSize = SubstanceSizeUtils
-								.getComponentFontSize(menuItem);
-						return SubstanceImageCreator.getArrowIcon(fontSize,
-								SwingConstants.EAST, theme);
-					}
-				});
+		this.ltrIcon = new ArrowButtonTransitionAwareIcon(menuItem,
+				SwingConstants.EAST);
+		// this.ltrIcon = new TransitionAwareIcon(menuItem,
+		// new TransitionAwareIcon.Delegate() {
+		// public Icon getColorSchemeIcon(SubstanceColorScheme scheme) {
+		// int fontSize = SubstanceSizeUtils
+		// .getComponentFontSize(menuItem);
+		// return SubstanceImageCreator.getArrowIcon(fontSize,
+		// SwingConstants.EAST, scheme);
+		// }
+		// });
 
-		this.rtlIcon = new TransitionAwareIcon(menuItem,
-				new TransitionAwareIcon.Delegate() {
-					public Icon getThemeIcon(SubstanceTheme theme) {
-						int fontSize = SubstanceSizeUtils
-								.getComponentFontSize(menuItem);
-						return SubstanceImageCreator.getArrowIcon(fontSize,
-								SwingConstants.WEST, theme);
-					}
-				});
+		this.rtlIcon = new ArrowButtonTransitionAwareIcon(menuItem,
+				SwingConstants.WEST);
+		// this.rtlIcon = new TransitionAwareIcon(menuItem,
+		// new TransitionAwareIcon.Delegate() {
+		// public Icon getColorSchemeIcon(SubstanceColorScheme scheme) {
+		// int fontSize = SubstanceSizeUtils
+		// .getComponentFontSize(menuItem);
+		// return SubstanceImageCreator.getArrowIcon(fontSize,
+		// SwingConstants.WEST, scheme);
+		// }
+		// });
 	}
 
 	/*
@@ -88,7 +88,7 @@ public class MenuArrowIcon implements Icon, UIResource {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.Icon#paintIcon(java.awt.Component, java.awt.Graphics,
-	 *      int, int)
+	 * int, int)
 	 */
 	public void paintIcon(Component c, Graphics g, int x, int y) {
 		if (c.getComponentOrientation().isLeftToRight()) {
