@@ -31,16 +31,14 @@ package org.jvnet.substance.utils.icon;
 
 import java.awt.Component;
 import java.awt.Graphics;
-import java.util.HashMap;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.plaf.UIResource;
 
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeState;
-import org.jvnet.substance.SubstanceImageCreator;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -62,20 +60,20 @@ public class RadioButtonMenuItemIcon implements Icon, UIResource {
 	/**
 	 * Icon cache to speed up the painting.
 	 */
-	private Map<String, Icon> iconMap;
+	private static LazyResettableHashMap<Icon> iconMap = new LazyResettableHashMap<Icon>(
+			"RadioButtonMenuItemIcon");
 
 	/**
 	 * Creates a new icon.
 	 * 
 	 * @param menuItem
-	 *            The corresponding menu item.
+	 * 		The corresponding menu item.
 	 * @param size
-	 *            The size of <code>this</code> icon.
+	 * 		The size of <code>this</code> icon.
 	 */
 	public RadioButtonMenuItemIcon(JMenuItem menuItem, int size) {
 		this.menuItem = menuItem;
 		this.size = size;
-		this.iconMap = new HashMap<String, Icon>();
 	}
 
 	/**
@@ -83,22 +81,19 @@ public class RadioButtonMenuItemIcon implements Icon, UIResource {
 	 * 
 	 * @return Icon to paint.
 	 */
-	private synchronized Icon getIconToPaint() {
+	private Icon getIconToPaint() {
 		if (this.menuItem == null)
 			return null;
-		ComponentState currState = ComponentState.getState(this.menuItem
-				.getModel(), this.menuItem);
+		ComponentState currState = ComponentState.getState(this.menuItem);
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevSelComponentState(this.menuItem);
 
 		float visibility = currState.isKindActive(FadeKind.SELECTION) ? 10 : 0;
 
-		SubstanceTheme theme = SubstanceThemeUtilities.getTheme(this.menuItem)
-				.getTheme(this.menuItem, currState,
-						currState == ComponentState.SELECTED);
-		SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(this.menuItem)
-				.getTheme(this.menuItem, prevState,
-						prevState == ComponentState.SELECTED);
+		SubstanceColorScheme scheme = SubstanceColorSchemeUtilities.getColorScheme(
+				this.menuItem, currState, currState == ComponentState.SELECTED);
+		SubstanceColorScheme scheme2 = SubstanceColorSchemeUtilities.getColorScheme(
+				this.menuItem, prevState, prevState == ComponentState.SELECTED);
 		float cyclePos = 0;
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(
 				this.menuItem, FadeKind.SELECTION, FadeKind.ROLLOVER,
@@ -106,26 +101,26 @@ public class RadioButtonMenuItemIcon implements Icon, UIResource {
 		if (fadeState != null) {
 			cyclePos = fadeState.getFadePosition();
 			if (fadeState.isFadingIn())
-				cyclePos = 10 - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 			if (fadeState.fadeKind == FadeKind.SELECTION) {
 				visibility = fadeState.getFadePosition();
 			}
 		}
 
-		String key = currState.name() + ":" + prevState.name() + ":"
-				+ theme.getDisplayName() + ":" + theme2.getDisplayName() + ":"
-				+ cyclePos + ":" + visibility;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(currState.name(),
+				prevState.name(), scheme.getDisplayName(), scheme2
+						.getDisplayName(), cyclePos, visibility, this.size);
 
 		// System.out.println(key);
 
-		Icon result = this.iconMap.get(key);
+		Icon result = iconMap.get(key);
 		if (result != null)
 			return result;
 		result = new ImageIcon(SubstanceImageCreator.getRadioButton(
-				this.menuItem, this.size, currState, 2, theme, theme2,
-				cyclePos, visibility / 10.f));
+				this.menuItem, this.size, currState, prevState, 2, scheme,
+				scheme2, cyclePos, visibility / 10.f));
 
-		this.iconMap.put(key, result);
+		iconMap.put(key, result);
 		return result;
 	}
 
@@ -133,7 +128,7 @@ public class RadioButtonMenuItemIcon implements Icon, UIResource {
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.Icon#paintIcon(java.awt.Component, java.awt.Graphics,
-	 *      int, int)
+	 * int, int)
 	 */
 	public void paintIcon(Component c, Graphics g, int x, int y) {
 		Icon iconToDraw = this.getIconToPaint();
