@@ -44,11 +44,10 @@ import javax.swing.plaf.basic.BasicSliderUI;
 
 import org.jvnet.lafwidget.animation.*;
 import org.jvnet.substance.*;
-import org.jvnet.substance.border.SubstanceBorderPainter;
-import org.jvnet.substance.button.BaseButtonShaper;
-import org.jvnet.substance.color.ColorScheme;
-import org.jvnet.substance.painter.SubstanceGradientPainter;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.painter.border.SubstanceBorderPainter;
+import org.jvnet.substance.painter.gradient.SubstanceGradientPainter;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -59,50 +58,36 @@ import org.jvnet.substance.utils.*;
  */
 public class SubstanceIconFactory {
 	/**
-	 * Icons for check box menu item in {@link SubstanceCheckBoxMenuItemUI}.
+	 * Icons for horizontal slider in {@link SubstanceSliderUI}.
 	 */
-	private static Map<Integer, Icon> checkBoxMenuItemIcons = new HashMap<Integer, Icon>();
-
-	/**
-	 * Icons for radio button menu item in
-	 * {@link SubstanceRadioButtonMenuItemUI}.
-	 */
-	private static Map<Integer, Icon> radioButtonMenuItemIcons = new HashMap<Integer, Icon>();
+	private static LazyResettableHashMap<Icon> sliderHorizontalIcons = new LazyResettableHashMap<Icon>(
+			"SubstanceIconFactory.sliderHorizontalIcon");
 
 	/**
 	 * Icons for horizontal slider in {@link SubstanceSliderUI}.
 	 */
-	private static Map<String, Icon> sliderHorizontalIcons = new HashMap<String, Icon>();
-
-	/**
-	 * Icons for horizontal slider in {@link SubstanceSliderUI}.
-	 */
-	private static Map<String, Icon> sliderRoundIcons = new HashMap<String, Icon>();
+	private static LazyResettableHashMap<Icon> sliderRoundIcons = new LazyResettableHashMap<Icon>(
+			"SubstanceIconFactory.sliderRoundIcon");
 
 	/**
 	 * Icons for vertical slider in {@link SubstanceSliderUI}.
 	 */
-	private static Map<String, Icon> sliderVerticalIcons = new HashMap<String, Icon>();
+	private static LazyResettableHashMap<Icon> sliderVerticalIcons = new LazyResettableHashMap<Icon>(
+			"SubstanceIconFactory.sliderVerticalIcon");
 
 	/**
 	 * Icons for tree collapse / expand in {@link SubstanceTreeUI}.
 	 */
-	private static Map<String, Icon> treeIcons = new HashMap<String, Icon>();
+	private static LazyResettableHashMap<Icon> treeIcons = new LazyResettableHashMap<Icon>(
+			"SubstanceIconFactory.treeIcon");
 
 	/**
-	 * Resets image maps (used when setting new theme).
+	 * Resets image maps (used when setting new skin).
 	 * 
-	 * @see SubstanceLookAndFeel#setCurrentTheme(String)
-	 * @see SubstanceLookAndFeel#setCurrentTheme(SubstanceTheme)
+	 * @see SubstanceLookAndFeel#setSkin(String)
+	 * @see SubstanceLookAndFeel#setSkin(org.jvnet.substance.skin.SubstanceSkin)
 	 */
 	public static synchronized void reset() {
-		SubstanceIconFactory.checkBoxMenuItemIcons.clear();
-		SubstanceIconFactory.radioButtonMenuItemIcons.clear();
-		SubstanceIconFactory.sliderHorizontalIcons.clear();
-		SubstanceIconFactory.sliderRoundIcons.clear();
-		SubstanceIconFactory.sliderVerticalIcons.clear();
-		SubstanceIconFactory.treeIcons.clear();
-
 		SubstanceIconFactory.titlePaneIcons.get(IconKind.CLOSE).clear();
 		SubstanceIconFactory.titlePaneIcons.get(IconKind.MINIMIZE).clear();
 		SubstanceIconFactory.titlePaneIcons.get(IconKind.MAXIMIZE).clear();
@@ -119,7 +104,7 @@ public class SubstanceIconFactory {
 	 * @return Icon for horizontal slider in {@link SubstanceSliderUI}.
 	 */
 	public static Icon getSliderHorizontalIcon(int size, boolean isMirrorred) {
-		String key = size + ":" + isMirrorred;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(size, isMirrorred);
 		if (SubstanceIconFactory.sliderHorizontalIcons.get(key) == null) {
 			Icon icon = new SliderHorizontalIcon(size, isMirrorred);
 			SubstanceIconFactory.sliderHorizontalIcons.put(key, icon);
@@ -135,7 +120,7 @@ public class SubstanceIconFactory {
 	 * @return Round icon for slider in {@link SubstanceSliderUI}.
 	 */
 	public static Icon getSliderRoundIcon(int size) {
-		String key = "" + size;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(size);
 		if (SubstanceIconFactory.sliderRoundIcons.get(key) == null) {
 			Icon icon = new SliderRoundIcon(size);
 			SubstanceIconFactory.sliderRoundIcons.put(key, icon);
@@ -153,7 +138,7 @@ public class SubstanceIconFactory {
 	 * @return Icon for vertical slider in {@link SubstanceSliderUI}.
 	 */
 	public static Icon getSliderVerticalIcon(int size, boolean isMirrorred) {
-		String key = size + ":" + isMirrorred;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(size, isMirrorred);
 		if (SubstanceIconFactory.sliderVerticalIcons.get(key) == null) {
 			Icon icon = new SliderVerticalIcon(size, isMirrorred);
 			SubstanceIconFactory.sliderVerticalIcons.put(key, icon);
@@ -165,7 +150,7 @@ public class SubstanceIconFactory {
 		int fontSize = SubstanceSizeUtils.getComponentFontSize(tree);
 		int size = SubstanceSizeUtils.getTreeIconSize(fontSize);
 
-		String key = size + ":" + isCollapsed;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(size, isCollapsed);
 		if (SubstanceIconFactory.treeIcons.get(key) == null) {
 			Icon icon = new TreeIcon(size, isCollapsed);
 			SubstanceIconFactory.treeIcons.put(key, icon);
@@ -220,7 +205,8 @@ public class SubstanceIconFactory {
 		/*
 		 * (non-Javadoc)
 		 * 
-		 * @see org.jvnet.substance.Trackable#isInside(java.awt.event.MouseEvent)
+		 * @see
+		 * org.jvnet.substance.Trackable#isInside(java.awt.event.MouseEvent)
 		 */
 		public boolean isInside(MouseEvent me) {
 			try {
@@ -244,8 +230,8 @@ public class SubstanceIconFactory {
 		/**
 		 * Icon hash.
 		 */
-		// private Map<ColorScheme, Map<ComponentState, Icon>> icons;
-		private static Map<String, Icon> icons = new HashMap<String, Icon>();
+		private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+				"SubstanceIconFactory.SliderHorizontalIcon");
 
 		/**
 		 * The size of <code>this</code> icon.
@@ -274,7 +260,6 @@ public class SubstanceIconFactory {
 		 *            Indication whether the icon should be mirrored.
 		 */
 		public SliderHorizontalIcon(int size, boolean isMirrorred) {
-			// icons = new HashMap<ColorScheme, Map<ComponentState, Icon>>();
 			this.size = size;
 			this.isMirrorred = isMirrorred;
 		}
@@ -292,21 +277,20 @@ public class SubstanceIconFactory {
 		 *            The slider icon.
 		 * @return Icon that matches the specified state of the slider thumb.
 		 */
-		private static synchronized Icon getIcon(ComponentState state,
+		private static Icon getIcon(ComponentState state,
 				ComponentState prevState, JSlider slider,
 				SliderHorizontalIcon sliderIcon) {
 
-			float cyclePos = state.getCycleCount();
+			float cyclePos = state.getCyclePosition();
 
-			SubstanceTheme theme = SubstanceThemeUtilities.getTheme(slider,
-					state);
-			SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(slider,
-					prevState);
-			ColorScheme colorScheme = theme.getColorScheme();
-			ColorScheme colorScheme2 = theme2.getColorScheme();
-			ColorScheme borderScheme = theme.getBorderTheme().getColorScheme();
-			ColorScheme borderScheme2 = theme2.getBorderTheme()
-					.getColorScheme();
+			SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, state);
+			SubstanceColorScheme colorScheme2 = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, prevState);
+			SubstanceColorScheme borderScheme = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, state);
+			SubstanceColorScheme borderScheme2 = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, prevState);
 
 			FadeTracker fadeTracker = FadeTracker.getInstance();
 			int width = 2 * sliderIcon.size / 3;
@@ -317,13 +301,13 @@ public class SubstanceIconFactory {
 			if (rolloverFadeState != null) {
 				cyclePos = rolloverFadeState.getFadePosition();
 				if (rolloverFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				width = (int) (sliderIcon.size
-						* (2.0 + rolloverFadeState.getFadePosition() / 10.0) / 3.0);
+						* (2.0 + rolloverFadeState.getFadePosition()) / 3.0);
 			} else if (pressFadeState != null) {
 				cyclePos = pressFadeState.getFadePosition();
 				if (pressFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				width = sliderIcon.size;
 			} else {
 				switch (state) {
@@ -338,57 +322,60 @@ public class SubstanceIconFactory {
 			width = Math.min(width, sliderIcon.size - 2);
 			int delta = (sliderIcon.size - width) / 2;
 
-			String key = sliderIcon.size + ":" + width + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme2) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme2) + ":"
-					+ cyclePos;
+			HashMapKey key = SubstanceCoreUtilities.getHashKey(sliderIcon.size,
+					width, colorScheme.getDisplayName(), colorScheme2
+							.getDisplayName(), borderScheme.getDisplayName(),
+					borderScheme2.getDisplayName(), cyclePos);
 
 			Icon result = SliderHorizontalIcon.icons.get(key);
 			if (result != null)
 				return result;
 
-			SubstanceGradientPainter painter = SubstanceLookAndFeel
-					.getCurrentGradientPainter();
+			SubstanceGradientPainter painter = SubstanceCoreUtilities
+					.getGradientPainter(slider);
 			SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
 					.getBorderPainter(slider);
 
 			int borderDelta = (int) Math.floor(SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
 							.getComponentFontSize(slider)) / 2.0);
-			Shape contour = BaseButtonShaper.getTriangleButtonOutline(width,
-					sliderIcon.size - 1, 2, borderDelta);
+			Shape contour = SubstanceOutlineUtilities.getTriangleButtonOutline(
+					width, sliderIcon.size - 1, 2, borderDelta);
 
-			BufferedImage stateImage = painter.getContourBackground(width,
+			BufferedImage stateImage = SubstanceCoreUtilities.getBlankImage(
+					sliderIcon.size - 1, sliderIcon.size - 1);
+			Graphics2D g2d = stateImage.createGraphics();
+			g2d.translate(delta, 0);
+
+			painter.paintContourBackground(g2d, slider, width,
 					sliderIcon.size - 1, contour, false, colorScheme,
 					colorScheme2, cyclePos, true, colorScheme != colorScheme2);
-			BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
-					sliderIcon.size - 1, sliderIcon.size - 1);
-			Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
-			bg2d.translate(delta, 0);
-			bg2d.drawImage(stateImage, 0, 0, null);
+			// BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
+			// sliderIcon.size - 1, sliderIcon.size - 1);
+			// Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
+			// bg2d.translate(delta, 0);
+			// bg2d.drawImage(stateImage, 0, 0, null);
 
 			int borderThickness = (int) SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
 							.getComponentFontSize(slider));
-			GeneralPath contourInner = BaseButtonShaper
+			GeneralPath contourInner = SubstanceOutlineUtilities
 					.getTriangleButtonOutline(width, sliderIcon.size - 1, 2,
 							borderThickness + borderDelta);
 
-			borderPainter.paintBorder(bg2d, slider, width, sliderIcon.size - 1,
+			borderPainter.paintBorder(g2d, slider, width, sliderIcon.size - 1,
 					contour, contourInner, borderScheme, borderScheme2,
 					cyclePos, borderScheme != borderScheme2);
-			bg2d.translate(-delta, 0);
+			g2d.translate(-delta, 0);
 
 			if (sliderIcon.isMirrorred)
-				biResult = SubstanceImageCreator.getRotated(biResult, 2);
+				stateImage = SubstanceImageCreator.getRotated(stateImage, 2);
 			// Graphics g = stateImage.getGraphics();
 			// g.setColor(Color.red);
 			// g.drawRect(0, 0, stateImage.getWidth()-1,
 			// stateImage.getHeight()-1);
 
-			result = new ImageIcon(biResult);
+			result = new ImageIcon(stateImage);
 			SliderHorizontalIcon.icons.put(key, result);
 
 			return result;
@@ -398,7 +385,7 @@ public class SubstanceIconFactory {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.Icon#paintIcon(java.awt.Component,
-		 *      java.awt.Graphics, int, int)
+		 * java.awt.Graphics, int, int)
 		 */
 		public void paintIcon(Component c, Graphics g, int x, int y) {
 			if (!(g instanceof Graphics2D)) {
@@ -461,8 +448,8 @@ public class SubstanceIconFactory {
 		/**
 		 * Icon hash.
 		 */
-		// private Map<ColorScheme, Map<ComponentState, Icon>> icons;
-		private static Map<String, Icon> icons = new HashMap<String, Icon>();
+		private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+				"SubstanceIconFactory.SliderRoundIcon");
 
 		/**
 		 * The size of <code>this</code> icon.
@@ -484,7 +471,6 @@ public class SubstanceIconFactory {
 		 *            The size of <code>this</code> icon.
 		 */
 		public SliderRoundIcon(int size) {
-			// icons = new HashMap<ColorScheme, Map<ComponentState, Icon>>();
 			this.size = size;
 		}
 
@@ -501,24 +487,23 @@ public class SubstanceIconFactory {
 		 *            The slider icon.
 		 * @return Icon that matches the specified state of the slider thumb.
 		 */
-		private static synchronized Icon getIcon(ComponentState state,
+		private static Icon getIcon(ComponentState state,
 				ComponentState prevState, JSlider slider,
 				SliderRoundIcon sliderIcon) {
 
 			// System.out.println("Curr : " + state.name() + ", prev : " +
 			// prevState.name());
 
-			float cyclePos = state.getCycleCount();
+			float cyclePos = state.getCyclePosition();
 
-			SubstanceTheme theme = SubstanceThemeUtilities.getTheme(slider,
-					state);
-			SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(slider,
-					prevState);
-			ColorScheme colorScheme = theme.getColorScheme();
-			ColorScheme colorScheme2 = theme2.getColorScheme();
-			ColorScheme borderScheme = theme.getBorderTheme().getColorScheme();
-			ColorScheme borderScheme2 = theme2.getBorderTheme()
-					.getColorScheme();
+			SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, state);
+			SubstanceColorScheme colorScheme2 = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, prevState);
+			SubstanceColorScheme borderScheme = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, state);
+			SubstanceColorScheme borderScheme2 = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, prevState);
 
 			FadeTracker fadeTracker = FadeTracker.getInstance();
 			int width = 2 * sliderIcon.size / 3;
@@ -529,13 +514,13 @@ public class SubstanceIconFactory {
 			if (rolloverFadeState != null) {
 				cyclePos = rolloverFadeState.getFadePosition();
 				if (rolloverFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				width = (int) (sliderIcon.size
-						* (2.0 + rolloverFadeState.getFadePosition() / 10.0) / 3.0);
+						* (2.0 + rolloverFadeState.getFadePosition()) / 3.0);
 			} else if (pressFadeState != null) {
 				cyclePos = pressFadeState.getFadePosition();
 				if (pressFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				width = sliderIcon.size;
 			} else {
 				switch (state) {
@@ -552,19 +537,17 @@ public class SubstanceIconFactory {
 				width--;
 			int delta = (sliderIcon.size - width) / 2;
 
-			String key = sliderIcon.size + ":" + width + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme2) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme2) + ":"
-					+ cyclePos;
+			HashMapKey key = SubstanceCoreUtilities.getHashKey(sliderIcon.size,
+					width, colorScheme.getDisplayName(), colorScheme2
+							.getDisplayName(), borderScheme.getDisplayName(),
+					borderScheme2.getDisplayName(), cyclePos);
 
 			Icon result = SliderRoundIcon.icons.get(key);
 			if (result != null)
 				return result;
 
-			SubstanceGradientPainter painter = SubstanceLookAndFeel
-					.getCurrentGradientPainter();
+			SubstanceGradientPainter painter = SubstanceCoreUtilities
+					.getGradientPainter(slider);
 			SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
 					.getBorderPainter(slider);
 
@@ -574,16 +557,20 @@ public class SubstanceIconFactory {
 			Shape contour = new Ellipse2D.Float(borderDelta, borderDelta, width
 					- 2 * borderDelta - 1, width - 2 * borderDelta - 1);
 
-			BufferedImage stateImage = painter.getContourBackground(width,
+			BufferedImage stateImage = SubstanceCoreUtilities.getBlankImage(
+					sliderIcon.size - 1, sliderIcon.size - 1);
+			Graphics2D g2d = stateImage.createGraphics();
+			g2d.translate(delta, delta);
+
+			painter.paintContourBackground(g2d, slider, width,
 					sliderIcon.size - 1, contour, false, colorScheme,
 					colorScheme2, cyclePos, true, colorScheme != colorScheme2);
-			BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
-					sliderIcon.size - 1, sliderIcon.size - 1);
-			Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
-			// bg2d.setColor(Color.red);
-			// bg2d.drawRect(0, 0, sliderIcon.size-2, sliderIcon.size-2);
-			bg2d.translate(delta, delta);
-			bg2d.drawImage(stateImage, 0, 0, null);
+			// BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
+			// sliderIcon.size - 1, sliderIcon.size - 1);
+			// Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
+			// // bg2d.setColor(Color.red);
+			// // bg2d.drawRect(0, 0, sliderIcon.size-2, sliderIcon.size-2);
+			// bg2d.drawImage(stateImage, 0, 0, null);
 
 			int borderThickness = (int) SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
@@ -593,12 +580,12 @@ public class SubstanceIconFactory {
 					* borderDelta - 2 * borderThickness - 1, width - 2
 					* borderDelta - 2 * borderThickness - 1);
 
-			borderPainter.paintBorder(bg2d, slider, width, sliderIcon.size - 1,
+			borderPainter.paintBorder(g2d, slider, width, sliderIcon.size - 1,
 					contour, contourInner, borderScheme, borderScheme2,
 					cyclePos, borderScheme != borderScheme2);
-			bg2d.translate(-delta, -delta);
+			// bg2d.translate(-delta, -delta);
 
-			result = new ImageIcon(biResult);
+			result = new ImageIcon(stateImage);
 			SliderRoundIcon.icons.put(key, result);
 
 			return result;
@@ -608,7 +595,7 @@ public class SubstanceIconFactory {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.Icon#paintIcon(java.awt.Component,
-		 *      java.awt.Graphics, int, int)
+		 * java.awt.Graphics, int, int)
 		 */
 		public void paintIcon(Component c, Graphics g, int x, int y) {
 			if (!(g instanceof Graphics2D)) {
@@ -670,7 +657,8 @@ public class SubstanceIconFactory {
 		/**
 		 * Icon hash.
 		 */
-		private static Map<String, Icon> icons = new HashMap<String, Icon>();
+		private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+				"SubstanceIconFactory.SliderVerticalIcon");
 
 		/**
 		 * The size of <code>this</code> icon.
@@ -716,21 +704,20 @@ public class SubstanceIconFactory {
 		 *            The slider icon.
 		 * @return Icon that matches the specified state of the slider thumb.
 		 */
-		private static synchronized Icon getIcon(ComponentState state,
+		private static Icon getIcon(ComponentState state,
 				ComponentState prevState, JSlider slider,
 				SliderVerticalIcon sliderIcon) {
 
-			float cyclePos = state.getCycleCount();
+			float cyclePos = state.getCyclePosition();
 
-			SubstanceTheme theme = SubstanceThemeUtilities.getTheme(slider,
-					state);
-			SubstanceTheme theme2 = SubstanceThemeUtilities.getTheme(slider,
-					prevState);
-			ColorScheme colorScheme = theme.getColorScheme();
-			ColorScheme colorScheme2 = theme2.getColorScheme();
-			ColorScheme borderScheme = theme.getBorderTheme().getColorScheme();
-			ColorScheme borderScheme2 = theme2.getBorderTheme()
-					.getColorScheme();
+			SubstanceColorScheme colorScheme = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, state);
+			SubstanceColorScheme colorScheme2 = SubstanceColorSchemeUtilities
+					.getColorScheme(slider, prevState);
+			SubstanceColorScheme borderScheme = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, state);
+			SubstanceColorScheme borderScheme2 = SubstanceColorSchemeUtilities
+					.getBorderColorScheme(slider, prevState);
 
 			FadeTracker fadeTracker = FadeTracker.getInstance();
 			int height = 2 * sliderIcon.size / 3;
@@ -742,13 +729,13 @@ public class SubstanceIconFactory {
 			if (rolloverFadeState != null) {
 				cyclePos = rolloverFadeState.getFadePosition();
 				if (rolloverFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				height = (int) (sliderIcon.size
-						* (2.0 + rolloverFadeState.getFadePosition() / 10.0) / 3.0);
+						* (2.0 + rolloverFadeState.getFadePosition()) / 3.0);
 			} else if (pressFadeState != null) {
 				cyclePos = pressFadeState.getFadePosition();
 				if (pressFadeState.isFadingIn())
-					cyclePos = 10 - cyclePos;
+					cyclePos = 1.0f - cyclePos;
 				height = sliderIcon.size;
 			} else {
 				switch (state) {
@@ -763,57 +750,60 @@ public class SubstanceIconFactory {
 			height = Math.min(height, sliderIcon.size - 2);
 			int delta = (sliderIcon.size - height) / 2 - 1;
 
-			String key = sliderIcon.size + ":" + height + ":"
-					+ slider.getComponentOrientation() + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(colorScheme2) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme) + ":"
-					+ SubstanceCoreUtilities.getSchemeId(borderScheme2) + ":"
-					+ cyclePos;
+			HashMapKey key = SubstanceCoreUtilities.getHashKey(sliderIcon.size,
+					height, slider.getComponentOrientation(), colorScheme
+							.getDisplayName(), colorScheme2.getDisplayName(),
+					borderScheme.getDisplayName(), borderScheme2
+							.getDisplayName(), cyclePos);
 
 			Icon result = SliderVerticalIcon.icons.get(key);
 			if (result != null)
 				return result;
 
-			SubstanceGradientPainter painter = SubstanceLookAndFeel
-					.getCurrentGradientPainter();
+			SubstanceGradientPainter painter = SubstanceCoreUtilities
+					.getGradientPainter(slider);
 			SubstanceBorderPainter borderPainter = SubstanceCoreUtilities
 					.getBorderPainter(slider);
 
 			int borderDelta = (int) Math.floor(SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
 							.getComponentFontSize(slider)) / 2.0);
-			Shape contour = BaseButtonShaper.getTriangleButtonOutline(height,
-					sliderIcon.size, 2, borderDelta);
+			Shape contour = SubstanceOutlineUtilities.getTriangleButtonOutline(
+					height, sliderIcon.size, 2, borderDelta);
 
-			BufferedImage stateImage = painter.getContourBackground(height,
+			BufferedImage stateImage = SubstanceCoreUtilities.getBlankImage(
+					sliderIcon.size - 1, sliderIcon.size - 1);
+			Graphics2D g2d = stateImage.createGraphics();
+			g2d.translate(delta, 0);
+
+			painter.paintContourBackground(g2d, slider, height,
 					sliderIcon.size, contour, false, colorScheme, colorScheme2,
 					cyclePos, true, colorScheme != colorScheme2);
-			BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
-					sliderIcon.size - 1, sliderIcon.size - 1);
-			Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
-			bg2d.translate(delta, 0);
-			bg2d.drawImage(stateImage, 0, 0, null);
+			// BufferedImage biResult = SubstanceCoreUtilities.getBlankImage(
+			// sliderIcon.size - 1, sliderIcon.size - 1);
+			// Graphics2D bg2d = (Graphics2D) biResult.getGraphics();
+			// bg2d.translate(delta, 0);
+			// bg2d.drawImage(stateImage, 0, 0, null);
 
 			int borderThickness = (int) SubstanceSizeUtils
 					.getBorderStrokeWidth(SubstanceSizeUtils
 							.getComponentFontSize(slider));
-			GeneralPath contourInner = BaseButtonShaper
+			GeneralPath contourInner = SubstanceOutlineUtilities
 					.getTriangleButtonOutline(height, sliderIcon.size, 2,
 							borderThickness + borderDelta);
 
-			borderPainter.paintBorder(bg2d, slider, height,
-					sliderIcon.size - 1, contour, contourInner, borderScheme,
-					borderScheme2, cyclePos, borderScheme != borderScheme2);
-			bg2d.translate(-delta, 0);
+			borderPainter.paintBorder(g2d, slider, height, sliderIcon.size - 1,
+					contour, contourInner, borderScheme, borderScheme2,
+					cyclePos, borderScheme != borderScheme2);
+			// bg2d.translate(-delta, 0);
 
 			if (sliderIcon.isMirrorred)
-				biResult = SubstanceImageCreator.getRotated(biResult, 1);
+				stateImage = SubstanceImageCreator.getRotated(stateImage, 1);
 			else
-				biResult = SubstanceImageCreator.getRotated(biResult, 3);
+				stateImage = SubstanceImageCreator.getRotated(stateImage, 3);
 
 			if (!slider.getComponentOrientation().isLeftToRight()) {
-				biResult = SubstanceImageCreator.getRotated(biResult, 2);
+				stateImage = SubstanceImageCreator.getRotated(stateImage, 2);
 			}
 
 			// Graphics g = stateImage.getGraphics();
@@ -821,7 +811,7 @@ public class SubstanceIconFactory {
 			// g.drawRect(0, 0, stateImage.getWidth()-1,
 			// stateImage.getHeight()-1);
 
-			result = new ImageIcon(biResult);
+			result = new ImageIcon(stateImage);
 			SliderVerticalIcon.icons.put(key, result);
 
 			return result;
@@ -831,7 +821,7 @@ public class SubstanceIconFactory {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.Icon#paintIcon(java.awt.Component,
-		 *      java.awt.Graphics, int, int)
+		 * java.awt.Graphics, int, int)
 		 */
 		public void paintIcon(Component c, Graphics g, int x, int y) {
 			if (!(g instanceof Graphics2D)) {
@@ -892,7 +882,8 @@ public class SubstanceIconFactory {
 		/**
 		 * Icon hash.
 		 */
-		private static Map<String, Icon> icons = new HashMap<String, Icon>();
+		private static LazyResettableHashMap<Icon> icons = new LazyResettableHashMap<Icon>(
+				"SubstanceIconFactory.TreeIcon");
 
 		/**
 		 * The collapsed indication of this icon
@@ -925,34 +916,23 @@ public class SubstanceIconFactory {
 		 *            The slider icon.
 		 * @return Icon that matches the specified state of the slider thumb.
 		 */
-		private static synchronized Icon getIcon(JTree tree, boolean isCollapsed) {
+		private static Icon getIcon(JTree tree, boolean isCollapsed) {
 			ComponentState state = ((tree == null) || tree.isEnabled()) ? ComponentState.DEFAULT
 					: ComponentState.DISABLED_UNSELECTED;
-			SubstanceTheme theme = SubstanceThemeUtilities.getTheme(tree, state);
+			SubstanceColorScheme scheme = SubstanceColorSchemeUtilities
+					.getColorScheme(tree, state);
 
-			// if ((tree != null) && SubstanceCoreUtilities.hasColorization(tree)) {
-			// Color treeBackgr = tree.getBackground();
-			// if (!(treeBackgr instanceof UIResource)) {
-			// double colorization = SubstanceCoreUtilities
-			// .getColorizationFactor(tree);
-			// if (!tree.isEnabled())
-			// colorization /= 2.0;
-			// theme = SubstanceShiftTheme.getShiftedTheme(theme,
-			// treeBackgr, colorization, null, 0.0);
-			// }
-			// }
-			//
 			int fontSize = SubstanceSizeUtils.getComponentFontSize(tree);
 
-			String key = fontSize + ":" + theme.getDisplayName() + ":"
-					+ isCollapsed;
+			HashMapKey key = SubstanceCoreUtilities.getHashKey(fontSize, scheme
+					.getDisplayName(), isCollapsed);
 
 			Icon result = TreeIcon.icons.get(key);
 			if (result != null)
 				return result;
 
 			result = new ImageIcon(SubstanceImageCreator.getTreeIcon(tree,
-					theme, isCollapsed));
+					scheme, isCollapsed));
 			TreeIcon.icons.put(key, result);
 
 			return result;
@@ -962,7 +942,7 @@ public class SubstanceIconFactory {
 		 * (non-Javadoc)
 		 * 
 		 * @see javax.swing.Icon#paintIcon(java.awt.Component,
-		 *      java.awt.Graphics, int, int)
+		 * java.awt.Graphics, int, int)
 		 */
 		public void paintIcon(Component c, Graphics g, int x, int y) {
 			if (!(g instanceof Graphics2D)) {
@@ -1028,7 +1008,7 @@ public class SubstanceIconFactory {
 	/**
 	 * Cache of title pane icons.
 	 */
-	private static final Map<IconKind, Map<SubstanceTheme, Icon>> titlePaneIcons = SubstanceIconFactory
+	private static final Map<IconKind, Map<SubstanceColorScheme, Icon>> titlePaneIcons = SubstanceIconFactory
 			.createTitlePaneIcons();
 
 	/**
@@ -1036,13 +1016,17 @@ public class SubstanceIconFactory {
 	 * 
 	 * @return Empty map of title pane icons.
 	 */
-	private static Map<IconKind, Map<SubstanceTheme, Icon>> createTitlePaneIcons() {
-		Map<IconKind, Map<SubstanceTheme, Icon>> result = new HashMap<IconKind, Map<SubstanceTheme, Icon>>();
+	private static Map<IconKind, Map<SubstanceColorScheme, Icon>> createTitlePaneIcons() {
+		Map<IconKind, Map<SubstanceColorScheme, Icon>> result = new HashMap<IconKind, Map<SubstanceColorScheme, Icon>>();
 
-		result.put(IconKind.CLOSE, new HashMap<SubstanceTheme, Icon>());
-		result.put(IconKind.MINIMIZE, new HashMap<SubstanceTheme, Icon>());
-		result.put(IconKind.MAXIMIZE, new HashMap<SubstanceTheme, Icon>());
-		result.put(IconKind.RESTORE, new HashMap<SubstanceTheme, Icon>());
+		result.put(IconKind.CLOSE, new HashMap<SubstanceColorScheme, Icon>());
+		result
+				.put(IconKind.MINIMIZE,
+						new HashMap<SubstanceColorScheme, Icon>());
+		result
+				.put(IconKind.MAXIMIZE,
+						new HashMap<SubstanceColorScheme, Icon>());
+		result.put(IconKind.RESTORE, new HashMap<SubstanceColorScheme, Icon>());
 		return result;
 	}
 
@@ -1051,33 +1035,33 @@ public class SubstanceIconFactory {
 	 * 
 	 * @param iconKind
 	 *            Icon kind.
-	 * @param theme
+	 * @param scheme
 	 *            Substance theme.
 	 * @return Title pane icon of the specified kind.
 	 */
-	public static synchronized Icon getTitlePaneIcon(IconKind iconKind,
-			SubstanceTheme theme) {
-		Map<SubstanceTheme, Icon> kindMap = SubstanceIconFactory.titlePaneIcons
+	public static Icon getTitlePaneIcon(IconKind iconKind,
+			SubstanceColorScheme scheme) {
+		Map<SubstanceColorScheme, Icon> kindMap = SubstanceIconFactory.titlePaneIcons
 				.get(iconKind);
-		Icon result = kindMap.get(theme);
+		Icon result = kindMap.get(scheme);
 		if (result != null)
 			return result;
 
 		switch (iconKind) {
 		case CLOSE:
-			result = SubstanceImageCreator.getCloseIcon(theme);
+			result = SubstanceImageCreator.getCloseIcon(scheme);
 			break;
 		case MINIMIZE:
-			result = SubstanceImageCreator.getMinimizeIcon(theme);
+			result = SubstanceImageCreator.getMinimizeIcon(scheme);
 			break;
 		case MAXIMIZE:
-			result = SubstanceImageCreator.getMaximizeIcon(theme);
+			result = SubstanceImageCreator.getMaximizeIcon(scheme);
 			break;
 		case RESTORE:
-			result = SubstanceImageCreator.getRestoreIcon(theme);
+			result = SubstanceImageCreator.getRestoreIcon(scheme);
 			break;
 		}
-		kindMap.put(theme, result);
+		kindMap.put(scheme, result);
 		return result;
 	}
 
