@@ -31,13 +31,13 @@ package org.jvnet.substance.utils.icon;
 
 import java.awt.*;
 import java.awt.image.BufferedImage;
-import java.util.Map;
 
 import javax.swing.*;
 
 import org.jvnet.lafwidget.animation.FadeKind;
 import org.jvnet.lafwidget.animation.FadeState;
-import org.jvnet.substance.theme.SubstanceTheme;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
 import org.jvnet.substance.utils.*;
 
 /**
@@ -58,13 +58,13 @@ public class TransitionAwareIcon implements Icon {
 	 */
 	public static interface Delegate {
 		/**
-		 * Returns the icon that matches the specified theme.
+		 * Returns the icon that matches the specified scheme.
 		 * 
-		 * @param theme
-		 *            Theme.
-		 * @return Icon that matches the specified theme.
+		 * @param scheme
+		 *            Color scheme.
+		 * @return Icon that matches the specified scheme.
 		 */
-		public Icon getThemeIcon(SubstanceTheme theme);
+		public Icon getColorSchemeIcon(SubstanceColorScheme scheme);
 	}
 
 	/**
@@ -80,14 +80,18 @@ public class TransitionAwareIcon implements Icon {
 	/**
 	 * Delegate to compute the actual icons.
 	 */
-	private Delegate delegate;
+	protected Delegate delegate;
 
 	/**
 	 * Icon cache to speed up the subsequent icon painting. The basic assumption
 	 * is that the {@link #delegate} returns an icon that paints the same for
 	 * the same parameters.
 	 */
-	private Map<String, Icon> iconMap;
+	private LazyResettableHashMap<Icon> iconMap;
+
+	private int iconWidth;
+
+	private int iconHeight;
 
 	/**
 	 * Creates a new transition-aware icon.
@@ -116,7 +120,16 @@ public class TransitionAwareIcon implements Icon {
 		this.comp = comp;
 		this.model = model;
 		this.delegate = delegate;
-		this.iconMap = new SoftHashMap<String, Icon>();
+		String suffix = (comp == null) ? "null" : comp.getClass()
+				.getSimpleName();
+		this.iconMap = new LazyResettableHashMap<Icon>("TransitionAwareIcon."
+				+ suffix);
+		this.iconWidth = this.delegate.getColorSchemeIcon(
+				SubstanceColorSchemeUtilities.getColorScheme(comp,
+						ComponentState.DEFAULT)).getIconWidth();
+		this.iconHeight = this.delegate.getColorSchemeIcon(
+				SubstanceColorSchemeUtilities.getColorScheme(comp,
+						ComponentState.DEFAULT)).getIconHeight();
 	}
 
 	/**
@@ -124,45 +137,49 @@ public class TransitionAwareIcon implements Icon {
 	 * 
 	 * @return Icon to paint.
 	 */
-	private Icon getIconToPaint() {
+	private Icon getIconToPaint(Component c) {
 		ComponentState currState = ComponentState.getState(this.model,
 				this.comp);
 		ComponentState prevState = SubstanceCoreUtilities
 				.getPrevComponentState(this.comp);
 		if (!currState.isKindActive(FadeKind.ENABLE))
 			prevState = currState;
-		float cyclePos = currState.getCycleCount();
-		SubstanceTheme mainTheme = SubstanceThemeUtilities.getTheme(this.comp);
-		SubstanceTheme currTheme = SubstanceThemeUtilities.getTheme(this.comp,
-				currState);
+		float cyclePos = currState.getCyclePosition();
+		// ColorScheme mainScheme =
+		// SubstanceThemeUtilities.getScheme(this.comp);
+		SubstanceColorScheme currScheme = SubstanceColorSchemeUtilities
+				.getColorScheme(this.comp, currState);
 
-		SubstanceTheme prevTheme = currTheme;
+		SubstanceColorScheme prevScheme = currScheme;
 
 		FadeState fadeState = SubstanceFadeUtilities.getFadeState(this.comp,
 				FadeKind.ROLLOVER, FadeKind.SELECTION, FadeKind.PRESS,
 				FadeKind.ARM);
 		if (fadeState != null) {
-			prevTheme = SubstanceThemeUtilities.getTheme(this.comp, prevState);
+			prevScheme = SubstanceColorSchemeUtilities.getColorScheme(
+					this.comp, prevState);
 			cyclePos = fadeState.getFadePosition();
 			if (!fadeState.isFadingIn())
-				cyclePos = 10 - cyclePos;
+				cyclePos = 1.0f - cyclePos;
 		}
-		float currAlpha = mainTheme.getThemeAlpha(this.comp, currState);
-		float prevAlpha = mainTheme.getThemeAlpha(this.comp, prevState);
+		float currAlpha = SubstanceColorSchemeUtilities.getAlpha(this.comp,
+				currState);
+		float prevAlpha = SubstanceColorSchemeUtilities.getAlpha(this.comp,
+				prevState);
 
-		String key = currTheme.getDisplayName() + ":"
-				+ prevTheme.getDisplayName() + ":" + currAlpha + ":"
-				+ prevAlpha + ":" + cyclePos;
+		HashMapKey key = SubstanceCoreUtilities.getHashKey(currScheme
+				.getDisplayName(), prevScheme.getDisplayName(), currAlpha,
+				prevAlpha, cyclePos);
 		// System.out.println(key);
 		if (!this.iconMap.containsKey(key)) {
-			Icon icon = this.delegate.getThemeIcon(currTheme);
-			Icon prevIcon = this.delegate.getThemeIcon(prevTheme);
+			Icon icon = this.delegate.getColorSchemeIcon(currScheme);
+			Icon prevIcon = this.delegate.getColorSchemeIcon(prevScheme);
 
 			BufferedImage temp = SubstanceCoreUtilities.getBlankImage(icon
 					.getIconWidth(), icon.getIconHeight());
 			Graphics2D g2d = temp.createGraphics();
 
-			if (currTheme == prevTheme) {
+			if (currScheme == prevScheme) {
 				// same theme - can paint just the current icon, no matter
 				// what the cycle position is.
 				g2d.setComposite(AlphaComposite.getInstance(
@@ -170,15 +187,13 @@ public class TransitionAwareIcon implements Icon {
 				icon.paintIcon(this.comp, g2d, 0, 0);
 			} else {
 				// make optimizations for limit values of the cycle position.
-				if (cyclePos < 10.0f) {
-					g2d.setComposite(AlphaComposite.getInstance(
-							AlphaComposite.SRC_OVER, prevAlpha));
+				if (cyclePos < 1.0f) {
+					g2d.setComposite(AlphaComposite.SrcOver.derive(prevAlpha));
 					prevIcon.paintIcon(this.comp, g2d, 0, 0);
 				}
 				if (cyclePos > 0.0f) {
-					g2d.setComposite(AlphaComposite.getInstance(
-							AlphaComposite.SRC_OVER, currAlpha * cyclePos
-									/ 10.0f));
+					g2d.setComposite(AlphaComposite.SrcOver.derive(currAlpha
+							* cyclePos));
 					icon.paintIcon(this.comp, g2d, 0, 0);
 				}
 			}
@@ -187,7 +202,23 @@ public class TransitionAwareIcon implements Icon {
 			g2d.dispose();
 		}
 
-		return this.iconMap.get(key);
+		Icon result = this.iconMap.get(key);
+		// if (result.getIconHeight() != this.getIconHeight())
+		// throw new IllegalStateException("Component "
+		// + comp.getClass().getSimpleName() + "[@" + comp.hashCode()
+		// + "] in " + comp.getParent().getClass().getSimpleName()
+		// + "[@" + comp.getParent().hashCode()
+		// + "] - unexpected height mismatch : "
+		// + result.getIconHeight() + ":" + this.getIconHeight());
+		// if (result.getIconWidth() != this.getIconWidth())
+		// throw new IllegalStateException("Component "
+		// + comp.getClass().getSimpleName() + "[@" + comp.hashCode()
+		// + "] in " + comp.getParent().getClass().getSimpleName()
+		// + "[@" + comp.getParent().hashCode()
+		// + "] - unexpected width mismatch : "
+		// + result.getIconWidth() + ":" + this.getIconWidth());
+
+		return result;
 	}
 
 	/*
@@ -196,7 +227,7 @@ public class TransitionAwareIcon implements Icon {
 	 * @see javax.swing.Icon#getIconHeight()
 	 */
 	public int getIconHeight() {
-		return this.getIconToPaint().getIconHeight();
+		return this.iconHeight;
 	}
 
 	/*
@@ -205,16 +236,16 @@ public class TransitionAwareIcon implements Icon {
 	 * @see javax.swing.Icon#getIconWidth()
 	 */
 	public int getIconWidth() {
-		return this.getIconToPaint().getIconWidth();
+		return this.iconWidth;
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
 	 * @see javax.swing.Icon#paintIcon(java.awt.Component, java.awt.Graphics,
-	 *      int, int)
+	 * int, int)
 	 */
 	public void paintIcon(Component c, Graphics g, int x, int y) {
-		this.getIconToPaint().paintIcon(c, g, x, y);
+		this.getIconToPaint(c).paintIcon(c, g, x, y);
 	}
 }
