@@ -41,15 +41,13 @@ import javax.swing.plaf.basic.BasicHTML;
 import javax.swing.text.View;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
-import org.jvnet.substance.*;
-import org.jvnet.substance.painter.text.SubstanceTextPainter;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
+import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.ComponentState;
+import org.jvnet.substance.api.SubstanceConstants.MenuGutterFillKind;
+import org.jvnet.substance.utils.*;
 
 /**
- * A collection of ugly finctions from
- * {@link javax.swing.plaf.basic.BasicMenuItemUI} since they are private. This
- * class is <b>for internal use only</b>.
+ * Menu-related utilities.
  * 
  * @author Kirill Grouchnikov
  */
@@ -60,299 +58,183 @@ public class MenuUtilities {
 	private static SubstanceMenuBackgroundDelegate backgroundDelegate = new SubstanceMenuBackgroundDelegate(
 			0.4f);
 
-	public static final String LAYOUT_METRICS = "substancelaf.internal.menus.layoutMetrics";
+	/**
+	 * Key to store the layout metrics. The value should be an instance of
+	 * {@link MenuLayoutMetrics}.
+	 */
+	private static final String LAYOUT_METRICS = "substancelaf.internal.menus.layoutMetrics";
 
-	public static final String GUTTER_X = "substancelaf.internal.menus.gutterX";
+	/**
+	 * Key to store the gutter X location. The value should be an instance of
+	 * {@link Integer}.
+	 */
+	private static final String GUTTER_X = "substancelaf.internal.menus.gutterX";
 
+	public static final String LAYOUT_INFO = "substancelaf.internal.menus.layoutInfo";
+
+	/**
+	 * Listener to track changes in the menu items. Once any property has been
+	 * changed, the popup layout metrics on the menu item and its parent popup
+	 * menu are cleared.
+	 * 
+	 * @author Kirill Grouchnikov
+	 */
 	public static class MenuPropertyListener implements PropertyChangeListener {
-		protected JMenuItem menuItem;
+		/**
+		 * Associated menu item.
+		 */
+		private JMenuItem menuItem;
 
-		public MenuPropertyListener(JMenuItem menuItem) {
+		/**
+		 * Runnable instance to clean the layout metrics.
+		 */
+		private Runnable cleanLayoutMetricsRunnable;
+
+		/**
+		 * Creates a new listener.
+		 * 
+		 * @param menuItem
+		 *            Menu item.
+		 */
+		public MenuPropertyListener(final JMenuItem menuItem) {
 			this.menuItem = menuItem;
+			this.cleanLayoutMetricsRunnable = new Runnable() {
+				public void run() {
+					MenuUtilities.cleanPopupLayoutMetrics(menuItem);
+				}
+			};
 		}
 
+		/**
+		 * Installs the property change listener on the associated menu item.
+		 */
 		public void install() {
 			this.menuItem.addPropertyChangeListener(this);
 		}
 
+		/**
+		 * Uninstalls the property change listener from the associated menu
+		 * item.
+		 */
 		public void uninstall() {
 			this.menuItem.removePropertyChangeListener(this);
 		}
 
+		/*
+		 * (non-Javadoc)
+		 * 
+		 * @seejava.beans.PropertyChangeListener#propertyChange(java.beans.
+		 * PropertyChangeEvent)
+		 */
 		public void propertyChange(PropertyChangeEvent evt) {
-			// if (!evt.getPropertyName().equals(
-			// SubstanceMenu.SINGLE_MENU_TEXT_OFFSET))
-			// SwingUtilities.invokeLater(new Runnable() {
-			// public void run() {
-			// menuItem.putClientProperty(
-			// SubstanceMenu.SINGLE_MENU_TEXT_OFFSET, null);
-			// if (menuItem.getParent() instanceof JPopupMenu) {
-			// JPopupMenu parent = (JPopupMenu) menuItem
-			// .getParent();
-			// parent
-			// .putClientProperty(
-			// SubstanceMenu.SINGLE_MENU_TEXT_OFFSET,
-			// null);
-			// }
-			// }
-			// });
 			if (!evt.getPropertyName().equals(MenuUtilities.LAYOUT_METRICS)) {
-				SwingUtilities.invokeLater(new Runnable() {
-					public void run() {
-						MenuUtilities.cleanPopupLayoutMetrics(menuItem);
-					}
-				});
+				SwingUtilities.invokeLater(cleanLayoutMetricsRunnable);
 			}
 		}
-
 	}
 
+	/**
+	 * Layout information for a single menu item.
+	 * 
+	 * @author Kirill Grouchnikov
+	 */
 	public static class MenuLayoutInfo {
+		/**
+		 * View rectangle.
+		 */
 		public Rectangle viewRect;
+
+		/**
+		 * Icon rectangle.
+		 */
 		public Rectangle iconRect;
+
+		/**
+		 * Check icon rectangle.
+		 */
 		public Rectangle checkIconRect;
+
+		/**
+		 * Text rectangle.
+		 */
 		public Rectangle textRect;
+
+		/**
+		 * Accelerator rectangle.
+		 */
 		public Rectangle acceleratorRect;
+
+		/**
+		 * Arrow icon rectangle.
+		 */
 		public Rectangle arrowIconRect;
+
+		/**
+		 * Menu item text.
+		 */
 		public String text;
 	}
 
+	/**
+	 * Layout metrics for a single popup menu. All menu items in a popup menu
+	 * share the same metrics so that different parts (icons, check icons,
+	 * texts, accelerator texts and arrow icons) are vertically aligned.
+	 * 
+	 * @author Kirill Grouchnikov
+	 */
 	public static class MenuLayoutMetrics {
+		/**
+		 * Maximum width of icons of the menu items of this popup menu.
+		 */
 		public int maxIconWidth;
+
+		/**
+		 * Maximum width of check icons of the menu items of this popup menu.
+		 */
 		public int maxCheckIconWidth;
+
+		/**
+		 * Maximum width of texts of the menu items of this popup menu.
+		 */
 		public int maxTextWidth;
+
+		/**
+		 * Maximum width of accelerator texts of the menu items of this popup
+		 * menu.
+		 */
 		public int maxAcceleratorWidth;
+
+		/**
+		 * Maximum width of arrow icons of the menu items of this popup menu.
+		 */
 		public int maxArrowIconWidth;
-		public int maxGap;
+
+		/**
+		 * Maximum gap between icon and text of the menu items of this popup
+		 * menu.
+		 */
+		public int maxIconTextGap;
 	}
 
-	/* Client Property keys for the icon and text maximal offsets */
-	// static final StringBuffer MAX_ICON_OFFSET = new StringBuffer(
-	// "maxIconOffset");
-	//
-	// static final StringBuffer MAX_TEXT_OFFSET = new StringBuffer(
-	// "maxTextOffset");
-	//
-	// public static int getTextOffset(Component menuItemParent) {
-	// if (!(menuItemParent instanceof JPopupMenu)) {
-	// return 0;
-	// }
-	//
-	// return getTextOffset(null, menuItemParent);
-	// }
-	// private static int getSingleItemTextOffset(JMenuItem menuItem) {
-	// // Check if we have this property on the menu item.
-	// Object prop = menuItem
-	// .getClientProperty(SubstanceMenu.SINGLE_MENU_TEXT_OFFSET);
-	// if (prop instanceof Integer) {
-	// // This property is reset on every property change
-	// // to the menu item. If the property exists, nothing
-	// // has changed since the last time it was computed.
-	// return (Integer) prop;
-	// }
-	//
-	// SubstanceMenu ui = (SubstanceMenu) menuItem.getUI();
-	// int result = MenuUtilities.getTextOffset(menuItem, ui
-	// .getAcceleratorFont(), ui.getCheckIcon(), ui.getArrowIcon(), ui
-	// .getDefaultTextIconGap());
-	// // Now that the offset has been computed, set it on the menu item.
-	// menuItem.putClientProperty(SubstanceMenu.SINGLE_MENU_TEXT_OFFSET,
-	// result);
-	// return result;
-	// }
-	// public static int getTextOffset(JMenuItem menuItem) {
-	// return getTextOffset(menuItem, menuItem.getParent());
-	// }
-	//
-	// public static int getTextOffset(JMenuItem menuItem, Component parent) {
-	// if (!(parent instanceof JPopupMenu)) {
-	// return getSingleItemTextOffset(menuItem);
-	// }
-	//
-	// // test if there's a computed property on the parent
-	// JPopupMenu popupMenu = (JPopupMenu) parent;
-	// Object prop = popupMenu
-	// .getClientProperty(SubstanceMenu.SINGLE_MENU_TEXT_OFFSET);
-	// if (prop instanceof Integer) {
-	// // This property is reset on every change to both the
-	// // popup (adding / removing child menu component) and
-	// // and each child component (on any property change).
-	// // So, if this property exists on the popup menu, nothing
-	// // has changed since the last time the offset was computed.
-	// return (Integer) prop;
-	// }
-	// int maxTextOffset = -1;
-	// int maxIconWidth = 0;
-	// int maxIconX = 0;
-	// int maxCheckIconX = 0;
-	// int maxCheckIconWidth = 0;
-	// // int maxViewRect = 0;
-	// for (int i = 0; i < popupMenu.getComponentCount(); i++) {
-	// Component comp = popupMenu.getComponent(i);
-	// if (comp instanceof JMenuItem) {
-	// JMenuItem childMenuItem = (JMenuItem) comp;
-	// ButtonUI bui = childMenuItem.getUI();
-	// if (!(bui instanceof SubstanceMenu))
-	// continue;
-	// SubstanceMenu ui = (SubstanceMenu) bui;
-	// MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(
-	// childMenuItem, ui.getAcceleratorFont(), ui
-	// .getCheckIcon(), ui.getArrowIcon(), ui
-	// .getDefaultTextIconGap());
-	//
-	// if (popupMenu.getComponentOrientation().isLeftToRight()) {
-	// if (mli.textRect != null) {
-	// maxTextOffset = Math.max(maxTextOffset, mli.textRect.x);
-	// }
-	// if (mli.iconRect != null) {
-	// maxIconWidth = Math
-	// .max(maxIconWidth, mli.iconRect.width
-	// + ui.getDefaultTextIconGap());
-	// maxIconX = Math.max(maxIconX, mli.iconRect.x);
-	// }
-	// if (mli.checkIconRect != null) {
-	// maxCheckIconWidth = Math.max(maxCheckIconWidth,
-	// mli.checkIconRect.width + 2
-	// * ui.getDefaultTextIconGap());
-	// maxCheckIconX = Math.max(maxCheckIconX,
-	// mli.checkIconRect.x);
-	// }
-	// } else {
-	// if (mli.textRect != null) {
-	// maxTextOffset = Math.max(maxTextOffset, mli.viewRect.x
-	// + mli.viewRect.width
-	// - (mli.textRect.x + mli.textRect.width));
-	// }
-	// if (mli.iconRect != null) {
-	// maxIconWidth = Math.max(maxIconWidth,
-	// mli.iconRect.width + 2
-	// * ui.getDefaultTextIconGap());
-	// maxIconX = Math.max(maxIconX, mli.iconRect.x
-	// + mli.iconRect.width);
-	// }
-	// if (mli.checkIconRect != null) {
-	// maxCheckIconWidth = Math.max(maxCheckIconWidth,
-	// mli.checkIconRect.width
-	// + ui.getDefaultTextIconGap());
-	// maxCheckIconX = Math.max(maxCheckIconX,
-	// mli.checkIconRect.x + mli.checkIconRect.width);
-	// }
-	// // maxViewRect = Math.max(maxViewRect, mli.viewRect.x
-	// // + mli.viewRect.width);
-	// }
-	//
-	// //
-	// // int childResult = MenuUtilities.getTextOffset(g,
-	// // childMenuItem,
-	// // ui.getAcceleratorFont(), ui.getCheckIcon(), ui
-	// // .getArrowIcon(), ui.getDefaultTextIconGap());
-	// // if (maxOffset < childResult)
-	// // maxOffset = childResult;
-	// }
-	// }
-	// // Now that the offset is computed, store it on the
-	// // popup menu.
-	// int maxOffset = Math.max(maxTextOffset, maxIconWidth
-	// + maxCheckIconWidth);
-	// if (popupMenu.getComponentOrientation().isLeftToRight()) {
-	// maxOffset = Math.max(maxOffset, maxIconX + maxIconWidth);
-	// maxOffset = Math.max(maxOffset, maxCheckIconX + maxCheckIconWidth);
-	// } else {
-	// // maxOffset = Math.max(maxOffset, maxViewRect
-	// // - (maxIconX - maxIconWidth));
-	// }
-	// popupMenu.putClientProperty(SubstanceMenu.SINGLE_MENU_TEXT_OFFSET,
-	// maxOffset);
-	// return maxOffset;
-	// }
-	//
-	// public static int getTextOffset(JMenuItem menuItem, Font acceleratorFont,
-	// Icon checkIcon, Icon arrowIcon, int defaultTextIconGap) {
-	//
-	// // Dimension size = b.getSize();
-	// // int menuWidth = menuItem.getWidth();
-	// // int menuHeight = menuItem.getHeight();
-	// Insets i = menuItem.getInsets();
-	//
-	// Rectangle iconRect = new Rectangle();
-	// Rectangle textRect = new Rectangle();
-	// Rectangle acceleratorRect = new Rectangle();
-	// Rectangle checkIconRect = new Rectangle();
-	// Rectangle arrowIconRect = new Rectangle();
-	// Rectangle viewRect = new Rectangle(Short.MAX_VALUE, Short.MAX_VALUE);
-	//
-	// int menuWidth = menuItem.getWidth();
-	// int menuHeight = menuItem.getHeight();
-	// if ((menuWidth > 0) && (menuHeight > 0))
-	// viewRect.setBounds(0, 0, menuWidth, menuHeight);
-	//
-	// // fix for defect 108 - failed on b62 of Mustang and later on Hebrew
-	// // localized menu strings.
-	// // viewRect.setBounds(0, 0, menuWidth, menuHeight);
-	//
-	// viewRect.x += i.left;
-	// viewRect.y += i.top;
-	// viewRect.width -= (i.right + viewRect.x);
-	// viewRect.height -= (i.bottom + viewRect.y);
-	//
-	// FontMetrics fm = menuItem.getFontMetrics(menuItem.getFont());
-	// FontMetrics fmAccel = menuItem.getFontMetrics(acceleratorFont);
-	//
-	// // get Accelerator text
-	// KeyStroke accelerator = menuItem.getAccelerator();
-	// String acceleratorText = "";
-	// if (accelerator != null) {
-	// int modifiers = accelerator.getModifiers();
-	// if (modifiers > 0) {
-	// acceleratorText = KeyEvent.getKeyModifiersText(modifiers);
-	// // acceleratorText += "-";
-	// acceleratorText += UIManager
-	// .getString("MenuItem.acceleratorDelimiter");
-	// }
-	//
-	// int keyCode = accelerator.getKeyCode();
-	// if (keyCode != 0) {
-	// acceleratorText += KeyEvent.getKeyText(keyCode);
-	// } else {
-	// acceleratorText += accelerator.getKeyChar();
-	// }
-	// }
-	//
-	// // layout the text and icon
-	// layoutMenuItem(menuItem, fm, menuItem.getText(), fmAccel,
-	// acceleratorText, menuItem.getIcon(), checkIcon, arrowIcon,
-	// menuItem.getVerticalAlignment(), menuItem
-	// .getHorizontalAlignment(), menuItem
-	// .getVerticalTextPosition(), menuItem
-	// .getHorizontalTextPosition(), viewRect, iconRect,
-	// textRect, acceleratorRect, checkIconRect, arrowIconRect,
-	// menuItem.getText() == null ? 0 : defaultTextIconGap,
-	// defaultTextIconGap);
-	//
-	// if (menuItem.getComponentOrientation().isLeftToRight()) {
-	// return textRect.x;
-	// } else {
-	// // int result = viewRect.x + viewRect.width;
-	// // if (iconRect.width != 0) {
-	// // result -= (iconRect.x + defaultTextIconGap);
-	// // }
-	// // else {
-	// // if (checkIconRect.width != 0) {
-	// // result -= (checkIconRect.x + defaultTextIconGap);
-	// // }
-	// // }
-	// return viewRect.x + viewRect.width - iconRect.x
-	// - ((iconRect.width != 0) ? 0 : defaultTextIconGap);
-	// }
-	// }
-	public static MenuLayoutInfo getMenuLayoutInfo(
-			// Graphics g,
+	/**
+	 * Returns the layout info for the specified menu item.
+	 * 
+	 * @param menuItem
+	 *            Menu item.
+	 * @param acceleratorFont
+	 *            Font for the accelerator text.
+	 * @param checkIcon
+	 *            Check icon.
+	 * @param arrowIcon
+	 *            Arrow icon.
+	 * @param defaultTextIconGap
+	 *            Gap between the icon and the text.
+	 * @return Layout info for the specified menu item.
+	 */
+	public static MenuLayoutInfo getMenuLayoutInfo(boolean forPainting,
 			JMenuItem menuItem, Font acceleratorFont, Icon checkIcon,
 			Icon arrowIcon, int defaultTextIconGap) {
 
-		// Dimension size = b.getSize();
-		// int menuWidth = menuItem.getWidth();
-		// int menuHeight = menuItem.getHeight();
 		Insets i = menuItem.getInsets();
 
 		Rectangle iconRect = new Rectangle(0, 0, 0, 0);
@@ -362,22 +244,20 @@ public class MenuUtilities {
 		Rectangle arrowIconRect = new Rectangle(0, 0, 0, 0);
 		Rectangle viewRect = new Rectangle(Short.MAX_VALUE, Short.MAX_VALUE);
 
-		int menuWidth = menuItem.getWidth();
-		int menuHeight = menuItem.getHeight();
-		if ((menuWidth > 0) && (menuHeight > 0))
-			viewRect.setBounds(0, 0, menuWidth, menuHeight);
+		if (forPainting) {
+			// fix for issue 379 - setting the available
+			// bounds only during the painting.
+			int menuWidth = menuItem.getWidth();
+			int menuHeight = menuItem.getHeight();
+			if ((menuWidth > 0) && (menuHeight > 0))
+				viewRect.setBounds(0, 0, menuWidth, menuHeight);
 
-		// fix for defect 108 - failed on b62 of Mustang and later on Hebrew
-		// localized menu strings.
-		// viewRect.setBounds(0, 0, menuWidth, menuHeight);
+			viewRect.x += i.left;
+			viewRect.y += i.top;
+			viewRect.width -= (i.right + viewRect.x);
+			viewRect.height -= (i.bottom + viewRect.y);
+		}
 
-		viewRect.x += i.left;
-		viewRect.y += i.top;
-		viewRect.width -= (i.right + viewRect.x);
-		viewRect.height -= (i.bottom + viewRect.y);
-
-		// Font f = menuItem.getFont();
-		// g.setFont(f);
 		FontMetrics fm = menuItem.getFontMetrics(menuItem.getFont());
 		FontMetrics fmAccel = menuItem.getFontMetrics(acceleratorFont);
 
@@ -413,11 +293,6 @@ public class MenuUtilities {
 				defaultTextIconGap);
 
 		MenuLayoutInfo mlInfo = new MenuLayoutInfo();
-		// mlInfo.checkIconRect = (checkIconRect.width > 0) ? checkIconRect :
-		// null;
-		// mlInfo.iconRect = (iconRect.width > 0) ? iconRect : null;
-		// mlInfo.textRect = (textRect.width > 0) ? textRect : null;
-		// mlInfo.viewRect = (viewRect.width > 0) ? viewRect : null;
 		mlInfo.checkIconRect = checkIconRect;
 		mlInfo.iconRect = iconRect;
 		mlInfo.textRect = textRect;
@@ -427,22 +302,6 @@ public class MenuUtilities {
 		mlInfo.text = text;
 
 		return mlInfo;
-		//		
-		// if (menuItem.getComponentOrientation().isLeftToRight()) {
-		// return textRect.x;
-		// } else {
-		// // int result = viewRect.x + viewRect.width;
-		// // if (iconRect.width != 0) {
-		// // result -= (iconRect.x + defaultTextIconGap);
-		// // }
-		// // else {
-		// // if (checkIconRect.width != 0) {
-		// // result -= (checkIconRect.x + defaultTextIconGap);
-		// // }
-		// // }
-		// return viewRect.x + viewRect.width - iconRect.x
-		// - ((iconRect.width != 0) ? 0 : defaultTextIconGap);
-		// }
 	}
 
 	/**
@@ -580,25 +439,25 @@ public class MenuUtilities {
 		}
 	}
 
-	// public static void lineupTextRectangle(JMenuItem menuItem,
-	// Rectangle textRect, Font acceleratorFont, Icon checkIcon,
-	// Icon arrowIcon, int defaultTextIconGap) {
-	// if (textRect == null)
-	// return;
-	// int textOffset = MenuUtilities.getTextOffset(menuItem);
-	// // System.out.println()
-	// if (menuItem.getComponentOrientation().isLeftToRight()) {
-	// textRect.setLocation(textOffset, textRect.y);
-	// } else {
-	// int loc = menuItem.getWidth() - textOffset - textRect.width
-	// - defaultTextIconGap;
-	// textRect.setLocation(loc, textRect.y);
-	// }
-	//
-	// }
-
+	/**
+	 * Paints the specified menu item.
+	 * 
+	 * @param g
+	 *            Graphics context.
+	 * @param menuItem
+	 *            Menu item.
+	 * @param checkIcon
+	 *            Check icon.
+	 * @param arrowIcon
+	 *            Arrow icon.
+	 * @param defaultTextIconGap
+	 *            Gap between the icon and the text.
+	 */
 	public static void paintMenuItem(Graphics g, JMenuItem menuItem,
 			Icon checkIcon, Icon arrowIcon, int defaultTextIconGap) {
+		if (!SubstanceLookAndFeel.isCurrentLookAndFeel())
+			return;
+
 		Graphics2D g2d = (Graphics2D) g.create();
 
 		// special handling of menu items covered by lightweight popups
@@ -661,11 +520,11 @@ public class MenuUtilities {
 		// .getAcceleratorFont(), menuUi.getCheckIcon(), menuUi
 		// .getArrowIcon(), menuUi.getDefaultTextIconGap());
 
-		MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(menuItem, menuUi
-				.getAcceleratorFont(), menuUi.getCheckIcon(), menuUi
-				.getArrowIcon(), menuUi.getDefaultTextIconGap());
-		MenuLayoutMetrics popupMetrics = MenuUtilities
-				.getPopupLayoutMetrics(menuItem);
+		MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(true, menuItem,
+				menuUi.getAcceleratorFont(), menuUi.getCheckIcon(), menuUi
+						.getArrowIcon(), menuUi.getDefaultTextIconGap());
+		MenuLayoutMetrics popupMetrics = MenuUtilities.getPopupLayoutMetrics(
+				menuItem, true);
 		Insets i = menuItem.getInsets();
 		// FontMetrics fm = menuItem.getFontMetrics(menuItem.getFont());
 		// int fontHeight = fm.getHeight();
@@ -674,7 +533,7 @@ public class MenuUtilities {
 					.getMenuGutterFillKind();
 			boolean needExtraIconTextGap = (gutterFillKind != null)
 					&& (gutterFillKind != MenuGutterFillKind.NONE);
-			int gap = popupMetrics.maxGap;
+			int gap = popupMetrics.maxIconTextGap;
 			if (menuItem.getComponentOrientation().isLeftToRight()) {
 				int currX = i.left + gap / 2;
 				if (checkIcon != null) {
@@ -828,6 +687,7 @@ public class MenuUtilities {
 				}
 			}
 		}
+		menuItem.putClientProperty(LAYOUT_INFO, mli);
 		Component parent = menuItem.getParent();
 		if (parent instanceof JPopupMenu) {
 			((JPopupMenu) parent).putClientProperty(GUTTER_X, menuItem
@@ -838,58 +698,35 @@ public class MenuUtilities {
 		// .getAcceleratorFont(), menuUi.getCheckIcon(), menuUi
 		// .getArrowIcon(), menuUi.getDefaultTextIconGap());
 
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		textPainter.init(menuItem, null, true);
-		if (textPainter.needsBackgroundImage()) {
-			// This is a workaround for disabled menu items. Since
-			// SWT (native) pipeline doesn't support painting translucent
-			// texts, we need a way to have the background painted in
-			// full opacity, but the texts (and highlights) painted with
-			// custom translucency. Here, we cheat and first paint the
-			// background fill (with watermark) with full opacity. Since
-			// there can be no highlights on disabled menu items, we don't
-			// need to worry about hightlights. Then, the painting will be done
-			// once again, overlaying the background, highlights and
-			// text with custom alpha factor.
-			paintBackground(g2d, menuItem);
-		}
-		textPainter.renderSurface(g2d);
-
-		// Paint background
-		textPainter.init(menuItem, null, true);
 		paintBackground(g2d, menuItem);
 		paintHighlights(g2d, menuItem);
 
-		float textAlpha = 1.0f;
+		Graphics2D graphics = (Graphics2D) g2d.create();
 		if (mli.text != null) {
 			View v = (View) menuItem.getClientProperty(BasicHTML.propertyKey);
 			if (v != null) {
-				v.paint(g2d, mli.textRect);
+				v.paint(graphics, mli.textRect);
 			} else {
-				textAlpha = SubstanceCoreUtilities.paintText(menuItem,
+				SubstanceTextUtilities.paintText(graphics, menuItem,
 						mli.textRect, mli.text, menuItem
 								.getDisplayedMnemonicIndex());
 			}
 		}
-
 		// Draw the Accelerator Text
 		if (acceleratorText != null && !acceleratorText.equals("")) {
-			SubstanceCoreUtilities.paintText(menuItem, mli.acceleratorRect,
-					acceleratorText, -1);
+			SubstanceTextUtilities.paintText(graphics, menuItem,
+					mli.acceleratorRect, acceleratorText, -1);
 		}
 
-		Graphics2D graphics = (Graphics2D) g2d.create();
+		float textAlpha = SubstanceColorSchemeUtilities.getAlpha(menuItem,
+				ComponentState.getState(menuItem.getModel(), menuItem, true));
+
 		graphics.setComposite(TransitionLayout.getAlphaComposite(menuItem,
 				textAlpha, g2d));
-
-		textPainter.renderSurface(graphics);
-		graphics.dispose();
-
 		// Paint the Check
 		if (checkIcon != null) {
 			if (useCheckAndArrow(menuItem))
-				checkIcon.paintIcon(menuItem, g2d, mli.checkIconRect.x,
+				checkIcon.paintIcon(menuItem, graphics, mli.checkIconRect.x,
 						mli.checkIconRect.y);
 		}
 
@@ -915,9 +752,10 @@ public class MenuUtilities {
 		// Paint the Arrow
 		if (arrowIcon != null) {
 			if (useCheckAndArrow(menuItem))
-				arrowIcon.paintIcon(menuItem, g2d, mli.arrowIconRect.x,
+				arrowIcon.paintIcon(menuItem, graphics, mli.arrowIconRect.x,
 						mli.arrowIconRect.y);
 		}
+		graphics.dispose();
 
 		// g2d.setColor(Color.red);
 		// if (mli.iconRect != null)
@@ -942,50 +780,45 @@ public class MenuUtilities {
 		g2d.dispose();
 	}
 
-	protected static void paintBackground(Graphics g, final JMenuItem menuItem) {
+	/**
+	 * Paints the background of the specified menu item.
+	 * 
+	 * @param g
+	 *            Graphics context.
+	 * @param menuItem
+	 *            Menu item.
+	 */
+	private static void paintBackground(Graphics g, JMenuItem menuItem) {
 		int textOffset = MenuUtilities.getTextOffset(menuItem, menuItem
 				.getParent());
 		// System.out.println(menuItem.getText() + ":" + textOffset);
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		final Color bgColor = SubstanceCoreUtilities
+		Color bgColor = SubstanceColorUtilities
 				.getBackgroundFillColor(menuItem);
-		final int finalTextOffset = textOffset;
-		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-			public void paintBackground(Graphics g) {
-				Graphics2D g2d = (Graphics2D) g.create();
-				backgroundDelegate.paintBackground(g, menuItem, bgColor, 0.5f,
-						finalTextOffset);
-				g2d.dispose();
-			}
-		};
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.setBackgroundFill(menuItem, bgColor, true, 0, 0);
-			textPainter.attachCallback(callback);
-		} else {
-			callback.paintBackground(g);
-		}
+		backgroundDelegate.paintBackground(g, menuItem, bgColor, 0.5f,
+				textOffset);
 	}
 
-	protected static void paintHighlights(Graphics g, final JMenuItem menuItem) {
-		SubstanceTextPainter textPainter = SubstanceLookAndFeel
-				.getCurrentTextPainter();
-		SubstanceTextPainter.BackgroundPaintingCallback callback = new SubstanceTextPainter.BackgroundPaintingCallback() {
-			public void paintBackground(Graphics g) {
-				Graphics2D g2d = (Graphics2D) g.create();
-				SubstanceMenuBackgroundDelegate.paintHighlights(g, menuItem,
-						0.5f);
-				g2d.dispose();
-			}
-		};
-		if (textPainter.needsBackgroundImage()) {
-			textPainter.attachCallback(callback);
-		} else {
-			callback.paintBackground(g);
-		}
+	/**
+	 * Paints the highlights of the specified menu item.
+	 * 
+	 * @param g
+	 *            Graphics context.
+	 * @param menuItem
+	 *            Menu item.
+	 */
+	private static void paintHighlights(Graphics g, JMenuItem menuItem) {
+		SubstanceMenuBackgroundDelegate.paintHighlights(g, menuItem, 0.5f);
 	}
 
-	protected static MenuLayoutMetrics getMetrics(JPopupMenu popupMenu) {
+	/**
+	 * Returns the layout metrics of the specified popup menu.
+	 * 
+	 * @param popupMenu
+	 *            Popup menu.
+	 * @return Layout metrics of the specified popup menu.
+	 */
+	protected static MenuLayoutMetrics getMetrics(JPopupMenu popupMenu,
+			boolean forPainting) {
 		MenuLayoutMetrics metrics = new MenuLayoutMetrics();
 		for (int i = 0; i < popupMenu.getComponentCount(); i++) {
 			Component comp = popupMenu.getComponent(i);
@@ -996,7 +829,7 @@ public class MenuUtilities {
 					continue;
 				SubstanceMenu ui = (SubstanceMenu) bui;
 				MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(
-						childMenuItem, ui.getAcceleratorFont(), ui
+						forPainting, childMenuItem, ui.getAcceleratorFont(), ui
 								.getCheckIcon(), ui.getArrowIcon(), ui
 								.getDefaultTextIconGap());
 				metrics.maxIconWidth = Math.max(metrics.maxIconWidth,
@@ -1009,14 +842,22 @@ public class MenuUtilities {
 						metrics.maxAcceleratorWidth, mli.acceleratorRect.width);
 				metrics.maxArrowIconWidth = Math.max(metrics.maxArrowIconWidth,
 						mli.arrowIconRect.width);
-				metrics.maxGap = Math.max(metrics.maxGap, ui
+				metrics.maxIconTextGap = Math.max(metrics.maxIconTextGap, ui
 						.getDefaultTextIconGap());
 			}
 		}
 		return metrics;
 	}
 
-	public static MenuLayoutMetrics getPopupLayoutMetrics(JMenuItem menuItem) {
+	/**
+	 * Returns the layout metrics of the popup menu of the specified menu item.
+	 * 
+	 * @param menuItem
+	 *            Menu item.
+	 * @return Layout metrics of the popup menu of the specified menu item.
+	 */
+	public static MenuLayoutMetrics getPopupLayoutMetrics(JMenuItem menuItem,
+			boolean forPainting) {
 		Component comp = menuItem.getParent();
 		if (comp instanceof JPopupMenu) {
 			JPopupMenu popupMenu = (JPopupMenu) comp;
@@ -1024,11 +865,10 @@ public class MenuUtilities {
 			if (prop instanceof MenuLayoutMetrics) {
 				return (MenuLayoutMetrics) prop;
 			}
-			MenuLayoutMetrics metrics = getMetrics(popupMenu);
+			MenuLayoutMetrics metrics = getMetrics(popupMenu, forPainting);
 			popupMenu.putClientProperty(LAYOUT_METRICS, metrics);
 			return metrics;
 		}
-
 		// fix for issue 347 - menu item in menu bar is not
 		// covered by the code above
 		if (!(comp instanceof JMenu)) {
@@ -1036,16 +876,17 @@ public class MenuUtilities {
 			if (bui instanceof SubstanceMenu) {
 				SubstanceMenu ui = (SubstanceMenu) bui;
 
-				MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(menuItem,
-						ui.getAcceleratorFont(), ui.getCheckIcon(), ui
-								.getArrowIcon(), ui.getDefaultTextIconGap());
+				MenuLayoutInfo mli = MenuUtilities.getMenuLayoutInfo(
+						forPainting, menuItem, ui.getAcceleratorFont(), ui
+								.getCheckIcon(), ui.getArrowIcon(), ui
+								.getDefaultTextIconGap());
 				MenuLayoutMetrics metrics = new MenuLayoutMetrics();
 				metrics.maxIconWidth = mli.iconRect.width;
 				metrics.maxCheckIconWidth = mli.checkIconRect.width;
 				metrics.maxTextWidth = mli.textRect.width;
 				metrics.maxAcceleratorWidth = mli.acceleratorRect.width;
 				metrics.maxArrowIconWidth = mli.arrowIconRect.width;
-				metrics.maxGap = ui.getDefaultTextIconGap();
+				metrics.maxIconTextGap = ui.getDefaultTextIconGap();
 				return metrics;
 			}
 		}
@@ -1055,7 +896,13 @@ public class MenuUtilities {
 		return null;
 	}
 
-	public static void cleanPopupLayoutMetrics(JMenuItem menuItem) {
+	/**
+	 * Cleans the layout metrics of the popup menu of the specified menu item.
+	 * 
+	 * @param menuItem
+	 *            Menu item.
+	 */
+	private static void cleanPopupLayoutMetrics(JMenuItem menuItem) {
 		Component comp = menuItem.getParent();
 		if (comp instanceof JPopupMenu) {
 			JPopupMenu popupMenu = (JPopupMenu) comp;
@@ -1063,16 +910,31 @@ public class MenuUtilities {
 		}
 	}
 
+	/**
+	 * Cleans the layout metrics of the specified popup menu.
+	 * 
+	 * @param popupMenu
+	 *            Popup menu.
+	 */
 	public static void cleanPopupLayoutMetrics(JPopupMenu popupMenu) {
 		if (popupMenu != null) {
 			popupMenu.putClientProperty(LAYOUT_METRICS, null);
 		}
 	}
 
+	/**
+	 * Returns the preferred width of the specified menu item. The preferred
+	 * width depends on the layout metrics of the entire popup menu of this menu
+	 * item.
+	 * 
+	 * @param menuItem
+	 *            Menu item.
+	 * @return Preferred width of the specified menu item
+	 */
 	public static int getPreferredWidth(JMenuItem menuItem) {
 		Insets ins = menuItem.getInsets();
-		MenuLayoutMetrics popupMetrics = MenuUtilities
-				.getPopupLayoutMetrics(menuItem);
+		MenuLayoutMetrics popupMetrics = MenuUtilities.getPopupLayoutMetrics(
+				menuItem, false);
 
 		int width = popupMetrics.maxCheckIconWidth + popupMetrics.maxIconWidth
 				+ popupMetrics.maxTextWidth + popupMetrics.maxAcceleratorWidth
@@ -1088,7 +950,7 @@ public class MenuUtilities {
 		if (popupMetrics.maxArrowIconWidth > 0)
 			gapsToAdd++;
 
-		int gap = popupMetrics.maxGap;
+		int gap = popupMetrics.maxIconTextGap;
 		width += ((1 + gapsToAdd) * gap);
 
 		if (popupMetrics.maxAcceleratorWidth > 0) {
@@ -1106,6 +968,15 @@ public class MenuUtilities {
 		return width;
 	}
 
+	/**
+	 * Returns the text offset of the specified menu item.
+	 * 
+	 * @param menuItem
+	 *            Menu item.
+	 * @param menuItemParent
+	 *            Menu item parent.
+	 * @return Text offset of the specified menu item.
+	 */
 	public static int getTextOffset(JComponent menuItem,
 			Component menuItemParent) {
 		if (!(menuItemParent instanceof JPopupMenu)) {
@@ -1123,18 +994,5 @@ public class MenuUtilities {
 			return (Integer) parentProp;
 		}
 		return 0;
-		// MenuLayoutMetrics metrics = getMetrics(popupMenu);
-		// if (popupMenu.getComponentOrientation().isLeftToRight()) {
-		// return SubstanceSizeUtils.getMenuItemMargin(SubstanceSizeUtils
-		// .getComponentFontSize(menuItem))
-		// + popupMenu.getInsets().left
-		// + metrics.maxCheckIconWidth
-		// + metrics.maxIconWidth
-		// + (int) (2.5 * SubstanceSizeUtils
-		// .getMenuTextIconGap(SubstanceSizeUtils
-		// .getComponentFontSize(popupMenu)));
-		// } else {
-		// return 0;
-		// }
 	}
 }
