@@ -34,15 +34,16 @@ import java.awt.image.BufferedImage;
 import java.io.File;
 import java.io.InputStream;
 import java.net.URL;
-import java.security.AccessControlException;
 
 import javax.imageio.IIOException;
 import javax.imageio.ImageIO;
 import javax.swing.JComponent;
 
+import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.SubstanceApi;
+import org.jvnet.substance.api.SubstanceSkin;
+import org.jvnet.substance.api.SubstanceConstants.ImageWatermarkKind;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceConstants.ImageWatermarkKind;
-import org.jvnet.substance.utils.params.ParamReader;
 
 /**
  * Implementation of {@link SubstanceWatermark}, drawing specified image as
@@ -56,17 +57,17 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	/**
 	 * Watermark image (screen-sized).
 	 */
-	protected static Image watermarkImage = null;
+	protected Image watermarkImage = null;
 
 	/**
 	 * Watermark image kind.
 	 */
-	private static ImageWatermarkKind kind = ImageWatermarkKind.SCREEN_CENTER_SCALE;
+	private ImageWatermarkKind kind = ImageWatermarkKind.SCREEN_CENTER_SCALE;
 
 	/**
 	 * Watermark image opacity.
 	 */
-	private static float opacity = 0.2f;
+	private float opacity = 0.2f;
 
 	/**
 	 * The original image (as read from the disk / HTTP connection).
@@ -78,30 +79,14 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	 */
 	protected String origImageLocation;
 
-	/**
-	 * Simple constructor. Uses {@link ParamReader#getWatermarkImageProperty()}
-	 * to retrieve the location of the image. Note that this constructor can
-	 * throw AccessControlException if this class is used in unsecure JNLP
-	 * environment. However, in this case we must have access to local disk in
-	 * any case since we need to read the image.
-	 * 
-	 * @param paramReader
-	 *            Substance parameter reader instance.
-	 * @throws AccessControlException
-	 *             if this class is used in unsecure JNLP environment
-	 */
-	public SubstanceImageWatermark(ParamReader paramReader)
-			throws AccessControlException {
-		this(paramReader.getWatermarkImageProperty());
-	}
-
 	/**
 	 * Creates an instance with specified image.
 	 * 
 	 * @param imageLocation
-	 *            Image location. Can point to a local file or HTTP URL (needs
-	 *            to start with <code>http</code> in the later case).
+	 * 		Image location. Can point to a local file or HTTP URL (needs to
+	 * 		start with <code>http</code> in the later case).
 	 */
+	@SubstanceApi
 	public SubstanceImageWatermark(String imageLocation) {
 		if (imageLocation != null) {
 			try {
@@ -136,8 +121,9 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	 * Creates an instance from the specified input stream.
 	 * 
 	 * @param inputStream
-	 *            Input stream.
+	 * 		Input stream.
 	 */
+	@SubstanceApi
 	public SubstanceImageWatermark(InputStream inputStream) {
 		if (inputStream != null) {
 			try {
@@ -156,8 +142,9 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#drawWatermarkImage(java.awt.Graphics,
-	 *      int, int, int, int)
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#drawWatermarkImage(java
+	 * .awt.Graphics, int, int, int, int)
 	 */
 	public void drawWatermarkImage(Graphics graphics, Component c, int x,
 			int y, int width, int height) {
@@ -203,16 +190,16 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 			dy -= (topParent.getHeight() / 2 - this.origImage.getHeight() / 2);
 		}
 
-		graphics.drawImage(SubstanceImageWatermark.watermarkImage, x, y, x
-				+ width, y + height, x + dx, y + dy, x + dx + width, y + dy
-				+ height, null);
+		graphics.drawImage(watermarkImage, x, y, x + width, y + height, x + dx,
+				y + dy, x + dx + width, y + dy + height, null);
 	}
 
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#previewWatermark(java.awt.Graphics,
-	 *      int, int, int, int)
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#previewWatermark(java
+	 * .awt.Graphics, int, int, int, int)
 	 */
 	public void previewWatermark(Graphics g, int x, int y, int width, int height) {
 	}
@@ -220,9 +207,11 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage()
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage
+	 * (org.jvnet.substance.skin.SubstanceSkin)
 	 */
-	public boolean updateWatermarkImage() {
+	public boolean updateWatermarkImage(SubstanceSkin skin) {
 		if (this.origImage == null) {
 			return false;
 		}
@@ -244,11 +233,11 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 		int origImageHeight = this.origImage.getHeight();
 
 		if (getKind() == ImageWatermarkKind.SCREEN_CENTER_SCALE) {
-			SubstanceImageWatermark.watermarkImage = SubstanceCoreUtilities
-					.getBlankImage(screenWidth, screenHeight);
+			watermarkImage = SubstanceCoreUtilities.getBlankImage(screenWidth,
+					screenHeight);
 
-			Graphics2D graphics = (Graphics2D) SubstanceImageWatermark.watermarkImage
-					.getGraphics().create();
+			Graphics2D graphics = (Graphics2D) watermarkImage.getGraphics()
+					.create();
 
 			Composite comp = AlphaComposite.getInstance(
 					AlphaComposite.SRC_OVER, opacity);
@@ -318,11 +307,11 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 
 		if ((getKind() == ImageWatermarkKind.SCREEN_TILE)
 				|| (getKind() == ImageWatermarkKind.APP_TILE)) {
-			SubstanceImageWatermark.watermarkImage = SubstanceCoreUtilities
-					.getBlankImage(screenWidth, screenHeight);
+			watermarkImage = SubstanceCoreUtilities.getBlankImage(screenWidth,
+					screenHeight);
 
-			Graphics2D graphics = (Graphics2D) SubstanceImageWatermark.watermarkImage
-					.getGraphics().create();
+			Graphics2D graphics = (Graphics2D) watermarkImage.getGraphics()
+					.create();
 
 			Composite comp = AlphaComposite.getInstance(
 					AlphaComposite.SRC_OVER, opacity);
@@ -343,11 +332,11 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 
 		if ((getKind() == ImageWatermarkKind.APP_ANCHOR)
 				|| (getKind() == ImageWatermarkKind.APP_CENTER)) {
-			SubstanceImageWatermark.watermarkImage = SubstanceCoreUtilities
-					.getBlankImage(origImageWidth, origImageHeight);
+			watermarkImage = SubstanceCoreUtilities.getBlankImage(
+					origImageWidth, origImageHeight);
 
-			Graphics2D graphics = (Graphics2D) SubstanceImageWatermark.watermarkImage
-					.getGraphics().create();
+			Graphics2D graphics = (Graphics2D) watermarkImage.getGraphics()
+					.create();
 
 			Composite comp = AlphaComposite.getInstance(
 					AlphaComposite.SRC_OVER, opacity);
@@ -364,30 +353,12 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#getDisplayName()
+	 * @see org.jvnet.substance.api.trait.SubstanceTrait#getDisplayName()
 	 */
 	public String getDisplayName() {
-		return SubstanceImageWatermark.getName();
-	}
-
-	/**
-	 * Returns the name of all watermarks of <code>this</code> class.
-	 * 
-	 * @return The name of all watermarks of <code>this</code> class.
-	 */
-	public static String getName() {
 		return "Image";
 	}
 
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#isDependingOnTheme()
-	 */
-	public boolean isDependingOnTheme() {
-		return true;
-	}
-
 	/*
 	 * (non-Javadoc)
 	 * 
@@ -410,14 +381,16 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	 * Sets image watermark kind.
 	 * 
 	 * @param kind
-	 *            Image watermark kind.
+	 * 		Image watermark kind.
 	 */
-	public static void setKind(ImageWatermarkKind kind) {
+	@SubstanceApi
+	public void setKind(ImageWatermarkKind kind) {
 		if (kind == null) {
 			throw new IllegalArgumentException(
 					"Can't pass null to SubstanceImageWatermark.setKind()");
 		}
-		SubstanceImageWatermark.kind = kind;
+		this.kind = kind;
+		this.updateWatermarkImage(SubstanceLookAndFeel.getCurrentSkin(null));
 	}
 
 	/**
@@ -425,8 +398,9 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	 * 
 	 * @return Image watermark kind.
 	 */
-	public static ImageWatermarkKind getKind() {
-		return kind;
+	@SubstanceApi
+	public ImageWatermarkKind getKind() {
+		return this.kind;
 	}
 
 	/**
@@ -434,24 +408,27 @@ public class SubstanceImageWatermark implements SubstanceWatermark {
 	 * 
 	 * @return Image watermark opacity.
 	 */
-	public static float getOpacity() {
-		return opacity;
+	@SubstanceApi
+	public float getOpacity() {
+		return this.opacity;
 	}
 
 	/**
 	 * Sets image watermark opacity.
 	 * 
 	 * @param opacity
-	 *            Image watermark opacity.
+	 * 		Image watermark opacity.
 	 * @throws IllegalArgumentException
-	 *             if the argument is not in 0.0-1.0 range.
+	 * 		if the argument is not in 0.0-1.0 range.
 	 */
-	public static void setOpacity(float opacity) {
+	@SubstanceApi
+	public void setOpacity(float opacity) {
 		if ((opacity < 0.0f) || (opacity > 1.0f)) {
 			throw new IllegalArgumentException(
 					"SubstanceImageWatermark.setOpacity() can get value in 0.0-1.0 range, was passed value "
 							+ opacity);
 		}
-		SubstanceImageWatermark.opacity = opacity;
+		this.opacity = opacity;
+		this.updateWatermarkImage(SubstanceLookAndFeel.getCurrentSkin(null));
 	}
 }
\ No newline at end of file
