@@ -2,10 +2,12 @@ package org.jvnet.substance.watermark;
 
 import java.awt.*;
 
-import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.api.SubstanceSkin;
 import org.jvnet.substance.painter.noise.NoiseFactory;
 import org.jvnet.substance.painter.noise.NoiseFilter;
-import org.jvnet.substance.utils.*;
+import org.jvnet.substance.utils.SubstanceCoreUtilities;
+import org.jvnet.substance.utils.SubstanceColorSchemeUtilities;
 
 /**
  * Base class for noise-based watermarks. This class is part of officially
@@ -46,8 +48,8 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 	protected NoiseFilter noiseFilter;
 
 	/**
-	 * Indicates whether the resulting image (after applying the
-	 * {@link #noiseFilter}) should be blurred.
+	 * Indicates whether the resulting image (after applying the {@link
+	 * #noiseFilter}) should be blurred.
 	 */
 	protected boolean toBlur;
 
@@ -55,18 +57,18 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 	 * Creates a new noise-based watermark.
 	 * 
 	 * @param displayName
-	 *            Display name of <code>this</code> watermark.
+	 * 		Display name of <code>this</code> watermark.
 	 * @param xFactor
-	 *            Factor along X axis.
+	 * 		Factor along X axis.
 	 * @param yFactor
-	 *            Factor along Y axis.
+	 * 		Factor along Y axis.
 	 * @param hasConstantZ
-	 *            Indicates whether <code>this</code> watermark is based on
-	 *            constant Z values.
+	 * 		Indicates whether <code>this</code> watermark is based on constant Z
+	 * 		values.
 	 * @param noiseFilter
-	 *            Noise filter of <code>this</code> watermark.
+	 * 		Noise filter of <code>this</code> watermark.
 	 * @param toBlur
-	 *            Indicates whether the resulting image should be blurred.
+	 * 		Indicates whether the resulting image should be blurred.
 	 */
 	public SubstanceNoiseWatermark(String displayName, double xFactor,
 			double yFactor, boolean hasConstantZ, NoiseFilter noiseFilter,
@@ -82,8 +84,9 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#drawWatermarkImage(java.awt.Graphics,
-	 *      java.awt.Component, int, int, int, int)
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#drawWatermarkImage(java
+	 * .awt.Graphics, java.awt.Component, int, int, int, int)
 	 */
 	public void drawWatermarkImage(Graphics graphics, Component c, int x,
 			int y, int width, int height) {
@@ -98,9 +101,11 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage()
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#updateWatermarkImage
+	 * (org.jvnet.substance.skin.SubstanceSkin)
 	 */
-	public boolean updateWatermarkImage() {
+	public boolean updateWatermarkImage(SubstanceSkin skin) {
 		// fix by Chris for bug 67 - support for multiple screens
 		Rectangle virtualBounds = new Rectangle();
 		GraphicsEnvironment ge = GraphicsEnvironment
@@ -119,8 +124,8 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 		Graphics2D graphics = (Graphics2D) this.watermarkImage.getGraphics()
 				.create();
 
-		boolean status = this.drawWatermarkImage(graphics, 0, 0, screenWidth,
-				screenHeight, false);
+		boolean status = this.drawWatermarkImage(skin, graphics, 0, 0,
+				screenWidth, screenHeight, false);
 		graphics.dispose();
 		return status;
 	}
@@ -137,60 +142,48 @@ public class SubstanceNoiseWatermark implements SubstanceWatermark {
 	/*
 	 * (non-Javadoc)
 	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#isDependingOnTheme()
-	 */
-	public boolean isDependingOnTheme() {
-		return true;
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * 
-	 * @see org.jvnet.substance.watermark.SubstanceWatermark#previewWatermark(java.awt.Graphics,
-	 *      int, int, int, int)
+	 * @see
+	 * org.jvnet.substance.watermark.SubstanceWatermark#previewWatermark(java
+	 * .awt.Graphics, int, int, int, int)
 	 */
 	public void previewWatermark(Graphics g, int x, int y, int width, int height) {
-		this.drawWatermarkImage((Graphics2D) g, x, y, width, height, true);
+		this.drawWatermarkImage(SubstanceColorSchemeUtilities.METALLIC_SKIN,
+				(Graphics2D) g, x, y, width, height, true);
 	}
 
 	/**
 	 * Draws the specified portion of the watermark image.
 	 * 
+	 * @param skin
+	 * 		Skin to use for painting the watermark.
 	 * @param graphics
-	 *            Graphic context.
+	 * 		Graphic context.
 	 * @param x
-	 *            the <i>x</i> coordinate of the watermark to be drawn.
+	 * 		the <i>x</i> coordinate of the watermark to be drawn.
 	 * @param y
-	 *            The <i>y</i> coordinate of the watermark to be drawn.
+	 * 		The <i>y</i> coordinate of the watermark to be drawn.
 	 * @param width
-	 *            The width of the watermark to be drawn.
+	 * 		The width of the watermark to be drawn.
 	 * @param height
-	 *            The height of the watermark to be drawn.
+	 * 		The height of the watermark to be drawn.
 	 * @param isPreview
-	 *            Indication whether the result is a preview image.
+	 * 		Indication whether the result is a preview image.
 	 * @return Indication whether the draw succeeded.
 	 */
-	private boolean drawWatermarkImage(Graphics2D graphics, int x, int y,
-			int width, int height, boolean isPreview) {
+	private boolean drawWatermarkImage(SubstanceSkin skin, Graphics2D graphics,
+			int x, int y, int width, int height, boolean isPreview) {
+		SubstanceColorScheme scheme = skin.getWatermarkColorScheme();
 		if (isPreview) {
-			graphics.drawImage(NoiseFactory.getNoiseImage(
-					SubstanceThemeUtilities.getTheme(null,
-							ComponentState.DEFAULT).getFirstTheme(),
-					SubstanceThemeUtilities.getTheme(null,
-							ComponentState.DEFAULT).getSecondTheme(), width,
-					height, this.xFactor, this.yFactor, this.hasConstantZ,
+			graphics.drawImage(NoiseFactory.getNoiseImage(skin, width, height,
+					this.xFactor, this.yFactor, this.hasConstantZ,
 					this.noiseFilter, this.toBlur, true), x, y, null);
 		} else {
-			int alpha = SubstanceCoreUtilities.isThemeDark(SubstanceLookAndFeel
-					.getTheme()) ? 200 : 50;
+			int alpha = scheme.isDark() ? 200 : 140;
 			graphics.setComposite(AlphaComposite.getInstance(
 					AlphaComposite.SRC_OVER, alpha / 255.0f));
-			graphics.drawImage(NoiseFactory.getNoiseImage(SubstanceLookAndFeel
-					.getTheme().getFirstTheme().getWatermarkTheme(),
-					SubstanceLookAndFeel.getTheme().getSecondTheme()
-							.getWatermarkTheme(), width, height, this.xFactor,
-					this.yFactor, this.hasConstantZ, this.noiseFilter,
-					this.toBlur, false), x, y, null);
+			graphics.drawImage(NoiseFactory.getNoiseImage(skin, width, height,
+					this.xFactor, this.yFactor, this.hasConstantZ,
+					this.noiseFilter, this.toBlur, false), x, y, null);
 		}
 		return true;
 	}
