@@ -1,15 +1,13 @@
 package test;
 
 import java.awt.*;
-import java.awt.image.BufferedImage;
 
 import javax.swing.*;
 
-import org.jvnet.substance.SubstanceImageCreator;
-import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.theme.SubstanceAquaTheme;
-import org.jvnet.substance.theme.SubstanceTheme;
-import org.jvnet.substance.utils.ComponentState;
+import org.jvnet.substance.api.SubstanceColorScheme;
+import org.jvnet.substance.colorscheme.AquaColorScheme;
+import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
+import org.jvnet.substance.utils.SubstanceImageCreator;
 
 public class CloseIcon extends JFrame {
 	public CloseIcon() {
@@ -24,7 +22,7 @@ public class CloseIcon extends JFrame {
 		protected void paintComponent(Graphics g) {
 			g.setColor(Color.lightGray.brighter());
 			g.fillRect(0, 0, getWidth(), getHeight());
-			SubstanceTheme st = new SubstanceAquaTheme();
+			SubstanceColorScheme st = new AquaColorScheme();
 			int x = 0;
 			for (int i = 12; i < 36; i++) {
 				Icon icon = SubstanceImageCreator.getCloseIcon(i, st);
@@ -35,14 +33,19 @@ public class CloseIcon extends JFrame {
 				icon.paintIcon(CPanel.this, g, x, 140);
 				icon = SubstanceImageCreator.getMinimizeIcon(i, st);
 				icon.paintIcon(CPanel.this, g, x, 180);
-				x += (i+2);
+				x += (i + 2);
 			}
 		}
 	}
 
 	public static void main(String[] args) throws Exception {
-		UIManager.setLookAndFeel(new SubstanceLookAndFeel());
-		new CloseIcon().setVisible(true);
+		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+		SwingUtilities.invokeLater(new Runnable() {
+			@Override
+			public void run() {
+				new CloseIcon().setVisible(true);
+			}
+		});
 	}
 
 }
