@@ -7,13 +7,12 @@ import javax.swing.*;
 
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
-import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
+import org.jvnet.substance.skin.SubstanceBusinessLookAndFeel;
 
 public class RoTextField extends JFrame {
 	public RoTextField() {
 		super("Some simple text");
 
-
 		this.setLayout(new FlowLayout());
 
 		JSlider result = new JSlider(JSlider.VERTICAL, 0, 100, 50);
@@ -22,9 +21,11 @@ public class RoTextField extends JFrame {
 		result.setMinorTickSpacing(5);
 		result.setPaintTicks(true);
 		result.setPaintLabels(true);
-		
+
 		this.add(result);
-		
+
+		this.add(new JTextField("text", 10));
+
 		this.add(new JSeparator());
 
 		this.setSize(650, 400);
@@ -36,8 +37,14 @@ public class RoTextField extends JFrame {
 		// FadeTracker.DEBUG_MODE = true;
 		JFrame.setDefaultLookAndFeelDecorated(true);
 		UIManager.put(LafWidget.ANIMATION_KIND, AnimationKind.SLOW);
-		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
+		UIManager.setLookAndFeel(new SubstanceBusinessLookAndFeel());
 		// JFrame.setDefaultLookAndFeelDecorated(true);
+		System.out.println("bg: "
+				+ UIManager.getColor("Table.selectionBackground"));
+		System.out.println("bg: "
+				+ UIManager.getColor("Tree.selectionBackground"));
+		System.out.println("fg: "
+				+ UIManager.getColor("Tree.selectionForeground"));
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
 				new RoTextField().setVisible(true);
