@@ -35,21 +35,16 @@ import java.lang.ref.*;
 import java.util.Locale;
 
 import javax.swing.*;
-import javax.swing.event.ChangeEvent;
-import javax.swing.event.ChangeListener;
 
 import org.jvnet.lafwidget.LafWidget;
 import org.jvnet.lafwidget.LafWidgetUtilities2;
-import org.jvnet.lafwidget.animation.FadeConfigurationManager;
-import org.jvnet.lafwidget.animation.FadeKind;
+import org.jvnet.lafwidget.animation.*;
 import org.jvnet.lafwidget.preview.DefaultPreviewPainter;
 import org.jvnet.lafwidget.utils.LafConstants.TabOverviewKind;
-import org.jvnet.substance.SubstanceDefaultComboBoxRenderer;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.painter.AlphaControlBackgroundComposite;
+import org.jvnet.substance.api.SubstanceConstants.*;
+import org.jvnet.substance.skin.NebulaBrickWallSkin;
 import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceConstants.FocusKind;
-import org.jvnet.substance.utils.SubstanceConstants.MenuGutterFillKind;
 
 import test.Check;
 import test.Check.MyMainTabPreviewPainter;
@@ -74,6 +69,8 @@ public class ControlPanelFactory {
 	 */
 	private static JDialog disposableDialog;
 
+	private static GlobalFadeTrackerCallback globalFadeTrackerCallback;
+
 	/**
 	 * Returns the main control panel.
 	 * 
@@ -108,17 +105,12 @@ public class ControlPanelFactory {
 		builder.append("Modified", markAsModified);
 
 		final JCheckBox heapPanel = new JCheckBox("Has heap panel");
-		heapPanel.setSelected(true);
+		heapPanel.setSelected(false);
 		heapPanel.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				if (heapPanel.isSelected())
-					SubstanceLookAndFeel
-							.permanentlyShowHeapStatusPanel(mainFrame
-									.getRootPane());
-				else
-					SubstanceLookAndFeel
-							.permanentlyHideHeapStatusPanel(mainFrame
-									.getRootPane());
+				SubstanceLookAndFeel.setWidgetVisible(mainFrame.getRootPane(),
+						heapPanel.isSelected(),
+						SubstanceWidgetType.TITLE_PANE_HEAP_STATUS);
 			}
 		});
 		builder.append("Heap panel", heapPanel);
@@ -173,13 +165,8 @@ public class ControlPanelFactory {
 						SubstanceLookAndFeel
 								.setToUseConstantThemesOnDialogs(useConstantThemesOnDialogs
 										.isSelected());
-						try {
-							UIManager
-									.setLookAndFeel(new SubstanceLookAndFeel());
-							for (Frame frame : Frame.getFrames())
-								SwingUtilities.updateComponentTreeUI(frame);
-						} catch (Throwable t) {
-						}
+						SubstanceLookAndFeel.setSkin(SubstanceLookAndFeel
+								.getCurrentSkin(mainFrame.getRootPane()));
 					}
 				});
 			}
@@ -204,9 +191,14 @@ public class ControlPanelFactory {
 		builder.append("Placement", placementCombo);
 
 		try {
-			final JComboBox overviewKindCombo = new JComboBox(new Object[] {
+			final JComboBox overviewKindCombo = new FlexiComboBox<TabOverviewKind>(
 					TabOverviewKind.GRID, TabOverviewKind.MENU_CAROUSEL,
-					TabOverviewKind.ROUND_CAROUSEL });
+					TabOverviewKind.ROUND_CAROUSEL) {
+				@Override
+				public String getCaption(TabOverviewKind item) {
+					return item.getName();
+				}
+			};
 			overviewKindCombo.setSelectedItem(LafWidgetUtilities2
 					.getTabPreviewPainter(mainTabbedPane).getOverviewKind(
 							mainTabbedPane));
@@ -217,39 +209,20 @@ public class ControlPanelFactory {
 									.getSelectedItem());
 				}
 			});
-			overviewKindCombo.setRenderer(new SubstanceDefaultComboBoxRenderer(
-					overviewKindCombo) {
-				@Override
-				public Component getListCellRendererComponent(JList list,
-						Object value, int index, boolean isSelected,
-						boolean cellHasFocus) {
-					TabOverviewKind kind = (TabOverviewKind) value;
-					return super.getListCellRendererComponent(list, kind
-							.getName(), index, isSelected, cellHasFocus);
-				}
-			});
+
 			builder.append("Overview kind", overviewKindCombo);
 		} catch (NoClassDefFoundError ncdfe) {
 		}
 
-		builder.append("Composite",
-				new BackgroundCompositeCombo(mainTabbedPane));
-
-		final JComboBox menuGutterFillCombo = new JComboBox(new Object[] {
+		final JComboBox menuGutterFillCombo = new FlexiComboBox<MenuGutterFillKind>(
 				MenuGutterFillKind.NONE, MenuGutterFillKind.SOFT,
 				MenuGutterFillKind.HARD, MenuGutterFillKind.SOFT_FILL,
-				MenuGutterFillKind.HARD_FILL });
-		menuGutterFillCombo.setRenderer(new SubstanceDefaultComboBoxRenderer(
-				menuGutterFillCombo) {
+				MenuGutterFillKind.HARD_FILL) {
 			@Override
-			public Component getListCellRendererComponent(JList list,
-					Object value, int index, boolean isSelected,
-					boolean cellHasFocus) {
-				MenuGutterFillKind mgfk = (MenuGutterFillKind) value;
-				return super.getListCellRendererComponent(list, mgfk.name()
-						.toLowerCase(), index, isSelected, cellHasFocus);
+			public String getCaption(MenuGutterFillKind item) {
+				return item.name();
 			}
-		});
+		};
 		menuGutterFillCombo.setSelectedItem(SubstanceCoreUtilities
 				.getMenuGutterFillKind());
 		menuGutterFillCombo.addActionListener(new ActionListener() {
@@ -260,18 +233,13 @@ public class ControlPanelFactory {
 		});
 		builder.append("Menu fill", menuGutterFillCombo);
 
-		final JComboBox focusKindCombo = new JComboBox(FocusKind.values());
-		focusKindCombo.setRenderer(new SubstanceDefaultComboBoxRenderer(
-				focusKindCombo) {
+		final JComboBox focusKindCombo = new FlexiComboBox<FocusKind>(FocusKind
+				.values()) {
 			@Override
-			public Component getListCellRendererComponent(JList list,
-					Object value, int index, boolean isSelected,
-					boolean cellHasFocus) {
-				FocusKind focusKind = (FocusKind) value;
-				return super.getListCellRendererComponent(list, focusKind
-						.name().toLowerCase(), index, isSelected, cellHasFocus);
+			public String getCaption(FocusKind item) {
+				return item.name();
 			}
-		});
+		};
 		focusKindCombo.setSelectedItem(SubstanceCoreUtilities
 				.getFocusKind(null));
 		focusKindCombo.addActionListener(new ActionListener() {
@@ -282,34 +250,6 @@ public class ControlPanelFactory {
 		});
 		builder.append("Focus kind", focusKindCombo);
 
-		// final JCheckBox fullScreenMode = new JCheckBox("Full screen mode");
-		// fullScreenMode.setSelected(false);
-		// fullScreenMode.addActionListener(new ActionListener() {
-		// public void actionPerformed(ActionEvent e) {
-		// boolean isDisp = mainFrame.isDisplayable();
-		// if (isDisp)
-		// mainFrame.dispose();
-		// GraphicsDevice device = GraphicsEnvironment
-		// .getLocalGraphicsEnvironment().getDefaultScreenDevice();
-		// if (fullScreenMode.isSelected()) {
-		// if (device.isFullScreenSupported()) {
-		// JFrame.setDefaultLookAndFeelDecorated(false);
-		// mainFrame.setUndecorated(true);
-		// mainFrame.setResizable(false);
-		// device.setFullScreenWindow(mainFrame);
-		// }
-		// } else {
-		// JFrame.setDefaultLookAndFeelDecorated(true);
-		// device.setFullScreenWindow(null);
-		// mainFrame.setUndecorated(false);
-		// mainFrame.setResizable(true);
-		// }
-		// if (isDisp)
-		// mainFrame.setVisible(true);
-		// }
-		// });
-		// builder.append("Screen mode", fullScreenMode);
-
 		JButton buttonGlassPane = new JButton("Show");
 		buttonGlassPane.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -420,48 +360,84 @@ public class ControlPanelFactory {
 		});
 		builder.append("Button press", allowGhostPressAnimations);
 
+		globalFadeTrackerCallback = new GlobalFadeTrackerCallback() {
+			@Override
+			public void fadePerformed(Component comp, Comparable subID,
+					FadeKind fadeKind, float fadeCycle10) {
+				System.out.println(fadeKind.toString() + " performed on "
+						+ comp.getName() + "["
+						+ comp.getClass().getSimpleName() + ":@"
+						+ comp.hashCode() + ":" + subID + "] at cycle "
+						+ fadeCycle10);
+			}
+
+			@Override
+			public void fadeStarted(Component comp, Comparable subID,
+					FadeKind fadeKind, float initialFadeCycle10) {
+				System.out.println(fadeKind.toString() + " started on "
+						+ comp.getName() + "["
+						+ comp.getClass().getSimpleName() + ":@"
+						+ comp.hashCode() + ":" + subID + "] at cycle "
+						+ initialFadeCycle10);
+			}
+
+			@Override
+			public void fadeEnded(Component comp, Comparable subID,
+					FadeKind fadeKind) {
+				System.out.println(fadeKind.toString() + " ended on "
+						+ comp.getName() + "["
+						+ comp.getClass().getSimpleName() + ":@"
+						+ comp.hashCode() + ":" + subID + "]");
+			}
+
+			@Override
+			public void fadeReversed(Component comp, Comparable subID,
+					FadeKind fadeKind, boolean isFadingIn, float fadeCycle10) {
+				System.out.println(fadeKind.toString() + " reversed on "
+						+ comp.getName() + "["
+						+ comp.getClass().getSimpleName() + ":@"
+						+ comp.hashCode() + ":" + subID + "] at cycle "
+						+ fadeCycle10 + " to fade "
+						+ (isFadingIn ? "in" : "out"));
+			}
+		};
+		final JCheckBox toTrackAllApplicationFades = new JCheckBox(
+				"track and report");
+		toTrackAllApplicationFades.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				if (toTrackAllApplicationFades.isSelected()) {
+					FadeConfigurationManager
+							.addGlobalFadeTrackerCallback(globalFadeTrackerCallback);
+				} else {
+					FadeConfigurationManager
+							.removeGlobalFadeTrackerCallback(globalFadeTrackerCallback);
+				}
+			}
+		});
+		builder.append("Global fade events", toTrackAllApplicationFades);
+
 		builder.appendSeparator("Toolbar");
 		final JCheckBox isToolbarFlat = new JCheckBox("Is flat");
-		final JSlider translucencySlider = new JSlider(0, 100, 100);
-		translucencySlider.setPreferredSize(new Dimension(50, 24));
 
 		isToolbarFlat.setSelected(true);
-		translucencySlider.setEnabled(false);
 		isToolbarFlat.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
 				toolbar.putClientProperty(SubstanceLookAndFeel.FLAT_PROPERTY,
 						Boolean.valueOf(isToolbarFlat.isSelected()));
-				if (isToolbarFlat.isSelected()) {
-					translucencySlider.setValue(100);
-					translucencySlider.setEnabled(false);
-				} else {
-					translucencySlider.setEnabled(true);
-				}
 				toolbar.repaint();
 			}
 		});
 		builder.append("Flat", isToolbarFlat);
 
-		translucencySlider.addChangeListener(new ChangeListener() {
-			public void stateChanged(ChangeEvent e) {
-				toolbar.putClientProperty(
-						SubstanceLookAndFeel.BACKGROUND_COMPOSITE,
-						new AlphaControlBackgroundComposite(translucencySlider
-								.getValue() / 100.f));
-				toolbar.repaint();
-			}
-		});
-		builder.append("Opacity", translucencySlider);
-
 		builder.appendSeparator("Menu bar");
 		final JCheckBox menuSearch = new JCheckBox("Has menu search");
-		menuSearch.setSelected(true);
+		menuSearch.setSelected(false);
 		menuSearch.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				if (menuSearch.isSelected())
-					SubstanceLookAndFeel.showMenuSearchPanels();
-				else
-					SubstanceLookAndFeel.hideMenuSearchPanels();
+				SubstanceLookAndFeel.setWidgetVisible(mainFrame.getRootPane(),
+						menuSearch.isSelected(),
+						SubstanceWidgetType.MENU_SEARCH);
 			}
 		});
 		builder.append("Menu search", menuSearch);
@@ -655,8 +631,55 @@ public class ControlPanelFactory {
 		});
 		builder.append("Custom", bopc);
 
-		JButton bopii = new JButton("Show");
-		bopii.addActionListener(new ActionListener() {
+		JButton buttonOptionPaneSimpleInput = new JButton("Show");
+		buttonOptionPaneSimpleInput.addActionListener(new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				SwingUtilities.invokeLater(new Runnable() {
+					public void run() {
+						JDialog dialog = new JDialog(mainFrame,
+								"Sample dialog", true);
+						dialog.setSize(400, 300);
+						dialog.setLocationRelativeTo(mainFrame);
+						dialog.setLayout(new BorderLayout());
+						JDesktopPane panel = new JDesktopPane();
+						dialog.add(panel, BorderLayout.CENTER);
+						JOptionPane.showInputDialog(panel,
+								"Sample Question Message?", "Default Answer");
+						dialog.dispose();
+					}
+				});
+			}
+		});
+		builder.append("Simple input", buttonOptionPaneSimpleInput);
+
+		JButton buttonOptionPaneComplexInput = new JButton("Show");
+		buttonOptionPaneComplexInput.addActionListener(new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				SwingUtilities.invokeLater(new Runnable() {
+					public void run() {
+						JDialog dialog = new JDialog(mainFrame,
+								"Sample dialog", true);
+						dialog.setSize(400, 300);
+						dialog.setLocationRelativeTo(mainFrame);
+						dialog.setLayout(new BorderLayout());
+						JDesktopPane panel = new JDesktopPane();
+						dialog.add(panel, BorderLayout.CENTER);
+						// dialog.setVisible(true);
+						String optionChoices[] = new String[] { "entry1",
+								"entry2", "entry3", "entry4" };
+						JOptionPane.showInputDialog(panel,
+								"Sample Question Message?", "Title Goes Here",
+								JOptionPane.QUESTION_MESSAGE, null,
+								optionChoices, "entry1");
+						dialog.dispose();
+					}
+				});
+			}
+		});
+		builder.append("Complex input", buttonOptionPaneComplexInput);
+
+		JButton buttonOptionPaneInternalInput = new JButton("Show");
+		buttonOptionPaneInternalInput.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
 				SwingUtilities.invokeLater(new Runnable() {
 					public void run() {
@@ -676,7 +699,7 @@ public class ControlPanelFactory {
 				});
 			}
 		});
-		builder.append("Internal input", bopii);
+		builder.append("Internal input", buttonOptionPaneInternalInput);
 
 		builder.appendSeparator("Default buttons");
 
@@ -815,7 +838,7 @@ public class ControlPanelFactory {
 		builder.append("Dialog with ESC close", buttonDialogCloseOnEsc);
 
 		JButton buttonDialogUndecorated = new JButton("Show");
-		buttonDialogCloseOnEsc.addActionListener(new ActionListener() {
+		buttonDialogUndecorated.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
 				SwingUtilities.invokeLater(new Runnable() {
 					public void run() {
@@ -855,6 +878,30 @@ public class ControlPanelFactory {
 
 		builder.appendSeparator("Miscellaneous");
 
+		JButton customSkinFrame = new JButton("Show");
+		customSkinFrame.addActionListener(new ActionListener() {
+			@Override
+			public void actionPerformed(ActionEvent e) {
+				SwingUtilities.invokeLater(new Runnable() {
+					@Override
+					public void run() {
+						JFrame testFrame = new SampleFrame(true);
+						testFrame.getRootPane().putClientProperty(
+								SubstanceLookAndFeel.SKIN_PROPERTY,
+								new NebulaBrickWallSkin());
+						SwingUtilities.updateComponentTreeUI(testFrame
+								.getRootPane());
+						testFrame.setSize(315, 245);
+						testFrame.setLocationRelativeTo(mainFrame);
+						testFrame
+								.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
+						testFrame.setVisible(true);
+					}
+				});
+			}
+		});
+		builder.append("Nebula brick wall frame", customSkinFrame);
+
 		JButton btf = new JButton("Show");
 		btf.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -862,7 +909,7 @@ public class ControlPanelFactory {
 					public void run() {
 						JFrame testFrame = new JFrame("test1");
 						testFrame.setSize(262, 100);
-						testFrame.setLocation(400, 400);
+						testFrame.setLocationRelativeTo(mainFrame);
 						testFrame
 								.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
 						testFrame.setVisible(true);
