@@ -34,10 +34,10 @@ import java.text.SimpleDateFormat;
 import java.util.Date;
 
 import javax.swing.JPanel;
+import javax.swing.UIManager;
 
 import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
 
 /**
  * A simple panel that paints the current time on itself.
@@ -60,7 +60,7 @@ public class NumberedPanel extends JPanel {
 		 * Creates a new panel.
 		 * 
 		 * @param number
-		 *            Panel ID number.
+		 * 		Panel ID number.
 		 */
 		public ColoredNumberedPanel(int number) {
 			this.number = number;
@@ -81,8 +81,9 @@ public class NumberedPanel extends JPanel {
 			Graphics2D graphics = (Graphics2D) g.create();
 			graphics.setComposite(TransitionLayout.getAlphaComposite(this));
 
-			if (SubstanceCoreUtilities.isThemeDark(SubstanceLookAndFeel
-					.getTheme()))
+			if ((UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel)
+					&& SubstanceLookAndFeel.getCurrentSkin(this)
+							.getMainActiveColorScheme().isDark())
 				graphics.setColor(Color.black);
 			else
 				graphics.setColor(Color.white);
@@ -92,8 +93,9 @@ public class NumberedPanel extends JPanel {
 			graphics.setColor(this.getBackground());
 			graphics.fillRect(0, 0, w, h);
 			graphics.setComposite(TransitionLayout.getAlphaComposite(this));
-			if (SubstanceCoreUtilities.isThemeDark(SubstanceLookAndFeel
-					.getTheme()))
+			if ((UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel)
+					&& SubstanceLookAndFeel.getCurrentSkin(this)
+							.getMainActiveColorScheme().isDark())
 				graphics.setColor(Color.white);
 			else
 				graphics.setColor(Color.black);
@@ -118,7 +120,7 @@ public class NumberedPanel extends JPanel {
 	 * Creates a new panel.
 	 * 
 	 * @param number
-	 *            Panel ID number.
+	 * 		Panel ID number.
 	 */
 	public NumberedPanel(int number) {
 		this.setLayout(new BorderLayout());
