@@ -44,14 +44,10 @@ import org.jvnet.lafwidget.layout.TransitionLayout;
 import org.jvnet.lafwidget.layout.TransitionLayoutManager;
 import org.jvnet.lafwidget.tabbed.DefaultTabPreviewPainter;
 import org.jvnet.lafwidget.utils.LafConstants.AnimationKind;
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.button.ButtonShaperChangeListener;
-import org.jvnet.substance.painter.GradientPainterChangeListener;
 import org.jvnet.substance.skin.SkinChangeListener;
 import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.watermark.WatermarkChangeListener;
+import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import test.Check;
 
@@ -99,10 +95,7 @@ public class SampleFrame extends JFrame {
 		}
 	}
 
-	protected static class TraitChangeListener implements ThemeChangeListener,
-			WatermarkChangeListener, 
-			GradientPainterChangeListener, ButtonShaperChangeListener,
-			SkinChangeListener {
+	protected static class TraitChangeListener implements SkinChangeListener {
 		protected JTabbedPane jtp;
 
 		protected boolean installTransitionLayout;
@@ -121,29 +114,9 @@ public class SampleFrame extends JFrame {
 			TransitionLayoutManager.getInstance().track(this.jtp, true);
 		}
 
-		public void buttonShaperChanged() {
-			this.update();
-		}
-
-		public void gradientPainterChanged() {
-			this.update();
-		}
-
 		public void skinChanged() {
 			this.update();
 		}
-
-		public void themeChanged() {
-			this.update();
-		}
-
-		public void titlePainterChanged() {
-			this.update();
-		}
-
-		public void watermarkChanged() {
-			this.update();
-		}
 	}
 
 	public SampleFrame(boolean installTransitionLayout) {
@@ -154,11 +127,7 @@ public class SampleFrame extends JFrame {
 			TransitionLayoutManager.getInstance().track(this.tabbed, true);
 		TraitChangeListener tcl = new TraitChangeListener(this.tabbed,
 				installTransitionLayout);
-		SubstanceLookAndFeel.registerThemeChangeListener(tcl);
-		SubstanceLookAndFeel.registerButtonShaperChangeListener(tcl);
-		SubstanceLookAndFeel.registerGradientPainterChangeListener(tcl);
 		SubstanceLookAndFeel.registerSkinChangeListener(tcl);
-		SubstanceLookAndFeel.registerWatermarkChangeListener(tcl);
 
 		this.add(Check.getToolbar("", 16, false), BorderLayout.NORTH);
 		this.add(this.tabbed, BorderLayout.CENTER);
@@ -314,9 +283,6 @@ public class SampleFrame extends JFrame {
 
 		JComboBox combo = new JComboBox(new Object[] { "item1" });
 		combo.setSelectedIndex(0);
-		combo.setEditable(true);
-		combo.putClientProperty(LafWidget.COMBO_BOX_USE_MODEL_ONLY,
-				Boolean.TRUE);
 		JTextField text = new JTextField("Text field");
 		text.setEditable(false);
 		text.putClientProperty(LafWidget.ANIMATION_KIND, AnimationKind.SLOW);
@@ -417,7 +383,7 @@ public class SampleFrame extends JFrame {
 		JMenuBar jmb = new JMenuBar();
 
 		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-			jmb.add(SampleMenuFactory.getThemeMenu());
+			// jmb.add(SampleMenuFactory.getThemeMenu());
 			jmb.add(SampleMenuFactory.getSkinMenu());
 		}
 
@@ -431,14 +397,9 @@ public class SampleFrame extends JFrame {
 
 		this.synchronize();
 		SubstanceLookAndFeel
-				.registerThemeChangeListener(new ThemeChangeListener() {
-					public void themeChanged() {
-						SampleFrame.this.synchronize();
-					}
-				});
-		SubstanceLookAndFeel
-				.registerWatermarkChangeListener(new WatermarkChangeListener() {
-					public void watermarkChanged() {
+				.registerSkinChangeListener(new SkinChangeListener() {
+					@Override
+					public void skinChanged() {
 						SampleFrame.this.synchronize();
 					}
 				});
@@ -448,11 +409,22 @@ public class SampleFrame extends JFrame {
 	protected void synchronize() {
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
-				SampleFrame.this.setIconImage(SubstanceImageCreator
-						.getThemeImage(null, new ImageIcon(Check.class
-								.getClassLoader().getResource(
-										"test/resource/image-x-generic.png")),
-								SubstanceLookAndFeel.getTheme(), false));
+				if (SubstanceLookAndFeel.isCurrentLookAndFeel()) {
+					SampleFrame.this
+							.setIconImage(SubstanceImageCreator
+									.getColorSchemeImage(
+											null,
+											new ImageIcon(
+													Check.class
+															.getClassLoader()
+															.getResource(
+																	"test/resource/image-x-generic.png")),
+											SubstanceLookAndFeel
+													.getCurrentSkin(
+															SampleFrame.this
+																	.getRootPane())
+													.getMainActiveColorScheme()));
+				}
 			}
 		});
 	}
@@ -463,39 +435,21 @@ public class SampleFrame extends JFrame {
 				UIManager
 						.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
 		} catch (AccessControlException ace) {
-			UIManager.setLookAndFeel(new SubstanceLookAndFeel());
+			UIManager
+					.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
 		}
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceMixTheme(
-				new SubstanceAquaTheme(), new SubstanceBottleGreenTheme()));
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceAquaTheme(),
-				new SubstanceLightAquaTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceAquaTheme(),
-				new SubstanceBottleGreenTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBarbyPinkTheme(),
-				new SubstanceRaspberryTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBottleGreenTheme(),
-				new SubstanceLimeGreenTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBrownTheme(),
-				new SubstanceSunGlareTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceSunsetTheme(),
-				new SubstanceOrangeTheme());
 
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBottleGreenTheme(),
-				new SubstanceLimeGreenTheme(), new SubstanceBottleGreenTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceAquaTheme(),
-				new SubstanceLimeGreenTheme(), new SubstanceBottleGreenTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBarbyPinkTheme(),
-				new SubstancePurpleTheme(), new SubstanceRaspberryTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceRaspberryTheme(),
-				new SubstanceSunsetTheme(), new SubstanceOrangeTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBrownTheme(),
-				new SubstanceSunGlareTheme(), new SubstanceOrangeTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceAquaTheme(),
-				new SubstanceLightAquaTheme(), new SubstancePurpleTheme(),
-				new SubstanceBarbyPinkTheme());
-		SubstanceLookAndFeel.addMixedTheme(new SubstanceBrownTheme(),
-				new SubstanceTerracottaTheme(), new SubstanceSunGlareTheme(),
-				new SubstanceOrangeTheme(), new SubstanceSunsetTheme());
+//		UIDefaults uid = UIManager.getLookAndFeelDefaults();
+//		Font segoe = new Font("Segoe UI", Font.PLAIN, 12);
+//		for (Object key : uid.keySet()) {
+//			if (key instanceof String) {
+//				String skey = (String) key;
+//				if (skey.endsWith(".font")) {
+//					System.out.println(skey);
+//					uid.put(skey, segoe);
+//				}
+//			}
+//		}
 
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
