@@ -30,21 +30,15 @@
 package test.check;
 
 import java.awt.*;
-import java.awt.event.ActionEvent;
-import java.awt.event.ActionListener;
 import java.util.LinkedList;
-import java.util.Map;
 
 import javax.swing.*;
 import javax.swing.border.EmptyBorder;
 
-import org.jvnet.lafwidget.LafWidget;
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.watermark.WatermarkChangeListener;
-import org.jvnet.substance.watermark.WatermarkInfo;
+import org.jvnet.substance.api.SubstanceSkin;
+import org.jvnet.substance.skin.SkinChangeListener;
+import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import com.jgoodies.forms.builder.DefaultFormBuilder;
 import com.jgoodies.forms.layout.FormLayout;
@@ -69,7 +63,8 @@ public class SampleInternalFrame extends JInternalFrame {
 		JPanel samplePanel = new JPanel(new BorderLayout());
 		FormLayout lm = new FormLayout("fill:default:grow(1), 4dlu,"
 				+ "fill:default:grow(1)", "");
-		DefaultFormBuilder builder = new DefaultFormBuilder(lm, new ScrollablePanel());
+		DefaultFormBuilder builder = new DefaultFormBuilder(lm,
+				new ScrollablePanel());
 		builder.setLineGapSize(Sizes.pixel(1));
 		builder.setBorder(new EmptyBorder(2, 2, 2, 2));
 		// lm.setColumnGroups(new int[][] { { 3, 5, 7 } });
@@ -99,8 +94,6 @@ public class SampleInternalFrame extends JInternalFrame {
 		JComboBox combo = new JComboBox(new Object[] { "item1" });
 		combo.setSelectedIndex(0);
 		combo.setEditable(true);
-		combo.putClientProperty(LafWidget.COMBO_BOX_USE_MODEL_ONLY,
-				Boolean.TRUE);
 		JTextField text = new JTextField("Text field");
 		text.setEditable(false);
 		builder.append(combo, text);
@@ -124,8 +117,6 @@ public class SampleInternalFrame extends JInternalFrame {
 		JButton cancel = new JButton("cancel");
 		cancel.setEnabled(false);
 		JButton ok = new JButton("OK");
-		ok.putClientProperty(SubstanceLookAndFeel.PAINT_ACTIVE_PROPERTY,
-				Boolean.TRUE);
 		buttons.add(prev);
 		buttons.add(cancel);
 		buttons.add(ok);
@@ -136,101 +127,7 @@ public class SampleInternalFrame extends JInternalFrame {
 		tabbed.setSelectedComponent(samplePanel);
 		tabbed.setOpaque(false);
 		JMenuBar jmb = new JMenuBar();
-
-		if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
-			Map<String, ThemeInfo> allThemes = SubstanceLookAndFeel
-					.getAllThemes();
-
-			JMenu jmTheme = new JMenu("Theme");
-			JMenu jmInvertedTheme = SubstanceLookAndFeel
-					.toEnableInvertedThemes() ? new JMenu("Inverted theme")
-					: null;
-
-			ButtonGroup bgTheme = new ButtonGroup();
-			for (Map.Entry<String, ThemeInfo> themeEntry : allThemes.entrySet()) {
-				String themeName = themeEntry.getKey();
-				final ThemeInfo themeInfo = themeEntry.getValue();
-				final String themeClassName = themeInfo.getClassName();
-
-				JRadioButtonMenuItem jmiTheme = new JRadioButtonMenuItem(
-						themeName);
-				try {
-					Class<?> themeClass = Class.forName(themeClassName);
-					SubstanceTheme theme = (SubstanceTheme) themeClass
-							.newInstance();
-					if (themeInfo.getThemeKind() == ThemeKind.INVERTED)
-						theme = new SubstanceInvertedTheme(theme);
-					jmiTheme.setIcon(SubstanceImageCreator.getThemeIcon(theme));
-				} catch (Exception exc) {
-					continue;
-				}
-
-				jmiTheme.addActionListener(new ActionListener() {
-					public void actionPerformed(ActionEvent e) {
-						try {
-							if ((themeInfo.getThemeKind() == ThemeKind.INVERTED)
-									|| (themeInfo.getThemeKind() == ThemeKind.NEGATED)) {
-								SubstanceLookAndFeel.setCurrentTheme(themeInfo);
-							} else {
-								SubstanceLookAndFeel
-										.setCurrentTheme(themeClassName);
-							}
-							// UIManager
-							// .setLookAndFeel(new SubstanceLookAndFeel());
-						} catch (Exception exc) {
-							exc.printStackTrace();
-						}
-						for (Frame frame : Frame.getFrames())
-							SwingUtilities.updateComponentTreeUI(frame);
-					}
-				});
-				if (themeName
-						.equals(SubstanceLookAndFeel.getCurrentThemeName())) {
-					jmiTheme.setSelected(true);
-				}
-				bgTheme.add(jmiTheme);
-
-				if (themeEntry.getValue().getThemeKind() == ThemeKind.INVERTED)
-					jmInvertedTheme.add(jmiTheme);
-				else
-					jmTheme.add(jmiTheme);
-			}
-
-			jmb.add(jmTheme);
-			if (jmInvertedTheme != null)
-				jmb.add(jmInvertedTheme);
-
-			JMenu jmWatermark = new JMenu("Watermark");
-
-			ButtonGroup bgWatermark = new ButtonGroup();
-			Map<String, WatermarkInfo> allWatermarks = SubstanceLookAndFeel
-					.getAllWatermarks();
-			for (Map.Entry<String, WatermarkInfo> watermarkEntry : allWatermarks
-					.entrySet()) {
-				String watermarkName = watermarkEntry.getKey();
-				final String watermarkClassName = watermarkEntry.getValue()
-						.getClassName();
-
-				JRadioButtonMenuItem jmiWatermark = new JRadioButtonMenuItem(
-						watermarkName);
-				jmiWatermark.addActionListener(new ActionListener() {
-					public void actionPerformed(ActionEvent e) {
-						SubstanceLookAndFeel
-								.setCurrentWatermark(watermarkClassName);
-						for (Frame frame : Frame.getFrames())
-							SwingUtilities.updateComponentTreeUI(frame);
-					}
-				});
-				if (watermarkName.equals(SubstanceLookAndFeel
-						.getCurrentWatermarkName())) {
-					jmiWatermark.setSelected(true);
-				}
-				bgWatermark.add(jmiWatermark);
-				jmWatermark.add(jmiWatermark);
-			}
-
-			jmWatermark.addSeparator();
-		}
+		jmb.add(SampleMenuFactory.getSkinMenu());
 
 		JMenu jm1 = new JMenu("Menu1");
 		jm1.setMnemonic('1');
@@ -258,14 +155,9 @@ public class SampleInternalFrame extends JInternalFrame {
 
 		synchronize();
 		SubstanceLookAndFeel
-				.registerThemeChangeListener(new ThemeChangeListener() {
-					public void themeChanged() {
-						synchronize();
-					}
-				});
-		SubstanceLookAndFeel
-				.registerWatermarkChangeListener(new WatermarkChangeListener() {
-					public void watermarkChanged() {
+				.registerSkinChangeListener(new SkinChangeListener() {
+					@Override
+					public void skinChanged() {
 						synchronize();
 					}
 				});
@@ -278,10 +170,14 @@ public class SampleInternalFrame extends JInternalFrame {
 	protected void synchronize() {
 		SwingUtilities.invokeLater(new Runnable() {
 			public void run() {
-				setFrameIcon(new ImageIcon(SubstanceImageCreator
-						.getBigHexaMarker(6, SubstanceLookAndFeel.getTheme())));
-				setTitle(SubstanceLookAndFeel.getCurrentThemeName() + " / "
-						+ SubstanceLookAndFeel.getCurrentWatermarkName());
+				if (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel) {
+					SubstanceSkin currentSkin = SubstanceLookAndFeel
+							.getCurrentSkin(getRootPane());
+					setFrameIcon(new ImageIcon(SubstanceImageCreator
+							.getBigHexaMarker(6, currentSkin
+									.getMainActiveColorScheme())));
+					setTitle(currentSkin.getDisplayName());
+				}
 			}
 		});
 	}
