@@ -30,20 +30,24 @@
 package test.check;
 
 import java.awt.Event;
-import java.awt.Frame;
 import java.awt.event.*;
 import java.util.LinkedList;
 import java.util.Map;
 
 import javax.swing.*;
 
-import org.jvnet.substance.SubstanceImageCreator;
 import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.*;
+import org.jvnet.substance.colorscheme.*;
+import org.jvnet.substance.painter.border.ClassicBorderPainter;
+import org.jvnet.substance.painter.decoration.ArcDecorationPainter;
+import org.jvnet.substance.painter.decoration.DecorationAreaType;
+import org.jvnet.substance.painter.gradient.GlassGradientPainter;
+import org.jvnet.substance.painter.highlight.GlassHighlightPainter;
+import org.jvnet.substance.shaper.ClassicButtonShaper;
+import org.jvnet.substance.skin.SkinChangeListener;
 import org.jvnet.substance.skin.SkinInfo;
-import org.jvnet.substance.skin.SubstanceSkin;
-import org.jvnet.substance.theme.*;
-import org.jvnet.substance.theme.SubstanceTheme.ThemeKind;
-import org.jvnet.substance.utils.menu.TraitMenuHandler;
+import org.jvnet.substance.utils.SubstanceImageCreator;
 
 import test.Check;
 
@@ -53,509 +57,6 @@ import test.Check;
  * @author Kirill Grouchnikov
  */
 public class SampleMenuFactory {
-	/**
-	 * Returns the menu for changing the themes.
-	 * 
-	 * @return The menu for changing the themes.
-	 */
-	public static JMenu getThemeMenu() {
-		Map<String, ThemeInfo> allThemes = SubstanceLookAndFeel.getAllThemes();
-
-		final TraitMenuHandler themeMenuHandler = new TraitMenuHandler();
-		JMenu themeMenu = new JMenu("Theme");
-		JMenu brightThemes = new JMenu(SubstanceLookAndFeel.getLabelBundle()
-				.getString("SystemMenu.themesBright"));
-		JMenu coldThemes = new JMenu(SubstanceLookAndFeel.getLabelBundle()
-				.getString("SystemMenu.themesCold"));
-		JMenu darkThemes = new JMenu(SubstanceLookAndFeel.getLabelBundle()
-				.getString("SystemMenu.themesDark"));
-		JMenu invertedThemes = SubstanceLookAndFeel.toEnableInvertedThemes() ? new JMenu(
-				SubstanceLookAndFeel.getLabelBundle().getString(
-						"SystemMenu.themesInverted"))
-				: null;
-		JMenu negatedThemes = SubstanceLookAndFeel.toEnableNegatedThemes() ? new JMenu(
-				SubstanceLookAndFeel.getLabelBundle().getString(
-						"SystemMenu.themesNegated"))
-				: null;
-		JMenu mixedThemes = SubstanceLookAndFeel.hasMixedThemes() ? new JMenu(
-				SubstanceLookAndFeel.getLabelBundle().getString(
-						"SystemMenu.themesMixed")) : null;
-		JMenu jmShiftTheme = new JMenu("Shift themes");
-
-		themeMenu.add(brightThemes);
-		themeMenu.add(coldThemes);
-		themeMenu.add(darkThemes);
-		if (invertedThemes != null)
-			themeMenu.add(invertedThemes);
-		if (negatedThemes != null)
-			themeMenu.add(negatedThemes);
-		if (mixedThemes != null)
-			themeMenu.add(mixedThemes);
-
-		for (Map.Entry<String, ThemeInfo> themeEntry : allThemes.entrySet()) {
-			final ThemeInfo themeInfo = themeEntry.getValue();
-			final String themeClassName = themeInfo.getClassName();
-			JRadioButtonMenuItem jmiTheme = new JRadioButtonMenuItem(themeEntry
-					.getKey());
-			themeMenuHandler.addTraitButton(themeInfo.getDisplayName(),
-					jmiTheme);
-			jmiTheme.addActionListener(new ActionListener() {
-				public void actionPerformed(ActionEvent e) {
-					setTheme(themeInfo);
-				}
-			});
-			try {
-				switch (themeInfo.getThemeKind()) {
-				case MIXED:
-					MixedThemeInfo mixedThemeInfo = (MixedThemeInfo) themeInfo;
-					String[] themeClassNames = mixedThemeInfo
-							.getThemeClassNames();
-					SubstanceTheme[] themeInstances = new SubstanceTheme[themeClassNames.length];
-					for (int i = 0; i < themeClassNames.length; i++) {
-						Class<?> themeClass = Class.forName(themeClassNames[i]);
-						themeInstances[i] = (SubstanceTheme) themeClass
-								.newInstance();
-					}
-
-					SubstanceTheme mixTheme = new SubstanceMixTheme(
-							themeInstances);
-					jmiTheme.setIcon(SubstanceImageCreator
-							.getThemeIcon(mixTheme));
-					break;
-				default:
-					Class<?> themeClass = Class.forName(themeClassName);
-					SubstanceTheme theme = (SubstanceTheme) themeClass
-							.newInstance();
-					if (themeInfo.getThemeKind() == ThemeKind.INVERTED)
-						theme = new SubstanceInvertedTheme(theme);
-					if (themeInfo.getThemeKind() == ThemeKind.NEGATED)
-						theme = new SubstanceNegatedTheme(theme);
-					jmiTheme.setIcon(SubstanceImageCreator.getThemeIcon(theme));
-				}
-			} catch (Exception exc) {
-				continue;
-			}
-			if (themeEntry.getKey().equals(
-					SubstanceLookAndFeel.getCurrentThemeName())) {
-				jmiTheme.setSelected(true);
-			}
-			switch (themeEntry.getValue().getThemeKind()) {
-			case BRIGHT:
-				brightThemes.add(jmiTheme);
-				break;
-			case COLD:
-				coldThemes.add(jmiTheme);
-				break;
-			case DARK:
-				darkThemes.add(jmiTheme);
-				break;
-			case INVERTED:
-				invertedThemes.add(jmiTheme);
-				break;
-			case NEGATED:
-				negatedThemes.add(jmiTheme);
-				break;
-			case MIXED:
-				mixedThemes.add(jmiTheme);
-				break;
-			// case DARK_MIXED:
-			// mixedDarkThemes.add(jmiTheme);
-			// break;
-			}
-		}
-
-		ThemeChangeListener themeChangeListener = new ThemeChangeListener() {
-			public void themeChanged() {
-				themeMenuHandler.selectTraitButton(SubstanceLookAndFeel
-						.getTheme());
-			}
-		};
-		SubstanceLookAndFeel.registerThemeChangeListener(themeChangeListener);
-
-		JMenuItem jmiAquaTint10Theme = new JMenuItem("Tint Aqua 10%");
-		jmiAquaTint10Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tint(0.1));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTint10Theme);
-
-		JMenuItem jmiAquaTint25Theme = new JMenuItem("Tint Aqua 25%");
-		jmiAquaTint25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tint(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTint25Theme);
-
-		JMenuItem jmiAquaTint40Theme = new JMenuItem("Tint Aqua 40%");
-		jmiAquaTint40Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tint(0.4));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTint40Theme);
-
-		JMenuItem jmiAquaTone10Theme = new JMenuItem("Tone Aqua 10%");
-		jmiAquaTone10Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tone(0.1));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTone10Theme);
-
-		JMenuItem jmiAquaTone25Theme = new JMenuItem("Tone Aqua 25%");
-		jmiAquaTone25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tone(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTone25Theme);
-
-		JMenuItem jmiAquaTone40Theme = new JMenuItem("Tone Aqua 40%");
-		jmiAquaTone40Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().tone(0.4));
-			}
-		});
-		jmShiftTheme.add(jmiAquaTone40Theme);
-
-		JMenuItem jmiAquaShade10Theme = new JMenuItem("Shade Aqua 10%");
-		jmiAquaShade10Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().shade(0.1));
-			}
-		});
-		jmShiftTheme.add(jmiAquaShade10Theme);
-
-		JMenuItem jmiAquaShade25Theme = new JMenuItem("Shade Aqua 25%");
-		jmiAquaShade25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().shade(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiAquaShade25Theme);
-
-		JMenuItem jmiAquaShade40Theme = new JMenuItem("Shade Aqua 40%");
-		jmiAquaShade40Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().shade(0.4));
-			}
-		});
-		jmShiftTheme.add(jmiAquaShade40Theme);
-
-		JMenuItem jmiSteelBlueTone25Theme = new JMenuItem("Tone Steel Blue 25%");
-		jmiSteelBlueTone25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceSteelBlueTheme().tone(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiSteelBlueTone25Theme);
-
-		JMenuItem jmiLimeGreenShade25Theme = new JMenuItem(
-				"Shade Lime Green 25%");
-		jmiLimeGreenShade25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceLimeGreenTheme().shade(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiLimeGreenShade25Theme);
-
-		JMenuItem jmiBarbyPinkTint25Theme = new JMenuItem("Tint Barby Pink 25%");
-		jmiBarbyPinkTint25Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceBarbyPinkTheme().tint(0.25));
-			}
-		});
-		jmShiftTheme.add(jmiBarbyPinkTint25Theme);
-
-		JMenuItem jmiAquaBottleGreenMixTint25Theme = new JMenuItem(
-				"Tint Aqua Bottle Green Mix 25%");
-		jmiAquaBottleGreenMixTint25Theme
-				.addActionListener(new ActionListener() {
-					public void actionPerformed(ActionEvent e) {
-						setTheme(new SubstanceMixTheme(
-								new SubstanceAquaTheme(),
-								new SubstanceBottleGreenTheme()).tint(0.25));
-					}
-				});
-		jmShiftTheme.add(jmiAquaBottleGreenMixTint25Theme);
-
-		JMenuItem jmiAquaDesaturate50Theme = new JMenuItem(
-				"Aqua Desaturate 50%");
-		jmiAquaDesaturate50Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().saturate(-0.5));
-			}
-		});
-		jmShiftTheme.add(jmiAquaDesaturate50Theme);
-
-		JMenuItem jmiAquaSaturate50Theme = new JMenuItem("Aqua Saturate 50%");
-		jmiAquaSaturate50Theme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceAquaTheme().saturate(0.5));
-			}
-		});
-		jmShiftTheme.add(jmiAquaSaturate50Theme);
-
-		jmShiftTheme.addSeparator();
-
-		JMenuItem jmiGreenBlendTheme = new JMenuItem("Green aqua blend");
-		jmiGreenBlendTheme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceMixTheme(new SubstanceBlendBiTheme(
-						new SubstanceBottleGreenTheme(),
-						new SubstanceLimeGreenTheme(), 0.6),
-						new SubstanceBlendBiTheme(new SubstancePurpleTheme(),
-								new SubstanceAquaTheme(), 0.4)));
-			}
-		});
-		jmShiftTheme.add(jmiGreenBlendTheme);
-
-		themeMenu.add(jmShiftTheme);
-
-		themeMenu.addSeparator();
-
-		JMenu changeTheme = new JMenu("Change current");
-
-		JMenuItem invertCurrent = new JMenuItem("Inverted current");
-		invertCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().invert());
-			}
-		});
-		changeTheme.add(invertCurrent);
-
-		JMenuItem negateCurrent = new JMenuItem("Negated current");
-		negateCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().negate());
-			}
-		});
-		changeTheme.add(negateCurrent);
-
-		changeTheme.addSeparator();
-
-		JMenuItem tintCurrent = new JMenuItem("Tinted current");
-		tintCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().tint(0.3));
-			}
-		});
-		changeTheme.add(tintCurrent);
-
-		JMenuItem toneCurrent = new JMenuItem("Toned current");
-		toneCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().tone(0.3));
-			}
-		});
-		changeTheme.add(toneCurrent);
-
-		JMenuItem shadeCurrent = new JMenuItem("Shaded current");
-		shadeCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().shade(0.3));
-			}
-		});
-		changeTheme.add(shadeCurrent);
-
-		changeTheme.addSeparator();
-
-		JMenuItem saturateCurrent = new JMenuItem("Saturated current");
-		saturateCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().saturate(0.3));
-			}
-		});
-		changeTheme.add(saturateCurrent);
-
-		JMenuItem saturateActiveCurrent = new JMenuItem(
-				"Saturated active current");
-		saturateActiveCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().saturate(0.3, false));
-			}
-		});
-		changeTheme.add(saturateActiveCurrent);
-
-		JMenuItem desaturateCurrent = new JMenuItem("Desaturated current");
-		desaturateCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().saturate(-0.3));
-			}
-		});
-		changeTheme.add(desaturateCurrent);
-
-		JMenuItem desaturateActiveCurrent = new JMenuItem(
-				"Desaturated active current");
-		desaturateActiveCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().saturate(-0.3, false));
-			}
-		});
-		changeTheme.add(desaturateActiveCurrent);
-
-		changeTheme.addSeparator();
-
-		JMenuItem hueShiftCurrent_p002 = new JMenuItem("Hue-shift current 0.02");
-		hueShiftCurrent_p002.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(0.02));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_p002);
-
-		JMenuItem hueShiftCurrent_m002 = new JMenuItem(
-				"Hue-shift current -0.02");
-		hueShiftCurrent_m002.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(-0.02));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_m002);
-
-		JMenuItem hueShiftCurrent_p01 = new JMenuItem("Hue-shift current 0.1");
-		hueShiftCurrent_p01.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(0.1));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_p01);
-
-		JMenuItem hueShiftCurrent_m01 = new JMenuItem("Hue-shift current -0.1");
-		hueShiftCurrent_m01.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(-0.1));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_m01);
-
-		JMenuItem hueShiftCurrent_p05 = new JMenuItem("Hue-shift current 0.5");
-		hueShiftCurrent_p05.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(0.5));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_p05);
-
-		JMenuItem hueShiftCurrent_m05 = new JMenuItem("Hue-shift current -0.5");
-		hueShiftCurrent_m05.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().hueShift(-0.5));
-			}
-		});
-		changeTheme.add(hueShiftCurrent_m05);
-
-		changeTheme.addSeparator();
-
-		final JMenuItem restoreOrig = new JMenuItem("Restore original");
-		restoreOrig
-				.setEnabled(SubstanceLookAndFeel.getTheme() instanceof SubstanceWrapperTheme);
-		restoreOrig.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(((SubstanceWrapperTheme) SubstanceLookAndFeel
-						.getTheme()).getOriginalTheme());
-			}
-		});
-		SubstanceLookAndFeel
-				.registerThemeChangeListener(new ThemeChangeListener() {
-					public void themeChanged() {
-						restoreOrig
-								.setEnabled(SubstanceLookAndFeel.getTheme() instanceof SubstanceWrapperTheme);
-					}
-				});
-		changeTheme.add(restoreOrig);
-
-		themeMenu.add(changeTheme);
-
-		JMenu cbMenu = new JMenu("Color blindness");
-		JMenuItem protanopiaCurrent = new JMenuItem("Protanopia current");
-		protanopiaCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().protanopia());
-			}
-		});
-		cbMenu.add(protanopiaCurrent);
-		JMenuItem deuteranopiaCurrent = new JMenuItem("Deuteranopia current");
-		deuteranopiaCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().deuteranopia());
-			}
-		});
-		cbMenu.add(deuteranopiaCurrent);
-		JMenuItem tritanopiaCurrent = new JMenuItem("Tritanopia current");
-		tritanopiaCurrent.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(SubstanceLookAndFeel.getTheme().tritanopia());
-			}
-		});
-		cbMenu.add(tritanopiaCurrent);
-		themeMenu.add(cbMenu);
-
-		themeMenu.addSeparator();
-
-		JMenuItem jmiCaribbeanBlueTheme = new JMenuItem("User - Caribbean blue");
-		jmiCaribbeanBlueTheme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceTheme(new CaribbeanBlueColorScheme(),
-						"Caribbean blue", SubstanceTheme.ThemeKind.BRIGHT));
-			}
-		});
-		themeMenu.add(jmiCaribbeanBlueTheme);
-
-		JMenuItem jmiCrimsonTheme = new JMenuItem("User - Crimson");
-		jmiCrimsonTheme.addActionListener(new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				setTheme(new SubstanceTheme(new CrimsonColorScheme(),
-						"Crimson", SubstanceTheme.ThemeKind.BRIGHT));
-			}
-		});
-		themeMenu.add(jmiCrimsonTheme);
-
-		return themeMenu;
-	}
-
-	/**
-	 * Sets the specified theme.
-	 * 
-	 * @param theme
-	 *            Theme to set.
-	 */
-	public static void setTheme(final SubstanceTheme theme) {
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				try {
-					SubstanceLookAndFeel.setCurrentTheme(theme);
-				} catch (Exception exc) {
-					exc.printStackTrace();
-				}
-				for (Frame frame : Frame.getFrames())
-					SwingUtilities.updateComponentTreeUI(frame);
-			}
-		});
-	}
-
-	/**
-	 * Sets the specified theme.
-	 * 
-	 * @param themeInfo
-	 *            Theme information object.
-	 */
-	public static void setTheme(final ThemeInfo themeInfo) {
-		SwingUtilities.invokeLater(new Runnable() {
-			public void run() {
-				try {
-					SubstanceLookAndFeel.setCurrentTheme(themeInfo);
-				} catch (Exception exc) {
-					exc.printStackTrace();
-				}
-				for (Frame frame : Frame.getFrames())
-					SwingUtilities.updateComponentTreeUI(frame);
-			}
-		});
-	}
-
 	/**
 	 * Returns a sample test menu.
 	 * 
@@ -603,9 +104,12 @@ public class SampleMenuFactory {
 		result.add(list1);
 
 		LinkedList<JMenuItem> list2 = new LinkedList<JMenuItem>();
+		boolean isSubstance = (UIManager.getLookAndFeel() instanceof SubstanceLookAndFeel);
+		SubstanceSkin currentSkin = SubstanceLookAndFeel.getCurrentSkin(null);
 		final JCheckBoxMenuItem jcbmi1 = new JCheckBoxMenuItem(
-				"Check enabled selected", SubstanceImageCreator.getHexaMarker(
-						2, SubstanceLookAndFeel.getTheme()));
+				"Check enabled selected", isSubstance ? SubstanceImageCreator
+						.getHexaMarker(2, currentSkin
+								.getMainActiveColorScheme()) : null);
 		jcbmi1.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_C,
 				Event.CTRL_MASK));
 		jcbmi1.setSelected(true);
@@ -621,8 +125,9 @@ public class SampleMenuFactory {
 		jcbmi3.setSelected(true);
 		jcbmi3.setEnabled(false);
 		final JCheckBoxMenuItem jcbmi4 = new JCheckBoxMenuItem(
-				"Check disabled unselected", SubstanceImageCreator
-						.getHexaMarker(3, SubstanceLookAndFeel.getTheme()));
+				"Check disabled unselected",
+				isSubstance ? SubstanceImageCreator.getHexaMarker(3,
+						currentSkin.getMainActiveColorScheme()) : null);
 		jcbmi4.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_F,
 				Event.CTRL_MASK));
 		jcbmi4.setSelected(false);
@@ -636,8 +141,9 @@ public class SampleMenuFactory {
 
 		LinkedList<JMenuItem> list3 = new LinkedList<JMenuItem>();
 		final JRadioButtonMenuItem jrbmi1 = new JRadioButtonMenuItem(
-				"Radio enabled selected", SubstanceImageCreator.getHexaMarker(
-						4, SubstanceLookAndFeel.getTheme()));
+				"Radio enabled selected", isSubstance ? SubstanceImageCreator
+						.getHexaMarker(4, currentSkin
+								.getMainActiveColorScheme()) : null);
 		jrbmi1.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_G,
 				Event.CTRL_MASK));
 		jrbmi1.setSelected(true);
@@ -677,24 +183,27 @@ public class SampleMenuFactory {
 		submenu1.add(new JMenuItem("submenu item2"));
 		submenu1.add(new JMenuItem("submenu item3"));
 		final JMenu submenu11 = new JMenu("submenu1-1");
-		submenu11.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu11.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu11.add(new JMenuItem("submenu item111"));
 		submenu11.add(new JMenuItem("submenu item112"));
 		submenu11.add(new JMenuItem("submenu item113"));
 		submenu11.add(new JMenuItem("submenu item114"));
 		submenu1.add(submenu11);
 		final JMenu submenu12 = new JMenu("submenu1-2");
-		submenu12.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu12.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu12.add(new JMenuItem("submenu item121"));
 		submenu12.add(new JMenuItem("submenu item122"));
 		submenu12.add(new JMenuItem("submenu item123"));
 		submenu12.add(new JMenuItem("submenu item124"));
 		submenu1.add(submenu12);
 		final JMenu submenu13 = new JMenu("submenu1-3");
-		submenu13.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu13.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu13.add(new JMenuItem("submenu item131"));
 		submenu13.add(new JMenuItem("submenu item132"));
 		submenu13.add(new JMenuItem("submenu item133"));
@@ -708,24 +217,27 @@ public class SampleMenuFactory {
 		submenu2.add(new JMenuItem("submenu item2"));
 		submenu2.add(new JMenuItem("submenu item3"));
 		final JMenu submenu21 = new JMenu("submenu2-1");
-		submenu21.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu21.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu21.add(new JMenuItem("submenu item211"));
 		submenu21.add(new JMenuItem("submenu item212"));
 		submenu21.add(new JMenuItem("submenu item213"));
 		submenu21.add(new JMenuItem("submenu item214"));
 		submenu2.add(submenu21);
 		final JMenu submenu22 = new JMenu("submenu2-2");
-		submenu22.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu22.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu22.add(new JMenuItem("submenu item221"));
 		submenu22.add(new JMenuItem("submenu item222"));
 		submenu22.add(new JMenuItem("submenu item223"));
 		submenu22.add(new JMenuItem("submenu item224"));
 		submenu2.add(submenu22);
 		final JMenu submenu23 = new JMenu("submenu2-3");
-		submenu23.setIcon(SubstanceImageCreator.getHexaMarker(5,
-				SubstanceLookAndFeel.getTheme()));
+		if (isSubstance)
+			submenu23.setIcon(SubstanceImageCreator.getHexaMarker(5,
+					currentSkin.getMainActiveColorScheme()));
 		submenu23.add(new JMenuItem("submenu item231"));
 		submenu23.add(new JMenuItem("submenu item232"));
 		submenu23.add(new JMenuItem("submenu item233"));
@@ -740,28 +252,28 @@ public class SampleMenuFactory {
 		result.add(list4);
 
 		SubstanceLookAndFeel
-				.registerThemeChangeListener(new ThemeChangeListener() {
-					public void themeChanged() {
-						// jmi1.setIcon(SubstanceImageCreator.getHexaMarker(1,
-						// SubstanceLookAndFeel.getTheme()));
+				.registerSkinChangeListener(new SkinChangeListener() {
+					public void skinChanged() {
+						SubstanceSkin currentSkin = SubstanceLookAndFeel
+								.getCurrentSkin(null);
 						jcbmi1.setIcon(SubstanceImageCreator.getHexaMarker(2,
-								SubstanceLookAndFeel.getTheme()));
+								currentSkin.getMainActiveColorScheme()));
 						jcbmi4.setIcon(SubstanceImageCreator.getHexaMarker(3,
-								SubstanceLookAndFeel.getTheme()));
+								currentSkin.getMainActiveColorScheme()));
 						jrbmi1.setIcon(SubstanceImageCreator.getHexaMarker(4,
-								SubstanceLookAndFeel.getTheme()));
+								currentSkin.getMainActiveColorScheme()));
 						submenu11.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 						submenu12.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 						submenu13.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 						submenu21.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 						submenu22.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 						submenu23.setIcon(SubstanceImageCreator.getHexaMarker(
-								5, SubstanceLookAndFeel.getTheme()));
+								5, currentSkin.getMainActiveColorScheme()));
 					}
 				});
 
@@ -785,36 +297,166 @@ public class SampleMenuFactory {
 				}
 			});
 
-			try {
-				SubstanceSkin skin = ((SubstanceSkin) Class.forName(
-						entry.getValue().getClassName()).newInstance());
-				jmiSkin
-						.setIcon(new ImageIcon(
-								SubstanceImageCreator
-										.getThemeImage(
-												jmiSkin,
-												new ImageIcon(
-														SampleMenuFactory.class
-																.getClassLoader()
-																.getResource(
-																		"test/resource/image-x-generic.png")),
-												skin.getTheme(), false)));
-			} catch (Exception exc) {
-			}
-
 			jmSkin.add(jmiSkin);
 		}
+
+		jmSkin.addSeparator();
+		final CustomSkin customSkin = new CustomSkin();
+		JMenuItem jmiSkin = new JMenuItem(customSkin.getDisplayName());
+		jmiSkin.addActionListener(new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				SubstanceLookAndFeel.setSkin(customSkin);
+			}
+		});
+
+		jmSkin.add(jmiSkin);
+
 		return jmSkin;
 	}
 
+	protected static class CustomSkin extends SubstanceSkin {
+		@Override
+		public String getDisplayName() {
+			return "Custom";
+		}
+
+		public CustomSkin() {
+			SubstanceColorScheme activeScheme = new OrangeColorScheme().shade(
+					0.2).invert();
+			SubstanceColorScheme defaultScheme = new MetallicColorScheme();
+			SubstanceColorScheme disabledScheme = new LightGrayColorScheme();
+
+			SubstanceColorSchemeBundle defaultSchemeBundle = new SubstanceColorSchemeBundle(
+					activeScheme, defaultScheme, disabledScheme);
+			defaultSchemeBundle.registerHighlightColorScheme(activeScheme,
+					0.6f, ComponentState.ROLLOVER_UNSELECTED);
+			defaultSchemeBundle.registerHighlightColorScheme(activeScheme,
+					0.8f, ComponentState.SELECTED);
+			defaultSchemeBundle.registerHighlightColorScheme(activeScheme,
+					0.95f, ComponentState.ROLLOVER_SELECTED);
+			defaultSchemeBundle.registerHighlightColorScheme(activeScheme,
+					0.8f, ComponentState.ARMED, ComponentState.ROLLOVER_ARMED);
+			this.registerDecorationAreaSchemeBundle(defaultSchemeBundle,
+					DecorationAreaType.NONE);
+
+			SubstanceColorSchemeBundle headerSchemeBundle = new SubstanceColorSchemeBundle(
+					activeScheme.saturate(0.3), activeScheme, disabledScheme);
+			this.registerDecorationAreaSchemeBundle(headerSchemeBundle,
+					headerSchemeBundle.getActiveColorScheme(),
+					DecorationAreaType.PRIMARY_TITLE_PANE,
+					DecorationAreaType.SECONDARY_TITLE_PANE,
+					DecorationAreaType.HEADER);
+
+			this.borderPainter = new ClassicBorderPainter();
+			this.gradientPainter = new GlassGradientPainter();
+			this.buttonShaper = new ClassicButtonShaper();
+			this.decorationPainter = new ArcDecorationPainter();
+			this.highlightPainter = new GlassHighlightPainter();
+
+			this.selectedTabFadeStart = 1.0f;
+			this.selectedTabFadeEnd = 1.0f;
+		}
+	}
+
+	public static JMenu getTransformMenu() {
+		JMenu jmTransform = new JMenu("Transforms");
+
+		JMenuItem itemShade = new JMenuItem("Shade 10%");
+		itemShade.addActionListener(new SkinChanger(new ColorSchemeTransform() {
+			@Override
+			public SubstanceColorScheme transform(SubstanceColorScheme scheme) {
+				return scheme.shade(0.1);
+			};
+		}, "Shaded current"));
+		jmTransform.add(itemShade);
+
+		JMenuItem itemTone = new JMenuItem("Tone 10%");
+		itemTone.addActionListener(new SkinChanger(new ColorSchemeTransform() {
+			@Override
+			public SubstanceColorScheme transform(SubstanceColorScheme scheme) {
+				return scheme.tone(0.1);
+			};
+		}, "Toned current"));
+		jmTransform.add(itemTone);
+
+		JMenuItem itemTint = new JMenuItem("Tint 10%");
+		itemTint.addActionListener(new SkinChanger(new ColorSchemeTransform() {
+			@Override
+			public SubstanceColorScheme transform(SubstanceColorScheme scheme) {
+				return scheme.tint(0.1);
+			};
+		}, "Tinted current"));
+		jmTransform.add(itemTint);
+
+		JMenuItem itemHueShift = new JMenuItem("Hue shift 10%");
+		itemHueShift.addActionListener(new SkinChanger(
+				new ColorSchemeTransform() {
+					@Override
+					public SubstanceColorScheme transform(
+							SubstanceColorScheme scheme) {
+						return scheme.hueShift(0.1);
+					};
+				}, "Hue shifted current"));
+		jmTransform.add(itemHueShift);
+
+		JMenuItem itemSaturate = new JMenuItem("Saturate 10%");
+		itemSaturate.addActionListener(new SkinChanger(
+				new ColorSchemeTransform() {
+					@Override
+					public SubstanceColorScheme transform(
+							SubstanceColorScheme scheme) {
+						return scheme.saturate(0.1);
+					};
+				}, "Saturated current"));
+		jmTransform.add(itemSaturate);
+
+		JMenuItem itemDesaturate = new JMenuItem("Desaturate 10%");
+		itemDesaturate.addActionListener(new SkinChanger(
+				new ColorSchemeTransform() {
+					@Override
+					public SubstanceColorScheme transform(
+							SubstanceColorScheme scheme) {
+						return scheme.saturate(-0.1);
+					};
+				}, "Desaturated current"));
+		jmTransform.add(itemDesaturate);
+
+		JMenuItem itemNegate = new JMenuItem("Negate");
+		itemNegate.addActionListener(new SkinChanger(
+				new ColorSchemeTransform() {
+					@Override
+					public SubstanceColorScheme transform(
+							SubstanceColorScheme scheme) {
+						return scheme.negate();
+					};
+				}, "Negated current"));
+		jmTransform.add(itemNegate);
+
+		JMenuItem itemInvert = new JMenuItem("Invert");
+		itemInvert.addActionListener(new SkinChanger(
+				new ColorSchemeTransform() {
+					@Override
+					public SubstanceColorScheme transform(
+							SubstanceColorScheme scheme) {
+						return scheme.invert();
+					};
+				}, "Inverted current"));
+		jmTransform.add(itemInvert);
+
+		return jmTransform;
+	}
+
 	public static JMenu getLookAndFeelMenu(JFrame frame) {
 		JMenu lafMenu = new JMenu("Look & feel");
 		JMenu substanceMenus = new JMenu("Substance family");
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Substance",
-				"org.jvnet.substance.SubstanceLookAndFeel"));
-		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Default",
-				"org.jvnet.substance.SubstanceDefaultLookAndFeel"));
-		substanceMenus.addSeparator();
+		// for (Map.Entry<String, SkinInfo> substanceSkinInfo :
+		// SubstanceLookAndFeel
+		// .getAllSkins().entrySet()) {
+		// substanceMenus.add(SubstanceLafChanger.getMenuItem(frame,
+		// substanceSkinInfo.getValue().getDisplayName(),
+		// substanceSkinInfo.getValue().getClassName()));
+		// }
+
 		substanceMenus.add(SubstanceLafChanger.getMenuItem(frame, "Business",
 				"org.jvnet.substance.skin.SubstanceBusinessLookAndFeel"));
 		substanceMenus
@@ -1020,6 +662,8 @@ public class SampleMenuFactory {
 				"com.oyoaha.swing.plaf.oyoaha.OyoahaLookAndFeel"));
 		customLafMenus.add(SubstanceLafChanger.getMenuItem(frame, "Pagosoft",
 				"com.pagosoft.plaf.PgsLookAndFeel"));
+		customLafMenus.add(SubstanceLafChanger.getMenuItem(frame, "Quaqua",
+				"ch.randelshofer.quaqua.QuaquaLookAndFeel"));
 		customLafMenus.add(SubstanceLafChanger.getMenuItem(frame, "Simple",
 				"com.memoire.slaf.SlafLookAndFeel"));
 		customLafMenus.add(SubstanceLafChanger.getMenuItem(frame, "Skin",
@@ -1216,4 +860,26 @@ public class SampleMenuFactory {
 
 		return lafMenu;
 	}
+
+	protected static class SkinChanger implements ActionListener {
+		protected ColorSchemeTransform transform;
+
+		protected String name;
+
+		public SkinChanger(ColorSchemeTransform transform, String name) {
+			super();
+			this.transform = transform;
+			this.name = name;
+		}
+
+		public void actionPerformed(ActionEvent e) {
+			SwingUtilities.invokeLater(new Runnable() {
+				public void run() {
+					SubstanceSkin newSkin = SubstanceLookAndFeel
+							.getCurrentSkin(null).transform(transform, name);
+					SubstanceLookAndFeel.setSkin(newSkin);
+				}
+			});
+		}
+	}
 }
