@@ -61,7 +61,8 @@ public class TextFieldsPanel extends JPanel {
 						+ "fill:default:grow(1), 4dlu, fill:default:grow(1)",
 				"");
 		// lm.setColumnGroups(new int[][] { { 3, 5, 7 } });
-		DefaultFormBuilder builder = new DefaultFormBuilder(lm, new ScrollablePanel());
+		DefaultFormBuilder builder = new DefaultFormBuilder(lm,
+				new ScrollablePanel());
 		builder.setDefaultDialogBorder();
 
 		JLabel textLabel = new JLabel("Text fields");
@@ -140,17 +141,17 @@ public class TextFieldsPanel extends JPanel {
 
 		JTextField jtfWatermarkBleed = new JTextField("sample text");
 		jtfWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		builder.append("Watermark bleed", jtfWatermarkBleed);
 
 		JFormattedTextField jftfWatermarkBleed = new JFormattedTextField(
 				new DecimalFormat("#,##0.0000"));
 		jftfWatermarkBleed.setText("2,430.0000");
 		jftfWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		JPasswordField jpfWatermarkBleed = new JPasswordField("password", 10);
 		jpfWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		builder.append(jftfWatermarkBleed, jpfWatermarkBleed);
 
 		JTextField jtf4 = new JTextField("sample text");
@@ -337,18 +338,18 @@ public class TextFieldsPanel extends JPanel {
 		JEditorPane jepWatermarkBleed = new JEditorPane("text/html;",
 				"Sample <b>content</b><br> <u>text</u>");
 		jepWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		builder.append("Watermark bleed", jepWatermarkBleed);
 
 		JTextArea jtaWatermarkBleed = new JTextArea("Sample content text", 3,
 				20);
 		jtaWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		JTextPane jtpWatermarkBleed = new JTextPane();
 		jtpWatermarkBleed.replaceSelection("Sample content text");
 		jtpWatermarkBleed.setPreferredSize(new Dimension(100, 40));
 		jtpWatermarkBleed.putClientProperty(
-				SubstanceLookAndFeel.WATERMARK_TO_BLEED, Boolean.TRUE);
+				SubstanceLookAndFeel.WATERMARK_VISIBLE, Boolean.TRUE);
 		builder.append(jtaWatermarkBleed, jtpWatermarkBleed);
 
 		JEditorPane jep4 = new JEditorPane("text/html;",
