@@ -35,11 +35,10 @@ import java.awt.event.ActionListener;
 
 import javax.swing.*;
 
-import org.jvnet.substance.SubstanceDefaultComboBoxRenderer;
 import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.SubstanceConstants.FocusKind;
+import org.jvnet.substance.api.renderers.SubstanceDefaultComboBoxRenderer;
 import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-import org.jvnet.substance.utils.SubstanceCoreUtilities;
-import org.jvnet.substance.utils.SubstanceConstants.FocusKind;
 
 /**
  * Test application that shows the use of the
@@ -81,8 +80,7 @@ public class FocusKindProperty extends JFrame {
 								cellHasFocus);
 					}
 				});
-		focusKindCombo.setSelectedItem(SubstanceCoreUtilities
-				.getFocusKind(button1));
+		focusKindCombo.setSelectedItem(FocusKind.ALL_INNER);
 		focusKindCombo.addActionListener(new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
 				// based on the selected value, set focus kind on the
