@@ -37,14 +37,12 @@ import java.awt.event.ActionListener;
 import javax.swing.*;
 
 import org.jvnet.substance.SubstanceLookAndFeel;
+import org.jvnet.substance.api.SubstanceConstants.TabContentPaneBorderKind;
 import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;
-import org.jvnet.substance.utils.SubstanceConstants.TabContentPaneBorderKind;
-
-import test.Check;
 
 /**
- * Test application that shows the use of the
- * {@link SubstanceLookAndFeel#TABBED_PANE_CONTENT_BORDER_KIND} client property.
+ * Test application that shows the use of the {@link
+ * SubstanceLookAndFeel#TABBED_PANE_CONTENT_BORDER_KIND} client property.
  * 
  * @author Kirill Grouchnikov
  * @see SubstanceLookAndFeel#TABBED_PANE_CONTENT_BORDER_KIND
@@ -60,9 +58,20 @@ public class TabbedPaneContentBorderKind extends JFrame {
 
 		// create tabbed pane with a few tabs
 		final JTabbedPane jtp = new JTabbedPane();
-		jtp.addTab("First", Check.getIcon("flag_mexico"), new JPanel());
-		jtp.addTab("Second", Check.getIcon("flag_sweden"), new JPanel());
-		jtp.addTab("Third", Check.getIcon("flag_hong_kong"), new JPanel());
+		String packageName = MenuGutterFillKindProperty.class.getPackage()
+				.getName();
+		jtp.addTab("First", new ImageIcon(MenuGutterFillKindProperty.class
+				.getClassLoader().getResource(
+						packageName.replace('.', '/') + "/flag_mexico.png")),
+				new JPanel());
+		jtp.addTab("Second", new ImageIcon(MenuGutterFillKindProperty.class
+				.getClassLoader().getResource(
+						packageName.replace('.', '/') + "/flag_sweden.png")),
+				new JPanel());
+		jtp.addTab("Third", new ImageIcon(MenuGutterFillKindProperty.class
+				.getClassLoader().getResource(
+						packageName.replace('.', '/') + "/flag_hong_kong.png")),
+				new JPanel());
 
 		this.add(jtp, BorderLayout.CENTER);
 
@@ -97,15 +106,13 @@ public class TabbedPaneContentBorderKind extends JFrame {
 	}
 
 	/**
-	 * The main method for <code>this</code> sample. The arguments are
-	 * ignored.
+	 * The main method for <code>this</code> sample. The arguments are ignored.
 	 * 
 	 * @param args
-	 *            Ignored.
+	 * 		Ignored.
 	 * @throws Exception
-	 *             If some exception occured. Note that there is no special
-	 *             treatment of exception conditions in <code>this</code>
-	 *             sample code.
+	 * 		If some exception occured. Note that there is no special treatment
+	 * 		of exception conditions in <code>this</code> sample code.
 	 */
 	public static void main(String[] args) throws Exception {
 		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
